(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    389923,      12218]
NotebookOptionsPosition[    387723,      12146]
NotebookOutlinePosition[    388170,      12164]
CellTagsIndexPosition[    388127,      12161]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Dynamics of the Bush-Mosteller learning algorithm in 2x2 games - Figure 13 \
(50000)\
\>", "Title",
 CellChangeTimes->{3.393473166953125*^9}],

Cell["Luis R. Izquierdo and Segismundo S. Izquierdo", "Subtitle"],

Cell["\<\
This program was used to generate figure 2 in the chapter of the \
reinforcement learning book: Izquierdo,L.R. & Izquierdo,S.S.(2007). Dynamics \
of the Bush-Mosteller 
learning algorithm in 2x2 games.\
\>", "Subsubtitle",
 CellChangeTimes->{{3.393473180296875*^9, 3.39347318196875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Licence", "Section"]], "Section"],

Cell["\<\
Copyright (C) 2007 Luis R. Izquierdo & Segismundo S. Izquierdo

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, \
USA.\
\>", "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting the Environment", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`MultipleListPlot`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "Payoffs", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Aspiration", " ", "Threshold"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Learning", " ", "rate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Noise", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"noiseList", "=", 
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.001", ",", "0.0001", ",", "0"}], "}"}]}], ";"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Simulation", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SeedRandom", "[", "0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfRuns", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfIterations", "=", "50000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb1", "=", "0.9"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb2", "=", "0.9"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Directory", " ", "where", " ", "the", " ", "figure", " ", "will", " ", 
     "be", " ", "saved"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", "\"\<C:\\\\temp\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"File", " ", "extensions", " ", "required"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"extensions", "=", 
     RowBox[{"{", "\"\<.gif\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"figureResolution", " ", "=", " ", "600"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfPoints", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"250", ",", "nOfIterations"}], "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of functions and labels", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Labels", ".", " ", "This"}], " ", "is", " ", "done", " ", "for", 
    " ", "efficiency", " ", "and", " ", "code", " ", "readability"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Cooperate", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Defect", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CC", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CD", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC", "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DD", "=", "3"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Calculation", " ", "of", " ", "possible", " ", 
     RowBox[{"stimuli", ".", " ", "These"}], " ", "operations", " ", "are", 
     " ", "performed", " ", "only", " ", "once", " ", "for", " ", 
     "efficiency"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"divisor", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"T", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"R", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"P", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"S", "-", "A"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"R", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"S", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"T", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"P", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Stimulus", " ", "after", " ", "a", " ", "certain", " ", 
     RowBox[{"outcome", ".", " ", "This"}], " ", "function", " ", "returns", 
     " ", "the", " ", "stimulus", " ", "after", " ", "a", " ", "given", " ", 
     "outcome", " ", 
     RowBox[{"(", 
      RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the", 
     " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ", 
     "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
     "letter", " ", "of", " ", "the", " ", "outcome", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"stimulusAfter", "[", "x_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "x", ",", "\[IndentingNewLine]", "CC", ",", "stimulusAfterCC", ",", 
       "\[IndentingNewLine]", "CD", ",", "stimulusAfterCD", ",", 
       "\[IndentingNewLine]", "DC", ",", "stimulusAfterDC", ",", 
       "\[IndentingNewLine]", "DD", ",", "stimulusAfterDD"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Changes", " ", "in", " ", "the", " ", "probability", " ", "of", " ", 
      "cooperating", " ", "after", " ", "given", " ", 
      RowBox[{"outcomes", ".", " ", "The"}], " ", "first", " ", "argument", 
      " ", "is", " ", "the", " ", "outcome"}], ",", " ", 
     RowBox[{
     "and", " ", "the", " ", "second", " ", "argument", " ", "is", " ", "the",
       " ", "probability", " ", "to", " ", "be", " ", 
      RowBox[{"updated", ".", " ", "This"}], " ", "function", " ", "returns", 
      " ", "the", " ", "change", " ", "on", " ", "the", " ", "probability", 
      " ", "indicated", " ", "by", " ", "the", " ", "second", " ", "argument",
       " ", "after", " ", "the", " ", "outcome", " ", "indicated", " ", "in", 
      " ", "the", " ", "first", " ", "argument", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the",
       " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ",
       "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
      "letter", " ", "of", " ", "the", " ", "outcome", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"changeAfterOn", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CC"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CD"}], ")"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "cooperated"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}], ",", 
         RowBox[{"y", "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "defected"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"y", "*", "l", "*", 
            RowBox[{"stimulusAfter", "[", "x", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y"}], ")"}]}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulations - Initialisation", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Vector", " ", "with", " ", "the", " ", "decisions", " ", "made", " ", 
    "by", " ", "each", " ", "of", " ", "the", " ", "agents"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"decisions", "=", 
     RowBox[{"{", ",", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Output", " ", "variables"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfAverages", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfStdErrors", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reportingFreq", "=", 
     RowBox[{"Floor", "[", 
      RowBox[{"nOfIterations", "/", "nOfPoints"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Auxiliary", " ", "arrays", " ", "to", " ", "calculate", " ", "the", " ", 
     "standard", " ", "error", " ", "dynamically"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mbefore", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nOfIterations", "+", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mnow", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nOfIterations", "+", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Snow", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nOfIterations", "+", "1"}]}], "}"}]}], "]"}]}], 
    ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulations - Execution", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"k", "=", "1"}], ",", 
    RowBox[{"k", "\[LessEqual]", 
     RowBox[{"Length", "[", "noiseList", "]"}]}], ",", 
    RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"noise", "=", 
      RowBox[{"noiseList", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Time", " ", "series", " ", "for", " ", "player", " ", "1"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"averages", "=", 
      RowBox[{"Table", " ", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}], "*", "reportingFreq", "*", 
         RowBox[{"(", 
          RowBox[{"2", "-", "j"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"nOfPoints", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"averages", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}], "=", "initialProb1"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"stdErrors", "=", 
      RowBox[{"Table", " ", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"2", "-", "j"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"nOfIterations", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "\[LessEqual]", "nOfRuns"}], ",", 
       RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Starting run \>\"", ",", " ", "j"}], "]"}], ";"}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"prob1", "=", "initialProb1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"prob2", "=", "initialProb2"}], ";", "\[IndentingNewLine]", 
        RowBox[{"reportedPoints", "=", "1"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "\[LessEqual]", "nOfIterations"}], ",", 
          RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<Starting iteration \>\"", ",", " ", "i"}], "]"}], 
            ";"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob1"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
               
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "Cooperate"}], 
                 ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}], ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}]}], 
                "]"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob2"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
               
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "Cooperate"}], 
                 ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}], ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}]}], 
                "]"}]}], "]"}]}], "]"}], ";", " ", "\[IndentingNewLine]", 
           "\t", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{"For", " ", "the", " ", "first", " ", "player"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"outcome", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{"decisions", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",",
               "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "CD", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "DC", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"prob1", "=", 
            RowBox[{"prob1", "+", 
             RowBox[{"changeAfterOn", "[", 
              RowBox[{"outcome", ",", "prob1"}], "]"}]}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{"For", " ", "the", " ", "second", " ", "player"}], "*)"}],
            "\[IndentingNewLine]", 
           RowBox[{"outcome", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{"decisions", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",",
               "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "DC", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "CD", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"prob2", "=", 
            RowBox[{"prob2", "+", 
             RowBox[{"changeAfterOn", "[", 
              RowBox[{"outcome", ",", "prob2"}], "]"}]}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{"Report", " ", "if", " ", "you", " ", "have", " ", "to"}],
             "*)"}], "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Mod", "[", 
               RowBox[{"i", ",", " ", "reportingFreq"}], "]"}], "\[Equal]", 
              "0"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"averages", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"reportedPoints", "+", "1"}], ",", "2"}], "]"}], 
                "]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"j", "-", "1"}], ")"}], "*", 
                   RowBox[{"averages", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"reportedPoints", "+", "1"}], ",", "2"}], "]"}], 
                    "]"}]}], "+", "prob1"}], ")"}], "/", "j"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"reportedPoints", "++"}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
            "Calculate", " ", "the", " ", "standard", " ", "error", " ", "of",
              " ", "the", " ", "average", " ", "dynamically"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Mnow", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "=", 
            RowBox[{
             RowBox[{"Mbefore", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"prob1", "-", 
                RowBox[{"Mbefore", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}], "/", 
              "j"}]}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Snow", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"Snow", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"prob1", "-", 
                RowBox[{"Mbefore", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"prob1", "-", 
                RowBox[{"Mnow", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}]}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Mbefore", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], "=", 
            RowBox[{"Mnow", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ";"}]}], 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<End of iteration \>\"", ",", "i"}], "]"}], ";"}], 
          "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
        ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{"j", ",", "100"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<End of run \>\"", ",", " ", "j"}], "]"}], ";", 
           RowBox[{"Print", "[", 
            RowBox[{"Date", "[", "]"}], "]"}], ";"}]}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"nOfRuns", ">", "1"}], ",", 
       RowBox[{
        RowBox[{"stdErrors", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"Snow", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"nOfRuns", "-", "1"}], ")"}], "*", "nOfRuns"}], ")"}]}], 
         "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     
     RowBox[{"oneSeriesFigure", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"averages", ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "nOfIterations"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1.01"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Iteration\>\"", ",", "\"\<Prop C, Player 1\>\""}], 
          "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig13-50000-n\>\"", ",", 
         RowBox[{"ToString", "[", "noise", "]"}], ",", "\"\<.gif\>\""}], 
        "]"}], ",", "oneSeriesFigure", ",", 
       RowBox[{"ImageResolution", "\[Rule]", " ", "figureResolution"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
      "\"\<The maximum standard error of this series is: \>\"", ",", " ", 
       RowBox[{"Max", "[", 
        RowBox[{"stdErrors", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"listOfAverages", ",", "averages"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"listOfStdErrors", ",", "stdErrors"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Finished noise = \>\"", ",", " ", 
       RowBox[{"noiseList", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.08744e-017 2e-005 -1.49349e-017 0.611915 [
[.2 -0.0125 -15 -9 ]
[.2 -0.0125 15 0 ]
[.4 -0.0125 -15 -9 ]
[.4 -0.0125 15 0 ]
[.6 -0.0125 -15 -9 ]
[.6 -0.0125 15 0 ]
[.8 -0.0125 -15 -9 ]
[.8 -0.0125 15 0 ]
[1 -0.0125 -15 -9 ]
[1 -0.0125 15 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(10000)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(20000)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(30000)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(40000)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(50000)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .02702 Mdot
.008 .00263 Mdot
.012 .00056 Mdot
.016 .00062 Mdot
.02 .00066 Mdot
.024 .00053 Mdot
.028 .00045 Mdot
.032 .00053 Mdot
.036 .00056 Mdot
.04 .00054 Mdot
.044 .00053 Mdot
.048 .0005 Mdot
.052 .00035 Mdot
.056 .00024 Mdot
.06 .00047 Mdot
.064 .00054 Mdot
.068 .00066 Mdot
.072 .00047 Mdot
.076 .00045 Mdot
.08 .00033 Mdot
.084 .00028 Mdot
.088 .00039 Mdot
.092 .00021 Mdot
.096 .00025 Mdot
.1 .00059 Mdot
.104 .00041 Mdot
.108 .00022 Mdot
.112 .00046 Mdot
.116 .00072 Mdot
.12 .00056 Mdot
.124 .00044 Mdot
.128 .00061 Mdot
.132 .00052 Mdot
.136 .00042 Mdot
.14 .00018 Mdot
.144 .00025 Mdot
.148 .00068 Mdot
.152 .00064 Mdot
.156 .00047 Mdot
.16 .00069 Mdot
.164 .0006 Mdot
.168 .00038 Mdot
.172 .00046 Mdot
.176 .0007 Mdot
.18 .00046 Mdot
.184 .0005 Mdot
.188 .00051 Mdot
.192 .00035 Mdot
.196 .00062 Mdot
.2 .00044 Mdot
.204 .00066 Mdot
.208 .00053 Mdot
.212 .00049 Mdot
.216 .00041 Mdot
.22 .00056 Mdot
.224 .00039 Mdot
.228 .00037 Mdot
.232 .00047 Mdot
.236 .00025 Mdot
.24 .00037 Mdot
.244 .00045 Mdot
.248 .00058 Mdot
.252 .00032 Mdot
.256 .00065 Mdot
.26 .00053 Mdot
.264 .00045 Mdot
.268 .00036 Mdot
.272 .00053 Mdot
.276 .00041 Mdot
.28 .00036 Mdot
.284 .00048 Mdot
.288 .0005 Mdot
.292 .00053 Mdot
.296 .00072 Mdot
.3 .0007 Mdot
.304 .00047 Mdot
.308 .00048 Mdot
.312 .00053 Mdot
.316 .00048 Mdot
.32 .00051 Mdot
.324 .00026 Mdot
.328 .00047 Mdot
.332 .00045 Mdot
.336 .00057 Mdot
.34 .0002 Mdot
.344 .00034 Mdot
.348 .0005 Mdot
.352 .00037 Mdot
.356 .00046 Mdot
.36 .00047 Mdot
.364 .00052 Mdot
.368 .00036 Mdot
.372 .00045 Mdot
.376 .00046 Mdot
.38 .00065 Mdot
.384 .00045 Mdot
.388 .00056 Mdot
.392 .00029 Mdot
.396 .00048 Mdot
.4 .00069 Mdot
.404 .00049 Mdot
.408 .0005 Mdot
.412 .00051 Mdot
.416 .00058 Mdot
.42 .00047 Mdot
.424 .00045 Mdot
.428 .0006 Mdot
.432 .0004 Mdot
.436 .00043 Mdot
.44 .00049 Mdot
.444 .00075 Mdot
.448 .00033 Mdot
.452 .00052 Mdot
.456 .00036 Mdot
.46 .00037 Mdot
.464 .00036 Mdot
.468 .00033 Mdot
.472 .00038 Mdot
.476 .00043 Mdot
.48 .00037 Mdot
.484 .00026 Mdot
.488 .00035 Mdot
.492 .00037 Mdot
.496 .00055 Mdot
.5 .00037 Mdot
.504 .00032 Mdot
.508 .0005 Mdot
.512 .00052 Mdot
.516 .00039 Mdot
.52 .00039 Mdot
.524 .00035 Mdot
.528 .00057 Mdot
.532 .0005 Mdot
.536 .00047 Mdot
.54 .00037 Mdot
.544 .00033 Mdot
.548 .00037 Mdot
.552 .00046 Mdot
.556 .0002 Mdot
.56 .00049 Mdot
.564 .00051 Mdot
.568 .00054 Mdot
.572 .0007 Mdot
.576 .00033 Mdot
.58 .00058 Mdot
.584 .00035 Mdot
.588 .00063 Mdot
.592 .00035 Mdot
.596 .00054 Mdot
.6 .00043 Mdot
.604 .00043 Mdot
.608 .00044 Mdot
.612 .00042 Mdot
.616 .0005 Mdot
.62 .00048 Mdot
.624 .00036 Mdot
.628 .00047 Mdot
.632 .00034 Mdot
.636 .00058 Mdot
.64 .00044 Mdot
.644 .00069 Mdot
.648 .00047 Mdot
.652 .00033 Mdot
.656 .00027 Mdot
.66 .00037 Mdot
.664 .00044 Mdot
.668 .00034 Mdot
.672 .00069 Mdot
.676 .00065 Mdot
.68 .00035 Mdot
.684 .00042 Mdot
.688 .00063 Mdot
.692 .00039 Mdot
.696 .00045 Mdot
.7 .0006 Mdot
.704 .00055 Mdot
.708 .00054 Mdot
.712 .00047 Mdot
.716 .0005 Mdot
.72 .00056 Mdot
.724 .00036 Mdot
.728 .00048 Mdot
.732 .00041 Mdot
.736 .00063 Mdot
.74 .00035 Mdot
.744 .00056 Mdot
.748 .00047 Mdot
.752 .00062 Mdot
.756 .00035 Mdot
.76 .00032 Mdot
.764 .00036 Mdot
.768 .00043 Mdot
.772 .00049 Mdot
.776 .00049 Mdot
.78 .00062 Mdot
.784 .00059 Mdot
.788 .0005 Mdot
.792 .00038 Mdot
.796 .0006 Mdot
.8 .00041 Mdot
.804 .00047 Mdot
.808 .00054 Mdot
.812 .0006 Mdot
.816 .00041 Mdot
.82 .00044 Mdot
.824 .00055 Mdot
.828 .0005 Mdot
.832 .00041 Mdot
.836 .00042 Mdot
.84 .00042 Mdot
.844 .00055 Mdot
.848 .00061 Mdot
.852 .00028 Mdot
.856 .0005 Mdot
.86 .00035 Mdot
.864 .0007 Mdot
.868 .00044 Mdot
.872 .0008 Mdot
.876 .00057 Mdot
.88 .00044 Mdot
.884 .00029 Mdot
.888 .00029 Mdot
.892 .00055 Mdot
.896 .00044 Mdot
.9 .00034 Mdot
.904 .00062 Mdot
.908 .00042 Mdot
.912 .0005 Mdot
.916 .0006 Mdot
.92 .00067 Mdot
.924 .00048 Mdot
.928 .00029 Mdot
.932 .00074 Mdot
.936 .00068 Mdot
.94 .00064 Mdot
.944 .00061 Mdot
.948 .00055 Mdot
.952 .00069 Mdot
.956 .00028 Mdot
.96 .00035 Mdot
.964 .0004 Mdot
.968 .00046 Mdot
.972 .0005 Mdot
.976 .00036 Mdot
.98 .00075 Mdot
.984 .00076 Mdot
.988 .0005 Mdot
.992 .00051 Mdot
.996 .00038 Mdot
1 .00049 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWc1uEzEQdta7bH5Ew6FVJUAQ4NYihNp3aLnwEKsKqT0gUMl7VZXgGvEW
iEdA7aXqA4TYTjy7289ee5Osm3arJjud8fx6xjP1fs7Gp1++ZuOzk2x0fJ59
Pz07+TE6+nY+Q/EOY50RY+xyxAQ8nYHzr+nsd/pGfAnM44KPxCMRYYgEFAko
tkJdAcUC4o4cPcd1BPUFxH2s8tdxqALwST5kBCS0+GjlLC7QaqJ5AZ0AHF+d
sjvodI2yDej+2lWikDbq4kHADHoCcOv0tResTJTORGtbueamM/VjwLRJQyjt
NhzgAEeBdFG2lXUe4yEPnABBDdC1uiXPm9YnPg20rGOdrq7Tkv98VXPqoyJy
1cF9OOZTn8to/M8knAbTWENohC7xRgBSp4XalgvtkV9tG0eB2MIU++tBp0KU
sx/Os0Vc3OIeNM42XiQ6JVFmGNpL7XnFOU1/QWNYvnB50XK1lms71F8Mn0FU
iEmVDdjLXbB+1yzqp7bwLaAOzYxXLSks6TXIHso8VG1zxle4DtBoge4d7FJ6
gIPsu7by9gEvqn0XPwwNrCKSNFFYPL8n+9+SqqpB7iGdtF5ZNAAcqFM45GKp
O9hrwD97HQvRuQYGxUiG39qWtEQN0ATif5avLBdtglxroqYPxn7k1Ap4WwYP
ioQqpNQvNrJCeo360M5Lm0/aEw+aTPCi94BUZ3k+g1cg80aR9rXoW4WQVI93
2dviIUV/0KL+KtIOUPsM4F4A3B8lItLSZSmV3oBTX6ZGg8KQFqXQOuPekV66
S6A5dKKMc71sW/52Gh0MqY92eAVERlRLQf9W5sNgbPLLOz+0yre+Iin7Zdjt
KucM4kvZSDg0Lw2xIGRO7sKL3sAuflRM2Z37bCnZ35HnGL3lbi268prkqlcK
ealdegoi905DvxWj7yH0GGDW+Q8GUg75\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14316, -0.296013, 286.316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.004591495905949376`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.004591495905949376],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0.01`"}],
  SequenceForm["Finished noise = ", 0.01],
  Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.08744e-017 2e-005 -1.49349e-017 0.611915 [
[.2 -0.0125 -15 -9 ]
[.2 -0.0125 15 0 ]
[.4 -0.0125 -15 -9 ]
[.4 -0.0125 15 0 ]
[.6 -0.0125 -15 -9 ]
[.6 -0.0125 15 0 ]
[.8 -0.0125 -15 -9 ]
[.8 -0.0125 15 0 ]
[1 -0.0125 -15 -9 ]
[1 -0.0125 15 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(10000)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(20000)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(30000)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(40000)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(50000)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .30704 Mdot
.008 .22658 Mdot
.012 .16887 Mdot
.016 .12486 Mdot
.02 .09255 Mdot
.024 .06949 Mdot
.028 .05053 Mdot
.032 .03764 Mdot
.036 .02844 Mdot
.04 .02162 Mdot
.044 .01639 Mdot
.048 .01209 Mdot
.052 .00883 Mdot
.056 .00629 Mdot
.06 .00485 Mdot
.064 .00315 Mdot
.068 .00263 Mdot
.072 .00206 Mdot
.076 .00141 Mdot
.08 .00098 Mdot
.084 .00074 Mdot
.088 .00055 Mdot
.092 .00043 Mdot
.096 .00024 Mdot
.1 .00012 Mdot
.104 9e-005 Mdot
.108 6e-005 Mdot
.112 6e-005 Mdot
.116 6e-005 Mdot
.12 0 Mdot
.124 1e-005 Mdot
.128 6e-005 Mdot
.132 6e-005 Mdot
.136 0 Mdot
.14 0 Mdot
.144 0 Mdot
.148 0 Mdot
.152 1e-005 Mdot
.156 0 Mdot
.16 6e-005 Mdot
.164 8e-005 Mdot
.168 6e-005 Mdot
.172 6e-005 Mdot
.176 6e-005 Mdot
.18 4e-005 Mdot
.184 6e-005 Mdot
.188 6e-005 Mdot
.192 6e-005 Mdot
.196 0 Mdot
.2 0 Mdot
.204 0 Mdot
.208 5e-005 Mdot
.212 0 Mdot
.216 0 Mdot
.22 0 Mdot
.224 0 Mdot
.228 0 Mdot
.232 0 Mdot
.236 0 Mdot
.24 0 Mdot
.244 0 Mdot
.248 6e-005 Mdot
.252 7e-005 Mdot
.256 6e-005 Mdot
.26 0 Mdot
.264 0 Mdot
.268 1e-005 Mdot
.272 0 Mdot
.276 2e-005 Mdot
.28 0 Mdot
.284 0 Mdot
.288 0 Mdot
.292 0 Mdot
.296 0 Mdot
.3 0 Mdot
.304 0 Mdot
.308 0 Mdot
.312 0 Mdot
.316 0 Mdot
.32 0 Mdot
.324 0 Mdot
.328 6e-005 Mdot
.332 .00012 Mdot
.336 .00012 Mdot
.34 .00012 Mdot
.344 6e-005 Mdot
.348 6e-005 Mdot
.352 6e-005 Mdot
.356 0 Mdot
.36 0 Mdot
.364 0 Mdot
.368 0 Mdot
.372 6e-005 Mdot
.376 6e-005 Mdot
.38 7e-005 Mdot
.384 1e-005 Mdot
.388 0 Mdot
.392 0 Mdot
.396 0 Mdot
.4 0 Mdot
.404 0 Mdot
.408 0 Mdot
.412 0 Mdot
.416 0 Mdot
.42 0 Mdot
.424 0 Mdot
.428 0 Mdot
.432 0 Mdot
.436 0 Mdot
.44 0 Mdot
.444 0 Mdot
.448 6e-005 Mdot
.452 6e-005 Mdot
.456 6e-005 Mdot
.46 .00012 Mdot
.464 9e-005 Mdot
.468 6e-005 Mdot
.472 0 Mdot
.476 1e-005 Mdot
.48 3e-005 Mdot
.484 1e-005 Mdot
.488 0 Mdot
.492 0 Mdot
.496 0 Mdot
.5 0 Mdot
.504 0 Mdot
.508 0 Mdot
.512 3e-005 Mdot
.516 0 Mdot
.52 0 Mdot
.524 1e-005 Mdot
.528 2e-005 Mdot
.532 0 Mdot
.536 6e-005 Mdot
.54 6e-005 Mdot
.544 6e-005 Mdot
.548 0 Mdot
.552 0 Mdot
.556 0 Mdot
.56 0 Mdot
.564 0 Mdot
.568 0 Mdot
.572 0 Mdot
.576 0 Mdot
.58 0 Mdot
.584 0 Mdot
.588 0 Mdot
.592 1e-005 Mdot
.596 0 Mdot
.6 0 Mdot
.604 0 Mdot
.608 0 Mdot
.612 6e-005 Mdot
.616 .00018 Mdot
.62 .00012 Mdot
.624 .00012 Mdot
.628 .00012 Mdot
.632 7e-005 Mdot
.636 6e-005 Mdot
.64 6e-005 Mdot
.644 1e-005 Mdot
.648 0 Mdot
.652 7e-005 Mdot
.656 7e-005 Mdot
.66 0 Mdot
.664 0 Mdot
.668 6e-005 Mdot
.672 0 Mdot
.676 2e-005 Mdot
.68 0 Mdot
.684 1e-005 Mdot
.688 0 Mdot
.692 6e-005 Mdot
.696 0 Mdot
.7 0 Mdot
.704 0 Mdot
.708 0 Mdot
.712 5e-005 Mdot
.716 0 Mdot
.72 1e-005 Mdot
.724 0 Mdot
.728 0 Mdot
.732 0 Mdot
.736 0 Mdot
.74 0 Mdot
.744 0 Mdot
.748 0 Mdot
.752 0 Mdot
.756 2e-005 Mdot
.76 0 Mdot
.764 0 Mdot
.768 0 Mdot
.772 0 Mdot
.776 0 Mdot
.78 0 Mdot
.784 0 Mdot
.788 0 Mdot
.792 3e-005 Mdot
.796 6e-005 Mdot
.8 0 Mdot
.804 0 Mdot
.808 0 Mdot
.812 0 Mdot
.816 0 Mdot
.82 7e-005 Mdot
.824 0 Mdot
.828 0 Mdot
.832 0 Mdot
.836 0 Mdot
.84 0 Mdot
.844 0 Mdot
.848 0 Mdot
.852 0 Mdot
.856 3e-005 Mdot
.86 5e-005 Mdot
.864 6e-005 Mdot
.868 0 Mdot
.872 0 Mdot
.876 0 Mdot
.88 0 Mdot
.884 0 Mdot
.888 1e-005 Mdot
.892 0 Mdot
.896 0 Mdot
.9 0 Mdot
.904 0 Mdot
.908 0 Mdot
.912 0 Mdot
.916 0 Mdot
.92 7e-005 Mdot
.924 6e-005 Mdot
.928 .00013 Mdot
.932 6e-005 Mdot
.936 6e-005 Mdot
.94 .00013 Mdot
.944 .00013 Mdot
.948 6e-005 Mdot
.952 .00012 Mdot
.956 .00012 Mdot
.96 .00012 Mdot
.964 .00012 Mdot
.968 .00012 Mdot
.972 6e-005 Mdot
.976 6e-005 Mdot
.98 6e-005 Mdot
.984 1e-005 Mdot
.988 0 Mdot
.992 0 Mdot
.996 6e-005 Mdot
1 .00012 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWV1uEzEQdta75KeC8ACqBFUJ8AYIIbhDywuHiCqk9qGiKj1XKy5QcQvE
BZAKvCAOEGI79ew6n53xJrsObaJudjpjz3hmvxlPvB/GZ4cfj8dnRwfj0f7p
+OTw6ODzaO/T6ZQlO0J0RkKILyOh6MmUnH1Npn+Tp+pLcW4XvaduhQpDpqhM
UXmQ6ikqV5RkzugzxxE1UJSMWVW8jXcmAO/1TUdAU9eXNS7yiqwmW1bYBeDJ
1RmbY3cb1O1hDxo3iULaqotvEyLoDuA16Ws/WZoYm4W1tnLLbSP1TULYdFMY
7bUc4ASlQLuot5Umy3jKgpMgqAl2rZ7jedv21NXClrVv4crtluL7q5pdHyUR
14aMmTHr+jit8ZVPOTWmuaVQC+3MzQBlqoV5LBfWo7jc9rYCeWBSHm8HVYWs
tH7Yz1ZTKQfjNrybwwu1F4WFpIsMMwdirna/woYpcuMcLlCUk1lWvTFjpV2b
+U/gukTJWfDTR10XgWhsg/HbcerPrSfPgHToV/bLL0JP4wdTE3b0qtY6uKIU
Nucg/LMhc08AGAnIKBNmE3fxOlH34h5tqE9YS9+XlXp9v4NzB0xoc/zw7JEL
IklNCzrUWQE6/KJyfBqC5tqLmDFAyNfPi4p0FGK2wAxU6hi4czaWMN7jkcpM
Ojbet6qRXBMYbERLVH9ps6HhqllDETcnavrg3XtYZV9u0uBGiVCGOPvFf5kh
/VZ9WIveaCNaSvRC3agzwYNeAVGd4WUEr0DnHyN6aVX/NQwtjXg1/kDdtOrX
VtV3I3oIzN4HvMeA982oyKx2nUrOC3Xal2mjQWHoVrXQOO+zI7t0DEF96KVZ
HJqIMn75w25UGLox1uGJEi1isRb0E7IcBu8mv7zzw6D+4BsX1y/P017knEe9
g0bioX5piBWh5ZTOyuiF7vXHxFTMHY9rzfGOPMLse/zVolOwy1L2aiU71qW7
IHLPLfXVTIwtQreBFp1/WMYm4Q==\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14316, -0.296013, 286.316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.006566689052596136`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.006566689052596136],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0.001`"}],
  SequenceForm["Finished noise = ", 0.001],
  Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.08744e-017 2e-005 -1.49349e-017 0.611915 [
[.2 -0.0125 -15 -9 ]
[.2 -0.0125 15 0 ]
[.4 -0.0125 -15 -9 ]
[.4 -0.0125 15 0 ]
[.6 -0.0125 -15 -9 ]
[.6 -0.0125 15 0 ]
[.8 -0.0125 -15 -9 ]
[.8 -0.0125 15 0 ]
[1 -0.0125 -15 -9 ]
[1 -0.0125 15 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(10000)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(20000)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(30000)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(40000)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(50000)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .39257 Mdot
.008 .38049 Mdot
.012 .36833 Mdot
.016 .35659 Mdot
.02 .34652 Mdot
.024 .3366 Mdot
.028 .32769 Mdot
.032 .31755 Mdot
.036 .3082 Mdot
.04 .29947 Mdot
.044 .29046 Mdot
.048 .28167 Mdot
.052 .27179 Mdot
.056 .26396 Mdot
.06 .25599 Mdot
.064 .24933 Mdot
.068 .24139 Mdot
.072 .23529 Mdot
.076 .22917 Mdot
.08 .22271 Mdot
.084 .21525 Mdot
.088 .20824 Mdot
.092 .20222 Mdot
.096 .1964 Mdot
.1 .19027 Mdot
.104 .18483 Mdot
.108 .18022 Mdot
.112 .17492 Mdot
.116 .16964 Mdot
.12 .16425 Mdot
.124 .15942 Mdot
.128 .15445 Mdot
.132 .14927 Mdot
.136 .14568 Mdot
.14 .14161 Mdot
.144 .13738 Mdot
.148 .13378 Mdot
.152 .1296 Mdot
.156 .12615 Mdot
.16 .12259 Mdot
.164 .11829 Mdot
.168 .11469 Mdot
.172 .11158 Mdot
.176 .10908 Mdot
.18 .10585 Mdot
.184 .10308 Mdot
.188 .10084 Mdot
.192 .0981 Mdot
.196 .09484 Mdot
.2 .09266 Mdot
.204 .08954 Mdot
.208 .08744 Mdot
.212 .08477 Mdot
.216 .08224 Mdot
.22 .07977 Mdot
.224 .07753 Mdot
.228 .07528 Mdot
.232 .07311 Mdot
.236 .07115 Mdot
.24 .0696 Mdot
.244 .06803 Mdot
.248 .06536 Mdot
.252 .06354 Mdot
.256 .06133 Mdot
.26 .05924 Mdot
.264 .05746 Mdot
.268 .05572 Mdot
.272 .05393 Mdot
.276 .05219 Mdot
.28 .05055 Mdot
.284 .04857 Mdot
.288 .04694 Mdot
.292 .0452 Mdot
.296 .04395 Mdot
.3 .04271 Mdot
.304 .04101 Mdot
.308 .04004 Mdot
.312 .03909 Mdot
.316 .03795 Mdot
.32 .03666 Mdot
.324 .03534 Mdot
.328 .03411 Mdot
.332 .03331 Mdot
.336 .032 Mdot
.34 .03123 Mdot
.344 .03036 Mdot
.348 .02912 Mdot
.352 .02827 Mdot
.356 .0273 Mdot
.36 .02689 Mdot
.364 .02643 Mdot
.368 .02568 Mdot
.372 .02505 Mdot
.376 .02412 Mdot
.38 .02334 Mdot
.384 .02252 Mdot
.388 .02215 Mdot
.392 .02154 Mdot
.396 .02078 Mdot
.4 .02 Mdot
.404 .01911 Mdot
.408 .01854 Mdot
.412 .01812 Mdot
.416 .0175 Mdot
.42 .01719 Mdot
.424 .01671 Mdot
.428 .01641 Mdot
.432 .01597 Mdot
.436 .01542 Mdot
.44 .01495 Mdot
.444 .01439 Mdot
.448 .01401 Mdot
.452 .01353 Mdot
.456 .01316 Mdot
.46 .01262 Mdot
.464 .01224 Mdot
.468 .01187 Mdot
.472 .01151 Mdot
.476 .01102 Mdot
.48 .01077 Mdot
.484 .01035 Mdot
.488 .00991 Mdot
.492 .00951 Mdot
.496 .0093 Mdot
.5 .00906 Mdot
.504 .00872 Mdot
.508 .00833 Mdot
.512 .00814 Mdot
.516 .00777 Mdot
.52 .00747 Mdot
.524 .00719 Mdot
.528 .00687 Mdot
.532 .00655 Mdot
.536 .00643 Mdot
.54 .0063 Mdot
.544 .00619 Mdot
.548 .00618 Mdot
.552 .006 Mdot
.556 .00557 Mdot
.56 .00545 Mdot
.564 .00545 Mdot
.568 .00533 Mdot
.572 .00514 Mdot
.576 .0049 Mdot
.58 .00483 Mdot
.584 .00465 Mdot
.588 .00444 Mdot
.592 .00434 Mdot
.596 .00422 Mdot
.6 .00422 Mdot
.604 .00416 Mdot
.608 .0041 Mdot
.612 .00392 Mdot
.616 .00386 Mdot
.62 .00386 Mdot
.624 .00373 Mdot
.628 .00367 Mdot
.632 .00349 Mdot
.636 .00342 Mdot
.64 .0033 Mdot
.644 .00319 Mdot
.648 .00312 Mdot
.652 .003 Mdot
.656 .00288 Mdot
.66 .0027 Mdot
.664 .00258 Mdot
.668 .00245 Mdot
.672 .00245 Mdot
.676 .00245 Mdot
.68 .00239 Mdot
.684 .00233 Mdot
.688 .0022 Mdot
.692 .00214 Mdot
.696 .00202 Mdot
.7 .00196 Mdot
.704 .00196 Mdot
.708 .00184 Mdot
.712 .00177 Mdot
.716 .00171 Mdot
.72 .00165 Mdot
.724 .00159 Mdot
.728 .00159 Mdot
.732 .00153 Mdot
.736 .00153 Mdot
.74 .00147 Mdot
.744 .00147 Mdot
.748 .00136 Mdot
.752 .00135 Mdot
.756 .00122 Mdot
.76 .00122 Mdot
.764 .00122 Mdot
.768 .00122 Mdot
.772 .0011 Mdot
.776 .00104 Mdot
.78 .00104 Mdot
.784 .00104 Mdot
.788 .00104 Mdot
.792 .00098 Mdot
.796 .00098 Mdot
.8 .00098 Mdot
.804 .00092 Mdot
.808 .00092 Mdot
.812 .00092 Mdot
.816 .00086 Mdot
.82 .00086 Mdot
.824 .00086 Mdot
.828 .00086 Mdot
.832 .00086 Mdot
.836 .00086 Mdot
.84 .00086 Mdot
.844 .00086 Mdot
.848 .00086 Mdot
.852 .0008 Mdot
.856 .0008 Mdot
.86 .00079 Mdot
.864 .00069 Mdot
.868 .00067 Mdot
.872 .00067 Mdot
.876 .00067 Mdot
.88 .00067 Mdot
.884 .00061 Mdot
.888 .00061 Mdot
.892 .00061 Mdot
.896 .00061 Mdot
.9 .00061 Mdot
.904 .00061 Mdot
.908 .00049 Mdot
.912 .00049 Mdot
.916 .00049 Mdot
.92 .00049 Mdot
.924 .00049 Mdot
.928 .00049 Mdot
.932 .00049 Mdot
.936 .00049 Mdot
.94 .00049 Mdot
.944 .00043 Mdot
.948 .00042 Mdot
.952 .00043 Mdot
.956 .00043 Mdot
.96 .00043 Mdot
.964 .00043 Mdot
.968 .00037 Mdot
.972 .00031 Mdot
.976 .00031 Mdot
.98 .00031 Mdot
.984 .00024 Mdot
.988 .00024 Mdot
.992 .00024 Mdot
.996 .00024 Mdot
1 .00024 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWltrE0EU3mY3TdPaRq1SbcWmiijeqSD45JOtL/6IUMT2QSxt/V2i4IMI
pYiIgnjB+/0uVPsi/oCYmd2e2Z1+ZzKTbnaDbWh2p998c86cmXNmzs7mQm1h
+uLl2sLMVK06OVebnZ6Zmq9OXJlrQH6X53VVPc+7XvVEud4oRpd6468+Ji4C
2VjlCXErimEoiFJBlAJjqUeUAlHyLVuULXmq1CtKvkuv3HWcCgfgvLzJEZCl
1S8p94JEXYuwn4CLAPPTU7YGLrVRNgP3tl0lGtJMTRzP0YO6AdZOW8u5hUmo
s0jaUtectaeezNFtSnko7cl4gHNYCqSJcltp5zKe54KTw6DmsGv1aJZnrU98
M9iyJsldbbMl9/yqxaxPBZGtDt+lRZT12aTGy5xwlZgGVEIptNa2AErhahFO
yzWyyC222VQgMDQK3PWgVaEQ6z/MZ5NY8J9g0ux+NYGd0assMFMCUSSnQ6PC
bCAtZyTWjnhOXMsCuQS75cWD1E/aEHJ96lH4n4fXGxV0Rb43Z8W1WyCzBsuH
QMshXugZEnqVer0P8Cq8iNPU8AZPGicLb/KkEyTpFk86RqTbPOkwkRZ50iEi
LfGkgzRJd3jSASLd5Un7iXSPJ40R6T5PqhLpAU8aBZiBvocG4yFPGiHFj3jS
MMAi+ijwfRU3aNXYDbDHobC98maVGKFTk10Ae2KUXAYtlB1I3lOjvF7QAq1/
O0nHcwvLmQ0biNSwZ/ocqawKjd8g1b7kfWEQYC94+naAGaRvA9ir1OhbAfaa
p1cA9oanDwDsbWr0foC94+lbAPY+NXofwD7wdBQWH1OjoyD+pHu+imrp+Wrf
1hr+Dhsy8Yjs5k85kthno2TZQss/kJQvzaXYrRclZ+H6OHOS0TPIV30++pIz
g2cBzTZauL7x9PQkoX5+b0kx8rsfqdENipGr/rSUhHPTZUeKQcEaf/vVtCGb
fEi2Pr/iYw5vh/BpXZDs5Urz5tCG5qrNKc2KPnDq7ZpjHG5WdW4VigttA0zN
nbOMi3KmNtimzZ0195tV8Sp5aqDSKkw6Cqpaocc9OAWZf8KqIyT6bwjIWoef
dewQNyn6OImKHmPQQyN6SBoBWPScVSDpMpS0H4Oo3VhtNGgYSkkpisfOndKr
jtpUEh2dEdmeyK7/RQ1aGFCKzWqHZ6WqE82loKem+DCwm/z6ja8Y5RvfFup2
MbPdzDhGvOaNCkNZUgULQt2JnQerHyOsfsIx9da82pGS3Q0ZxvCAfW/R6e9i
LHqlEHVa2A9GTp10LoUNXRehjVD2uv4BMH5IzQ==\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14316, -0.296013, 286.316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.008062449843775481`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.008062449843775481],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0.0001`"}],
  SequenceForm["Finished noise = ", 0.0001],
  Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.08744e-017 2e-005 -1.49349e-017 0.611915 [
[.2 -0.0125 -15 -9 ]
[.2 -0.0125 15 0 ]
[.4 -0.0125 -15 -9 ]
[.4 -0.0125 15 0 ]
[.6 -0.0125 -15 -9 ]
[.6 -0.0125 15 0 ]
[.8 -0.0125 -15 -9 ]
[.8 -0.0125 15 0 ]
[1 -0.0125 -15 -9 ]
[1 -0.0125 15 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(10000)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(20000)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(30000)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(40000)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(50000)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .40276 Mdot
.008 .40276 Mdot
.012 .40276 Mdot
.016 .40276 Mdot
.02 .40276 Mdot
.024 .40276 Mdot
.028 .40276 Mdot
.032 .40276 Mdot
.036 .40276 Mdot
.04 .40276 Mdot
.044 .40276 Mdot
.048 .40276 Mdot
.052 .40276 Mdot
.056 .40276 Mdot
.06 .40276 Mdot
.064 .40276 Mdot
.068 .40276 Mdot
.072 .40276 Mdot
.076 .40276 Mdot
.08 .40276 Mdot
.084 .40276 Mdot
.088 .40276 Mdot
.092 .40276 Mdot
.096 .40276 Mdot
.1 .40276 Mdot
.104 .40276 Mdot
.108 .40276 Mdot
.112 .40276 Mdot
.116 .40276 Mdot
.12 .40276 Mdot
.124 .40276 Mdot
.128 .40276 Mdot
.132 .40276 Mdot
.136 .40276 Mdot
.14 .40276 Mdot
.144 .40276 Mdot
.148 .40276 Mdot
.152 .40276 Mdot
.156 .40276 Mdot
.16 .40276 Mdot
.164 .40276 Mdot
.168 .40276 Mdot
.172 .40276 Mdot
.176 .40276 Mdot
.18 .40276 Mdot
.184 .40276 Mdot
.188 .40276 Mdot
.192 .40276 Mdot
.196 .40276 Mdot
.2 .40276 Mdot
.204 .40276 Mdot
.208 .40276 Mdot
.212 .40276 Mdot
.216 .40276 Mdot
.22 .40276 Mdot
.224 .40276 Mdot
.228 .40276 Mdot
.232 .40276 Mdot
.236 .40276 Mdot
.24 .40276 Mdot
.244 .40276 Mdot
.248 .40276 Mdot
.252 .40276 Mdot
.256 .40276 Mdot
.26 .40276 Mdot
.264 .40276 Mdot
.268 .40276 Mdot
.272 .40276 Mdot
.276 .40276 Mdot
.28 .40276 Mdot
.284 .40276 Mdot
.288 .40276 Mdot
.292 .40276 Mdot
.296 .40276 Mdot
.3 .40276 Mdot
.304 .40276 Mdot
.308 .40276 Mdot
.312 .40276 Mdot
.316 .40276 Mdot
.32 .40276 Mdot
.324 .40276 Mdot
.328 .40276 Mdot
.332 .40276 Mdot
.336 .40276 Mdot
.34 .40276 Mdot
.344 .40276 Mdot
.348 .40276 Mdot
.352 .40276 Mdot
.356 .40276 Mdot
.36 .40276 Mdot
.364 .40276 Mdot
.368 .40276 Mdot
.372 .40276 Mdot
.376 .40276 Mdot
.38 .40276 Mdot
.384 .40276 Mdot
.388 .40276 Mdot
.392 .40276 Mdot
.396 .40276 Mdot
.4 .40276 Mdot
.404 .40276 Mdot
.408 .40276 Mdot
.412 .40276 Mdot
.416 .40276 Mdot
.42 .40276 Mdot
.424 .40276 Mdot
.428 .40276 Mdot
.432 .40276 Mdot
.436 .40276 Mdot
.44 .40276 Mdot
.444 .40276 Mdot
.448 .40276 Mdot
.452 .40276 Mdot
.456 .40276 Mdot
.46 .40276 Mdot
.464 .40276 Mdot
.468 .40276 Mdot
.472 .40276 Mdot
.476 .40276 Mdot
.48 .40276 Mdot
.484 .40276 Mdot
.488 .40276 Mdot
.492 .40276 Mdot
.496 .40276 Mdot
.5 .40276 Mdot
.504 .40276 Mdot
.508 .40276 Mdot
.512 .40276 Mdot
.516 .40276 Mdot
.52 .40276 Mdot
.524 .40276 Mdot
.528 .40276 Mdot
.532 .40276 Mdot
.536 .40276 Mdot
.54 .40276 Mdot
.544 .40276 Mdot
.548 .40276 Mdot
.552 .40276 Mdot
.556 .40276 Mdot
.56 .40276 Mdot
.564 .40276 Mdot
.568 .40276 Mdot
.572 .40276 Mdot
.576 .40276 Mdot
.58 .40276 Mdot
.584 .40276 Mdot
.588 .40276 Mdot
.592 .40276 Mdot
.596 .40276 Mdot
.6 .40276 Mdot
.604 .40276 Mdot
.608 .40276 Mdot
.612 .40276 Mdot
.616 .40276 Mdot
.62 .40276 Mdot
.624 .40276 Mdot
.628 .40276 Mdot
.632 .40276 Mdot
.636 .40276 Mdot
.64 .40276 Mdot
.644 .40276 Mdot
.648 .40276 Mdot
.652 .40276 Mdot
.656 .40276 Mdot
.66 .40276 Mdot
.664 .40276 Mdot
.668 .40276 Mdot
.672 .40276 Mdot
.676 .40276 Mdot
.68 .40276 Mdot
.684 .40276 Mdot
.688 .40276 Mdot
.692 .40276 Mdot
.696 .40276 Mdot
.7 .40276 Mdot
.704 .40276 Mdot
.708 .40276 Mdot
.712 .40276 Mdot
.716 .40276 Mdot
.72 .40276 Mdot
.724 .40276 Mdot
.728 .40276 Mdot
.732 .40276 Mdot
.736 .40276 Mdot
.74 .40276 Mdot
.744 .40276 Mdot
.748 .40276 Mdot
.752 .40276 Mdot
.756 .40276 Mdot
.76 .40276 Mdot
.764 .40276 Mdot
.768 .40276 Mdot
.772 .40276 Mdot
.776 .40276 Mdot
.78 .40276 Mdot
.784 .40276 Mdot
.788 .40276 Mdot
.792 .40276 Mdot
.796 .40276 Mdot
.8 .40276 Mdot
.804 .40276 Mdot
.808 .40276 Mdot
.812 .40276 Mdot
.816 .40276 Mdot
.82 .40276 Mdot
.824 .40276 Mdot
.828 .40276 Mdot
.832 .40276 Mdot
.836 .40276 Mdot
.84 .40276 Mdot
.844 .40276 Mdot
.848 .40276 Mdot
.852 .40276 Mdot
.856 .40276 Mdot
.86 .40276 Mdot
.864 .40276 Mdot
.868 .40276 Mdot
.872 .40276 Mdot
.876 .40276 Mdot
.88 .40276 Mdot
.884 .40276 Mdot
.888 .40276 Mdot
.892 .40276 Mdot
.896 .40276 Mdot
.9 .40276 Mdot
.904 .40276 Mdot
.908 .40276 Mdot
.912 .40276 Mdot
.916 .40276 Mdot
.92 .40276 Mdot
.924 .40276 Mdot
.928 .40276 Mdot
.932 .40276 Mdot
.936 .40276 Mdot
.94 .40276 Mdot
.944 .40276 Mdot
.948 .40276 Mdot
.952 .40276 Mdot
.956 .40276 Mdot
.96 .40276 Mdot
.964 .40276 Mdot
.968 .40276 Mdot
.972 .40276 Mdot
.976 .40276 Mdot
.98 .40276 Mdot
.984 .40276 Mdot
.988 .40276 Mdot
.992 .40276 Mdot
.996 .40276 Mdot
1 .40276 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWc1O3DAQ9sYJ+4PocgAh0ard0htFCMEDcAMuPMQKIcEBUVHeq6pUroi3
qHiEqlwQD7Cs7cWThM+Ond3E/ATBZpjx/HrGM+scDi9Pjs+Gl6dHw8H+xfDH
yenRz8He+cUYxVuMtQaMsd8DJuDRGJx8jMa/o6/iQ2DeF7wnHokIQySgSECx
FeoIKBYQd+ToOq4jqCcg7mOVv44dFYAD+ZARkNDTn1bO4gytJJpn0AnA8dkp
e4ZuVyjbgO5VrhKFtFYXtwNm0BzAVelrN1iZKJ2J1jZzzXVn6lbAtGmHUNqp
OcABjgLpomwrVR7jIQ+cAEEN0LU6Oc/r1if+amhZ+zpdXacl//mq5NRHReSq
g/twTKY+l9H4n0k4DaaxhtAIneONAKROC7Utv7RHfrVtHAViC1PsrwedClHK
fjjPZnFxg3vTONt4keiURJlhaC+l5xXnNL2CxrB04fKs5Wot13ao/xg+g6gQ
kyIbsJcrYP2KWdQfbeEaoPbNjP8bUljSF5A9lHmo2iaMn3EdoNEC3TvYpXQB
B9l3Z+XtAV5U+y5+GBpYQSRporB4/kL2vyEVVYPcQzppvbJoHnCgTuGQi7nu
YK8B/+x1LETnGpjPRjL81jakKWqAJhD/s3xmuWgT5FoTJX0w9iOnVsCrKwP5
7W33ReXPWyWhush1iVdZF91afWimpNdPWhcPmkfwog1AKrM8ncEzkHmvSN+1
6AeFkFSPN9hL4iFFb2pRt4q0DNQuAtxHgPurRERauiyl3Htv6sbUXlAY2lkp
tM64d6SXbhBo+rxWxrlesU1/J40OhraPdnjxQ0YUS0FfJtNhMLb26Z3vW+Vb
X4zk/TLsdpFzBvG5bCQcmpL6WBAyJ3XNRe9dn35UTNmzW2wp2d+RVYz+4G4t
uui6TlWvFPJJu7QAIvdNQzeK0fcQeg8waz0Cc1gI/w==\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14316, -0.296013, 286.316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.009333278866479998`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.009333278866479998],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["Finished noise = ", 0],
  Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"finalFigure", "=", 
   RowBox[{"MultipleListPlot", "[", 
    RowBox[{"listOfAverages", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4000"}], ",", 
          RowBox[{"nOfIterations", "+", "200"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.15"}], ",", "1.01"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1000"}], ",", 
        RowBox[{"-", "0.05"}]}], "}"}]}], ",", 
     RowBox[{"SymbolShape", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Star", ",", "1"}], "]"}], ",", 
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Star", ",", "1"}], "]"}], ",", 
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Diamond", ",", "1"}], "]"}], ",", 
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Diamond", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"SymbolStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"TextStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "9"}]}], "}"}]}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"StyleForm", "[", 
         RowBox[{"\"\<       Iteration\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "10"}]}], "]"}], ",", 
        RowBox[{"StyleForm", "[", 
         RowBox[{"\"\<      Propensity to Cooperate\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "10"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "None"}]}], "]"}]}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0738007 1.84502e-005 0.0799182 0.532788 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -27.5625 -12.125 ]
[.5 -0.0125 27.5625 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -12.125 -57.5313 ]
[-0.01875 .30902 0 57.5313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.0738 .04078 -4.28125 -12.125 ]
[.0738 .04078 4.28125 0 ]
[.2583 .04078 -13.4063 -12.125 ]
[.2583 .04078 13.4063 0 ]
[.4428 .04078 -13.4063 -12.125 ]
[.4428 .04078 13.4063 0 ]
[.62731 .04078 -13.4063 -12.125 ]
[.62731 .04078 13.4063 0 ]
[.81181 .04078 -13.4063 -12.125 ]
[.81181 .04078 13.4063 0 ]
[.99631 .04078 -13.4063 -12.125 ]
[.99631 .04078 13.4063 0 ]
[.04285 .07992 -8.5625 -6.0625 ]
[.04285 .07992 0 6.0625 ]
[.04285 .18648 -15.375 -6.0625 ]
[.04285 .18648 0 6.0625 ]
[.04285 .29303 -15.375 -6.0625 ]
[.04285 .29303 0 6.0625 ]
[.04285 .39959 -15.375 -6.0625 ]
[.04285 .39959 0 6.0625 ]
[.04285 .50615 -15.375 -6.0625 ]
[.04285 .50615 0 6.0625 ]
[.04285 .61271 -8.5625 -6.0625 ]
[.04285 .61271 0 6.0625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 1 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 g
gsave
.5 -0.0125 -88.5625 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
80.500 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
114.125 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 1 1 r
0 0 m
0 .61803 L
s
0 g
gsave
-0.01875 .30902 -124.594 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
118.531 10.0625 translate
90 rotate
-118.531 -10.0625 translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
78.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Propensity) show
122.875 13.000 moveto
(to) show
133.125 13.000 moveto
(Cooperate) show
174.063 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 1 1 r
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 g
.0738 .05328 m
.0738 .05953 L
s
gsave
.0738 .04078 -65.2813 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2583 .05328 m
.2583 .05953 L
s
gsave
.2583 .04078 -74.4063 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.4428 .05328 m
.4428 .05953 L
s
gsave
.4428 .04078 -74.4063 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.62731 .05328 m
.62731 .05953 L
s
gsave
.62731 .04078 -74.4063 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30000) show
1.000 setlinewidth
grestore
.81181 .05328 m
.81181 .05953 L
s
gsave
.81181 .04078 -74.4063 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40000) show
1.000 setlinewidth
grestore
.99631 .05328 m
.99631 .05953 L
s
gsave
.99631 .04078 -74.4063 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
1.000 setlinewidth
grestore
.125 Mabswid
.1107 .05328 m
.1107 .05703 L
s
.1476 .05328 m
.1476 .05703 L
s
.1845 .05328 m
.1845 .05703 L
s
.2214 .05328 m
.2214 .05703 L
s
.2952 .05328 m
.2952 .05703 L
s
.3321 .05328 m
.3321 .05703 L
s
.369 .05328 m
.369 .05703 L
s
.4059 .05328 m
.4059 .05703 L
s
.4797 .05328 m
.4797 .05703 L
s
.51661 .05328 m
.51661 .05703 L
s
.55351 .05328 m
.55351 .05703 L
s
.59041 .05328 m
.59041 .05703 L
s
.66421 .05328 m
.66421 .05703 L
s
.70111 .05328 m
.70111 .05703 L
s
.73801 .05328 m
.73801 .05703 L
s
.77491 .05328 m
.77491 .05703 L
s
.84871 .05328 m
.84871 .05703 L
s
.88561 .05328 m
.88561 .05703 L
s
.92251 .05328 m
.92251 .05703 L
s
.95941 .05328 m
.95941 .05703 L
s
.0369 .05328 m
.0369 .05703 L
s
.25 Mabswid
0 .05328 m
1 .05328 L
s
.05535 .07992 m
.0616 .07992 L
s
gsave
.04285 .07992 -69.5625 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.05535 .18648 m
.0616 .18648 L
s
gsave
.04285 .18648 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.05535 .29303 m
.0616 .29303 L
s
gsave
.04285 .29303 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.05535 .39959 m
.0616 .39959 L
s
gsave
.04285 .39959 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.05535 .50615 m
.0616 .50615 L
s
gsave
.04285 .50615 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.05535 .61271 m
.0616 .61271 L
s
gsave
.04285 .61271 -69.5625 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05535 .10656 m
.0591 .10656 L
s
.05535 .1332 m
.0591 .1332 L
s
.05535 .15984 m
.0591 .15984 L
s
.05535 .21312 m
.0591 .21312 L
s
.05535 .23975 m
.0591 .23975 L
s
.05535 .26639 m
.0591 .26639 L
s
.05535 .31967 m
.0591 .31967 L
s
.05535 .34631 m
.0591 .34631 L
s
.05535 .37295 m
.0591 .37295 L
s
.05535 .42623 m
.0591 .42623 L
s
.05535 .45287 m
.0591 .45287 L
s
.05535 .47951 m
.0591 .47951 L
s
.05535 .53279 m
.0591 .53279 L
s
.05535 .55943 m
.0591 .55943 L
s
.05535 .58607 m
.0591 .58607 L
s
.05535 .02664 m
.0591 .02664 L
s
.25 Mabswid
.05535 0 m
.05535 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.0001 w
.0738 .55943 0 1 Mabsadd m
.0738 .55943 -0.22607 .31116 Mabsadd L
.0738 .55943 -0.95106 .30902 Mabsadd L
.0738 .55943 -0.36579 -0.11885 Mabsadd L
.0738 .55943 -0.58778 -0.80902 Mabsadd L
.0738 .55943 0 -0.38461 Mabsadd L
.0738 .55943 .58779 -0.80902 Mabsadd L
.0738 .55943 .36579 -0.11885 Mabsadd L
.0738 .55943 .95106 .30902 Mabsadd L
.0738 .55943 .22607 .31116 Mabsadd L
.0738 .55943 0 1 Mabsadd L closepath F
.07749 .10344 0 1 Mabsadd m
.07749 .10344 -0.22607 .31116 Mabsadd L
.07749 .10344 -0.95106 .30902 Mabsadd L
.07749 .10344 -0.36579 -0.11885 Mabsadd L
.07749 .10344 -0.58778 -0.80902 Mabsadd L
.07749 .10344 0 -0.38461 Mabsadd L
.07749 .10344 .58779 -0.80902 Mabsadd L
.07749 .10344 .36579 -0.11885 Mabsadd L
.07749 .10344 .95106 .30902 Mabsadd L
.07749 .10344 .22607 .31116 Mabsadd L
.07749 .10344 0 1 Mabsadd L closepath F
.08118 .08221 0 1 Mabsadd m
.08118 .08221 -0.22607 .31116 Mabsadd L
.08118 .08221 -0.95106 .30902 Mabsadd L
.08118 .08221 -0.36579 -0.11885 Mabsadd L
.08118 .08221 -0.58778 -0.80902 Mabsadd L
.08118 .08221 0 -0.38461 Mabsadd L
.08118 .08221 .58779 -0.80902 Mabsadd L
.08118 .08221 .36579 -0.11885 Mabsadd L
.08118 .08221 .95106 .30902 Mabsadd L
.08118 .08221 .22607 .31116 Mabsadd L
.08118 .08221 0 1 Mabsadd L closepath F
.08487 .08041 0 1 Mabsadd m
.08487 .08041 -0.22607 .31116 Mabsadd L
.08487 .08041 -0.95106 .30902 Mabsadd L
.08487 .08041 -0.36579 -0.11885 Mabsadd L
.08487 .08041 -0.58778 -0.80902 Mabsadd L
.08487 .08041 0 -0.38461 Mabsadd L
.08487 .08041 .58779 -0.80902 Mabsadd L
.08487 .08041 .36579 -0.11885 Mabsadd L
.08487 .08041 .95106 .30902 Mabsadd L
.08487 .08041 .22607 .31116 Mabsadd L
.08487 .08041 0 1 Mabsadd L closepath F
.08856 .08046 0 1 Mabsadd m
.08856 .08046 -0.22607 .31116 Mabsadd L
.08856 .08046 -0.95106 .30902 Mabsadd L
.08856 .08046 -0.36579 -0.11885 Mabsadd L
.08856 .08046 -0.58778 -0.80902 Mabsadd L
.08856 .08046 0 -0.38461 Mabsadd L
.08856 .08046 .58779 -0.80902 Mabsadd L
.08856 .08046 .36579 -0.11885 Mabsadd L
.08856 .08046 .95106 .30902 Mabsadd L
.08856 .08046 .22607 .31116 Mabsadd L
.08856 .08046 0 1 Mabsadd L closepath F
.09225 .08049 0 1 Mabsadd m
.09225 .08049 -0.22607 .31116 Mabsadd L
.09225 .08049 -0.95106 .30902 Mabsadd L
.09225 .08049 -0.36579 -0.11885 Mabsadd L
.09225 .08049 -0.58778 -0.80902 Mabsadd L
.09225 .08049 0 -0.38461 Mabsadd L
.09225 .08049 .58779 -0.80902 Mabsadd L
.09225 .08049 .36579 -0.11885 Mabsadd L
.09225 .08049 .95106 .30902 Mabsadd L
.09225 .08049 .22607 .31116 Mabsadd L
.09225 .08049 0 1 Mabsadd L closepath F
.09594 .08038 0 1 Mabsadd m
.09594 .08038 -0.22607 .31116 Mabsadd L
.09594 .08038 -0.95106 .30902 Mabsadd L
.09594 .08038 -0.36579 -0.11885 Mabsadd L
.09594 .08038 -0.58778 -0.80902 Mabsadd L
.09594 .08038 0 -0.38461 Mabsadd L
.09594 .08038 .58779 -0.80902 Mabsadd L
.09594 .08038 .36579 -0.11885 Mabsadd L
.09594 .08038 .95106 .30902 Mabsadd L
.09594 .08038 .22607 .31116 Mabsadd L
.09594 .08038 0 1 Mabsadd L closepath F
.09963 .08031 0 1 Mabsadd m
.09963 .08031 -0.22607 .31116 Mabsadd L
.09963 .08031 -0.95106 .30902 Mabsadd L
.09963 .08031 -0.36579 -0.11885 Mabsadd L
.09963 .08031 -0.58778 -0.80902 Mabsadd L
.09963 .08031 0 -0.38461 Mabsadd L
.09963 .08031 .58779 -0.80902 Mabsadd L
.09963 .08031 .36579 -0.11885 Mabsadd L
.09963 .08031 .95106 .30902 Mabsadd L
.09963 .08031 .22607 .31116 Mabsadd L
.09963 .08031 0 1 Mabsadd L closepath F
.10332 .08038 0 1 Mabsadd m
.10332 .08038 -0.22607 .31116 Mabsadd L
.10332 .08038 -0.95106 .30902 Mabsadd L
.10332 .08038 -0.36579 -0.11885 Mabsadd L
.10332 .08038 -0.58778 -0.80902 Mabsadd L
.10332 .08038 0 -0.38461 Mabsadd L
.10332 .08038 .58779 -0.80902 Mabsadd L
.10332 .08038 .36579 -0.11885 Mabsadd L
.10332 .08038 .95106 .30902 Mabsadd L
.10332 .08038 .22607 .31116 Mabsadd L
.10332 .08038 0 1 Mabsadd L closepath F
.10701 .0804 0 1 Mabsadd m
.10701 .0804 -0.22607 .31116 Mabsadd L
.10701 .0804 -0.95106 .30902 Mabsadd L
.10701 .0804 -0.36579 -0.11885 Mabsadd L
.10701 .0804 -0.58778 -0.80902 Mabsadd L
.10701 .0804 0 -0.38461 Mabsadd L
.10701 .0804 .58779 -0.80902 Mabsadd L
.10701 .0804 .36579 -0.11885 Mabsadd L
.10701 .0804 .95106 .30902 Mabsadd L
.10701 .0804 .22607 .31116 Mabsadd L
.10701 .0804 0 1 Mabsadd L closepath F
.1107 .08039 0 1 Mabsadd m
.1107 .08039 -0.22607 .31116 Mabsadd L
.1107 .08039 -0.95106 .30902 Mabsadd L
.1107 .08039 -0.36579 -0.11885 Mabsadd L
.1107 .08039 -0.58778 -0.80902 Mabsadd L
.1107 .08039 0 -0.38461 Mabsadd L
.1107 .08039 .58779 -0.80902 Mabsadd L
.1107 .08039 .36579 -0.11885 Mabsadd L
.1107 .08039 .95106 .30902 Mabsadd L
.1107 .08039 .22607 .31116 Mabsadd L
.1107 .08039 0 1 Mabsadd L closepath F
.11439 .08038 0 1 Mabsadd m
.11439 .08038 -0.22607 .31116 Mabsadd L
.11439 .08038 -0.95106 .30902 Mabsadd L
.11439 .08038 -0.36579 -0.11885 Mabsadd L
.11439 .08038 -0.58778 -0.80902 Mabsadd L
.11439 .08038 0 -0.38461 Mabsadd L
.11439 .08038 .58779 -0.80902 Mabsadd L
.11439 .08038 .36579 -0.11885 Mabsadd L
.11439 .08038 .95106 .30902 Mabsadd L
.11439 .08038 .22607 .31116 Mabsadd L
.11439 .08038 0 1 Mabsadd L closepath F
.11808 .08035 0 1 Mabsadd m
.11808 .08035 -0.22607 .31116 Mabsadd L
.11808 .08035 -0.95106 .30902 Mabsadd L
.11808 .08035 -0.36579 -0.11885 Mabsadd L
.11808 .08035 -0.58778 -0.80902 Mabsadd L
.11808 .08035 0 -0.38461 Mabsadd L
.11808 .08035 .58779 -0.80902 Mabsadd L
.11808 .08035 .36579 -0.11885 Mabsadd L
.11808 .08035 .95106 .30902 Mabsadd L
.11808 .08035 .22607 .31116 Mabsadd L
.11808 .08035 0 1 Mabsadd L closepath F
.12177 .08022 0 1 Mabsadd m
.12177 .08022 -0.22607 .31116 Mabsadd L
.12177 .08022 -0.95106 .30902 Mabsadd L
.12177 .08022 -0.36579 -0.11885 Mabsadd L
.12177 .08022 -0.58778 -0.80902 Mabsadd L
.12177 .08022 0 -0.38461 Mabsadd L
.12177 .08022 .58779 -0.80902 Mabsadd L
.12177 .08022 .36579 -0.11885 Mabsadd L
.12177 .08022 .95106 .30902 Mabsadd L
.12177 .08022 .22607 .31116 Mabsadd L
.12177 .08022 0 1 Mabsadd L closepath F
.12546 .08013 0 1 Mabsadd m
.12546 .08013 -0.22607 .31116 Mabsadd L
.12546 .08013 -0.95106 .30902 Mabsadd L
.12546 .08013 -0.36579 -0.11885 Mabsadd L
.12546 .08013 -0.58778 -0.80902 Mabsadd L
.12546 .08013 0 -0.38461 Mabsadd L
.12546 .08013 .58779 -0.80902 Mabsadd L
.12546 .08013 .36579 -0.11885 Mabsadd L
.12546 .08013 .95106 .30902 Mabsadd L
.12546 .08013 .22607 .31116 Mabsadd L
.12546 .08013 0 1 Mabsadd L closepath F
.12915 .08033 0 1 Mabsadd m
.12915 .08033 -0.22607 .31116 Mabsadd L
.12915 .08033 -0.95106 .30902 Mabsadd L
.12915 .08033 -0.36579 -0.11885 Mabsadd L
.12915 .08033 -0.58778 -0.80902 Mabsadd L
.12915 .08033 0 -0.38461 Mabsadd L
.12915 .08033 .58779 -0.80902 Mabsadd L
.12915 .08033 .36579 -0.11885 Mabsadd L
.12915 .08033 .95106 .30902 Mabsadd L
.12915 .08033 .22607 .31116 Mabsadd L
.12915 .08033 0 1 Mabsadd L closepath F
.13284 .08039 0 1 Mabsadd m
.13284 .08039 -0.22607 .31116 Mabsadd L
.13284 .08039 -0.95106 .30902 Mabsadd L
.13284 .08039 -0.36579 -0.11885 Mabsadd L
.13284 .08039 -0.58778 -0.80902 Mabsadd L
.13284 .08039 0 -0.38461 Mabsadd L
.13284 .08039 .58779 -0.80902 Mabsadd L
.13284 .08039 .36579 -0.11885 Mabsadd L
.13284 .08039 .95106 .30902 Mabsadd L
.13284 .08039 .22607 .31116 Mabsadd L
.13284 .08039 0 1 Mabsadd L closepath F
.13653 .08049 0 1 Mabsadd m
.13653 .08049 -0.22607 .31116 Mabsadd L
.13653 .08049 -0.95106 .30902 Mabsadd L
.13653 .08049 -0.36579 -0.11885 Mabsadd L
.13653 .08049 -0.58778 -0.80902 Mabsadd L
.13653 .08049 0 -0.38461 Mabsadd L
.13653 .08049 .58779 -0.80902 Mabsadd L
.13653 .08049 .36579 -0.11885 Mabsadd L
.13653 .08049 .95106 .30902 Mabsadd L
.13653 .08049 .22607 .31116 Mabsadd L
.13653 .08049 0 1 Mabsadd L closepath F
.14022 .08033 0 1 Mabsadd m
.14022 .08033 -0.22607 .31116 Mabsadd L
.14022 .08033 -0.95106 .30902 Mabsadd L
.14022 .08033 -0.36579 -0.11885 Mabsadd L
.14022 .08033 -0.58778 -0.80902 Mabsadd L
.14022 .08033 0 -0.38461 Mabsadd L
.14022 .08033 .58779 -0.80902 Mabsadd L
.14022 .08033 .36579 -0.11885 Mabsadd L
.14022 .08033 .95106 .30902 Mabsadd L
.14022 .08033 .22607 .31116 Mabsadd L
.14022 .08033 0 1 Mabsadd L closepath F
.14391 .08031 0 1 Mabsadd m
.14391 .08031 -0.22607 .31116 Mabsadd L
.14391 .08031 -0.95106 .30902 Mabsadd L
.14391 .08031 -0.36579 -0.11885 Mabsadd L
.14391 .08031 -0.58778 -0.80902 Mabsadd L
.14391 .08031 0 -0.38461 Mabsadd L
.14391 .08031 .58779 -0.80902 Mabsadd L
.14391 .08031 .36579 -0.11885 Mabsadd L
.14391 .08031 .95106 .30902 Mabsadd L
.14391 .08031 .22607 .31116 Mabsadd L
.14391 .08031 0 1 Mabsadd L closepath F
.1476 .0802 0 1 Mabsadd m
.1476 .0802 -0.22607 .31116 Mabsadd L
.1476 .0802 -0.95106 .30902 Mabsadd L
.1476 .0802 -0.36579 -0.11885 Mabsadd L
.1476 .0802 -0.58778 -0.80902 Mabsadd L
.1476 .0802 0 -0.38461 Mabsadd L
.1476 .0802 .58779 -0.80902 Mabsadd L
.1476 .0802 .36579 -0.11885 Mabsadd L
.1476 .0802 .95106 .30902 Mabsadd L
.1476 .0802 .22607 .31116 Mabsadd L
.1476 .0802 0 1 Mabsadd L closepath F
.15129 .08016 0 1 Mabsadd m
.15129 .08016 -0.22607 .31116 Mabsadd L
.15129 .08016 -0.95106 .30902 Mabsadd L
.15129 .08016 -0.36579 -0.11885 Mabsadd L
.15129 .08016 -0.58778 -0.80902 Mabsadd L
.15129 .08016 0 -0.38461 Mabsadd L
.15129 .08016 .58779 -0.80902 Mabsadd L
.15129 .08016 .36579 -0.11885 Mabsadd L
.15129 .08016 .95106 .30902 Mabsadd L
.15129 .08016 .22607 .31116 Mabsadd L
.15129 .08016 0 1 Mabsadd L closepath F
.15498 .08026 0 1 Mabsadd m
.15498 .08026 -0.22607 .31116 Mabsadd L
.15498 .08026 -0.95106 .30902 Mabsadd L
.15498 .08026 -0.36579 -0.11885 Mabsadd L
.15498 .08026 -0.58778 -0.80902 Mabsadd L
.15498 .08026 0 -0.38461 Mabsadd L
.15498 .08026 .58779 -0.80902 Mabsadd L
.15498 .08026 .36579 -0.11885 Mabsadd L
.15498 .08026 .95106 .30902 Mabsadd L
.15498 .08026 .22607 .31116 Mabsadd L
.15498 .08026 0 1 Mabsadd L closepath F
.15867 .0801 0 1 Mabsadd m
.15867 .0801 -0.22607 .31116 Mabsadd L
.15867 .0801 -0.95106 .30902 Mabsadd L
.15867 .0801 -0.36579 -0.11885 Mabsadd L
.15867 .0801 -0.58778 -0.80902 Mabsadd L
.15867 .0801 0 -0.38461 Mabsadd L
.15867 .0801 .58779 -0.80902 Mabsadd L
.15867 .0801 .36579 -0.11885 Mabsadd L
.15867 .0801 .95106 .30902 Mabsadd L
.15867 .0801 .22607 .31116 Mabsadd L
.15867 .0801 0 1 Mabsadd L closepath F
.16236 .08014 0 1 Mabsadd m
.16236 .08014 -0.22607 .31116 Mabsadd L
.16236 .08014 -0.95106 .30902 Mabsadd L
.16236 .08014 -0.36579 -0.11885 Mabsadd L
.16236 .08014 -0.58778 -0.80902 Mabsadd L
.16236 .08014 0 -0.38461 Mabsadd L
.16236 .08014 .58779 -0.80902 Mabsadd L
.16236 .08014 .36579 -0.11885 Mabsadd L
.16236 .08014 .95106 .30902 Mabsadd L
.16236 .08014 .22607 .31116 Mabsadd L
.16236 .08014 0 1 Mabsadd L closepath F
.16605 .08043 0 1 Mabsadd m
.16605 .08043 -0.22607 .31116 Mabsadd L
.16605 .08043 -0.95106 .30902 Mabsadd L
.16605 .08043 -0.36579 -0.11885 Mabsadd L
.16605 .08043 -0.58778 -0.80902 Mabsadd L
.16605 .08043 0 -0.38461 Mabsadd L
.16605 .08043 .58779 -0.80902 Mabsadd L
.16605 .08043 .36579 -0.11885 Mabsadd L
.16605 .08043 .95106 .30902 Mabsadd L
.16605 .08043 .22607 .31116 Mabsadd L
.16605 .08043 0 1 Mabsadd L closepath F
.16974 .08027 0 1 Mabsadd m
.16974 .08027 -0.22607 .31116 Mabsadd L
.16974 .08027 -0.95106 .30902 Mabsadd L
.16974 .08027 -0.36579 -0.11885 Mabsadd L
.16974 .08027 -0.58778 -0.80902 Mabsadd L
.16974 .08027 0 -0.38461 Mabsadd L
.16974 .08027 .58779 -0.80902 Mabsadd L
.16974 .08027 .36579 -0.11885 Mabsadd L
.16974 .08027 .95106 .30902 Mabsadd L
.16974 .08027 .22607 .31116 Mabsadd L
.16974 .08027 0 1 Mabsadd L closepath F
.17343 .08011 0 1 Mabsadd m
.17343 .08011 -0.22607 .31116 Mabsadd L
.17343 .08011 -0.95106 .30902 Mabsadd L
.17343 .08011 -0.36579 -0.11885 Mabsadd L
.17343 .08011 -0.58778 -0.80902 Mabsadd L
.17343 .08011 0 -0.38461 Mabsadd L
.17343 .08011 .58779 -0.80902 Mabsadd L
.17343 .08011 .36579 -0.11885 Mabsadd L
.17343 .08011 .95106 .30902 Mabsadd L
.17343 .08011 .22607 .31116 Mabsadd L
.17343 .08011 0 1 Mabsadd L closepath F
.17712 .08032 0 1 Mabsadd m
.17712 .08032 -0.22607 .31116 Mabsadd L
.17712 .08032 -0.95106 .30902 Mabsadd L
.17712 .08032 -0.36579 -0.11885 Mabsadd L
.17712 .08032 -0.58778 -0.80902 Mabsadd L
.17712 .08032 0 -0.38461 Mabsadd L
.17712 .08032 .58779 -0.80902 Mabsadd L
.17712 .08032 .36579 -0.11885 Mabsadd L
.17712 .08032 .95106 .30902 Mabsadd L
.17712 .08032 .22607 .31116 Mabsadd L
.17712 .08032 0 1 Mabsadd L closepath F
.18081 .08054 0 1 Mabsadd m
.18081 .08054 -0.22607 .31116 Mabsadd L
.18081 .08054 -0.95106 .30902 Mabsadd L
.18081 .08054 -0.36579 -0.11885 Mabsadd L
.18081 .08054 -0.58778 -0.80902 Mabsadd L
.18081 .08054 0 -0.38461 Mabsadd L
.18081 .08054 .58779 -0.80902 Mabsadd L
.18081 .08054 .36579 -0.11885 Mabsadd L
.18081 .08054 .95106 .30902 Mabsadd L
.18081 .08054 .22607 .31116 Mabsadd L
.18081 .08054 0 1 Mabsadd L closepath F
.1845 .08041 0 1 Mabsadd m
.1845 .08041 -0.22607 .31116 Mabsadd L
.1845 .08041 -0.95106 .30902 Mabsadd L
.1845 .08041 -0.36579 -0.11885 Mabsadd L
.1845 .08041 -0.58778 -0.80902 Mabsadd L
.1845 .08041 0 -0.38461 Mabsadd L
.1845 .08041 .58779 -0.80902 Mabsadd L
.1845 .08041 .36579 -0.11885 Mabsadd L
.1845 .08041 .95106 .30902 Mabsadd L
.1845 .08041 .22607 .31116 Mabsadd L
.1845 .08041 0 1 Mabsadd L closepath F
.18819 .08031 0 1 Mabsadd m
.18819 .08031 -0.22607 .31116 Mabsadd L
.18819 .08031 -0.95106 .30902 Mabsadd L
.18819 .08031 -0.36579 -0.11885 Mabsadd L
.18819 .08031 -0.58778 -0.80902 Mabsadd L
.18819 .08031 0 -0.38461 Mabsadd L
.18819 .08031 .58779 -0.80902 Mabsadd L
.18819 .08031 .36579 -0.11885 Mabsadd L
.18819 .08031 .95106 .30902 Mabsadd L
.18819 .08031 .22607 .31116 Mabsadd L
.18819 .08031 0 1 Mabsadd L closepath F
.19188 .08045 0 1 Mabsadd m
.19188 .08045 -0.22607 .31116 Mabsadd L
.19188 .08045 -0.95106 .30902 Mabsadd L
.19188 .08045 -0.36579 -0.11885 Mabsadd L
.19188 .08045 -0.58778 -0.80902 Mabsadd L
.19188 .08045 0 -0.38461 Mabsadd L
.19188 .08045 .58779 -0.80902 Mabsadd L
.19188 .08045 .36579 -0.11885 Mabsadd L
.19188 .08045 .95106 .30902 Mabsadd L
.19188 .08045 .22607 .31116 Mabsadd L
.19188 .08045 0 1 Mabsadd L closepath F
.19557 .08037 0 1 Mabsadd m
.19557 .08037 -0.22607 .31116 Mabsadd L
.19557 .08037 -0.95106 .30902 Mabsadd L
.19557 .08037 -0.36579 -0.11885 Mabsadd L
.19557 .08037 -0.58778 -0.80902 Mabsadd L
.19557 .08037 0 -0.38461 Mabsadd L
.19557 .08037 .58779 -0.80902 Mabsadd L
.19557 .08037 .36579 -0.11885 Mabsadd L
.19557 .08037 .95106 .30902 Mabsadd L
.19557 .08037 .22607 .31116 Mabsadd L
.19557 .08037 0 1 Mabsadd L closepath F
.19926 .08029 0 1 Mabsadd m
.19926 .08029 -0.22607 .31116 Mabsadd L
.19926 .08029 -0.95106 .30902 Mabsadd L
.19926 .08029 -0.36579 -0.11885 Mabsadd L
.19926 .08029 -0.58778 -0.80902 Mabsadd L
.19926 .08029 0 -0.38461 Mabsadd L
.19926 .08029 .58779 -0.80902 Mabsadd L
.19926 .08029 .36579 -0.11885 Mabsadd L
.19926 .08029 .95106 .30902 Mabsadd L
.19926 .08029 .22607 .31116 Mabsadd L
.19926 .08029 0 1 Mabsadd L closepath F
.20295 .08008 0 1 Mabsadd m
.20295 .08008 -0.22607 .31116 Mabsadd L
.20295 .08008 -0.95106 .30902 Mabsadd L
.20295 .08008 -0.36579 -0.11885 Mabsadd L
.20295 .08008 -0.58778 -0.80902 Mabsadd L
.20295 .08008 0 -0.38461 Mabsadd L
.20295 .08008 .58779 -0.80902 Mabsadd L
.20295 .08008 .36579 -0.11885 Mabsadd L
.20295 .08008 .95106 .30902 Mabsadd L
.20295 .08008 .22607 .31116 Mabsadd L
.20295 .08008 0 1 Mabsadd L closepath F
.20664 .08014 0 1 Mabsadd m
.20664 .08014 -0.22607 .31116 Mabsadd L
.20664 .08014 -0.95106 .30902 Mabsadd L
.20664 .08014 -0.36579 -0.11885 Mabsadd L
.20664 .08014 -0.58778 -0.80902 Mabsadd L
.20664 .08014 0 -0.38461 Mabsadd L
.20664 .08014 .58779 -0.80902 Mabsadd L
.20664 .08014 .36579 -0.11885 Mabsadd L
.20664 .08014 .95106 .30902 Mabsadd L
.20664 .08014 .22607 .31116 Mabsadd L
.20664 .08014 0 1 Mabsadd L closepath F
.21033 .08051 0 1 Mabsadd m
.21033 .08051 -0.22607 .31116 Mabsadd L
.21033 .08051 -0.95106 .30902 Mabsadd L
.21033 .08051 -0.36579 -0.11885 Mabsadd L
.21033 .08051 -0.58778 -0.80902 Mabsadd L
.21033 .08051 0 -0.38461 Mabsadd L
.21033 .08051 .58779 -0.80902 Mabsadd L
.21033 .08051 .36579 -0.11885 Mabsadd L
.21033 .08051 .95106 .30902 Mabsadd L
.21033 .08051 .22607 .31116 Mabsadd L
.21033 .08051 0 1 Mabsadd L closepath F
.21402 .08047 0 1 Mabsadd m
.21402 .08047 -0.22607 .31116 Mabsadd L
.21402 .08047 -0.95106 .30902 Mabsadd L
.21402 .08047 -0.36579 -0.11885 Mabsadd L
.21402 .08047 -0.58778 -0.80902 Mabsadd L
.21402 .08047 0 -0.38461 Mabsadd L
.21402 .08047 .58779 -0.80902 Mabsadd L
.21402 .08047 .36579 -0.11885 Mabsadd L
.21402 .08047 .95106 .30902 Mabsadd L
.21402 .08047 .22607 .31116 Mabsadd L
.21402 .08047 0 1 Mabsadd L closepath F
.21771 .08033 0 1 Mabsadd m
.21771 .08033 -0.22607 .31116 Mabsadd L
.21771 .08033 -0.95106 .30902 Mabsadd L
.21771 .08033 -0.36579 -0.11885 Mabsadd L
.21771 .08033 -0.58778 -0.80902 Mabsadd L
.21771 .08033 0 -0.38461 Mabsadd L
.21771 .08033 .58779 -0.80902 Mabsadd L
.21771 .08033 .36579 -0.11885 Mabsadd L
.21771 .08033 .95106 .30902 Mabsadd L
.21771 .08033 .22607 .31116 Mabsadd L
.21771 .08033 0 1 Mabsadd L closepath F
.2214 .08052 0 1 Mabsadd m
.2214 .08052 -0.22607 .31116 Mabsadd L
.2214 .08052 -0.95106 .30902 Mabsadd L
.2214 .08052 -0.36579 -0.11885 Mabsadd L
.2214 .08052 -0.58778 -0.80902 Mabsadd L
.2214 .08052 0 -0.38461 Mabsadd L
.2214 .08052 .58779 -0.80902 Mabsadd L
.2214 .08052 .36579 -0.11885 Mabsadd L
.2214 .08052 .95106 .30902 Mabsadd L
.2214 .08052 .22607 .31116 Mabsadd L
.2214 .08052 0 1 Mabsadd L closepath F
.22509 .08044 0 1 Mabsadd m
.22509 .08044 -0.22607 .31116 Mabsadd L
.22509 .08044 -0.95106 .30902 Mabsadd L
.22509 .08044 -0.36579 -0.11885 Mabsadd L
.22509 .08044 -0.58778 -0.80902 Mabsadd L
.22509 .08044 0 -0.38461 Mabsadd L
.22509 .08044 .58779 -0.80902 Mabsadd L
.22509 .08044 .36579 -0.11885 Mabsadd L
.22509 .08044 .95106 .30902 Mabsadd L
.22509 .08044 .22607 .31116 Mabsadd L
.22509 .08044 0 1 Mabsadd L closepath F
.22878 .08025 0 1 Mabsadd m
.22878 .08025 -0.22607 .31116 Mabsadd L
.22878 .08025 -0.95106 .30902 Mabsadd L
.22878 .08025 -0.36579 -0.11885 Mabsadd L
.22878 .08025 -0.58778 -0.80902 Mabsadd L
.22878 .08025 0 -0.38461 Mabsadd L
.22878 .08025 .58779 -0.80902 Mabsadd L
.22878 .08025 .36579 -0.11885 Mabsadd L
.22878 .08025 .95106 .30902 Mabsadd L
.22878 .08025 .22607 .31116 Mabsadd L
.22878 .08025 0 1 Mabsadd L closepath F
.23247 .08032 0 1 Mabsadd m
.23247 .08032 -0.22607 .31116 Mabsadd L
.23247 .08032 -0.95106 .30902 Mabsadd L
.23247 .08032 -0.36579 -0.11885 Mabsadd L
.23247 .08032 -0.58778 -0.80902 Mabsadd L
.23247 .08032 0 -0.38461 Mabsadd L
.23247 .08032 .58779 -0.80902 Mabsadd L
.23247 .08032 .36579 -0.11885 Mabsadd L
.23247 .08032 .95106 .30902 Mabsadd L
.23247 .08032 .22607 .31116 Mabsadd L
.23247 .08032 0 1 Mabsadd L closepath F
.23616 .08052 0 1 Mabsadd m
.23616 .08052 -0.22607 .31116 Mabsadd L
.23616 .08052 -0.95106 .30902 Mabsadd L
.23616 .08052 -0.36579 -0.11885 Mabsadd L
.23616 .08052 -0.58778 -0.80902 Mabsadd L
.23616 .08052 0 -0.38461 Mabsadd L
.23616 .08052 .58779 -0.80902 Mabsadd L
.23616 .08052 .36579 -0.11885 Mabsadd L
.23616 .08052 .95106 .30902 Mabsadd L
.23616 .08052 .22607 .31116 Mabsadd L
.23616 .08052 0 1 Mabsadd L closepath F
.23985 .08032 0 1 Mabsadd m
.23985 .08032 -0.22607 .31116 Mabsadd L
.23985 .08032 -0.95106 .30902 Mabsadd L
.23985 .08032 -0.36579 -0.11885 Mabsadd L
.23985 .08032 -0.58778 -0.80902 Mabsadd L
.23985 .08032 0 -0.38461 Mabsadd L
.23985 .08032 .58779 -0.80902 Mabsadd L
.23985 .08032 .36579 -0.11885 Mabsadd L
.23985 .08032 .95106 .30902 Mabsadd L
.23985 .08032 .22607 .31116 Mabsadd L
.23985 .08032 0 1 Mabsadd L closepath F
.24354 .08035 0 1 Mabsadd m
.24354 .08035 -0.22607 .31116 Mabsadd L
.24354 .08035 -0.95106 .30902 Mabsadd L
.24354 .08035 -0.36579 -0.11885 Mabsadd L
.24354 .08035 -0.58778 -0.80902 Mabsadd L
.24354 .08035 0 -0.38461 Mabsadd L
.24354 .08035 .58779 -0.80902 Mabsadd L
.24354 .08035 .36579 -0.11885 Mabsadd L
.24354 .08035 .95106 .30902 Mabsadd L
.24354 .08035 .22607 .31116 Mabsadd L
.24354 .08035 0 1 Mabsadd L closepath F
.24723 .08036 0 1 Mabsadd m
.24723 .08036 -0.22607 .31116 Mabsadd L
.24723 .08036 -0.95106 .30902 Mabsadd L
.24723 .08036 -0.36579 -0.11885 Mabsadd L
.24723 .08036 -0.58778 -0.80902 Mabsadd L
.24723 .08036 0 -0.38461 Mabsadd L
.24723 .08036 .58779 -0.80902 Mabsadd L
.24723 .08036 .36579 -0.11885 Mabsadd L
.24723 .08036 .95106 .30902 Mabsadd L
.24723 .08036 .22607 .31116 Mabsadd L
.24723 .08036 0 1 Mabsadd L closepath F
.25092 .08023 0 1 Mabsadd m
.25092 .08023 -0.22607 .31116 Mabsadd L
.25092 .08023 -0.95106 .30902 Mabsadd L
.25092 .08023 -0.36579 -0.11885 Mabsadd L
.25092 .08023 -0.58778 -0.80902 Mabsadd L
.25092 .08023 0 -0.38461 Mabsadd L
.25092 .08023 .58779 -0.80902 Mabsadd L
.25092 .08023 .36579 -0.11885 Mabsadd L
.25092 .08023 .95106 .30902 Mabsadd L
.25092 .08023 .22607 .31116 Mabsadd L
.25092 .08023 0 1 Mabsadd L closepath F
.25461 .08046 0 1 Mabsadd m
.25461 .08046 -0.22607 .31116 Mabsadd L
.25461 .08046 -0.95106 .30902 Mabsadd L
.25461 .08046 -0.36579 -0.11885 Mabsadd L
.25461 .08046 -0.58778 -0.80902 Mabsadd L
.25461 .08046 0 -0.38461 Mabsadd L
.25461 .08046 .58779 -0.80902 Mabsadd L
.25461 .08046 .36579 -0.11885 Mabsadd L
.25461 .08046 .95106 .30902 Mabsadd L
.25461 .08046 .22607 .31116 Mabsadd L
.25461 .08046 0 1 Mabsadd L closepath F
.2583 .0803 0 1 Mabsadd m
.2583 .0803 -0.22607 .31116 Mabsadd L
.2583 .0803 -0.95106 .30902 Mabsadd L
.2583 .0803 -0.36579 -0.11885 Mabsadd L
.2583 .0803 -0.58778 -0.80902 Mabsadd L
.2583 .0803 0 -0.38461 Mabsadd L
.2583 .0803 .58779 -0.80902 Mabsadd L
.2583 .0803 .36579 -0.11885 Mabsadd L
.2583 .0803 .95106 .30902 Mabsadd L
.2583 .0803 .22607 .31116 Mabsadd L
.2583 .0803 0 1 Mabsadd L closepath F
.26199 .0805 0 1 Mabsadd m
.26199 .0805 -0.22607 .31116 Mabsadd L
.26199 .0805 -0.95106 .30902 Mabsadd L
.26199 .0805 -0.36579 -0.11885 Mabsadd L
.26199 .0805 -0.58778 -0.80902 Mabsadd L
.26199 .0805 0 -0.38461 Mabsadd L
.26199 .0805 .58779 -0.80902 Mabsadd L
.26199 .0805 .36579 -0.11885 Mabsadd L
.26199 .0805 .95106 .30902 Mabsadd L
.26199 .0805 .22607 .31116 Mabsadd L
.26199 .0805 0 1 Mabsadd L closepath F
.26568 .08038 0 1 Mabsadd m
.26568 .08038 -0.22607 .31116 Mabsadd L
.26568 .08038 -0.95106 .30902 Mabsadd L
.26568 .08038 -0.36579 -0.11885 Mabsadd L
.26568 .08038 -0.58778 -0.80902 Mabsadd L
.26568 .08038 0 -0.38461 Mabsadd L
.26568 .08038 .58779 -0.80902 Mabsadd L
.26568 .08038 .36579 -0.11885 Mabsadd L
.26568 .08038 .95106 .30902 Mabsadd L
.26568 .08038 .22607 .31116 Mabsadd L
.26568 .08038 0 1 Mabsadd L closepath F
.26937 .08035 0 1 Mabsadd m
.26937 .08035 -0.22607 .31116 Mabsadd L
.26937 .08035 -0.95106 .30902 Mabsadd L
.26937 .08035 -0.36579 -0.11885 Mabsadd L
.26937 .08035 -0.58778 -0.80902 Mabsadd L
.26937 .08035 0 -0.38461 Mabsadd L
.26937 .08035 .58779 -0.80902 Mabsadd L
.26937 .08035 .36579 -0.11885 Mabsadd L
.26937 .08035 .95106 .30902 Mabsadd L
.26937 .08035 .22607 .31116 Mabsadd L
.26937 .08035 0 1 Mabsadd L closepath F
.27306 .08027 0 1 Mabsadd m
.27306 .08027 -0.22607 .31116 Mabsadd L
.27306 .08027 -0.95106 .30902 Mabsadd L
.27306 .08027 -0.36579 -0.11885 Mabsadd L
.27306 .08027 -0.58778 -0.80902 Mabsadd L
.27306 .08027 0 -0.38461 Mabsadd L
.27306 .08027 .58779 -0.80902 Mabsadd L
.27306 .08027 .36579 -0.11885 Mabsadd L
.27306 .08027 .95106 .30902 Mabsadd L
.27306 .08027 .22607 .31116 Mabsadd L
.27306 .08027 0 1 Mabsadd L closepath F
.27675 .08041 0 1 Mabsadd m
.27675 .08041 -0.22607 .31116 Mabsadd L
.27675 .08041 -0.95106 .30902 Mabsadd L
.27675 .08041 -0.36579 -0.11885 Mabsadd L
.27675 .08041 -0.58778 -0.80902 Mabsadd L
.27675 .08041 0 -0.38461 Mabsadd L
.27675 .08041 .58779 -0.80902 Mabsadd L
.27675 .08041 .36579 -0.11885 Mabsadd L
.27675 .08041 .95106 .30902 Mabsadd L
.27675 .08041 .22607 .31116 Mabsadd L
.27675 .08041 0 1 Mabsadd L closepath F
.28044 .08026 0 1 Mabsadd m
.28044 .08026 -0.22607 .31116 Mabsadd L
.28044 .08026 -0.95106 .30902 Mabsadd L
.28044 .08026 -0.36579 -0.11885 Mabsadd L
.28044 .08026 -0.58778 -0.80902 Mabsadd L
.28044 .08026 0 -0.38461 Mabsadd L
.28044 .08026 .58779 -0.80902 Mabsadd L
.28044 .08026 .36579 -0.11885 Mabsadd L
.28044 .08026 .95106 .30902 Mabsadd L
.28044 .08026 .22607 .31116 Mabsadd L
.28044 .08026 0 1 Mabsadd L closepath F
.28413 .08024 0 1 Mabsadd m
.28413 .08024 -0.22607 .31116 Mabsadd L
.28413 .08024 -0.95106 .30902 Mabsadd L
.28413 .08024 -0.36579 -0.11885 Mabsadd L
.28413 .08024 -0.58778 -0.80902 Mabsadd L
.28413 .08024 0 -0.38461 Mabsadd L
.28413 .08024 .58779 -0.80902 Mabsadd L
.28413 .08024 .36579 -0.11885 Mabsadd L
.28413 .08024 .95106 .30902 Mabsadd L
.28413 .08024 .22607 .31116 Mabsadd L
.28413 .08024 0 1 Mabsadd L closepath F
.28782 .08032 0 1 Mabsadd m
.28782 .08032 -0.22607 .31116 Mabsadd L
.28782 .08032 -0.95106 .30902 Mabsadd L
.28782 .08032 -0.36579 -0.11885 Mabsadd L
.28782 .08032 -0.58778 -0.80902 Mabsadd L
.28782 .08032 0 -0.38461 Mabsadd L
.28782 .08032 .58779 -0.80902 Mabsadd L
.28782 .08032 .36579 -0.11885 Mabsadd L
.28782 .08032 .95106 .30902 Mabsadd L
.28782 .08032 .22607 .31116 Mabsadd L
.28782 .08032 0 1 Mabsadd L closepath F
.29151 .08014 0 1 Mabsadd m
.29151 .08014 -0.22607 .31116 Mabsadd L
.29151 .08014 -0.95106 .30902 Mabsadd L
.29151 .08014 -0.36579 -0.11885 Mabsadd L
.29151 .08014 -0.58778 -0.80902 Mabsadd L
.29151 .08014 0 -0.38461 Mabsadd L
.29151 .08014 .58779 -0.80902 Mabsadd L
.29151 .08014 .36579 -0.11885 Mabsadd L
.29151 .08014 .95106 .30902 Mabsadd L
.29151 .08014 .22607 .31116 Mabsadd L
.29151 .08014 0 1 Mabsadd L closepath F
.2952 .08024 0 1 Mabsadd m
.2952 .08024 -0.22607 .31116 Mabsadd L
.2952 .08024 -0.95106 .30902 Mabsadd L
.2952 .08024 -0.36579 -0.11885 Mabsadd L
.2952 .08024 -0.58778 -0.80902 Mabsadd L
.2952 .08024 0 -0.38461 Mabsadd L
.2952 .08024 .58779 -0.80902 Mabsadd L
.2952 .08024 .36579 -0.11885 Mabsadd L
.2952 .08024 .95106 .30902 Mabsadd L
.2952 .08024 .22607 .31116 Mabsadd L
.2952 .08024 0 1 Mabsadd L closepath F
.29889 .08031 0 1 Mabsadd m
.29889 .08031 -0.22607 .31116 Mabsadd L
.29889 .08031 -0.95106 .30902 Mabsadd L
.29889 .08031 -0.36579 -0.11885 Mabsadd L
.29889 .08031 -0.58778 -0.80902 Mabsadd L
.29889 .08031 0 -0.38461 Mabsadd L
.29889 .08031 .58779 -0.80902 Mabsadd L
.29889 .08031 .36579 -0.11885 Mabsadd L
.29889 .08031 .95106 .30902 Mabsadd L
.29889 .08031 .22607 .31116 Mabsadd L
.29889 .08031 0 1 Mabsadd L closepath F
.30258 .08043 0 1 Mabsadd m
.30258 .08043 -0.22607 .31116 Mabsadd L
.30258 .08043 -0.95106 .30902 Mabsadd L
.30258 .08043 -0.36579 -0.11885 Mabsadd L
.30258 .08043 -0.58778 -0.80902 Mabsadd L
.30258 .08043 0 -0.38461 Mabsadd L
.30258 .08043 .58779 -0.80902 Mabsadd L
.30258 .08043 .36579 -0.11885 Mabsadd L
.30258 .08043 .95106 .30902 Mabsadd L
.30258 .08043 .22607 .31116 Mabsadd L
.30258 .08043 0 1 Mabsadd L closepath F
.30627 .0802 0 1 Mabsadd m
.30627 .0802 -0.22607 .31116 Mabsadd L
.30627 .0802 -0.95106 .30902 Mabsadd L
.30627 .0802 -0.36579 -0.11885 Mabsadd L
.30627 .0802 -0.58778 -0.80902 Mabsadd L
.30627 .0802 0 -0.38461 Mabsadd L
.30627 .0802 .58779 -0.80902 Mabsadd L
.30627 .0802 .36579 -0.11885 Mabsadd L
.30627 .0802 .95106 .30902 Mabsadd L
.30627 .0802 .22607 .31116 Mabsadd L
.30627 .0802 0 1 Mabsadd L closepath F
.30996 .08048 0 1 Mabsadd m
.30996 .08048 -0.22607 .31116 Mabsadd L
.30996 .08048 -0.95106 .30902 Mabsadd L
.30996 .08048 -0.36579 -0.11885 Mabsadd L
.30996 .08048 -0.58778 -0.80902 Mabsadd L
.30996 .08048 0 -0.38461 Mabsadd L
.30996 .08048 .58779 -0.80902 Mabsadd L
.30996 .08048 .36579 -0.11885 Mabsadd L
.30996 .08048 .95106 .30902 Mabsadd L
.30996 .08048 .22607 .31116 Mabsadd L
.30996 .08048 0 1 Mabsadd L closepath F
.31365 .08038 0 1 Mabsadd m
.31365 .08038 -0.22607 .31116 Mabsadd L
.31365 .08038 -0.95106 .30902 Mabsadd L
.31365 .08038 -0.36579 -0.11885 Mabsadd L
.31365 .08038 -0.58778 -0.80902 Mabsadd L
.31365 .08038 0 -0.38461 Mabsadd L
.31365 .08038 .58779 -0.80902 Mabsadd L
.31365 .08038 .36579 -0.11885 Mabsadd L
.31365 .08038 .95106 .30902 Mabsadd L
.31365 .08038 .22607 .31116 Mabsadd L
.31365 .08038 0 1 Mabsadd L closepath F
.31734 .08031 0 1 Mabsadd m
.31734 .08031 -0.22607 .31116 Mabsadd L
.31734 .08031 -0.95106 .30902 Mabsadd L
.31734 .08031 -0.36579 -0.11885 Mabsadd L
.31734 .08031 -0.58778 -0.80902 Mabsadd L
.31734 .08031 0 -0.38461 Mabsadd L
.31734 .08031 .58779 -0.80902 Mabsadd L
.31734 .08031 .36579 -0.11885 Mabsadd L
.31734 .08031 .95106 .30902 Mabsadd L
.31734 .08031 .22607 .31116 Mabsadd L
.31734 .08031 0 1 Mabsadd L closepath F
.32103 .08023 0 1 Mabsadd m
.32103 .08023 -0.22607 .31116 Mabsadd L
.32103 .08023 -0.95106 .30902 Mabsadd L
.32103 .08023 -0.36579 -0.11885 Mabsadd L
.32103 .08023 -0.58778 -0.80902 Mabsadd L
.32103 .08023 0 -0.38461 Mabsadd L
.32103 .08023 .58779 -0.80902 Mabsadd L
.32103 .08023 .36579 -0.11885 Mabsadd L
.32103 .08023 .95106 .30902 Mabsadd L
.32103 .08023 .22607 .31116 Mabsadd L
.32103 .08023 0 1 Mabsadd L closepath F
.32472 .08038 0 1 Mabsadd m
.32472 .08038 -0.22607 .31116 Mabsadd L
.32472 .08038 -0.95106 .30902 Mabsadd L
.32472 .08038 -0.36579 -0.11885 Mabsadd L
.32472 .08038 -0.58778 -0.80902 Mabsadd L
.32472 .08038 0 -0.38461 Mabsadd L
.32472 .08038 .58779 -0.80902 Mabsadd L
.32472 .08038 .36579 -0.11885 Mabsadd L
.32472 .08038 .95106 .30902 Mabsadd L
.32472 .08038 .22607 .31116 Mabsadd L
.32472 .08038 0 1 Mabsadd L closepath F
.32841 .08027 0 1 Mabsadd m
.32841 .08027 -0.22607 .31116 Mabsadd L
.32841 .08027 -0.95106 .30902 Mabsadd L
.32841 .08027 -0.36579 -0.11885 Mabsadd L
.32841 .08027 -0.58778 -0.80902 Mabsadd L
.32841 .08027 0 -0.38461 Mabsadd L
.32841 .08027 .58779 -0.80902 Mabsadd L
.32841 .08027 .36579 -0.11885 Mabsadd L
.32841 .08027 .95106 .30902 Mabsadd L
.32841 .08027 .22607 .31116 Mabsadd L
.32841 .08027 0 1 Mabsadd L closepath F
.3321 .08023 0 1 Mabsadd m
.3321 .08023 -0.22607 .31116 Mabsadd L
.3321 .08023 -0.95106 .30902 Mabsadd L
.3321 .08023 -0.36579 -0.11885 Mabsadd L
.3321 .08023 -0.58778 -0.80902 Mabsadd L
.3321 .08023 0 -0.38461 Mabsadd L
.3321 .08023 .58779 -0.80902 Mabsadd L
.3321 .08023 .36579 -0.11885 Mabsadd L
.3321 .08023 .95106 .30902 Mabsadd L
.3321 .08023 .22607 .31116 Mabsadd L
.3321 .08023 0 1 Mabsadd L closepath F
.33579 .08034 0 1 Mabsadd m
.33579 .08034 -0.22607 .31116 Mabsadd L
.33579 .08034 -0.95106 .30902 Mabsadd L
.33579 .08034 -0.36579 -0.11885 Mabsadd L
.33579 .08034 -0.58778 -0.80902 Mabsadd L
.33579 .08034 0 -0.38461 Mabsadd L
.33579 .08034 .58779 -0.80902 Mabsadd L
.33579 .08034 .36579 -0.11885 Mabsadd L
.33579 .08034 .95106 .30902 Mabsadd L
.33579 .08034 .22607 .31116 Mabsadd L
.33579 .08034 0 1 Mabsadd L closepath F
.33948 .08036 0 1 Mabsadd m
.33948 .08036 -0.22607 .31116 Mabsadd L
.33948 .08036 -0.95106 .30902 Mabsadd L
.33948 .08036 -0.36579 -0.11885 Mabsadd L
.33948 .08036 -0.58778 -0.80902 Mabsadd L
.33948 .08036 0 -0.38461 Mabsadd L
.33948 .08036 .58779 -0.80902 Mabsadd L
.33948 .08036 .36579 -0.11885 Mabsadd L
.33948 .08036 .95106 .30902 Mabsadd L
.33948 .08036 .22607 .31116 Mabsadd L
.33948 .08036 0 1 Mabsadd L closepath F
.34317 .08038 0 1 Mabsadd m
.34317 .08038 -0.22607 .31116 Mabsadd L
.34317 .08038 -0.95106 .30902 Mabsadd L
.34317 .08038 -0.36579 -0.11885 Mabsadd L
.34317 .08038 -0.58778 -0.80902 Mabsadd L
.34317 .08038 0 -0.38461 Mabsadd L
.34317 .08038 .58779 -0.80902 Mabsadd L
.34317 .08038 .36579 -0.11885 Mabsadd L
.34317 .08038 .95106 .30902 Mabsadd L
.34317 .08038 .22607 .31116 Mabsadd L
.34317 .08038 0 1 Mabsadd L closepath F
.34686 .08055 0 1 Mabsadd m
.34686 .08055 -0.22607 .31116 Mabsadd L
.34686 .08055 -0.95106 .30902 Mabsadd L
.34686 .08055 -0.36579 -0.11885 Mabsadd L
.34686 .08055 -0.58778 -0.80902 Mabsadd L
.34686 .08055 0 -0.38461 Mabsadd L
.34686 .08055 .58779 -0.80902 Mabsadd L
.34686 .08055 .36579 -0.11885 Mabsadd L
.34686 .08055 .95106 .30902 Mabsadd L
.34686 .08055 .22607 .31116 Mabsadd L
.34686 .08055 0 1 Mabsadd L closepath F
.35055 .08053 0 1 Mabsadd m
.35055 .08053 -0.22607 .31116 Mabsadd L
.35055 .08053 -0.95106 .30902 Mabsadd L
.35055 .08053 -0.36579 -0.11885 Mabsadd L
.35055 .08053 -0.58778 -0.80902 Mabsadd L
.35055 .08053 0 -0.38461 Mabsadd L
.35055 .08053 .58779 -0.80902 Mabsadd L
.35055 .08053 .36579 -0.11885 Mabsadd L
.35055 .08053 .95106 .30902 Mabsadd L
.35055 .08053 .22607 .31116 Mabsadd L
.35055 .08053 0 1 Mabsadd L closepath F
.35424 .08032 0 1 Mabsadd m
.35424 .08032 -0.22607 .31116 Mabsadd L
.35424 .08032 -0.95106 .30902 Mabsadd L
.35424 .08032 -0.36579 -0.11885 Mabsadd L
.35424 .08032 -0.58778 -0.80902 Mabsadd L
.35424 .08032 0 -0.38461 Mabsadd L
.35424 .08032 .58779 -0.80902 Mabsadd L
.35424 .08032 .36579 -0.11885 Mabsadd L
.35424 .08032 .95106 .30902 Mabsadd L
.35424 .08032 .22607 .31116 Mabsadd L
.35424 .08032 0 1 Mabsadd L closepath F
.35793 .08034 0 1 Mabsadd m
.35793 .08034 -0.22607 .31116 Mabsadd L
.35793 .08034 -0.95106 .30902 Mabsadd L
.35793 .08034 -0.36579 -0.11885 Mabsadd L
.35793 .08034 -0.58778 -0.80902 Mabsadd L
.35793 .08034 0 -0.38461 Mabsadd L
.35793 .08034 .58779 -0.80902 Mabsadd L
.35793 .08034 .36579 -0.11885 Mabsadd L
.35793 .08034 .95106 .30902 Mabsadd L
.35793 .08034 .22607 .31116 Mabsadd L
.35793 .08034 0 1 Mabsadd L closepath F
.36162 .08038 0 1 Mabsadd m
.36162 .08038 -0.22607 .31116 Mabsadd L
.36162 .08038 -0.95106 .30902 Mabsadd L
.36162 .08038 -0.36579 -0.11885 Mabsadd L
.36162 .08038 -0.58778 -0.80902 Mabsadd L
.36162 .08038 0 -0.38461 Mabsadd L
.36162 .08038 .58779 -0.80902 Mabsadd L
.36162 .08038 .36579 -0.11885 Mabsadd L
.36162 .08038 .95106 .30902 Mabsadd L
.36162 .08038 .22607 .31116 Mabsadd L
.36162 .08038 0 1 Mabsadd L closepath F
.36531 .08034 0 1 Mabsadd m
.36531 .08034 -0.22607 .31116 Mabsadd L
.36531 .08034 -0.95106 .30902 Mabsadd L
.36531 .08034 -0.36579 -0.11885 Mabsadd L
.36531 .08034 -0.58778 -0.80902 Mabsadd L
.36531 .08034 0 -0.38461 Mabsadd L
.36531 .08034 .58779 -0.80902 Mabsadd L
.36531 .08034 .36579 -0.11885 Mabsadd L
.36531 .08034 .95106 .30902 Mabsadd L
.36531 .08034 .22607 .31116 Mabsadd L
.36531 .08034 0 1 Mabsadd L closepath F
.369 .08036 0 1 Mabsadd m
.369 .08036 -0.22607 .31116 Mabsadd L
.369 .08036 -0.95106 .30902 Mabsadd L
.369 .08036 -0.36579 -0.11885 Mabsadd L
.369 .08036 -0.58778 -0.80902 Mabsadd L
.369 .08036 0 -0.38461 Mabsadd L
.369 .08036 .58779 -0.80902 Mabsadd L
.369 .08036 .36579 -0.11885 Mabsadd L
.369 .08036 .95106 .30902 Mabsadd L
.369 .08036 .22607 .31116 Mabsadd L
.369 .08036 0 1 Mabsadd L closepath F
.37269 .08014 0 1 Mabsadd m
.37269 .08014 -0.22607 .31116 Mabsadd L
.37269 .08014 -0.95106 .30902 Mabsadd L
.37269 .08014 -0.36579 -0.11885 Mabsadd L
.37269 .08014 -0.58778 -0.80902 Mabsadd L
.37269 .08014 0 -0.38461 Mabsadd L
.37269 .08014 .58779 -0.80902 Mabsadd L
.37269 .08014 .36579 -0.11885 Mabsadd L
.37269 .08014 .95106 .30902 Mabsadd L
.37269 .08014 .22607 .31116 Mabsadd L
.37269 .08014 0 1 Mabsadd L closepath F
.37638 .08032 0 1 Mabsadd m
.37638 .08032 -0.22607 .31116 Mabsadd L
.37638 .08032 -0.95106 .30902 Mabsadd L
.37638 .08032 -0.36579 -0.11885 Mabsadd L
.37638 .08032 -0.58778 -0.80902 Mabsadd L
.37638 .08032 0 -0.38461 Mabsadd L
.37638 .08032 .58779 -0.80902 Mabsadd L
.37638 .08032 .36579 -0.11885 Mabsadd L
.37638 .08032 .95106 .30902 Mabsadd L
.37638 .08032 .22607 .31116 Mabsadd L
.37638 .08032 0 1 Mabsadd L closepath F
.38007 .08031 0 1 Mabsadd m
.38007 .08031 -0.22607 .31116 Mabsadd L
.38007 .08031 -0.95106 .30902 Mabsadd L
.38007 .08031 -0.36579 -0.11885 Mabsadd L
.38007 .08031 -0.58778 -0.80902 Mabsadd L
.38007 .08031 0 -0.38461 Mabsadd L
.38007 .08031 .58779 -0.80902 Mabsadd L
.38007 .08031 .36579 -0.11885 Mabsadd L
.38007 .08031 .95106 .30902 Mabsadd L
.38007 .08031 .22607 .31116 Mabsadd L
.38007 .08031 0 1 Mabsadd L closepath F
.38376 .08041 0 1 Mabsadd m
.38376 .08041 -0.22607 .31116 Mabsadd L
.38376 .08041 -0.95106 .30902 Mabsadd L
.38376 .08041 -0.36579 -0.11885 Mabsadd L
.38376 .08041 -0.58778 -0.80902 Mabsadd L
.38376 .08041 0 -0.38461 Mabsadd L
.38376 .08041 .58779 -0.80902 Mabsadd L
.38376 .08041 .36579 -0.11885 Mabsadd L
.38376 .08041 .95106 .30902 Mabsadd L
.38376 .08041 .22607 .31116 Mabsadd L
.38376 .08041 0 1 Mabsadd L closepath F
.38745 .08009 0 1 Mabsadd m
.38745 .08009 -0.22607 .31116 Mabsadd L
.38745 .08009 -0.95106 .30902 Mabsadd L
.38745 .08009 -0.36579 -0.11885 Mabsadd L
.38745 .08009 -0.58778 -0.80902 Mabsadd L
.38745 .08009 0 -0.38461 Mabsadd L
.38745 .08009 .58779 -0.80902 Mabsadd L
.38745 .08009 .36579 -0.11885 Mabsadd L
.38745 .08009 .95106 .30902 Mabsadd L
.38745 .08009 .22607 .31116 Mabsadd L
.38745 .08009 0 1 Mabsadd L closepath F
.39114 .08021 0 1 Mabsadd m
.39114 .08021 -0.22607 .31116 Mabsadd L
.39114 .08021 -0.95106 .30902 Mabsadd L
.39114 .08021 -0.36579 -0.11885 Mabsadd L
.39114 .08021 -0.58778 -0.80902 Mabsadd L
.39114 .08021 0 -0.38461 Mabsadd L
.39114 .08021 .58779 -0.80902 Mabsadd L
.39114 .08021 .36579 -0.11885 Mabsadd L
.39114 .08021 .95106 .30902 Mabsadd L
.39114 .08021 .22607 .31116 Mabsadd L
.39114 .08021 0 1 Mabsadd L closepath F
.39483 .08035 0 1 Mabsadd m
.39483 .08035 -0.22607 .31116 Mabsadd L
.39483 .08035 -0.95106 .30902 Mabsadd L
.39483 .08035 -0.36579 -0.11885 Mabsadd L
.39483 .08035 -0.58778 -0.80902 Mabsadd L
.39483 .08035 0 -0.38461 Mabsadd L
.39483 .08035 .58779 -0.80902 Mabsadd L
.39483 .08035 .36579 -0.11885 Mabsadd L
.39483 .08035 .95106 .30902 Mabsadd L
.39483 .08035 .22607 .31116 Mabsadd L
.39483 .08035 0 1 Mabsadd L closepath F
.39852 .08024 0 1 Mabsadd m
.39852 .08024 -0.22607 .31116 Mabsadd L
.39852 .08024 -0.95106 .30902 Mabsadd L
.39852 .08024 -0.36579 -0.11885 Mabsadd L
.39852 .08024 -0.58778 -0.80902 Mabsadd L
.39852 .08024 0 -0.38461 Mabsadd L
.39852 .08024 .58779 -0.80902 Mabsadd L
.39852 .08024 .36579 -0.11885 Mabsadd L
.39852 .08024 .95106 .30902 Mabsadd L
.39852 .08024 .22607 .31116 Mabsadd L
.39852 .08024 0 1 Mabsadd L closepath F
.40221 .08032 0 1 Mabsadd m
.40221 .08032 -0.22607 .31116 Mabsadd L
.40221 .08032 -0.95106 .30902 Mabsadd L
.40221 .08032 -0.36579 -0.11885 Mabsadd L
.40221 .08032 -0.58778 -0.80902 Mabsadd L
.40221 .08032 0 -0.38461 Mabsadd L
.40221 .08032 .58779 -0.80902 Mabsadd L
.40221 .08032 .36579 -0.11885 Mabsadd L
.40221 .08032 .95106 .30902 Mabsadd L
.40221 .08032 .22607 .31116 Mabsadd L
.40221 .08032 0 1 Mabsadd L closepath F
.4059 .08033 0 1 Mabsadd m
.4059 .08033 -0.22607 .31116 Mabsadd L
.4059 .08033 -0.95106 .30902 Mabsadd L
.4059 .08033 -0.36579 -0.11885 Mabsadd L
.4059 .08033 -0.58778 -0.80902 Mabsadd L
.4059 .08033 0 -0.38461 Mabsadd L
.4059 .08033 .58779 -0.80902 Mabsadd L
.4059 .08033 .36579 -0.11885 Mabsadd L
.4059 .08033 .95106 .30902 Mabsadd L
.4059 .08033 .22607 .31116 Mabsadd L
.4059 .08033 0 1 Mabsadd L closepath F
.40959 .08037 0 1 Mabsadd m
.40959 .08037 -0.22607 .31116 Mabsadd L
.40959 .08037 -0.95106 .30902 Mabsadd L
.40959 .08037 -0.36579 -0.11885 Mabsadd L
.40959 .08037 -0.58778 -0.80902 Mabsadd L
.40959 .08037 0 -0.38461 Mabsadd L
.40959 .08037 .58779 -0.80902 Mabsadd L
.40959 .08037 .36579 -0.11885 Mabsadd L
.40959 .08037 .95106 .30902 Mabsadd L
.40959 .08037 .22607 .31116 Mabsadd L
.40959 .08037 0 1 Mabsadd L closepath F
.41328 .08023 0 1 Mabsadd m
.41328 .08023 -0.22607 .31116 Mabsadd L
.41328 .08023 -0.95106 .30902 Mabsadd L
.41328 .08023 -0.36579 -0.11885 Mabsadd L
.41328 .08023 -0.58778 -0.80902 Mabsadd L
.41328 .08023 0 -0.38461 Mabsadd L
.41328 .08023 .58779 -0.80902 Mabsadd L
.41328 .08023 .36579 -0.11885 Mabsadd L
.41328 .08023 .95106 .30902 Mabsadd L
.41328 .08023 .22607 .31116 Mabsadd L
.41328 .08023 0 1 Mabsadd L closepath F
.41697 .08031 0 1 Mabsadd m
.41697 .08031 -0.22607 .31116 Mabsadd L
.41697 .08031 -0.95106 .30902 Mabsadd L
.41697 .08031 -0.36579 -0.11885 Mabsadd L
.41697 .08031 -0.58778 -0.80902 Mabsadd L
.41697 .08031 0 -0.38461 Mabsadd L
.41697 .08031 .58779 -0.80902 Mabsadd L
.41697 .08031 .36579 -0.11885 Mabsadd L
.41697 .08031 .95106 .30902 Mabsadd L
.41697 .08031 .22607 .31116 Mabsadd L
.41697 .08031 0 1 Mabsadd L closepath F
.42066 .08032 0 1 Mabsadd m
.42066 .08032 -0.22607 .31116 Mabsadd L
.42066 .08032 -0.95106 .30902 Mabsadd L
.42066 .08032 -0.36579 -0.11885 Mabsadd L
.42066 .08032 -0.58778 -0.80902 Mabsadd L
.42066 .08032 0 -0.38461 Mabsadd L
.42066 .08032 .58779 -0.80902 Mabsadd L
.42066 .08032 .36579 -0.11885 Mabsadd L
.42066 .08032 .95106 .30902 Mabsadd L
.42066 .08032 .22607 .31116 Mabsadd L
.42066 .08032 0 1 Mabsadd L closepath F
.42435 .08049 0 1 Mabsadd m
.42435 .08049 -0.22607 .31116 Mabsadd L
.42435 .08049 -0.95106 .30902 Mabsadd L
.42435 .08049 -0.36579 -0.11885 Mabsadd L
.42435 .08049 -0.58778 -0.80902 Mabsadd L
.42435 .08049 0 -0.38461 Mabsadd L
.42435 .08049 .58779 -0.80902 Mabsadd L
.42435 .08049 .36579 -0.11885 Mabsadd L
.42435 .08049 .95106 .30902 Mabsadd L
.42435 .08049 .22607 .31116 Mabsadd L
.42435 .08049 0 1 Mabsadd L closepath F
.42804 .08031 0 1 Mabsadd m
.42804 .08031 -0.22607 .31116 Mabsadd L
.42804 .08031 -0.95106 .30902 Mabsadd L
.42804 .08031 -0.36579 -0.11885 Mabsadd L
.42804 .08031 -0.58778 -0.80902 Mabsadd L
.42804 .08031 0 -0.38461 Mabsadd L
.42804 .08031 .58779 -0.80902 Mabsadd L
.42804 .08031 .36579 -0.11885 Mabsadd L
.42804 .08031 .95106 .30902 Mabsadd L
.42804 .08031 .22607 .31116 Mabsadd L
.42804 .08031 0 1 Mabsadd L closepath F
.43173 .08041 0 1 Mabsadd m
.43173 .08041 -0.22607 .31116 Mabsadd L
.43173 .08041 -0.95106 .30902 Mabsadd L
.43173 .08041 -0.36579 -0.11885 Mabsadd L
.43173 .08041 -0.58778 -0.80902 Mabsadd L
.43173 .08041 0 -0.38461 Mabsadd L
.43173 .08041 .58779 -0.80902 Mabsadd L
.43173 .08041 .36579 -0.11885 Mabsadd L
.43173 .08041 .95106 .30902 Mabsadd L
.43173 .08041 .22607 .31116 Mabsadd L
.43173 .08041 0 1 Mabsadd L closepath F
.43542 .08017 0 1 Mabsadd m
.43542 .08017 -0.22607 .31116 Mabsadd L
.43542 .08017 -0.95106 .30902 Mabsadd L
.43542 .08017 -0.36579 -0.11885 Mabsadd L
.43542 .08017 -0.58778 -0.80902 Mabsadd L
.43542 .08017 0 -0.38461 Mabsadd L
.43542 .08017 .58779 -0.80902 Mabsadd L
.43542 .08017 .36579 -0.11885 Mabsadd L
.43542 .08017 .95106 .30902 Mabsadd L
.43542 .08017 .22607 .31116 Mabsadd L
.43542 .08017 0 1 Mabsadd L closepath F
.43911 .08033 0 1 Mabsadd m
.43911 .08033 -0.22607 .31116 Mabsadd L
.43911 .08033 -0.95106 .30902 Mabsadd L
.43911 .08033 -0.36579 -0.11885 Mabsadd L
.43911 .08033 -0.58778 -0.80902 Mabsadd L
.43911 .08033 0 -0.38461 Mabsadd L
.43911 .08033 .58779 -0.80902 Mabsadd L
.43911 .08033 .36579 -0.11885 Mabsadd L
.43911 .08033 .95106 .30902 Mabsadd L
.43911 .08033 .22607 .31116 Mabsadd L
.43911 .08033 0 1 Mabsadd L closepath F
.4428 .08052 0 1 Mabsadd m
.4428 .08052 -0.22607 .31116 Mabsadd L
.4428 .08052 -0.95106 .30902 Mabsadd L
.4428 .08052 -0.36579 -0.11885 Mabsadd L
.4428 .08052 -0.58778 -0.80902 Mabsadd L
.4428 .08052 0 -0.38461 Mabsadd L
.4428 .08052 .58779 -0.80902 Mabsadd L
.4428 .08052 .36579 -0.11885 Mabsadd L
.4428 .08052 .95106 .30902 Mabsadd L
.4428 .08052 .22607 .31116 Mabsadd L
.4428 .08052 0 1 Mabsadd L closepath F
.44649 .08035 0 1 Mabsadd m
.44649 .08035 -0.22607 .31116 Mabsadd L
.44649 .08035 -0.95106 .30902 Mabsadd L
.44649 .08035 -0.36579 -0.11885 Mabsadd L
.44649 .08035 -0.58778 -0.80902 Mabsadd L
.44649 .08035 0 -0.38461 Mabsadd L
.44649 .08035 .58779 -0.80902 Mabsadd L
.44649 .08035 .36579 -0.11885 Mabsadd L
.44649 .08035 .95106 .30902 Mabsadd L
.44649 .08035 .22607 .31116 Mabsadd L
.44649 .08035 0 1 Mabsadd L closepath F
.45018 .08035 0 1 Mabsadd m
.45018 .08035 -0.22607 .31116 Mabsadd L
.45018 .08035 -0.95106 .30902 Mabsadd L
.45018 .08035 -0.36579 -0.11885 Mabsadd L
.45018 .08035 -0.58778 -0.80902 Mabsadd L
.45018 .08035 0 -0.38461 Mabsadd L
.45018 .08035 .58779 -0.80902 Mabsadd L
.45018 .08035 .36579 -0.11885 Mabsadd L
.45018 .08035 .95106 .30902 Mabsadd L
.45018 .08035 .22607 .31116 Mabsadd L
.45018 .08035 0 1 Mabsadd L closepath F
.45387 .08036 0 1 Mabsadd m
.45387 .08036 -0.22607 .31116 Mabsadd L
.45387 .08036 -0.95106 .30902 Mabsadd L
.45387 .08036 -0.36579 -0.11885 Mabsadd L
.45387 .08036 -0.58778 -0.80902 Mabsadd L
.45387 .08036 0 -0.38461 Mabsadd L
.45387 .08036 .58779 -0.80902 Mabsadd L
.45387 .08036 .36579 -0.11885 Mabsadd L
.45387 .08036 .95106 .30902 Mabsadd L
.45387 .08036 .22607 .31116 Mabsadd L
.45387 .08036 0 1 Mabsadd L closepath F
.45756 .08043 0 1 Mabsadd m
.45756 .08043 -0.22607 .31116 Mabsadd L
.45756 .08043 -0.95106 .30902 Mabsadd L
.45756 .08043 -0.36579 -0.11885 Mabsadd L
.45756 .08043 -0.58778 -0.80902 Mabsadd L
.45756 .08043 0 -0.38461 Mabsadd L
.45756 .08043 .58779 -0.80902 Mabsadd L
.45756 .08043 .36579 -0.11885 Mabsadd L
.45756 .08043 .95106 .30902 Mabsadd L
.45756 .08043 .22607 .31116 Mabsadd L
.45756 .08043 0 1 Mabsadd L closepath F
.46125 .08032 0 1 Mabsadd m
.46125 .08032 -0.22607 .31116 Mabsadd L
.46125 .08032 -0.95106 .30902 Mabsadd L
.46125 .08032 -0.36579 -0.11885 Mabsadd L
.46125 .08032 -0.58778 -0.80902 Mabsadd L
.46125 .08032 0 -0.38461 Mabsadd L
.46125 .08032 .58779 -0.80902 Mabsadd L
.46125 .08032 .36579 -0.11885 Mabsadd L
.46125 .08032 .95106 .30902 Mabsadd L
.46125 .08032 .22607 .31116 Mabsadd L
.46125 .08032 0 1 Mabsadd L closepath F
.46494 .08031 0 1 Mabsadd m
.46494 .08031 -0.22607 .31116 Mabsadd L
.46494 .08031 -0.95106 .30902 Mabsadd L
.46494 .08031 -0.36579 -0.11885 Mabsadd L
.46494 .08031 -0.58778 -0.80902 Mabsadd L
.46494 .08031 0 -0.38461 Mabsadd L
.46494 .08031 .58779 -0.80902 Mabsadd L
.46494 .08031 .36579 -0.11885 Mabsadd L
.46494 .08031 .95106 .30902 Mabsadd L
.46494 .08031 .22607 .31116 Mabsadd L
.46494 .08031 0 1 Mabsadd L closepath F
.46863 .08044 0 1 Mabsadd m
.46863 .08044 -0.22607 .31116 Mabsadd L
.46863 .08044 -0.95106 .30902 Mabsadd L
.46863 .08044 -0.36579 -0.11885 Mabsadd L
.46863 .08044 -0.58778 -0.80902 Mabsadd L
.46863 .08044 0 -0.38461 Mabsadd L
.46863 .08044 .58779 -0.80902 Mabsadd L
.46863 .08044 .36579 -0.11885 Mabsadd L
.46863 .08044 .95106 .30902 Mabsadd L
.46863 .08044 .22607 .31116 Mabsadd L
.46863 .08044 0 1 Mabsadd L closepath F
.47232 .08027 0 1 Mabsadd m
.47232 .08027 -0.22607 .31116 Mabsadd L
.47232 .08027 -0.95106 .30902 Mabsadd L
.47232 .08027 -0.36579 -0.11885 Mabsadd L
.47232 .08027 -0.58778 -0.80902 Mabsadd L
.47232 .08027 0 -0.38461 Mabsadd L
.47232 .08027 .58779 -0.80902 Mabsadd L
.47232 .08027 .36579 -0.11885 Mabsadd L
.47232 .08027 .95106 .30902 Mabsadd L
.47232 .08027 .22607 .31116 Mabsadd L
.47232 .08027 0 1 Mabsadd L closepath F
.47601 .08029 0 1 Mabsadd m
.47601 .08029 -0.22607 .31116 Mabsadd L
.47601 .08029 -0.95106 .30902 Mabsadd L
.47601 .08029 -0.36579 -0.11885 Mabsadd L
.47601 .08029 -0.58778 -0.80902 Mabsadd L
.47601 .08029 0 -0.38461 Mabsadd L
.47601 .08029 .58779 -0.80902 Mabsadd L
.47601 .08029 .36579 -0.11885 Mabsadd L
.47601 .08029 .95106 .30902 Mabsadd L
.47601 .08029 .22607 .31116 Mabsadd L
.47601 .08029 0 1 Mabsadd L closepath F
.4797 .08034 0 1 Mabsadd m
.4797 .08034 -0.22607 .31116 Mabsadd L
.4797 .08034 -0.95106 .30902 Mabsadd L
.4797 .08034 -0.36579 -0.11885 Mabsadd L
.4797 .08034 -0.58778 -0.80902 Mabsadd L
.4797 .08034 0 -0.38461 Mabsadd L
.4797 .08034 .58779 -0.80902 Mabsadd L
.4797 .08034 .36579 -0.11885 Mabsadd L
.4797 .08034 .95106 .30902 Mabsadd L
.4797 .08034 .22607 .31116 Mabsadd L
.4797 .08034 0 1 Mabsadd L closepath F
.48339 .08057 0 1 Mabsadd m
.48339 .08057 -0.22607 .31116 Mabsadd L
.48339 .08057 -0.95106 .30902 Mabsadd L
.48339 .08057 -0.36579 -0.11885 Mabsadd L
.48339 .08057 -0.58778 -0.80902 Mabsadd L
.48339 .08057 0 -0.38461 Mabsadd L
.48339 .08057 .58779 -0.80902 Mabsadd L
.48339 .08057 .36579 -0.11885 Mabsadd L
.48339 .08057 .95106 .30902 Mabsadd L
.48339 .08057 .22607 .31116 Mabsadd L
.48339 .08057 0 1 Mabsadd L closepath F
.48708 .08021 0 1 Mabsadd m
.48708 .08021 -0.22607 .31116 Mabsadd L
.48708 .08021 -0.95106 .30902 Mabsadd L
.48708 .08021 -0.36579 -0.11885 Mabsadd L
.48708 .08021 -0.58778 -0.80902 Mabsadd L
.48708 .08021 0 -0.38461 Mabsadd L
.48708 .08021 .58779 -0.80902 Mabsadd L
.48708 .08021 .36579 -0.11885 Mabsadd L
.48708 .08021 .95106 .30902 Mabsadd L
.48708 .08021 .22607 .31116 Mabsadd L
.48708 .08021 0 1 Mabsadd L closepath F
.49077 .08037 0 1 Mabsadd m
.49077 .08037 -0.22607 .31116 Mabsadd L
.49077 .08037 -0.95106 .30902 Mabsadd L
.49077 .08037 -0.36579 -0.11885 Mabsadd L
.49077 .08037 -0.58778 -0.80902 Mabsadd L
.49077 .08037 0 -0.38461 Mabsadd L
.49077 .08037 .58779 -0.80902 Mabsadd L
.49077 .08037 .36579 -0.11885 Mabsadd L
.49077 .08037 .95106 .30902 Mabsadd L
.49077 .08037 .22607 .31116 Mabsadd L
.49077 .08037 0 1 Mabsadd L closepath F
.49446 .08023 0 1 Mabsadd m
.49446 .08023 -0.22607 .31116 Mabsadd L
.49446 .08023 -0.95106 .30902 Mabsadd L
.49446 .08023 -0.36579 -0.11885 Mabsadd L
.49446 .08023 -0.58778 -0.80902 Mabsadd L
.49446 .08023 0 -0.38461 Mabsadd L
.49446 .08023 .58779 -0.80902 Mabsadd L
.49446 .08023 .36579 -0.11885 Mabsadd L
.49446 .08023 .95106 .30902 Mabsadd L
.49446 .08023 .22607 .31116 Mabsadd L
.49446 .08023 0 1 Mabsadd L closepath F
.49815 .08024 0 1 Mabsadd m
.49815 .08024 -0.22607 .31116 Mabsadd L
.49815 .08024 -0.95106 .30902 Mabsadd L
.49815 .08024 -0.36579 -0.11885 Mabsadd L
.49815 .08024 -0.58778 -0.80902 Mabsadd L
.49815 .08024 0 -0.38461 Mabsadd L
.49815 .08024 .58779 -0.80902 Mabsadd L
.49815 .08024 .36579 -0.11885 Mabsadd L
.49815 .08024 .95106 .30902 Mabsadd L
.49815 .08024 .22607 .31116 Mabsadd L
.49815 .08024 0 1 Mabsadd L closepath F
.50185 .08023 0 1 Mabsadd m
.50185 .08023 -0.22607 .31116 Mabsadd L
.50185 .08023 -0.95106 .30902 Mabsadd L
.50185 .08023 -0.36579 -0.11885 Mabsadd L
.50185 .08023 -0.58778 -0.80902 Mabsadd L
.50185 .08023 0 -0.38461 Mabsadd L
.50185 .08023 .58779 -0.80902 Mabsadd L
.50185 .08023 .36579 -0.11885 Mabsadd L
.50185 .08023 .95106 .30902 Mabsadd L
.50185 .08023 .22607 .31116 Mabsadd L
.50185 .08023 0 1 Mabsadd L closepath F
.50554 .08021 0 1 Mabsadd m
.50554 .08021 -0.22607 .31116 Mabsadd L
.50554 .08021 -0.95106 .30902 Mabsadd L
.50554 .08021 -0.36579 -0.11885 Mabsadd L
.50554 .08021 -0.58778 -0.80902 Mabsadd L
.50554 .08021 0 -0.38461 Mabsadd L
.50554 .08021 .58779 -0.80902 Mabsadd L
.50554 .08021 .36579 -0.11885 Mabsadd L
.50554 .08021 .95106 .30902 Mabsadd L
.50554 .08021 .22607 .31116 Mabsadd L
.50554 .08021 0 1 Mabsadd L closepath F
.50923 .08025 0 1 Mabsadd m
.50923 .08025 -0.22607 .31116 Mabsadd L
.50923 .08025 -0.95106 .30902 Mabsadd L
.50923 .08025 -0.36579 -0.11885 Mabsadd L
.50923 .08025 -0.58778 -0.80902 Mabsadd L
.50923 .08025 0 -0.38461 Mabsadd L
.50923 .08025 .58779 -0.80902 Mabsadd L
.50923 .08025 .36579 -0.11885 Mabsadd L
.50923 .08025 .95106 .30902 Mabsadd L
.50923 .08025 .22607 .31116 Mabsadd L
.50923 .08025 0 1 Mabsadd L closepath F
.51292 .08029 0 1 Mabsadd m
.51292 .08029 -0.22607 .31116 Mabsadd L
.51292 .08029 -0.95106 .30902 Mabsadd L
.51292 .08029 -0.36579 -0.11885 Mabsadd L
.51292 .08029 -0.58778 -0.80902 Mabsadd L
.51292 .08029 0 -0.38461 Mabsadd L
.51292 .08029 .58779 -0.80902 Mabsadd L
.51292 .08029 .36579 -0.11885 Mabsadd L
.51292 .08029 .95106 .30902 Mabsadd L
.51292 .08029 .22607 .31116 Mabsadd L
.51292 .08029 0 1 Mabsadd L closepath F
.51661 .08024 0 1 Mabsadd m
.51661 .08024 -0.22607 .31116 Mabsadd L
.51661 .08024 -0.95106 .30902 Mabsadd L
.51661 .08024 -0.36579 -0.11885 Mabsadd L
.51661 .08024 -0.58778 -0.80902 Mabsadd L
.51661 .08024 0 -0.38461 Mabsadd L
.51661 .08024 .58779 -0.80902 Mabsadd L
.51661 .08024 .36579 -0.11885 Mabsadd L
.51661 .08024 .95106 .30902 Mabsadd L
.51661 .08024 .22607 .31116 Mabsadd L
.51661 .08024 0 1 Mabsadd L closepath F
.5203 .08014 0 1 Mabsadd m
.5203 .08014 -0.22607 .31116 Mabsadd L
.5203 .08014 -0.95106 .30902 Mabsadd L
.5203 .08014 -0.36579 -0.11885 Mabsadd L
.5203 .08014 -0.58778 -0.80902 Mabsadd L
.5203 .08014 0 -0.38461 Mabsadd L
.5203 .08014 .58779 -0.80902 Mabsadd L
.5203 .08014 .36579 -0.11885 Mabsadd L
.5203 .08014 .95106 .30902 Mabsadd L
.5203 .08014 .22607 .31116 Mabsadd L
.5203 .08014 0 1 Mabsadd L closepath F
.52399 .08023 0 1 Mabsadd m
.52399 .08023 -0.22607 .31116 Mabsadd L
.52399 .08023 -0.95106 .30902 Mabsadd L
.52399 .08023 -0.36579 -0.11885 Mabsadd L
.52399 .08023 -0.58778 -0.80902 Mabsadd L
.52399 .08023 0 -0.38461 Mabsadd L
.52399 .08023 .58779 -0.80902 Mabsadd L
.52399 .08023 .36579 -0.11885 Mabsadd L
.52399 .08023 .95106 .30902 Mabsadd L
.52399 .08023 .22607 .31116 Mabsadd L
.52399 .08023 0 1 Mabsadd L closepath F
.52768 .08024 0 1 Mabsadd m
.52768 .08024 -0.22607 .31116 Mabsadd L
.52768 .08024 -0.95106 .30902 Mabsadd L
.52768 .08024 -0.36579 -0.11885 Mabsadd L
.52768 .08024 -0.58778 -0.80902 Mabsadd L
.52768 .08024 0 -0.38461 Mabsadd L
.52768 .08024 .58779 -0.80902 Mabsadd L
.52768 .08024 .36579 -0.11885 Mabsadd L
.52768 .08024 .95106 .30902 Mabsadd L
.52768 .08024 .22607 .31116 Mabsadd L
.52768 .08024 0 1 Mabsadd L closepath F
.53137 .0804 0 1 Mabsadd m
.53137 .0804 -0.22607 .31116 Mabsadd L
.53137 .0804 -0.95106 .30902 Mabsadd L
.53137 .0804 -0.36579 -0.11885 Mabsadd L
.53137 .0804 -0.58778 -0.80902 Mabsadd L
.53137 .0804 0 -0.38461 Mabsadd L
.53137 .0804 .58779 -0.80902 Mabsadd L
.53137 .0804 .36579 -0.11885 Mabsadd L
.53137 .0804 .95106 .30902 Mabsadd L
.53137 .0804 .22607 .31116 Mabsadd L
.53137 .0804 0 1 Mabsadd L closepath F
.53506 .08024 0 1 Mabsadd m
.53506 .08024 -0.22607 .31116 Mabsadd L
.53506 .08024 -0.95106 .30902 Mabsadd L
.53506 .08024 -0.36579 -0.11885 Mabsadd L
.53506 .08024 -0.58778 -0.80902 Mabsadd L
.53506 .08024 0 -0.38461 Mabsadd L
.53506 .08024 .58779 -0.80902 Mabsadd L
.53506 .08024 .36579 -0.11885 Mabsadd L
.53506 .08024 .95106 .30902 Mabsadd L
.53506 .08024 .22607 .31116 Mabsadd L
.53506 .08024 0 1 Mabsadd L closepath F
.53875 .0802 0 1 Mabsadd m
.53875 .0802 -0.22607 .31116 Mabsadd L
.53875 .0802 -0.95106 .30902 Mabsadd L
.53875 .0802 -0.36579 -0.11885 Mabsadd L
.53875 .0802 -0.58778 -0.80902 Mabsadd L
.53875 .0802 0 -0.38461 Mabsadd L
.53875 .0802 .58779 -0.80902 Mabsadd L
.53875 .0802 .36579 -0.11885 Mabsadd L
.53875 .0802 .95106 .30902 Mabsadd L
.53875 .0802 .22607 .31116 Mabsadd L
.53875 .0802 0 1 Mabsadd L closepath F
.54244 .08035 0 1 Mabsadd m
.54244 .08035 -0.22607 .31116 Mabsadd L
.54244 .08035 -0.95106 .30902 Mabsadd L
.54244 .08035 -0.36579 -0.11885 Mabsadd L
.54244 .08035 -0.58778 -0.80902 Mabsadd L
.54244 .08035 0 -0.38461 Mabsadd L
.54244 .08035 .58779 -0.80902 Mabsadd L
.54244 .08035 .36579 -0.11885 Mabsadd L
.54244 .08035 .95106 .30902 Mabsadd L
.54244 .08035 .22607 .31116 Mabsadd L
.54244 .08035 0 1 Mabsadd L closepath F
.54613 .08037 0 1 Mabsadd m
.54613 .08037 -0.22607 .31116 Mabsadd L
.54613 .08037 -0.95106 .30902 Mabsadd L
.54613 .08037 -0.36579 -0.11885 Mabsadd L
.54613 .08037 -0.58778 -0.80902 Mabsadd L
.54613 .08037 0 -0.38461 Mabsadd L
.54613 .08037 .58779 -0.80902 Mabsadd L
.54613 .08037 .36579 -0.11885 Mabsadd L
.54613 .08037 .95106 .30902 Mabsadd L
.54613 .08037 .22607 .31116 Mabsadd L
.54613 .08037 0 1 Mabsadd L closepath F
.54982 .08026 0 1 Mabsadd m
.54982 .08026 -0.22607 .31116 Mabsadd L
.54982 .08026 -0.95106 .30902 Mabsadd L
.54982 .08026 -0.36579 -0.11885 Mabsadd L
.54982 .08026 -0.58778 -0.80902 Mabsadd L
.54982 .08026 0 -0.38461 Mabsadd L
.54982 .08026 .58779 -0.80902 Mabsadd L
.54982 .08026 .36579 -0.11885 Mabsadd L
.54982 .08026 .95106 .30902 Mabsadd L
.54982 .08026 .22607 .31116 Mabsadd L
.54982 .08026 0 1 Mabsadd L closepath F
.55351 .08026 0 1 Mabsadd m
.55351 .08026 -0.22607 .31116 Mabsadd L
.55351 .08026 -0.95106 .30902 Mabsadd L
.55351 .08026 -0.36579 -0.11885 Mabsadd L
.55351 .08026 -0.58778 -0.80902 Mabsadd L
.55351 .08026 0 -0.38461 Mabsadd L
.55351 .08026 .58779 -0.80902 Mabsadd L
.55351 .08026 .36579 -0.11885 Mabsadd L
.55351 .08026 .95106 .30902 Mabsadd L
.55351 .08026 .22607 .31116 Mabsadd L
.55351 .08026 0 1 Mabsadd L closepath F
.5572 .08022 0 1 Mabsadd m
.5572 .08022 -0.22607 .31116 Mabsadd L
.5572 .08022 -0.95106 .30902 Mabsadd L
.5572 .08022 -0.36579 -0.11885 Mabsadd L
.5572 .08022 -0.58778 -0.80902 Mabsadd L
.5572 .08022 0 -0.38461 Mabsadd L
.5572 .08022 .58779 -0.80902 Mabsadd L
.5572 .08022 .36579 -0.11885 Mabsadd L
.5572 .08022 .95106 .30902 Mabsadd L
.5572 .08022 .22607 .31116 Mabsadd L
.5572 .08022 0 1 Mabsadd L closepath F
.56089 .08042 0 1 Mabsadd m
.56089 .08042 -0.22607 .31116 Mabsadd L
.56089 .08042 -0.95106 .30902 Mabsadd L
.56089 .08042 -0.36579 -0.11885 Mabsadd L
.56089 .08042 -0.58778 -0.80902 Mabsadd L
.56089 .08042 0 -0.38461 Mabsadd L
.56089 .08042 .58779 -0.80902 Mabsadd L
.56089 .08042 .36579 -0.11885 Mabsadd L
.56089 .08042 .95106 .30902 Mabsadd L
.56089 .08042 .22607 .31116 Mabsadd L
.56089 .08042 0 1 Mabsadd L closepath F
.56458 .08035 0 1 Mabsadd m
.56458 .08035 -0.22607 .31116 Mabsadd L
.56458 .08035 -0.95106 .30902 Mabsadd L
.56458 .08035 -0.36579 -0.11885 Mabsadd L
.56458 .08035 -0.58778 -0.80902 Mabsadd L
.56458 .08035 0 -0.38461 Mabsadd L
.56458 .08035 .58779 -0.80902 Mabsadd L
.56458 .08035 .36579 -0.11885 Mabsadd L
.56458 .08035 .95106 .30902 Mabsadd L
.56458 .08035 .22607 .31116 Mabsadd L
.56458 .08035 0 1 Mabsadd L closepath F
.56827 .08032 0 1 Mabsadd m
.56827 .08032 -0.22607 .31116 Mabsadd L
.56827 .08032 -0.95106 .30902 Mabsadd L
.56827 .08032 -0.36579 -0.11885 Mabsadd L
.56827 .08032 -0.58778 -0.80902 Mabsadd L
.56827 .08032 0 -0.38461 Mabsadd L
.56827 .08032 .58779 -0.80902 Mabsadd L
.56827 .08032 .36579 -0.11885 Mabsadd L
.56827 .08032 .95106 .30902 Mabsadd L
.56827 .08032 .22607 .31116 Mabsadd L
.56827 .08032 0 1 Mabsadd L closepath F
.57196 .08024 0 1 Mabsadd m
.57196 .08024 -0.22607 .31116 Mabsadd L
.57196 .08024 -0.95106 .30902 Mabsadd L
.57196 .08024 -0.36579 -0.11885 Mabsadd L
.57196 .08024 -0.58778 -0.80902 Mabsadd L
.57196 .08024 0 -0.38461 Mabsadd L
.57196 .08024 .58779 -0.80902 Mabsadd L
.57196 .08024 .36579 -0.11885 Mabsadd L
.57196 .08024 .95106 .30902 Mabsadd L
.57196 .08024 .22607 .31116 Mabsadd L
.57196 .08024 0 1 Mabsadd L closepath F
.57565 .08021 0 1 Mabsadd m
.57565 .08021 -0.22607 .31116 Mabsadd L
.57565 .08021 -0.95106 .30902 Mabsadd L
.57565 .08021 -0.36579 -0.11885 Mabsadd L
.57565 .08021 -0.58778 -0.80902 Mabsadd L
.57565 .08021 0 -0.38461 Mabsadd L
.57565 .08021 .58779 -0.80902 Mabsadd L
.57565 .08021 .36579 -0.11885 Mabsadd L
.57565 .08021 .95106 .30902 Mabsadd L
.57565 .08021 .22607 .31116 Mabsadd L
.57565 .08021 0 1 Mabsadd L closepath F
.57934 .08024 0 1 Mabsadd m
.57934 .08024 -0.22607 .31116 Mabsadd L
.57934 .08024 -0.95106 .30902 Mabsadd L
.57934 .08024 -0.36579 -0.11885 Mabsadd L
.57934 .08024 -0.58778 -0.80902 Mabsadd L
.57934 .08024 0 -0.38461 Mabsadd L
.57934 .08024 .58779 -0.80902 Mabsadd L
.57934 .08024 .36579 -0.11885 Mabsadd L
.57934 .08024 .95106 .30902 Mabsadd L
.57934 .08024 .22607 .31116 Mabsadd L
.57934 .08024 0 1 Mabsadd L closepath F
.58303 .08032 0 1 Mabsadd m
.58303 .08032 -0.22607 .31116 Mabsadd L
.58303 .08032 -0.95106 .30902 Mabsadd L
.58303 .08032 -0.36579 -0.11885 Mabsadd L
.58303 .08032 -0.58778 -0.80902 Mabsadd L
.58303 .08032 0 -0.38461 Mabsadd L
.58303 .08032 .58779 -0.80902 Mabsadd L
.58303 .08032 .36579 -0.11885 Mabsadd L
.58303 .08032 .95106 .30902 Mabsadd L
.58303 .08032 .22607 .31116 Mabsadd L
.58303 .08032 0 1 Mabsadd L closepath F
.58672 .08009 0 1 Mabsadd m
.58672 .08009 -0.22607 .31116 Mabsadd L
.58672 .08009 -0.95106 .30902 Mabsadd L
.58672 .08009 -0.36579 -0.11885 Mabsadd L
.58672 .08009 -0.58778 -0.80902 Mabsadd L
.58672 .08009 0 -0.38461 Mabsadd L
.58672 .08009 .58779 -0.80902 Mabsadd L
.58672 .08009 .36579 -0.11885 Mabsadd L
.58672 .08009 .95106 .30902 Mabsadd L
.58672 .08009 .22607 .31116 Mabsadd L
.58672 .08009 0 1 Mabsadd L closepath F
.59041 .08035 0 1 Mabsadd m
.59041 .08035 -0.22607 .31116 Mabsadd L
.59041 .08035 -0.95106 .30902 Mabsadd L
.59041 .08035 -0.36579 -0.11885 Mabsadd L
.59041 .08035 -0.58778 -0.80902 Mabsadd L
.59041 .08035 0 -0.38461 Mabsadd L
.59041 .08035 .58779 -0.80902 Mabsadd L
.59041 .08035 .36579 -0.11885 Mabsadd L
.59041 .08035 .95106 .30902 Mabsadd L
.59041 .08035 .22607 .31116 Mabsadd L
.59041 .08035 0 1 Mabsadd L closepath F
.5941 .08036 0 1 Mabsadd m
.5941 .08036 -0.22607 .31116 Mabsadd L
.5941 .08036 -0.95106 .30902 Mabsadd L
.5941 .08036 -0.36579 -0.11885 Mabsadd L
.5941 .08036 -0.58778 -0.80902 Mabsadd L
.5941 .08036 0 -0.38461 Mabsadd L
.5941 .08036 .58779 -0.80902 Mabsadd L
.5941 .08036 .36579 -0.11885 Mabsadd L
.5941 .08036 .95106 .30902 Mabsadd L
.5941 .08036 .22607 .31116 Mabsadd L
.5941 .08036 0 1 Mabsadd L closepath F
.59779 .08038 0 1 Mabsadd m
.59779 .08038 -0.22607 .31116 Mabsadd L
.59779 .08038 -0.95106 .30902 Mabsadd L
.59779 .08038 -0.36579 -0.11885 Mabsadd L
.59779 .08038 -0.58778 -0.80902 Mabsadd L
.59779 .08038 0 -0.38461 Mabsadd L
.59779 .08038 .58779 -0.80902 Mabsadd L
.59779 .08038 .36579 -0.11885 Mabsadd L
.59779 .08038 .95106 .30902 Mabsadd L
.59779 .08038 .22607 .31116 Mabsadd L
.59779 .08038 0 1 Mabsadd L closepath F
.60148 .08053 0 1 Mabsadd m
.60148 .08053 -0.22607 .31116 Mabsadd L
.60148 .08053 -0.95106 .30902 Mabsadd L
.60148 .08053 -0.36579 -0.11885 Mabsadd L
.60148 .08053 -0.58778 -0.80902 Mabsadd L
.60148 .08053 0 -0.38461 Mabsadd L
.60148 .08053 .58779 -0.80902 Mabsadd L
.60148 .08053 .36579 -0.11885 Mabsadd L
.60148 .08053 .95106 .30902 Mabsadd L
.60148 .08053 .22607 .31116 Mabsadd L
.60148 .08053 0 1 Mabsadd L closepath F
.60517 .0802 0 1 Mabsadd m
.60517 .0802 -0.22607 .31116 Mabsadd L
.60517 .0802 -0.95106 .30902 Mabsadd L
.60517 .0802 -0.36579 -0.11885 Mabsadd L
.60517 .0802 -0.58778 -0.80902 Mabsadd L
.60517 .0802 0 -0.38461 Mabsadd L
.60517 .0802 .58779 -0.80902 Mabsadd L
.60517 .0802 .36579 -0.11885 Mabsadd L
.60517 .0802 .95106 .30902 Mabsadd L
.60517 .0802 .22607 .31116 Mabsadd L
.60517 .0802 0 1 Mabsadd L closepath F
.60886 .08042 0 1 Mabsadd m
.60886 .08042 -0.22607 .31116 Mabsadd L
.60886 .08042 -0.95106 .30902 Mabsadd L
.60886 .08042 -0.36579 -0.11885 Mabsadd L
.60886 .08042 -0.58778 -0.80902 Mabsadd L
.60886 .08042 0 -0.38461 Mabsadd L
.60886 .08042 .58779 -0.80902 Mabsadd L
.60886 .08042 .36579 -0.11885 Mabsadd L
.60886 .08042 .95106 .30902 Mabsadd L
.60886 .08042 .22607 .31116 Mabsadd L
.60886 .08042 0 1 Mabsadd L closepath F
.61255 .08022 0 1 Mabsadd m
.61255 .08022 -0.22607 .31116 Mabsadd L
.61255 .08022 -0.95106 .30902 Mabsadd L
.61255 .08022 -0.36579 -0.11885 Mabsadd L
.61255 .08022 -0.58778 -0.80902 Mabsadd L
.61255 .08022 0 -0.38461 Mabsadd L
.61255 .08022 .58779 -0.80902 Mabsadd L
.61255 .08022 .36579 -0.11885 Mabsadd L
.61255 .08022 .95106 .30902 Mabsadd L
.61255 .08022 .22607 .31116 Mabsadd L
.61255 .08022 0 1 Mabsadd L closepath F
.61624 .08047 0 1 Mabsadd m
.61624 .08047 -0.22607 .31116 Mabsadd L
.61624 .08047 -0.95106 .30902 Mabsadd L
.61624 .08047 -0.36579 -0.11885 Mabsadd L
.61624 .08047 -0.58778 -0.80902 Mabsadd L
.61624 .08047 0 -0.38461 Mabsadd L
.61624 .08047 .58779 -0.80902 Mabsadd L
.61624 .08047 .36579 -0.11885 Mabsadd L
.61624 .08047 .95106 .30902 Mabsadd L
.61624 .08047 .22607 .31116 Mabsadd L
.61624 .08047 0 1 Mabsadd L closepath F
.61993 .08023 0 1 Mabsadd m
.61993 .08023 -0.22607 .31116 Mabsadd L
.61993 .08023 -0.95106 .30902 Mabsadd L
.61993 .08023 -0.36579 -0.11885 Mabsadd L
.61993 .08023 -0.58778 -0.80902 Mabsadd L
.61993 .08023 0 -0.38461 Mabsadd L
.61993 .08023 .58779 -0.80902 Mabsadd L
.61993 .08023 .36579 -0.11885 Mabsadd L
.61993 .08023 .95106 .30902 Mabsadd L
.61993 .08023 .22607 .31116 Mabsadd L
.61993 .08023 0 1 Mabsadd L closepath F
.62362 .08038 0 1 Mabsadd m
.62362 .08038 -0.22607 .31116 Mabsadd L
.62362 .08038 -0.95106 .30902 Mabsadd L
.62362 .08038 -0.36579 -0.11885 Mabsadd L
.62362 .08038 -0.58778 -0.80902 Mabsadd L
.62362 .08038 0 -0.38461 Mabsadd L
.62362 .08038 .58779 -0.80902 Mabsadd L
.62362 .08038 .36579 -0.11885 Mabsadd L
.62362 .08038 .95106 .30902 Mabsadd L
.62362 .08038 .22607 .31116 Mabsadd L
.62362 .08038 0 1 Mabsadd L closepath F
.62731 .08029 0 1 Mabsadd m
.62731 .08029 -0.22607 .31116 Mabsadd L
.62731 .08029 -0.95106 .30902 Mabsadd L
.62731 .08029 -0.36579 -0.11885 Mabsadd L
.62731 .08029 -0.58778 -0.80902 Mabsadd L
.62731 .08029 0 -0.38461 Mabsadd L
.62731 .08029 .58779 -0.80902 Mabsadd L
.62731 .08029 .36579 -0.11885 Mabsadd L
.62731 .08029 .95106 .30902 Mabsadd L
.62731 .08029 .22607 .31116 Mabsadd L
.62731 .08029 0 1 Mabsadd L closepath F
.631 .08029 0 1 Mabsadd m
.631 .08029 -0.22607 .31116 Mabsadd L
.631 .08029 -0.95106 .30902 Mabsadd L
.631 .08029 -0.36579 -0.11885 Mabsadd L
.631 .08029 -0.58778 -0.80902 Mabsadd L
.631 .08029 0 -0.38461 Mabsadd L
.631 .08029 .58779 -0.80902 Mabsadd L
.631 .08029 .36579 -0.11885 Mabsadd L
.631 .08029 .95106 .30902 Mabsadd L
.631 .08029 .22607 .31116 Mabsadd L
.631 .08029 0 1 Mabsadd L closepath F
.63469 .0803 0 1 Mabsadd m
.63469 .0803 -0.22607 .31116 Mabsadd L
.63469 .0803 -0.95106 .30902 Mabsadd L
.63469 .0803 -0.36579 -0.11885 Mabsadd L
.63469 .0803 -0.58778 -0.80902 Mabsadd L
.63469 .0803 0 -0.38461 Mabsadd L
.63469 .0803 .58779 -0.80902 Mabsadd L
.63469 .0803 .36579 -0.11885 Mabsadd L
.63469 .0803 .95106 .30902 Mabsadd L
.63469 .0803 .22607 .31116 Mabsadd L
.63469 .0803 0 1 Mabsadd L closepath F
.63838 .08028 0 1 Mabsadd m
.63838 .08028 -0.22607 .31116 Mabsadd L
.63838 .08028 -0.95106 .30902 Mabsadd L
.63838 .08028 -0.36579 -0.11885 Mabsadd L
.63838 .08028 -0.58778 -0.80902 Mabsadd L
.63838 .08028 0 -0.38461 Mabsadd L
.63838 .08028 .58779 -0.80902 Mabsadd L
.63838 .08028 .36579 -0.11885 Mabsadd L
.63838 .08028 .95106 .30902 Mabsadd L
.63838 .08028 .22607 .31116 Mabsadd L
.63838 .08028 0 1 Mabsadd L closepath F
.64207 .08035 0 1 Mabsadd m
.64207 .08035 -0.22607 .31116 Mabsadd L
.64207 .08035 -0.95106 .30902 Mabsadd L
.64207 .08035 -0.36579 -0.11885 Mabsadd L
.64207 .08035 -0.58778 -0.80902 Mabsadd L
.64207 .08035 0 -0.38461 Mabsadd L
.64207 .08035 .58779 -0.80902 Mabsadd L
.64207 .08035 .36579 -0.11885 Mabsadd L
.64207 .08035 .95106 .30902 Mabsadd L
.64207 .08035 .22607 .31116 Mabsadd L
.64207 .08035 0 1 Mabsadd L closepath F
.64576 .08033 0 1 Mabsadd m
.64576 .08033 -0.22607 .31116 Mabsadd L
.64576 .08033 -0.95106 .30902 Mabsadd L
.64576 .08033 -0.36579 -0.11885 Mabsadd L
.64576 .08033 -0.58778 -0.80902 Mabsadd L
.64576 .08033 0 -0.38461 Mabsadd L
.64576 .08033 .58779 -0.80902 Mabsadd L
.64576 .08033 .36579 -0.11885 Mabsadd L
.64576 .08033 .95106 .30902 Mabsadd L
.64576 .08033 .22607 .31116 Mabsadd L
.64576 .08033 0 1 Mabsadd L closepath F
.64945 .08023 0 1 Mabsadd m
.64945 .08023 -0.22607 .31116 Mabsadd L
.64945 .08023 -0.95106 .30902 Mabsadd L
.64945 .08023 -0.36579 -0.11885 Mabsadd L
.64945 .08023 -0.58778 -0.80902 Mabsadd L
.64945 .08023 0 -0.38461 Mabsadd L
.64945 .08023 .58779 -0.80902 Mabsadd L
.64945 .08023 .36579 -0.11885 Mabsadd L
.64945 .08023 .95106 .30902 Mabsadd L
.64945 .08023 .22607 .31116 Mabsadd L
.64945 .08023 0 1 Mabsadd L closepath F
.65314 .08033 0 1 Mabsadd m
.65314 .08033 -0.22607 .31116 Mabsadd L
.65314 .08033 -0.95106 .30902 Mabsadd L
.65314 .08033 -0.36579 -0.11885 Mabsadd L
.65314 .08033 -0.58778 -0.80902 Mabsadd L
.65314 .08033 0 -0.38461 Mabsadd L
.65314 .08033 .58779 -0.80902 Mabsadd L
.65314 .08033 .36579 -0.11885 Mabsadd L
.65314 .08033 .95106 .30902 Mabsadd L
.65314 .08033 .22607 .31116 Mabsadd L
.65314 .08033 0 1 Mabsadd L closepath F
.65683 .08022 0 1 Mabsadd m
.65683 .08022 -0.22607 .31116 Mabsadd L
.65683 .08022 -0.95106 .30902 Mabsadd L
.65683 .08022 -0.36579 -0.11885 Mabsadd L
.65683 .08022 -0.58778 -0.80902 Mabsadd L
.65683 .08022 0 -0.38461 Mabsadd L
.65683 .08022 .58779 -0.80902 Mabsadd L
.65683 .08022 .36579 -0.11885 Mabsadd L
.65683 .08022 .95106 .30902 Mabsadd L
.65683 .08022 .22607 .31116 Mabsadd L
.65683 .08022 0 1 Mabsadd L closepath F
.66052 .08042 0 1 Mabsadd m
.66052 .08042 -0.22607 .31116 Mabsadd L
.66052 .08042 -0.95106 .30902 Mabsadd L
.66052 .08042 -0.36579 -0.11885 Mabsadd L
.66052 .08042 -0.58778 -0.80902 Mabsadd L
.66052 .08042 0 -0.38461 Mabsadd L
.66052 .08042 .58779 -0.80902 Mabsadd L
.66052 .08042 .36579 -0.11885 Mabsadd L
.66052 .08042 .95106 .30902 Mabsadd L
.66052 .08042 .22607 .31116 Mabsadd L
.66052 .08042 0 1 Mabsadd L closepath F
.66421 .0803 0 1 Mabsadd m
.66421 .0803 -0.22607 .31116 Mabsadd L
.66421 .0803 -0.95106 .30902 Mabsadd L
.66421 .0803 -0.36579 -0.11885 Mabsadd L
.66421 .0803 -0.58778 -0.80902 Mabsadd L
.66421 .0803 0 -0.38461 Mabsadd L
.66421 .0803 .58779 -0.80902 Mabsadd L
.66421 .0803 .36579 -0.11885 Mabsadd L
.66421 .0803 .95106 .30902 Mabsadd L
.66421 .0803 .22607 .31116 Mabsadd L
.66421 .0803 0 1 Mabsadd L closepath F
.6679 .08052 0 1 Mabsadd m
.6679 .08052 -0.22607 .31116 Mabsadd L
.6679 .08052 -0.95106 .30902 Mabsadd L
.6679 .08052 -0.36579 -0.11885 Mabsadd L
.6679 .08052 -0.58778 -0.80902 Mabsadd L
.6679 .08052 0 -0.38461 Mabsadd L
.6679 .08052 .58779 -0.80902 Mabsadd L
.6679 .08052 .36579 -0.11885 Mabsadd L
.6679 .08052 .95106 .30902 Mabsadd L
.6679 .08052 .22607 .31116 Mabsadd L
.6679 .08052 0 1 Mabsadd L closepath F
.67159 .08033 0 1 Mabsadd m
.67159 .08033 -0.22607 .31116 Mabsadd L
.67159 .08033 -0.95106 .30902 Mabsadd L
.67159 .08033 -0.36579 -0.11885 Mabsadd L
.67159 .08033 -0.58778 -0.80902 Mabsadd L
.67159 .08033 0 -0.38461 Mabsadd L
.67159 .08033 .58779 -0.80902 Mabsadd L
.67159 .08033 .36579 -0.11885 Mabsadd L
.67159 .08033 .95106 .30902 Mabsadd L
.67159 .08033 .22607 .31116 Mabsadd L
.67159 .08033 0 1 Mabsadd L closepath F
.67528 .0802 0 1 Mabsadd m
.67528 .0802 -0.22607 .31116 Mabsadd L
.67528 .0802 -0.95106 .30902 Mabsadd L
.67528 .0802 -0.36579 -0.11885 Mabsadd L
.67528 .0802 -0.58778 -0.80902 Mabsadd L
.67528 .0802 0 -0.38461 Mabsadd L
.67528 .0802 .58779 -0.80902 Mabsadd L
.67528 .0802 .36579 -0.11885 Mabsadd L
.67528 .0802 .95106 .30902 Mabsadd L
.67528 .0802 .22607 .31116 Mabsadd L
.67528 .0802 0 1 Mabsadd L closepath F
.67897 .08015 0 1 Mabsadd m
.67897 .08015 -0.22607 .31116 Mabsadd L
.67897 .08015 -0.95106 .30902 Mabsadd L
.67897 .08015 -0.36579 -0.11885 Mabsadd L
.67897 .08015 -0.58778 -0.80902 Mabsadd L
.67897 .08015 0 -0.38461 Mabsadd L
.67897 .08015 .58779 -0.80902 Mabsadd L
.67897 .08015 .36579 -0.11885 Mabsadd L
.67897 .08015 .95106 .30902 Mabsadd L
.67897 .08015 .22607 .31116 Mabsadd L
.67897 .08015 0 1 Mabsadd L closepath F
.68266 .08024 0 1 Mabsadd m
.68266 .08024 -0.22607 .31116 Mabsadd L
.68266 .08024 -0.95106 .30902 Mabsadd L
.68266 .08024 -0.36579 -0.11885 Mabsadd L
.68266 .08024 -0.58778 -0.80902 Mabsadd L
.68266 .08024 0 -0.38461 Mabsadd L
.68266 .08024 .58779 -0.80902 Mabsadd L
.68266 .08024 .36579 -0.11885 Mabsadd L
.68266 .08024 .95106 .30902 Mabsadd L
.68266 .08024 .22607 .31116 Mabsadd L
.68266 .08024 0 1 Mabsadd L closepath F
.68635 .0803 0 1 Mabsadd m
.68635 .0803 -0.22607 .31116 Mabsadd L
.68635 .0803 -0.95106 .30902 Mabsadd L
.68635 .0803 -0.36579 -0.11885 Mabsadd L
.68635 .0803 -0.58778 -0.80902 Mabsadd L
.68635 .0803 0 -0.38461 Mabsadd L
.68635 .0803 .58779 -0.80902 Mabsadd L
.68635 .0803 .36579 -0.11885 Mabsadd L
.68635 .0803 .95106 .30902 Mabsadd L
.68635 .0803 .22607 .31116 Mabsadd L
.68635 .0803 0 1 Mabsadd L closepath F
.69004 .08022 0 1 Mabsadd m
.69004 .08022 -0.22607 .31116 Mabsadd L
.69004 .08022 -0.95106 .30902 Mabsadd L
.69004 .08022 -0.36579 -0.11885 Mabsadd L
.69004 .08022 -0.58778 -0.80902 Mabsadd L
.69004 .08022 0 -0.38461 Mabsadd L
.69004 .08022 .58779 -0.80902 Mabsadd L
.69004 .08022 .36579 -0.11885 Mabsadd L
.69004 .08022 .95106 .30902 Mabsadd L
.69004 .08022 .22607 .31116 Mabsadd L
.69004 .08022 0 1 Mabsadd L closepath F
.69373 .08052 0 1 Mabsadd m
.69373 .08052 -0.22607 .31116 Mabsadd L
.69373 .08052 -0.95106 .30902 Mabsadd L
.69373 .08052 -0.36579 -0.11885 Mabsadd L
.69373 .08052 -0.58778 -0.80902 Mabsadd L
.69373 .08052 0 -0.38461 Mabsadd L
.69373 .08052 .58779 -0.80902 Mabsadd L
.69373 .08052 .36579 -0.11885 Mabsadd L
.69373 .08052 .95106 .30902 Mabsadd L
.69373 .08052 .22607 .31116 Mabsadd L
.69373 .08052 0 1 Mabsadd L closepath F
.69742 .08048 0 1 Mabsadd m
.69742 .08048 -0.22607 .31116 Mabsadd L
.69742 .08048 -0.95106 .30902 Mabsadd L
.69742 .08048 -0.36579 -0.11885 Mabsadd L
.69742 .08048 -0.58778 -0.80902 Mabsadd L
.69742 .08048 0 -0.38461 Mabsadd L
.69742 .08048 .58779 -0.80902 Mabsadd L
.69742 .08048 .36579 -0.11885 Mabsadd L
.69742 .08048 .95106 .30902 Mabsadd L
.69742 .08048 .22607 .31116 Mabsadd L
.69742 .08048 0 1 Mabsadd L closepath F
.70111 .08023 0 1 Mabsadd m
.70111 .08023 -0.22607 .31116 Mabsadd L
.70111 .08023 -0.95106 .30902 Mabsadd L
.70111 .08023 -0.36579 -0.11885 Mabsadd L
.70111 .08023 -0.58778 -0.80902 Mabsadd L
.70111 .08023 0 -0.38461 Mabsadd L
.70111 .08023 .58779 -0.80902 Mabsadd L
.70111 .08023 .36579 -0.11885 Mabsadd L
.70111 .08023 .95106 .30902 Mabsadd L
.70111 .08023 .22607 .31116 Mabsadd L
.70111 .08023 0 1 Mabsadd L closepath F
.7048 .08028 0 1 Mabsadd m
.7048 .08028 -0.22607 .31116 Mabsadd L
.7048 .08028 -0.95106 .30902 Mabsadd L
.7048 .08028 -0.36579 -0.11885 Mabsadd L
.7048 .08028 -0.58778 -0.80902 Mabsadd L
.7048 .08028 0 -0.38461 Mabsadd L
.7048 .08028 .58779 -0.80902 Mabsadd L
.7048 .08028 .36579 -0.11885 Mabsadd L
.7048 .08028 .95106 .30902 Mabsadd L
.7048 .08028 .22607 .31116 Mabsadd L
.7048 .08028 0 1 Mabsadd L closepath F
.70849 .08047 0 1 Mabsadd m
.70849 .08047 -0.22607 .31116 Mabsadd L
.70849 .08047 -0.95106 .30902 Mabsadd L
.70849 .08047 -0.36579 -0.11885 Mabsadd L
.70849 .08047 -0.58778 -0.80902 Mabsadd L
.70849 .08047 0 -0.38461 Mabsadd L
.70849 .08047 .58779 -0.80902 Mabsadd L
.70849 .08047 .36579 -0.11885 Mabsadd L
.70849 .08047 .95106 .30902 Mabsadd L
.70849 .08047 .22607 .31116 Mabsadd L
.70849 .08047 0 1 Mabsadd L closepath F
.71218 .08026 0 1 Mabsadd m
.71218 .08026 -0.22607 .31116 Mabsadd L
.71218 .08026 -0.95106 .30902 Mabsadd L
.71218 .08026 -0.36579 -0.11885 Mabsadd L
.71218 .08026 -0.58778 -0.80902 Mabsadd L
.71218 .08026 0 -0.38461 Mabsadd L
.71218 .08026 .58779 -0.80902 Mabsadd L
.71218 .08026 .36579 -0.11885 Mabsadd L
.71218 .08026 .95106 .30902 Mabsadd L
.71218 .08026 .22607 .31116 Mabsadd L
.71218 .08026 0 1 Mabsadd L closepath F
.71587 .08031 0 1 Mabsadd m
.71587 .08031 -0.22607 .31116 Mabsadd L
.71587 .08031 -0.95106 .30902 Mabsadd L
.71587 .08031 -0.36579 -0.11885 Mabsadd L
.71587 .08031 -0.58778 -0.80902 Mabsadd L
.71587 .08031 0 -0.38461 Mabsadd L
.71587 .08031 .58779 -0.80902 Mabsadd L
.71587 .08031 .36579 -0.11885 Mabsadd L
.71587 .08031 .95106 .30902 Mabsadd L
.71587 .08031 .22607 .31116 Mabsadd L
.71587 .08031 0 1 Mabsadd L closepath F
.71956 .08044 0 1 Mabsadd m
.71956 .08044 -0.22607 .31116 Mabsadd L
.71956 .08044 -0.95106 .30902 Mabsadd L
.71956 .08044 -0.36579 -0.11885 Mabsadd L
.71956 .08044 -0.58778 -0.80902 Mabsadd L
.71956 .08044 0 -0.38461 Mabsadd L
.71956 .08044 .58779 -0.80902 Mabsadd L
.71956 .08044 .36579 -0.11885 Mabsadd L
.71956 .08044 .95106 .30902 Mabsadd L
.71956 .08044 .22607 .31116 Mabsadd L
.71956 .08044 0 1 Mabsadd L closepath F
.72325 .0804 0 1 Mabsadd m
.72325 .0804 -0.22607 .31116 Mabsadd L
.72325 .0804 -0.95106 .30902 Mabsadd L
.72325 .0804 -0.36579 -0.11885 Mabsadd L
.72325 .0804 -0.58778 -0.80902 Mabsadd L
.72325 .0804 0 -0.38461 Mabsadd L
.72325 .0804 .58779 -0.80902 Mabsadd L
.72325 .0804 .36579 -0.11885 Mabsadd L
.72325 .0804 .95106 .30902 Mabsadd L
.72325 .0804 .22607 .31116 Mabsadd L
.72325 .0804 0 1 Mabsadd L closepath F
.72694 .08039 0 1 Mabsadd m
.72694 .08039 -0.22607 .31116 Mabsadd L
.72694 .08039 -0.95106 .30902 Mabsadd L
.72694 .08039 -0.36579 -0.11885 Mabsadd L
.72694 .08039 -0.58778 -0.80902 Mabsadd L
.72694 .08039 0 -0.38461 Mabsadd L
.72694 .08039 .58779 -0.80902 Mabsadd L
.72694 .08039 .36579 -0.11885 Mabsadd L
.72694 .08039 .95106 .30902 Mabsadd L
.72694 .08039 .22607 .31116 Mabsadd L
.72694 .08039 0 1 Mabsadd L closepath F
.73063 .08032 0 1 Mabsadd m
.73063 .08032 -0.22607 .31116 Mabsadd L
.73063 .08032 -0.95106 .30902 Mabsadd L
.73063 .08032 -0.36579 -0.11885 Mabsadd L
.73063 .08032 -0.58778 -0.80902 Mabsadd L
.73063 .08032 0 -0.38461 Mabsadd L
.73063 .08032 .58779 -0.80902 Mabsadd L
.73063 .08032 .36579 -0.11885 Mabsadd L
.73063 .08032 .95106 .30902 Mabsadd L
.73063 .08032 .22607 .31116 Mabsadd L
.73063 .08032 0 1 Mabsadd L closepath F
.73432 .08035 0 1 Mabsadd m
.73432 .08035 -0.22607 .31116 Mabsadd L
.73432 .08035 -0.95106 .30902 Mabsadd L
.73432 .08035 -0.36579 -0.11885 Mabsadd L
.73432 .08035 -0.58778 -0.80902 Mabsadd L
.73432 .08035 0 -0.38461 Mabsadd L
.73432 .08035 .58779 -0.80902 Mabsadd L
.73432 .08035 .36579 -0.11885 Mabsadd L
.73432 .08035 .95106 .30902 Mabsadd L
.73432 .08035 .22607 .31116 Mabsadd L
.73432 .08035 0 1 Mabsadd L closepath F
.73801 .0804 0 1 Mabsadd m
.73801 .0804 -0.22607 .31116 Mabsadd L
.73801 .0804 -0.95106 .30902 Mabsadd L
.73801 .0804 -0.36579 -0.11885 Mabsadd L
.73801 .0804 -0.58778 -0.80902 Mabsadd L
.73801 .0804 0 -0.38461 Mabsadd L
.73801 .0804 .58779 -0.80902 Mabsadd L
.73801 .0804 .36579 -0.11885 Mabsadd L
.73801 .0804 .95106 .30902 Mabsadd L
.73801 .0804 .22607 .31116 Mabsadd L
.73801 .0804 0 1 Mabsadd L closepath F
.7417 .08023 0 1 Mabsadd m
.7417 .08023 -0.22607 .31116 Mabsadd L
.7417 .08023 -0.95106 .30902 Mabsadd L
.7417 .08023 -0.36579 -0.11885 Mabsadd L
.7417 .08023 -0.58778 -0.80902 Mabsadd L
.7417 .08023 0 -0.38461 Mabsadd L
.7417 .08023 .58779 -0.80902 Mabsadd L
.7417 .08023 .36579 -0.11885 Mabsadd L
.7417 .08023 .95106 .30902 Mabsadd L
.7417 .08023 .22607 .31116 Mabsadd L
.7417 .08023 0 1 Mabsadd L closepath F
.74539 .08034 0 1 Mabsadd m
.74539 .08034 -0.22607 .31116 Mabsadd L
.74539 .08034 -0.95106 .30902 Mabsadd L
.74539 .08034 -0.36579 -0.11885 Mabsadd L
.74539 .08034 -0.58778 -0.80902 Mabsadd L
.74539 .08034 0 -0.38461 Mabsadd L
.74539 .08034 .58779 -0.80902 Mabsadd L
.74539 .08034 .36579 -0.11885 Mabsadd L
.74539 .08034 .95106 .30902 Mabsadd L
.74539 .08034 .22607 .31116 Mabsadd L
.74539 .08034 0 1 Mabsadd L closepath F
.74908 .08027 0 1 Mabsadd m
.74908 .08027 -0.22607 .31116 Mabsadd L
.74908 .08027 -0.95106 .30902 Mabsadd L
.74908 .08027 -0.36579 -0.11885 Mabsadd L
.74908 .08027 -0.58778 -0.80902 Mabsadd L
.74908 .08027 0 -0.38461 Mabsadd L
.74908 .08027 .58779 -0.80902 Mabsadd L
.74908 .08027 .36579 -0.11885 Mabsadd L
.74908 .08027 .95106 .30902 Mabsadd L
.74908 .08027 .22607 .31116 Mabsadd L
.74908 .08027 0 1 Mabsadd L closepath F
.75277 .08047 0 1 Mabsadd m
.75277 .08047 -0.22607 .31116 Mabsadd L
.75277 .08047 -0.95106 .30902 Mabsadd L
.75277 .08047 -0.36579 -0.11885 Mabsadd L
.75277 .08047 -0.58778 -0.80902 Mabsadd L
.75277 .08047 0 -0.38461 Mabsadd L
.75277 .08047 .58779 -0.80902 Mabsadd L
.75277 .08047 .36579 -0.11885 Mabsadd L
.75277 .08047 .95106 .30902 Mabsadd L
.75277 .08047 .22607 .31116 Mabsadd L
.75277 .08047 0 1 Mabsadd L closepath F
.75646 .08022 0 1 Mabsadd m
.75646 .08022 -0.22607 .31116 Mabsadd L
.75646 .08022 -0.95106 .30902 Mabsadd L
.75646 .08022 -0.36579 -0.11885 Mabsadd L
.75646 .08022 -0.58778 -0.80902 Mabsadd L
.75646 .08022 0 -0.38461 Mabsadd L
.75646 .08022 .58779 -0.80902 Mabsadd L
.75646 .08022 .36579 -0.11885 Mabsadd L
.75646 .08022 .95106 .30902 Mabsadd L
.75646 .08022 .22607 .31116 Mabsadd L
.75646 .08022 0 1 Mabsadd L closepath F
.76015 .0804 0 1 Mabsadd m
.76015 .0804 -0.22607 .31116 Mabsadd L
.76015 .0804 -0.95106 .30902 Mabsadd L
.76015 .0804 -0.36579 -0.11885 Mabsadd L
.76015 .0804 -0.58778 -0.80902 Mabsadd L
.76015 .0804 0 -0.38461 Mabsadd L
.76015 .0804 .58779 -0.80902 Mabsadd L
.76015 .0804 .36579 -0.11885 Mabsadd L
.76015 .0804 .95106 .30902 Mabsadd L
.76015 .0804 .22607 .31116 Mabsadd L
.76015 .0804 0 1 Mabsadd L closepath F
.76384 .08033 0 1 Mabsadd m
.76384 .08033 -0.22607 .31116 Mabsadd L
.76384 .08033 -0.95106 .30902 Mabsadd L
.76384 .08033 -0.36579 -0.11885 Mabsadd L
.76384 .08033 -0.58778 -0.80902 Mabsadd L
.76384 .08033 0 -0.38461 Mabsadd L
.76384 .08033 .58779 -0.80902 Mabsadd L
.76384 .08033 .36579 -0.11885 Mabsadd L
.76384 .08033 .95106 .30902 Mabsadd L
.76384 .08033 .22607 .31116 Mabsadd L
.76384 .08033 0 1 Mabsadd L closepath F
.76753 .08046 0 1 Mabsadd m
.76753 .08046 -0.22607 .31116 Mabsadd L
.76753 .08046 -0.95106 .30902 Mabsadd L
.76753 .08046 -0.36579 -0.11885 Mabsadd L
.76753 .08046 -0.58778 -0.80902 Mabsadd L
.76753 .08046 0 -0.38461 Mabsadd L
.76753 .08046 .58779 -0.80902 Mabsadd L
.76753 .08046 .36579 -0.11885 Mabsadd L
.76753 .08046 .95106 .30902 Mabsadd L
.76753 .08046 .22607 .31116 Mabsadd L
.76753 .08046 0 1 Mabsadd L closepath F
.77122 .08022 0 1 Mabsadd m
.77122 .08022 -0.22607 .31116 Mabsadd L
.77122 .08022 -0.95106 .30902 Mabsadd L
.77122 .08022 -0.36579 -0.11885 Mabsadd L
.77122 .08022 -0.58778 -0.80902 Mabsadd L
.77122 .08022 0 -0.38461 Mabsadd L
.77122 .08022 .58779 -0.80902 Mabsadd L
.77122 .08022 .36579 -0.11885 Mabsadd L
.77122 .08022 .95106 .30902 Mabsadd L
.77122 .08022 .22607 .31116 Mabsadd L
.77122 .08022 0 1 Mabsadd L closepath F
.77491 .0802 0 1 Mabsadd m
.77491 .0802 -0.22607 .31116 Mabsadd L
.77491 .0802 -0.95106 .30902 Mabsadd L
.77491 .0802 -0.36579 -0.11885 Mabsadd L
.77491 .0802 -0.58778 -0.80902 Mabsadd L
.77491 .0802 0 -0.38461 Mabsadd L
.77491 .0802 .58779 -0.80902 Mabsadd L
.77491 .0802 .36579 -0.11885 Mabsadd L
.77491 .0802 .95106 .30902 Mabsadd L
.77491 .0802 .22607 .31116 Mabsadd L
.77491 .0802 0 1 Mabsadd L closepath F
.7786 .08023 0 1 Mabsadd m
.7786 .08023 -0.22607 .31116 Mabsadd L
.7786 .08023 -0.95106 .30902 Mabsadd L
.7786 .08023 -0.36579 -0.11885 Mabsadd L
.7786 .08023 -0.58778 -0.80902 Mabsadd L
.7786 .08023 0 -0.38461 Mabsadd L
.7786 .08023 .58779 -0.80902 Mabsadd L
.7786 .08023 .36579 -0.11885 Mabsadd L
.7786 .08023 .95106 .30902 Mabsadd L
.7786 .08023 .22607 .31116 Mabsadd L
.7786 .08023 0 1 Mabsadd L closepath F
.78229 .08029 0 1 Mabsadd m
.78229 .08029 -0.22607 .31116 Mabsadd L
.78229 .08029 -0.95106 .30902 Mabsadd L
.78229 .08029 -0.36579 -0.11885 Mabsadd L
.78229 .08029 -0.58778 -0.80902 Mabsadd L
.78229 .08029 0 -0.38461 Mabsadd L
.78229 .08029 .58779 -0.80902 Mabsadd L
.78229 .08029 .36579 -0.11885 Mabsadd L
.78229 .08029 .95106 .30902 Mabsadd L
.78229 .08029 .22607 .31116 Mabsadd L
.78229 .08029 0 1 Mabsadd L closepath F
.78598 .08034 0 1 Mabsadd m
.78598 .08034 -0.22607 .31116 Mabsadd L
.78598 .08034 -0.95106 .30902 Mabsadd L
.78598 .08034 -0.36579 -0.11885 Mabsadd L
.78598 .08034 -0.58778 -0.80902 Mabsadd L
.78598 .08034 0 -0.38461 Mabsadd L
.78598 .08034 .58779 -0.80902 Mabsadd L
.78598 .08034 .36579 -0.11885 Mabsadd L
.78598 .08034 .95106 .30902 Mabsadd L
.78598 .08034 .22607 .31116 Mabsadd L
.78598 .08034 0 1 Mabsadd L closepath F
.78967 .08035 0 1 Mabsadd m
.78967 .08035 -0.22607 .31116 Mabsadd L
.78967 .08035 -0.95106 .30902 Mabsadd L
.78967 .08035 -0.36579 -0.11885 Mabsadd L
.78967 .08035 -0.58778 -0.80902 Mabsadd L
.78967 .08035 0 -0.38461 Mabsadd L
.78967 .08035 .58779 -0.80902 Mabsadd L
.78967 .08035 .36579 -0.11885 Mabsadd L
.78967 .08035 .95106 .30902 Mabsadd L
.78967 .08035 .22607 .31116 Mabsadd L
.78967 .08035 0 1 Mabsadd L closepath F
.79336 .08046 0 1 Mabsadd m
.79336 .08046 -0.22607 .31116 Mabsadd L
.79336 .08046 -0.95106 .30902 Mabsadd L
.79336 .08046 -0.36579 -0.11885 Mabsadd L
.79336 .08046 -0.58778 -0.80902 Mabsadd L
.79336 .08046 0 -0.38461 Mabsadd L
.79336 .08046 .58779 -0.80902 Mabsadd L
.79336 .08046 .36579 -0.11885 Mabsadd L
.79336 .08046 .95106 .30902 Mabsadd L
.79336 .08046 .22607 .31116 Mabsadd L
.79336 .08046 0 1 Mabsadd L closepath F
.79705 .08043 0 1 Mabsadd m
.79705 .08043 -0.22607 .31116 Mabsadd L
.79705 .08043 -0.95106 .30902 Mabsadd L
.79705 .08043 -0.36579 -0.11885 Mabsadd L
.79705 .08043 -0.58778 -0.80902 Mabsadd L
.79705 .08043 0 -0.38461 Mabsadd L
.79705 .08043 .58779 -0.80902 Mabsadd L
.79705 .08043 .36579 -0.11885 Mabsadd L
.79705 .08043 .95106 .30902 Mabsadd L
.79705 .08043 .22607 .31116 Mabsadd L
.79705 .08043 0 1 Mabsadd L closepath F
.80074 .08035 0 1 Mabsadd m
.80074 .08035 -0.22607 .31116 Mabsadd L
.80074 .08035 -0.95106 .30902 Mabsadd L
.80074 .08035 -0.36579 -0.11885 Mabsadd L
.80074 .08035 -0.58778 -0.80902 Mabsadd L
.80074 .08035 0 -0.38461 Mabsadd L
.80074 .08035 .58779 -0.80902 Mabsadd L
.80074 .08035 .36579 -0.11885 Mabsadd L
.80074 .08035 .95106 .30902 Mabsadd L
.80074 .08035 .22607 .31116 Mabsadd L
.80074 .08035 0 1 Mabsadd L closepath F
.80443 .08025 0 1 Mabsadd m
.80443 .08025 -0.22607 .31116 Mabsadd L
.80443 .08025 -0.95106 .30902 Mabsadd L
.80443 .08025 -0.36579 -0.11885 Mabsadd L
.80443 .08025 -0.58778 -0.80902 Mabsadd L
.80443 .08025 0 -0.38461 Mabsadd L
.80443 .08025 .58779 -0.80902 Mabsadd L
.80443 .08025 .36579 -0.11885 Mabsadd L
.80443 .08025 .95106 .30902 Mabsadd L
.80443 .08025 .22607 .31116 Mabsadd L
.80443 .08025 0 1 Mabsadd L closepath F
.80812 .08044 0 1 Mabsadd m
.80812 .08044 -0.22607 .31116 Mabsadd L
.80812 .08044 -0.95106 .30902 Mabsadd L
.80812 .08044 -0.36579 -0.11885 Mabsadd L
.80812 .08044 -0.58778 -0.80902 Mabsadd L
.80812 .08044 0 -0.38461 Mabsadd L
.80812 .08044 .58779 -0.80902 Mabsadd L
.80812 .08044 .36579 -0.11885 Mabsadd L
.80812 .08044 .95106 .30902 Mabsadd L
.80812 .08044 .22607 .31116 Mabsadd L
.80812 .08044 0 1 Mabsadd L closepath F
.81181 .08027 0 1 Mabsadd m
.81181 .08027 -0.22607 .31116 Mabsadd L
.81181 .08027 -0.95106 .30902 Mabsadd L
.81181 .08027 -0.36579 -0.11885 Mabsadd L
.81181 .08027 -0.58778 -0.80902 Mabsadd L
.81181 .08027 0 -0.38461 Mabsadd L
.81181 .08027 .58779 -0.80902 Mabsadd L
.81181 .08027 .36579 -0.11885 Mabsadd L
.81181 .08027 .95106 .30902 Mabsadd L
.81181 .08027 .22607 .31116 Mabsadd L
.81181 .08027 0 1 Mabsadd L closepath F
.8155 .08033 0 1 Mabsadd m
.8155 .08033 -0.22607 .31116 Mabsadd L
.8155 .08033 -0.95106 .30902 Mabsadd L
.8155 .08033 -0.36579 -0.11885 Mabsadd L
.8155 .08033 -0.58778 -0.80902 Mabsadd L
.8155 .08033 0 -0.38461 Mabsadd L
.8155 .08033 .58779 -0.80902 Mabsadd L
.8155 .08033 .36579 -0.11885 Mabsadd L
.8155 .08033 .95106 .30902 Mabsadd L
.8155 .08033 .22607 .31116 Mabsadd L
.8155 .08033 0 1 Mabsadd L closepath F
.81919 .08039 0 1 Mabsadd m
.81919 .08039 -0.22607 .31116 Mabsadd L
.81919 .08039 -0.95106 .30902 Mabsadd L
.81919 .08039 -0.36579 -0.11885 Mabsadd L
.81919 .08039 -0.58778 -0.80902 Mabsadd L
.81919 .08039 0 -0.38461 Mabsadd L
.81919 .08039 .58779 -0.80902 Mabsadd L
.81919 .08039 .36579 -0.11885 Mabsadd L
.81919 .08039 .95106 .30902 Mabsadd L
.81919 .08039 .22607 .31116 Mabsadd L
.81919 .08039 0 1 Mabsadd L closepath F
.82288 .08044 0 1 Mabsadd m
.82288 .08044 -0.22607 .31116 Mabsadd L
.82288 .08044 -0.95106 .30902 Mabsadd L
.82288 .08044 -0.36579 -0.11885 Mabsadd L
.82288 .08044 -0.58778 -0.80902 Mabsadd L
.82288 .08044 0 -0.38461 Mabsadd L
.82288 .08044 .58779 -0.80902 Mabsadd L
.82288 .08044 .36579 -0.11885 Mabsadd L
.82288 .08044 .95106 .30902 Mabsadd L
.82288 .08044 .22607 .31116 Mabsadd L
.82288 .08044 0 1 Mabsadd L closepath F
.82657 .08027 0 1 Mabsadd m
.82657 .08027 -0.22607 .31116 Mabsadd L
.82657 .08027 -0.95106 .30902 Mabsadd L
.82657 .08027 -0.36579 -0.11885 Mabsadd L
.82657 .08027 -0.58778 -0.80902 Mabsadd L
.82657 .08027 0 -0.38461 Mabsadd L
.82657 .08027 .58779 -0.80902 Mabsadd L
.82657 .08027 .36579 -0.11885 Mabsadd L
.82657 .08027 .95106 .30902 Mabsadd L
.82657 .08027 .22607 .31116 Mabsadd L
.82657 .08027 0 1 Mabsadd L closepath F
.83026 .0803 0 1 Mabsadd m
.83026 .0803 -0.22607 .31116 Mabsadd L
.83026 .0803 -0.95106 .30902 Mabsadd L
.83026 .0803 -0.36579 -0.11885 Mabsadd L
.83026 .0803 -0.58778 -0.80902 Mabsadd L
.83026 .0803 0 -0.38461 Mabsadd L
.83026 .0803 .58779 -0.80902 Mabsadd L
.83026 .0803 .36579 -0.11885 Mabsadd L
.83026 .0803 .95106 .30902 Mabsadd L
.83026 .0803 .22607 .31116 Mabsadd L
.83026 .0803 0 1 Mabsadd L closepath F
.83395 .0804 0 1 Mabsadd m
.83395 .0804 -0.22607 .31116 Mabsadd L
.83395 .0804 -0.95106 .30902 Mabsadd L
.83395 .0804 -0.36579 -0.11885 Mabsadd L
.83395 .0804 -0.58778 -0.80902 Mabsadd L
.83395 .0804 0 -0.38461 Mabsadd L
.83395 .0804 .58779 -0.80902 Mabsadd L
.83395 .0804 .36579 -0.11885 Mabsadd L
.83395 .0804 .95106 .30902 Mabsadd L
.83395 .0804 .22607 .31116 Mabsadd L
.83395 .0804 0 1 Mabsadd L closepath F
.83764 .08036 0 1 Mabsadd m
.83764 .08036 -0.22607 .31116 Mabsadd L
.83764 .08036 -0.95106 .30902 Mabsadd L
.83764 .08036 -0.36579 -0.11885 Mabsadd L
.83764 .08036 -0.58778 -0.80902 Mabsadd L
.83764 .08036 0 -0.38461 Mabsadd L
.83764 .08036 .58779 -0.80902 Mabsadd L
.83764 .08036 .36579 -0.11885 Mabsadd L
.83764 .08036 .95106 .30902 Mabsadd L
.83764 .08036 .22607 .31116 Mabsadd L
.83764 .08036 0 1 Mabsadd L closepath F
.84133 .08028 0 1 Mabsadd m
.84133 .08028 -0.22607 .31116 Mabsadd L
.84133 .08028 -0.95106 .30902 Mabsadd L
.84133 .08028 -0.36579 -0.11885 Mabsadd L
.84133 .08028 -0.58778 -0.80902 Mabsadd L
.84133 .08028 0 -0.38461 Mabsadd L
.84133 .08028 .58779 -0.80902 Mabsadd L
.84133 .08028 .36579 -0.11885 Mabsadd L
.84133 .08028 .95106 .30902 Mabsadd L
.84133 .08028 .22607 .31116 Mabsadd L
.84133 .08028 0 1 Mabsadd L closepath F
.84502 .08028 0 1 Mabsadd m
.84502 .08028 -0.22607 .31116 Mabsadd L
.84502 .08028 -0.95106 .30902 Mabsadd L
.84502 .08028 -0.36579 -0.11885 Mabsadd L
.84502 .08028 -0.58778 -0.80902 Mabsadd L
.84502 .08028 0 -0.38461 Mabsadd L
.84502 .08028 .58779 -0.80902 Mabsadd L
.84502 .08028 .36579 -0.11885 Mabsadd L
.84502 .08028 .95106 .30902 Mabsadd L
.84502 .08028 .22607 .31116 Mabsadd L
.84502 .08028 0 1 Mabsadd L closepath F
.84871 .08028 0 1 Mabsadd m
.84871 .08028 -0.22607 .31116 Mabsadd L
.84871 .08028 -0.95106 .30902 Mabsadd L
.84871 .08028 -0.36579 -0.11885 Mabsadd L
.84871 .08028 -0.58778 -0.80902 Mabsadd L
.84871 .08028 0 -0.38461 Mabsadd L
.84871 .08028 .58779 -0.80902 Mabsadd L
.84871 .08028 .36579 -0.11885 Mabsadd L
.84871 .08028 .95106 .30902 Mabsadd L
.84871 .08028 .22607 .31116 Mabsadd L
.84871 .08028 0 1 Mabsadd L closepath F
.8524 .0804 0 1 Mabsadd m
.8524 .0804 -0.22607 .31116 Mabsadd L
.8524 .0804 -0.95106 .30902 Mabsadd L
.8524 .0804 -0.36579 -0.11885 Mabsadd L
.8524 .0804 -0.58778 -0.80902 Mabsadd L
.8524 .0804 0 -0.38461 Mabsadd L
.8524 .0804 .58779 -0.80902 Mabsadd L
.8524 .0804 .36579 -0.11885 Mabsadd L
.8524 .0804 .95106 .30902 Mabsadd L
.8524 .0804 .22607 .31116 Mabsadd L
.8524 .0804 0 1 Mabsadd L closepath F
.85609 .08045 0 1 Mabsadd m
.85609 .08045 -0.22607 .31116 Mabsadd L
.85609 .08045 -0.95106 .30902 Mabsadd L
.85609 .08045 -0.36579 -0.11885 Mabsadd L
.85609 .08045 -0.58778 -0.80902 Mabsadd L
.85609 .08045 0 -0.38461 Mabsadd L
.85609 .08045 .58779 -0.80902 Mabsadd L
.85609 .08045 .36579 -0.11885 Mabsadd L
.85609 .08045 .95106 .30902 Mabsadd L
.85609 .08045 .22607 .31116 Mabsadd L
.85609 .08045 0 1 Mabsadd L closepath F
.85978 .08016 0 1 Mabsadd m
.85978 .08016 -0.22607 .31116 Mabsadd L
.85978 .08016 -0.95106 .30902 Mabsadd L
.85978 .08016 -0.36579 -0.11885 Mabsadd L
.85978 .08016 -0.58778 -0.80902 Mabsadd L
.85978 .08016 0 -0.38461 Mabsadd L
.85978 .08016 .58779 -0.80902 Mabsadd L
.85978 .08016 .36579 -0.11885 Mabsadd L
.85978 .08016 .95106 .30902 Mabsadd L
.85978 .08016 .22607 .31116 Mabsadd L
.85978 .08016 0 1 Mabsadd L closepath F
.86347 .08035 0 1 Mabsadd m
.86347 .08035 -0.22607 .31116 Mabsadd L
.86347 .08035 -0.95106 .30902 Mabsadd L
.86347 .08035 -0.36579 -0.11885 Mabsadd L
.86347 .08035 -0.58778 -0.80902 Mabsadd L
.86347 .08035 0 -0.38461 Mabsadd L
.86347 .08035 .58779 -0.80902 Mabsadd L
.86347 .08035 .36579 -0.11885 Mabsadd L
.86347 .08035 .95106 .30902 Mabsadd L
.86347 .08035 .22607 .31116 Mabsadd L
.86347 .08035 0 1 Mabsadd L closepath F
.86716 .08022 0 1 Mabsadd m
.86716 .08022 -0.22607 .31116 Mabsadd L
.86716 .08022 -0.95106 .30902 Mabsadd L
.86716 .08022 -0.36579 -0.11885 Mabsadd L
.86716 .08022 -0.58778 -0.80902 Mabsadd L
.86716 .08022 0 -0.38461 Mabsadd L
.86716 .08022 .58779 -0.80902 Mabsadd L
.86716 .08022 .36579 -0.11885 Mabsadd L
.86716 .08022 .95106 .30902 Mabsadd L
.86716 .08022 .22607 .31116 Mabsadd L
.86716 .08022 0 1 Mabsadd L closepath F
.87085 .08053 0 1 Mabsadd m
.87085 .08053 -0.22607 .31116 Mabsadd L
.87085 .08053 -0.95106 .30902 Mabsadd L
.87085 .08053 -0.36579 -0.11885 Mabsadd L
.87085 .08053 -0.58778 -0.80902 Mabsadd L
.87085 .08053 0 -0.38461 Mabsadd L
.87085 .08053 .58779 -0.80902 Mabsadd L
.87085 .08053 .36579 -0.11885 Mabsadd L
.87085 .08053 .95106 .30902 Mabsadd L
.87085 .08053 .22607 .31116 Mabsadd L
.87085 .08053 0 1 Mabsadd L closepath F
.87454 .08031 0 1 Mabsadd m
.87454 .08031 -0.22607 .31116 Mabsadd L
.87454 .08031 -0.95106 .30902 Mabsadd L
.87454 .08031 -0.36579 -0.11885 Mabsadd L
.87454 .08031 -0.58778 -0.80902 Mabsadd L
.87454 .08031 0 -0.38461 Mabsadd L
.87454 .08031 .58779 -0.80902 Mabsadd L
.87454 .08031 .36579 -0.11885 Mabsadd L
.87454 .08031 .95106 .30902 Mabsadd L
.87454 .08031 .22607 .31116 Mabsadd L
.87454 .08031 0 1 Mabsadd L closepath F
.87823 .08062 0 1 Mabsadd m
.87823 .08062 -0.22607 .31116 Mabsadd L
.87823 .08062 -0.95106 .30902 Mabsadd L
.87823 .08062 -0.36579 -0.11885 Mabsadd L
.87823 .08062 -0.58778 -0.80902 Mabsadd L
.87823 .08062 0 -0.38461 Mabsadd L
.87823 .08062 .58779 -0.80902 Mabsadd L
.87823 .08062 .36579 -0.11885 Mabsadd L
.87823 .08062 .95106 .30902 Mabsadd L
.87823 .08062 .22607 .31116 Mabsadd L
.87823 .08062 0 1 Mabsadd L closepath F
.88192 .08042 0 1 Mabsadd m
.88192 .08042 -0.22607 .31116 Mabsadd L
.88192 .08042 -0.95106 .30902 Mabsadd L
.88192 .08042 -0.36579 -0.11885 Mabsadd L
.88192 .08042 -0.58778 -0.80902 Mabsadd L
.88192 .08042 0 -0.38461 Mabsadd L
.88192 .08042 .58779 -0.80902 Mabsadd L
.88192 .08042 .36579 -0.11885 Mabsadd L
.88192 .08042 .95106 .30902 Mabsadd L
.88192 .08042 .22607 .31116 Mabsadd L
.88192 .08042 0 1 Mabsadd L closepath F
.88561 .0803 0 1 Mabsadd m
.88561 .0803 -0.22607 .31116 Mabsadd L
.88561 .0803 -0.95106 .30902 Mabsadd L
.88561 .0803 -0.36579 -0.11885 Mabsadd L
.88561 .0803 -0.58778 -0.80902 Mabsadd L
.88561 .0803 0 -0.38461 Mabsadd L
.88561 .0803 .58779 -0.80902 Mabsadd L
.88561 .0803 .36579 -0.11885 Mabsadd L
.88561 .0803 .95106 .30902 Mabsadd L
.88561 .0803 .22607 .31116 Mabsadd L
.88561 .0803 0 1 Mabsadd L closepath F
.8893 .08017 0 1 Mabsadd m
.8893 .08017 -0.22607 .31116 Mabsadd L
.8893 .08017 -0.95106 .30902 Mabsadd L
.8893 .08017 -0.36579 -0.11885 Mabsadd L
.8893 .08017 -0.58778 -0.80902 Mabsadd L
.8893 .08017 0 -0.38461 Mabsadd L
.8893 .08017 .58779 -0.80902 Mabsadd L
.8893 .08017 .36579 -0.11885 Mabsadd L
.8893 .08017 .95106 .30902 Mabsadd L
.8893 .08017 .22607 .31116 Mabsadd L
.8893 .08017 0 1 Mabsadd L closepath F
.89299 .08017 0 1 Mabsadd m
.89299 .08017 -0.22607 .31116 Mabsadd L
.89299 .08017 -0.95106 .30902 Mabsadd L
.89299 .08017 -0.36579 -0.11885 Mabsadd L
.89299 .08017 -0.58778 -0.80902 Mabsadd L
.89299 .08017 0 -0.38461 Mabsadd L
.89299 .08017 .58779 -0.80902 Mabsadd L
.89299 .08017 .36579 -0.11885 Mabsadd L
.89299 .08017 .95106 .30902 Mabsadd L
.89299 .08017 .22607 .31116 Mabsadd L
.89299 .08017 0 1 Mabsadd L closepath F
.89668 .0804 0 1 Mabsadd m
.89668 .0804 -0.22607 .31116 Mabsadd L
.89668 .0804 -0.95106 .30902 Mabsadd L
.89668 .0804 -0.36579 -0.11885 Mabsadd L
.89668 .0804 -0.58778 -0.80902 Mabsadd L
.89668 .0804 0 -0.38461 Mabsadd L
.89668 .0804 .58779 -0.80902 Mabsadd L
.89668 .0804 .36579 -0.11885 Mabsadd L
.89668 .0804 .95106 .30902 Mabsadd L
.89668 .0804 .22607 .31116 Mabsadd L
.89668 .0804 0 1 Mabsadd L closepath F
.90037 .0803 0 1 Mabsadd m
.90037 .0803 -0.22607 .31116 Mabsadd L
.90037 .0803 -0.95106 .30902 Mabsadd L
.90037 .0803 -0.36579 -0.11885 Mabsadd L
.90037 .0803 -0.58778 -0.80902 Mabsadd L
.90037 .0803 0 -0.38461 Mabsadd L
.90037 .0803 .58779 -0.80902 Mabsadd L
.90037 .0803 .36579 -0.11885 Mabsadd L
.90037 .0803 .95106 .30902 Mabsadd L
.90037 .0803 .22607 .31116 Mabsadd L
.90037 .0803 0 1 Mabsadd L closepath F
.90406 .08021 0 1 Mabsadd m
.90406 .08021 -0.22607 .31116 Mabsadd L
.90406 .08021 -0.95106 .30902 Mabsadd L
.90406 .08021 -0.36579 -0.11885 Mabsadd L
.90406 .08021 -0.58778 -0.80902 Mabsadd L
.90406 .08021 0 -0.38461 Mabsadd L
.90406 .08021 .58779 -0.80902 Mabsadd L
.90406 .08021 .36579 -0.11885 Mabsadd L
.90406 .08021 .95106 .30902 Mabsadd L
.90406 .08021 .22607 .31116 Mabsadd L
.90406 .08021 0 1 Mabsadd L closepath F
.90775 .08046 0 1 Mabsadd m
.90775 .08046 -0.22607 .31116 Mabsadd L
.90775 .08046 -0.95106 .30902 Mabsadd L
.90775 .08046 -0.36579 -0.11885 Mabsadd L
.90775 .08046 -0.58778 -0.80902 Mabsadd L
.90775 .08046 0 -0.38461 Mabsadd L
.90775 .08046 .58779 -0.80902 Mabsadd L
.90775 .08046 .36579 -0.11885 Mabsadd L
.90775 .08046 .95106 .30902 Mabsadd L
.90775 .08046 .22607 .31116 Mabsadd L
.90775 .08046 0 1 Mabsadd L closepath F
.91144 .08029 0 1 Mabsadd m
.91144 .08029 -0.22607 .31116 Mabsadd L
.91144 .08029 -0.95106 .30902 Mabsadd L
.91144 .08029 -0.36579 -0.11885 Mabsadd L
.91144 .08029 -0.58778 -0.80902 Mabsadd L
.91144 .08029 0 -0.38461 Mabsadd L
.91144 .08029 .58779 -0.80902 Mabsadd L
.91144 .08029 .36579 -0.11885 Mabsadd L
.91144 .08029 .95106 .30902 Mabsadd L
.91144 .08029 .22607 .31116 Mabsadd L
.91144 .08029 0 1 Mabsadd L closepath F
.91513 .08036 0 1 Mabsadd m
.91513 .08036 -0.22607 .31116 Mabsadd L
.91513 .08036 -0.95106 .30902 Mabsadd L
.91513 .08036 -0.36579 -0.11885 Mabsadd L
.91513 .08036 -0.58778 -0.80902 Mabsadd L
.91513 .08036 0 -0.38461 Mabsadd L
.91513 .08036 .58779 -0.80902 Mabsadd L
.91513 .08036 .36579 -0.11885 Mabsadd L
.91513 .08036 .95106 .30902 Mabsadd L
.91513 .08036 .22607 .31116 Mabsadd L
.91513 .08036 0 1 Mabsadd L closepath F
.91882 .08044 0 1 Mabsadd m
.91882 .08044 -0.22607 .31116 Mabsadd L
.91882 .08044 -0.95106 .30902 Mabsadd L
.91882 .08044 -0.36579 -0.11885 Mabsadd L
.91882 .08044 -0.58778 -0.80902 Mabsadd L
.91882 .08044 0 -0.38461 Mabsadd L
.91882 .08044 .58779 -0.80902 Mabsadd L
.91882 .08044 .36579 -0.11885 Mabsadd L
.91882 .08044 .95106 .30902 Mabsadd L
.91882 .08044 .22607 .31116 Mabsadd L
.91882 .08044 0 1 Mabsadd L closepath F
.92251 .0805 0 1 Mabsadd m
.92251 .0805 -0.22607 .31116 Mabsadd L
.92251 .0805 -0.95106 .30902 Mabsadd L
.92251 .0805 -0.36579 -0.11885 Mabsadd L
.92251 .0805 -0.58778 -0.80902 Mabsadd L
.92251 .0805 0 -0.38461 Mabsadd L
.92251 .0805 .58779 -0.80902 Mabsadd L
.92251 .0805 .36579 -0.11885 Mabsadd L
.92251 .0805 .95106 .30902 Mabsadd L
.92251 .0805 .22607 .31116 Mabsadd L
.92251 .0805 0 1 Mabsadd L closepath F
.9262 .08034 0 1 Mabsadd m
.9262 .08034 -0.22607 .31116 Mabsadd L
.9262 .08034 -0.95106 .30902 Mabsadd L
.9262 .08034 -0.36579 -0.11885 Mabsadd L
.9262 .08034 -0.58778 -0.80902 Mabsadd L
.9262 .08034 0 -0.38461 Mabsadd L
.9262 .08034 .58779 -0.80902 Mabsadd L
.9262 .08034 .36579 -0.11885 Mabsadd L
.9262 .08034 .95106 .30902 Mabsadd L
.9262 .08034 .22607 .31116 Mabsadd L
.9262 .08034 0 1 Mabsadd L closepath F
.92989 .08017 0 1 Mabsadd m
.92989 .08017 -0.22607 .31116 Mabsadd L
.92989 .08017 -0.95106 .30902 Mabsadd L
.92989 .08017 -0.36579 -0.11885 Mabsadd L
.92989 .08017 -0.58778 -0.80902 Mabsadd L
.92989 .08017 0 -0.38461 Mabsadd L
.92989 .08017 .58779 -0.80902 Mabsadd L
.92989 .08017 .36579 -0.11885 Mabsadd L
.92989 .08017 .95106 .30902 Mabsadd L
.92989 .08017 .22607 .31116 Mabsadd L
.92989 .08017 0 1 Mabsadd L closepath F
.93358 .08057 0 1 Mabsadd m
.93358 .08057 -0.22607 .31116 Mabsadd L
.93358 .08057 -0.95106 .30902 Mabsadd L
.93358 .08057 -0.36579 -0.11885 Mabsadd L
.93358 .08057 -0.58778 -0.80902 Mabsadd L
.93358 .08057 0 -0.38461 Mabsadd L
.93358 .08057 .58779 -0.80902 Mabsadd L
.93358 .08057 .36579 -0.11885 Mabsadd L
.93358 .08057 .95106 .30902 Mabsadd L
.93358 .08057 .22607 .31116 Mabsadd L
.93358 .08057 0 1 Mabsadd L closepath F
.93727 .08051 0 1 Mabsadd m
.93727 .08051 -0.22607 .31116 Mabsadd L
.93727 .08051 -0.95106 .30902 Mabsadd L
.93727 .08051 -0.36579 -0.11885 Mabsadd L
.93727 .08051 -0.58778 -0.80902 Mabsadd L
.93727 .08051 0 -0.38461 Mabsadd L
.93727 .08051 .58779 -0.80902 Mabsadd L
.93727 .08051 .36579 -0.11885 Mabsadd L
.93727 .08051 .95106 .30902 Mabsadd L
.93727 .08051 .22607 .31116 Mabsadd L
.93727 .08051 0 1 Mabsadd L closepath F
.94096 .08047 0 1 Mabsadd m
.94096 .08047 -0.22607 .31116 Mabsadd L
.94096 .08047 -0.95106 .30902 Mabsadd L
.94096 .08047 -0.36579 -0.11885 Mabsadd L
.94096 .08047 -0.58778 -0.80902 Mabsadd L
.94096 .08047 0 -0.38461 Mabsadd L
.94096 .08047 .58779 -0.80902 Mabsadd L
.94096 .08047 .36579 -0.11885 Mabsadd L
.94096 .08047 .95106 .30902 Mabsadd L
.94096 .08047 .22607 .31116 Mabsadd L
.94096 .08047 0 1 Mabsadd L closepath F
.94465 .08045 0 1 Mabsadd m
.94465 .08045 -0.22607 .31116 Mabsadd L
.94465 .08045 -0.95106 .30902 Mabsadd L
.94465 .08045 -0.36579 -0.11885 Mabsadd L
.94465 .08045 -0.58778 -0.80902 Mabsadd L
.94465 .08045 0 -0.38461 Mabsadd L
.94465 .08045 .58779 -0.80902 Mabsadd L
.94465 .08045 .36579 -0.11885 Mabsadd L
.94465 .08045 .95106 .30902 Mabsadd L
.94465 .08045 .22607 .31116 Mabsadd L
.94465 .08045 0 1 Mabsadd L closepath F
.94834 .0804 0 1 Mabsadd m
.94834 .0804 -0.22607 .31116 Mabsadd L
.94834 .0804 -0.95106 .30902 Mabsadd L
.94834 .0804 -0.36579 -0.11885 Mabsadd L
.94834 .0804 -0.58778 -0.80902 Mabsadd L
.94834 .0804 0 -0.38461 Mabsadd L
.94834 .0804 .58779 -0.80902 Mabsadd L
.94834 .0804 .36579 -0.11885 Mabsadd L
.94834 .0804 .95106 .30902 Mabsadd L
.94834 .0804 .22607 .31116 Mabsadd L
.94834 .0804 0 1 Mabsadd L closepath F
.95203 .08052 0 1 Mabsadd m
.95203 .08052 -0.22607 .31116 Mabsadd L
.95203 .08052 -0.95106 .30902 Mabsadd L
.95203 .08052 -0.36579 -0.11885 Mabsadd L
.95203 .08052 -0.58778 -0.80902 Mabsadd L
.95203 .08052 0 -0.38461 Mabsadd L
.95203 .08052 .58779 -0.80902 Mabsadd L
.95203 .08052 .36579 -0.11885 Mabsadd L
.95203 .08052 .95106 .30902 Mabsadd L
.95203 .08052 .22607 .31116 Mabsadd L
.95203 .08052 0 1 Mabsadd L closepath F
.95572 .08016 0 1 Mabsadd m
.95572 .08016 -0.22607 .31116 Mabsadd L
.95572 .08016 -0.95106 .30902 Mabsadd L
.95572 .08016 -0.36579 -0.11885 Mabsadd L
.95572 .08016 -0.58778 -0.80902 Mabsadd L
.95572 .08016 0 -0.38461 Mabsadd L
.95572 .08016 .58779 -0.80902 Mabsadd L
.95572 .08016 .36579 -0.11885 Mabsadd L
.95572 .08016 .95106 .30902 Mabsadd L
.95572 .08016 .22607 .31116 Mabsadd L
.95572 .08016 0 1 Mabsadd L closepath F
.95941 .08022 0 1 Mabsadd m
.95941 .08022 -0.22607 .31116 Mabsadd L
.95941 .08022 -0.95106 .30902 Mabsadd L
.95941 .08022 -0.36579 -0.11885 Mabsadd L
.95941 .08022 -0.58778 -0.80902 Mabsadd L
.95941 .08022 0 -0.38461 Mabsadd L
.95941 .08022 .58779 -0.80902 Mabsadd L
.95941 .08022 .36579 -0.11885 Mabsadd L
.95941 .08022 .95106 .30902 Mabsadd L
.95941 .08022 .22607 .31116 Mabsadd L
.95941 .08022 0 1 Mabsadd L closepath F
.9631 .08026 0 1 Mabsadd m
.9631 .08026 -0.22607 .31116 Mabsadd L
.9631 .08026 -0.95106 .30902 Mabsadd L
.9631 .08026 -0.36579 -0.11885 Mabsadd L
.9631 .08026 -0.58778 -0.80902 Mabsadd L
.9631 .08026 0 -0.38461 Mabsadd L
.9631 .08026 .58779 -0.80902 Mabsadd L
.9631 .08026 .36579 -0.11885 Mabsadd L
.9631 .08026 .95106 .30902 Mabsadd L
.9631 .08026 .22607 .31116 Mabsadd L
.9631 .08026 0 1 Mabsadd L closepath F
.96679 .08032 0 1 Mabsadd m
.96679 .08032 -0.22607 .31116 Mabsadd L
.96679 .08032 -0.95106 .30902 Mabsadd L
.96679 .08032 -0.36579 -0.11885 Mabsadd L
.96679 .08032 -0.58778 -0.80902 Mabsadd L
.96679 .08032 0 -0.38461 Mabsadd L
.96679 .08032 .58779 -0.80902 Mabsadd L
.96679 .08032 .36579 -0.11885 Mabsadd L
.96679 .08032 .95106 .30902 Mabsadd L
.96679 .08032 .22607 .31116 Mabsadd L
.96679 .08032 0 1 Mabsadd L closepath F
.97048 .08035 0 1 Mabsadd m
.97048 .08035 -0.22607 .31116 Mabsadd L
.97048 .08035 -0.95106 .30902 Mabsadd L
.97048 .08035 -0.36579 -0.11885 Mabsadd L
.97048 .08035 -0.58778 -0.80902 Mabsadd L
.97048 .08035 0 -0.38461 Mabsadd L
.97048 .08035 .58779 -0.80902 Mabsadd L
.97048 .08035 .36579 -0.11885 Mabsadd L
.97048 .08035 .95106 .30902 Mabsadd L
.97048 .08035 .22607 .31116 Mabsadd L
.97048 .08035 0 1 Mabsadd L closepath F
.97417 .08023 0 1 Mabsadd m
.97417 .08023 -0.22607 .31116 Mabsadd L
.97417 .08023 -0.95106 .30902 Mabsadd L
.97417 .08023 -0.36579 -0.11885 Mabsadd L
.97417 .08023 -0.58778 -0.80902 Mabsadd L
.97417 .08023 0 -0.38461 Mabsadd L
.97417 .08023 .58779 -0.80902 Mabsadd L
.97417 .08023 .36579 -0.11885 Mabsadd L
.97417 .08023 .95106 .30902 Mabsadd L
.97417 .08023 .22607 .31116 Mabsadd L
.97417 .08023 0 1 Mabsadd L closepath F
.97786 .08058 0 1 Mabsadd m
.97786 .08058 -0.22607 .31116 Mabsadd L
.97786 .08058 -0.95106 .30902 Mabsadd L
.97786 .08058 -0.36579 -0.11885 Mabsadd L
.97786 .08058 -0.58778 -0.80902 Mabsadd L
.97786 .08058 0 -0.38461 Mabsadd L
.97786 .08058 .58779 -0.80902 Mabsadd L
.97786 .08058 .36579 -0.11885 Mabsadd L
.97786 .08058 .95106 .30902 Mabsadd L
.97786 .08058 .22607 .31116 Mabsadd L
.97786 .08058 0 1 Mabsadd L closepath F
.98155 .08058 0 1 Mabsadd m
.98155 .08058 -0.22607 .31116 Mabsadd L
.98155 .08058 -0.95106 .30902 Mabsadd L
.98155 .08058 -0.36579 -0.11885 Mabsadd L
.98155 .08058 -0.58778 -0.80902 Mabsadd L
.98155 .08058 0 -0.38461 Mabsadd L
.98155 .08058 .58779 -0.80902 Mabsadd L
.98155 .08058 .36579 -0.11885 Mabsadd L
.98155 .08058 .95106 .30902 Mabsadd L
.98155 .08058 .22607 .31116 Mabsadd L
.98155 .08058 0 1 Mabsadd L closepath F
.98524 .08036 0 1 Mabsadd m
.98524 .08036 -0.22607 .31116 Mabsadd L
.98524 .08036 -0.95106 .30902 Mabsadd L
.98524 .08036 -0.36579 -0.11885 Mabsadd L
.98524 .08036 -0.58778 -0.80902 Mabsadd L
.98524 .08036 0 -0.38461 Mabsadd L
.98524 .08036 .58779 -0.80902 Mabsadd L
.98524 .08036 .36579 -0.11885 Mabsadd L
.98524 .08036 .95106 .30902 Mabsadd L
.98524 .08036 .22607 .31116 Mabsadd L
.98524 .08036 0 1 Mabsadd L closepath F
.98893 .08036 0 1 Mabsadd m
.98893 .08036 -0.22607 .31116 Mabsadd L
.98893 .08036 -0.95106 .30902 Mabsadd L
.98893 .08036 -0.36579 -0.11885 Mabsadd L
.98893 .08036 -0.58778 -0.80902 Mabsadd L
.98893 .08036 0 -0.38461 Mabsadd L
.98893 .08036 .58779 -0.80902 Mabsadd L
.98893 .08036 .36579 -0.11885 Mabsadd L
.98893 .08036 .95106 .30902 Mabsadd L
.98893 .08036 .22607 .31116 Mabsadd L
.98893 .08036 0 1 Mabsadd L closepath F
.99262 .08025 0 1 Mabsadd m
.99262 .08025 -0.22607 .31116 Mabsadd L
.99262 .08025 -0.95106 .30902 Mabsadd L
.99262 .08025 -0.36579 -0.11885 Mabsadd L
.99262 .08025 -0.58778 -0.80902 Mabsadd L
.99262 .08025 0 -0.38461 Mabsadd L
.99262 .08025 .58779 -0.80902 Mabsadd L
.99262 .08025 .36579 -0.11885 Mabsadd L
.99262 .08025 .95106 .30902 Mabsadd L
.99262 .08025 .22607 .31116 Mabsadd L
.99262 .08025 0 1 Mabsadd L closepath F
.99631 .08035 0 1 Mabsadd m
.99631 .08035 -0.22607 .31116 Mabsadd L
.99631 .08035 -0.95106 .30902 Mabsadd L
.99631 .08035 -0.36579 -0.11885 Mabsadd L
.99631 .08035 -0.58778 -0.80902 Mabsadd L
.99631 .08035 0 -0.38461 Mabsadd L
.99631 .08035 .58779 -0.80902 Mabsadd L
.99631 .08035 .36579 -0.11885 Mabsadd L
.99631 .08035 .95106 .30902 Mabsadd L
.99631 .08035 .22607 .31116 Mabsadd L
.99631 .08035 0 1 Mabsadd L closepath F
0 1 0 r
.0738 .55943 0 1 Mabsadd m
.0738 .55943 -0.22607 .31116 Mabsadd L
.0738 .55943 -0.95106 .30902 Mabsadd L
.0738 .55943 -0.36579 -0.11885 Mabsadd L
.0738 .55943 -0.58778 -0.80902 Mabsadd L
.0738 .55943 0 -0.38461 Mabsadd L
.0738 .55943 .58779 -0.80902 Mabsadd L
.0738 .55943 .36579 -0.11885 Mabsadd L
.0738 .55943 .95106 .30902 Mabsadd L
.0738 .55943 .22607 .31116 Mabsadd L
.0738 .55943 0 1 Mabsadd L closepath F
.07749 .34726 0 1 Mabsadd m
.07749 .34726 -0.22607 .31116 Mabsadd L
.07749 .34726 -0.95106 .30902 Mabsadd L
.07749 .34726 -0.36579 -0.11885 Mabsadd L
.07749 .34726 -0.58778 -0.80902 Mabsadd L
.07749 .34726 0 -0.38461 Mabsadd L
.07749 .34726 .58779 -0.80902 Mabsadd L
.07749 .34726 .36579 -0.11885 Mabsadd L
.07749 .34726 .95106 .30902 Mabsadd L
.07749 .34726 .22607 .31116 Mabsadd L
.07749 .34726 0 1 Mabsadd L closepath F
.08118 .2772 0 1 Mabsadd m
.08118 .2772 -0.22607 .31116 Mabsadd L
.08118 .2772 -0.95106 .30902 Mabsadd L
.08118 .2772 -0.36579 -0.11885 Mabsadd L
.08118 .2772 -0.58778 -0.80902 Mabsadd L
.08118 .2772 0 -0.38461 Mabsadd L
.08118 .2772 .58779 -0.80902 Mabsadd L
.08118 .2772 .36579 -0.11885 Mabsadd L
.08118 .2772 .95106 .30902 Mabsadd L
.08118 .2772 .22607 .31116 Mabsadd L
.08118 .2772 0 1 Mabsadd L closepath F
.08487 .22695 0 1 Mabsadd m
.08487 .22695 -0.22607 .31116 Mabsadd L
.08487 .22695 -0.95106 .30902 Mabsadd L
.08487 .22695 -0.36579 -0.11885 Mabsadd L
.08487 .22695 -0.58778 -0.80902 Mabsadd L
.08487 .22695 0 -0.38461 Mabsadd L
.08487 .22695 .58779 -0.80902 Mabsadd L
.08487 .22695 .36579 -0.11885 Mabsadd L
.08487 .22695 .95106 .30902 Mabsadd L
.08487 .22695 .22607 .31116 Mabsadd L
.08487 .22695 0 1 Mabsadd L closepath F
.08856 .18863 0 1 Mabsadd m
.08856 .18863 -0.22607 .31116 Mabsadd L
.08856 .18863 -0.95106 .30902 Mabsadd L
.08856 .18863 -0.36579 -0.11885 Mabsadd L
.08856 .18863 -0.58778 -0.80902 Mabsadd L
.08856 .18863 0 -0.38461 Mabsadd L
.08856 .18863 .58779 -0.80902 Mabsadd L
.08856 .18863 .36579 -0.11885 Mabsadd L
.08856 .18863 .95106 .30902 Mabsadd L
.08856 .18863 .22607 .31116 Mabsadd L
.08856 .18863 0 1 Mabsadd L closepath F
.09225 .1605 0 1 Mabsadd m
.09225 .1605 -0.22607 .31116 Mabsadd L
.09225 .1605 -0.95106 .30902 Mabsadd L
.09225 .1605 -0.36579 -0.11885 Mabsadd L
.09225 .1605 -0.58778 -0.80902 Mabsadd L
.09225 .1605 0 -0.38461 Mabsadd L
.09225 .1605 .58779 -0.80902 Mabsadd L
.09225 .1605 .36579 -0.11885 Mabsadd L
.09225 .1605 .95106 .30902 Mabsadd L
.09225 .1605 .22607 .31116 Mabsadd L
.09225 .1605 0 1 Mabsadd L closepath F
.09594 .14042 0 1 Mabsadd m
.09594 .14042 -0.22607 .31116 Mabsadd L
.09594 .14042 -0.95106 .30902 Mabsadd L
.09594 .14042 -0.36579 -0.11885 Mabsadd L
.09594 .14042 -0.58778 -0.80902 Mabsadd L
.09594 .14042 0 -0.38461 Mabsadd L
.09594 .14042 .58779 -0.80902 Mabsadd L
.09594 .14042 .36579 -0.11885 Mabsadd L
.09594 .14042 .95106 .30902 Mabsadd L
.09594 .14042 .22607 .31116 Mabsadd L
.09594 .14042 0 1 Mabsadd L closepath F
.09963 .12392 0 1 Mabsadd m
.09963 .12392 -0.22607 .31116 Mabsadd L
.09963 .12392 -0.95106 .30902 Mabsadd L
.09963 .12392 -0.36579 -0.11885 Mabsadd L
.09963 .12392 -0.58778 -0.80902 Mabsadd L
.09963 .12392 0 -0.38461 Mabsadd L
.09963 .12392 .58779 -0.80902 Mabsadd L
.09963 .12392 .36579 -0.11885 Mabsadd L
.09963 .12392 .95106 .30902 Mabsadd L
.09963 .12392 .22607 .31116 Mabsadd L
.09963 .12392 0 1 Mabsadd L closepath F
.10332 .11269 0 1 Mabsadd m
.10332 .11269 -0.22607 .31116 Mabsadd L
.10332 .11269 -0.95106 .30902 Mabsadd L
.10332 .11269 -0.36579 -0.11885 Mabsadd L
.10332 .11269 -0.58778 -0.80902 Mabsadd L
.10332 .11269 0 -0.38461 Mabsadd L
.10332 .11269 .58779 -0.80902 Mabsadd L
.10332 .11269 .36579 -0.11885 Mabsadd L
.10332 .11269 .95106 .30902 Mabsadd L
.10332 .11269 .22607 .31116 Mabsadd L
.10332 .11269 0 1 Mabsadd L closepath F
.10701 .10468 0 1 Mabsadd m
.10701 .10468 -0.22607 .31116 Mabsadd L
.10701 .10468 -0.95106 .30902 Mabsadd L
.10701 .10468 -0.36579 -0.11885 Mabsadd L
.10701 .10468 -0.58778 -0.80902 Mabsadd L
.10701 .10468 0 -0.38461 Mabsadd L
.10701 .10468 .58779 -0.80902 Mabsadd L
.10701 .10468 .36579 -0.11885 Mabsadd L
.10701 .10468 .95106 .30902 Mabsadd L
.10701 .10468 .22607 .31116 Mabsadd L
.10701 .10468 0 1 Mabsadd L closepath F
.1107 .09874 0 1 Mabsadd m
.1107 .09874 -0.22607 .31116 Mabsadd L
.1107 .09874 -0.95106 .30902 Mabsadd L
.1107 .09874 -0.36579 -0.11885 Mabsadd L
.1107 .09874 -0.58778 -0.80902 Mabsadd L
.1107 .09874 0 -0.38461 Mabsadd L
.1107 .09874 .58779 -0.80902 Mabsadd L
.1107 .09874 .36579 -0.11885 Mabsadd L
.1107 .09874 .95106 .30902 Mabsadd L
.1107 .09874 .22607 .31116 Mabsadd L
.1107 .09874 0 1 Mabsadd L closepath F
.11439 .09419 0 1 Mabsadd m
.11439 .09419 -0.22607 .31116 Mabsadd L
.11439 .09419 -0.95106 .30902 Mabsadd L
.11439 .09419 -0.36579 -0.11885 Mabsadd L
.11439 .09419 -0.58778 -0.80902 Mabsadd L
.11439 .09419 0 -0.38461 Mabsadd L
.11439 .09419 .58779 -0.80902 Mabsadd L
.11439 .09419 .36579 -0.11885 Mabsadd L
.11439 .09419 .95106 .30902 Mabsadd L
.11439 .09419 .22607 .31116 Mabsadd L
.11439 .09419 0 1 Mabsadd L closepath F
.11808 .09044 0 1 Mabsadd m
.11808 .09044 -0.22607 .31116 Mabsadd L
.11808 .09044 -0.95106 .30902 Mabsadd L
.11808 .09044 -0.36579 -0.11885 Mabsadd L
.11808 .09044 -0.58778 -0.80902 Mabsadd L
.11808 .09044 0 -0.38461 Mabsadd L
.11808 .09044 .58779 -0.80902 Mabsadd L
.11808 .09044 .36579 -0.11885 Mabsadd L
.11808 .09044 .95106 .30902 Mabsadd L
.11808 .09044 .22607 .31116 Mabsadd L
.11808 .09044 0 1 Mabsadd L closepath F
.12177 .0876 0 1 Mabsadd m
.12177 .0876 -0.22607 .31116 Mabsadd L
.12177 .0876 -0.95106 .30902 Mabsadd L
.12177 .0876 -0.36579 -0.11885 Mabsadd L
.12177 .0876 -0.58778 -0.80902 Mabsadd L
.12177 .0876 0 -0.38461 Mabsadd L
.12177 .0876 .58779 -0.80902 Mabsadd L
.12177 .0876 .36579 -0.11885 Mabsadd L
.12177 .0876 .95106 .30902 Mabsadd L
.12177 .0876 .22607 .31116 Mabsadd L
.12177 .0876 0 1 Mabsadd L closepath F
.12546 .0854 0 1 Mabsadd m
.12546 .0854 -0.22607 .31116 Mabsadd L
.12546 .0854 -0.95106 .30902 Mabsadd L
.12546 .0854 -0.36579 -0.11885 Mabsadd L
.12546 .0854 -0.58778 -0.80902 Mabsadd L
.12546 .0854 0 -0.38461 Mabsadd L
.12546 .0854 .58779 -0.80902 Mabsadd L
.12546 .0854 .36579 -0.11885 Mabsadd L
.12546 .0854 .95106 .30902 Mabsadd L
.12546 .0854 .22607 .31116 Mabsadd L
.12546 .0854 0 1 Mabsadd L closepath F
.12915 .08414 0 1 Mabsadd m
.12915 .08414 -0.22607 .31116 Mabsadd L
.12915 .08414 -0.95106 .30902 Mabsadd L
.12915 .08414 -0.36579 -0.11885 Mabsadd L
.12915 .08414 -0.58778 -0.80902 Mabsadd L
.12915 .08414 0 -0.38461 Mabsadd L
.12915 .08414 .58779 -0.80902 Mabsadd L
.12915 .08414 .36579 -0.11885 Mabsadd L
.12915 .08414 .95106 .30902 Mabsadd L
.12915 .08414 .22607 .31116 Mabsadd L
.12915 .08414 0 1 Mabsadd L closepath F
.13284 .08266 0 1 Mabsadd m
.13284 .08266 -0.22607 .31116 Mabsadd L
.13284 .08266 -0.95106 .30902 Mabsadd L
.13284 .08266 -0.36579 -0.11885 Mabsadd L
.13284 .08266 -0.58778 -0.80902 Mabsadd L
.13284 .08266 0 -0.38461 Mabsadd L
.13284 .08266 .58779 -0.80902 Mabsadd L
.13284 .08266 .36579 -0.11885 Mabsadd L
.13284 .08266 .95106 .30902 Mabsadd L
.13284 .08266 .22607 .31116 Mabsadd L
.13284 .08266 0 1 Mabsadd L closepath F
.13653 .08221 0 1 Mabsadd m
.13653 .08221 -0.22607 .31116 Mabsadd L
.13653 .08221 -0.95106 .30902 Mabsadd L
.13653 .08221 -0.36579 -0.11885 Mabsadd L
.13653 .08221 -0.58778 -0.80902 Mabsadd L
.13653 .08221 0 -0.38461 Mabsadd L
.13653 .08221 .58779 -0.80902 Mabsadd L
.13653 .08221 .36579 -0.11885 Mabsadd L
.13653 .08221 .95106 .30902 Mabsadd L
.13653 .08221 .22607 .31116 Mabsadd L
.13653 .08221 0 1 Mabsadd L closepath F
.14022 .08171 0 1 Mabsadd m
.14022 .08171 -0.22607 .31116 Mabsadd L
.14022 .08171 -0.95106 .30902 Mabsadd L
.14022 .08171 -0.36579 -0.11885 Mabsadd L
.14022 .08171 -0.58778 -0.80902 Mabsadd L
.14022 .08171 0 -0.38461 Mabsadd L
.14022 .08171 .58779 -0.80902 Mabsadd L
.14022 .08171 .36579 -0.11885 Mabsadd L
.14022 .08171 .95106 .30902 Mabsadd L
.14022 .08171 .22607 .31116 Mabsadd L
.14022 .08171 0 1 Mabsadd L closepath F
.14391 .08115 0 1 Mabsadd m
.14391 .08115 -0.22607 .31116 Mabsadd L
.14391 .08115 -0.95106 .30902 Mabsadd L
.14391 .08115 -0.36579 -0.11885 Mabsadd L
.14391 .08115 -0.58778 -0.80902 Mabsadd L
.14391 .08115 0 -0.38461 Mabsadd L
.14391 .08115 .58779 -0.80902 Mabsadd L
.14391 .08115 .36579 -0.11885 Mabsadd L
.14391 .08115 .95106 .30902 Mabsadd L
.14391 .08115 .22607 .31116 Mabsadd L
.14391 .08115 0 1 Mabsadd L closepath F
.1476 .08077 0 1 Mabsadd m
.1476 .08077 -0.22607 .31116 Mabsadd L
.1476 .08077 -0.95106 .30902 Mabsadd L
.1476 .08077 -0.36579 -0.11885 Mabsadd L
.1476 .08077 -0.58778 -0.80902 Mabsadd L
.1476 .08077 0 -0.38461 Mabsadd L
.1476 .08077 .58779 -0.80902 Mabsadd L
.1476 .08077 .36579 -0.11885 Mabsadd L
.1476 .08077 .95106 .30902 Mabsadd L
.1476 .08077 .22607 .31116 Mabsadd L
.1476 .08077 0 1 Mabsadd L closepath F
.15129 .08056 0 1 Mabsadd m
.15129 .08056 -0.22607 .31116 Mabsadd L
.15129 .08056 -0.95106 .30902 Mabsadd L
.15129 .08056 -0.36579 -0.11885 Mabsadd L
.15129 .08056 -0.58778 -0.80902 Mabsadd L
.15129 .08056 0 -0.38461 Mabsadd L
.15129 .08056 .58779 -0.80902 Mabsadd L
.15129 .08056 .36579 -0.11885 Mabsadd L
.15129 .08056 .95106 .30902 Mabsadd L
.15129 .08056 .22607 .31116 Mabsadd L
.15129 .08056 0 1 Mabsadd L closepath F
.15498 .0804 0 1 Mabsadd m
.15498 .0804 -0.22607 .31116 Mabsadd L
.15498 .0804 -0.95106 .30902 Mabsadd L
.15498 .0804 -0.36579 -0.11885 Mabsadd L
.15498 .0804 -0.58778 -0.80902 Mabsadd L
.15498 .0804 0 -0.38461 Mabsadd L
.15498 .0804 .58779 -0.80902 Mabsadd L
.15498 .0804 .36579 -0.11885 Mabsadd L
.15498 .0804 .95106 .30902 Mabsadd L
.15498 .0804 .22607 .31116 Mabsadd L
.15498 .0804 0 1 Mabsadd L closepath F
.15867 .08029 0 1 Mabsadd m
.15867 .08029 -0.22607 .31116 Mabsadd L
.15867 .08029 -0.95106 .30902 Mabsadd L
.15867 .08029 -0.36579 -0.11885 Mabsadd L
.15867 .08029 -0.58778 -0.80902 Mabsadd L
.15867 .08029 0 -0.38461 Mabsadd L
.15867 .08029 .58779 -0.80902 Mabsadd L
.15867 .08029 .36579 -0.11885 Mabsadd L
.15867 .08029 .95106 .30902 Mabsadd L
.15867 .08029 .22607 .31116 Mabsadd L
.15867 .08029 0 1 Mabsadd L closepath F
.16236 .08013 0 1 Mabsadd m
.16236 .08013 -0.22607 .31116 Mabsadd L
.16236 .08013 -0.95106 .30902 Mabsadd L
.16236 .08013 -0.36579 -0.11885 Mabsadd L
.16236 .08013 -0.58778 -0.80902 Mabsadd L
.16236 .08013 0 -0.38461 Mabsadd L
.16236 .08013 .58779 -0.80902 Mabsadd L
.16236 .08013 .36579 -0.11885 Mabsadd L
.16236 .08013 .95106 .30902 Mabsadd L
.16236 .08013 .22607 .31116 Mabsadd L
.16236 .08013 0 1 Mabsadd L closepath F
.16605 .08002 0 1 Mabsadd m
.16605 .08002 -0.22607 .31116 Mabsadd L
.16605 .08002 -0.95106 .30902 Mabsadd L
.16605 .08002 -0.36579 -0.11885 Mabsadd L
.16605 .08002 -0.58778 -0.80902 Mabsadd L
.16605 .08002 0 -0.38461 Mabsadd L
.16605 .08002 .58779 -0.80902 Mabsadd L
.16605 .08002 .36579 -0.11885 Mabsadd L
.16605 .08002 .95106 .30902 Mabsadd L
.16605 .08002 .22607 .31116 Mabsadd L
.16605 .08002 0 1 Mabsadd L closepath F
.16974 .08 0 1 Mabsadd m
.16974 .08 -0.22607 .31116 Mabsadd L
.16974 .08 -0.95106 .30902 Mabsadd L
.16974 .08 -0.36579 -0.11885 Mabsadd L
.16974 .08 -0.58778 -0.80902 Mabsadd L
.16974 .08 0 -0.38461 Mabsadd L
.16974 .08 .58779 -0.80902 Mabsadd L
.16974 .08 .36579 -0.11885 Mabsadd L
.16974 .08 .95106 .30902 Mabsadd L
.16974 .08 .22607 .31116 Mabsadd L
.16974 .08 0 1 Mabsadd L closepath F
.17343 .07997 0 1 Mabsadd m
.17343 .07997 -0.22607 .31116 Mabsadd L
.17343 .07997 -0.95106 .30902 Mabsadd L
.17343 .07997 -0.36579 -0.11885 Mabsadd L
.17343 .07997 -0.58778 -0.80902 Mabsadd L
.17343 .07997 0 -0.38461 Mabsadd L
.17343 .07997 .58779 -0.80902 Mabsadd L
.17343 .07997 .36579 -0.11885 Mabsadd L
.17343 .07997 .95106 .30902 Mabsadd L
.17343 .07997 .22607 .31116 Mabsadd L
.17343 .07997 0 1 Mabsadd L closepath F
.17712 .07997 0 1 Mabsadd m
.17712 .07997 -0.22607 .31116 Mabsadd L
.17712 .07997 -0.95106 .30902 Mabsadd L
.17712 .07997 -0.36579 -0.11885 Mabsadd L
.17712 .07997 -0.58778 -0.80902 Mabsadd L
.17712 .07997 0 -0.38461 Mabsadd L
.17712 .07997 .58779 -0.80902 Mabsadd L
.17712 .07997 .36579 -0.11885 Mabsadd L
.17712 .07997 .95106 .30902 Mabsadd L
.17712 .07997 .22607 .31116 Mabsadd L
.17712 .07997 0 1 Mabsadd L closepath F
.18081 .07997 0 1 Mabsadd m
.18081 .07997 -0.22607 .31116 Mabsadd L
.18081 .07997 -0.95106 .30902 Mabsadd L
.18081 .07997 -0.36579 -0.11885 Mabsadd L
.18081 .07997 -0.58778 -0.80902 Mabsadd L
.18081 .07997 0 -0.38461 Mabsadd L
.18081 .07997 .58779 -0.80902 Mabsadd L
.18081 .07997 .36579 -0.11885 Mabsadd L
.18081 .07997 .95106 .30902 Mabsadd L
.18081 .07997 .22607 .31116 Mabsadd L
.18081 .07997 0 1 Mabsadd L closepath F
.1845 .07992 0 1 Mabsadd m
.1845 .07992 -0.22607 .31116 Mabsadd L
.1845 .07992 -0.95106 .30902 Mabsadd L
.1845 .07992 -0.36579 -0.11885 Mabsadd L
.1845 .07992 -0.58778 -0.80902 Mabsadd L
.1845 .07992 0 -0.38461 Mabsadd L
.1845 .07992 .58779 -0.80902 Mabsadd L
.1845 .07992 .36579 -0.11885 Mabsadd L
.1845 .07992 .95106 .30902 Mabsadd L
.1845 .07992 .22607 .31116 Mabsadd L
.1845 .07992 0 1 Mabsadd L closepath F
.18819 .07992 0 1 Mabsadd m
.18819 .07992 -0.22607 .31116 Mabsadd L
.18819 .07992 -0.95106 .30902 Mabsadd L
.18819 .07992 -0.36579 -0.11885 Mabsadd L
.18819 .07992 -0.58778 -0.80902 Mabsadd L
.18819 .07992 0 -0.38461 Mabsadd L
.18819 .07992 .58779 -0.80902 Mabsadd L
.18819 .07992 .36579 -0.11885 Mabsadd L
.18819 .07992 .95106 .30902 Mabsadd L
.18819 .07992 .22607 .31116 Mabsadd L
.18819 .07992 0 1 Mabsadd L closepath F
.19188 .07997 0 1 Mabsadd m
.19188 .07997 -0.22607 .31116 Mabsadd L
.19188 .07997 -0.95106 .30902 Mabsadd L
.19188 .07997 -0.36579 -0.11885 Mabsadd L
.19188 .07997 -0.58778 -0.80902 Mabsadd L
.19188 .07997 0 -0.38461 Mabsadd L
.19188 .07997 .58779 -0.80902 Mabsadd L
.19188 .07997 .36579 -0.11885 Mabsadd L
.19188 .07997 .95106 .30902 Mabsadd L
.19188 .07997 .22607 .31116 Mabsadd L
.19188 .07997 0 1 Mabsadd L closepath F
.19557 .07997 0 1 Mabsadd m
.19557 .07997 -0.22607 .31116 Mabsadd L
.19557 .07997 -0.95106 .30902 Mabsadd L
.19557 .07997 -0.36579 -0.11885 Mabsadd L
.19557 .07997 -0.58778 -0.80902 Mabsadd L
.19557 .07997 0 -0.38461 Mabsadd L
.19557 .07997 .58779 -0.80902 Mabsadd L
.19557 .07997 .36579 -0.11885 Mabsadd L
.19557 .07997 .95106 .30902 Mabsadd L
.19557 .07997 .22607 .31116 Mabsadd L
.19557 .07997 0 1 Mabsadd L closepath F
.19926 .07992 0 1 Mabsadd m
.19926 .07992 -0.22607 .31116 Mabsadd L
.19926 .07992 -0.95106 .30902 Mabsadd L
.19926 .07992 -0.36579 -0.11885 Mabsadd L
.19926 .07992 -0.58778 -0.80902 Mabsadd L
.19926 .07992 0 -0.38461 Mabsadd L
.19926 .07992 .58779 -0.80902 Mabsadd L
.19926 .07992 .36579 -0.11885 Mabsadd L
.19926 .07992 .95106 .30902 Mabsadd L
.19926 .07992 .22607 .31116 Mabsadd L
.19926 .07992 0 1 Mabsadd L closepath F
.20295 .07992 0 1 Mabsadd m
.20295 .07992 -0.22607 .31116 Mabsadd L
.20295 .07992 -0.95106 .30902 Mabsadd L
.20295 .07992 -0.36579 -0.11885 Mabsadd L
.20295 .07992 -0.58778 -0.80902 Mabsadd L
.20295 .07992 0 -0.38461 Mabsadd L
.20295 .07992 .58779 -0.80902 Mabsadd L
.20295 .07992 .36579 -0.11885 Mabsadd L
.20295 .07992 .95106 .30902 Mabsadd L
.20295 .07992 .22607 .31116 Mabsadd L
.20295 .07992 0 1 Mabsadd L closepath F
.20664 .07992 0 1 Mabsadd m
.20664 .07992 -0.22607 .31116 Mabsadd L
.20664 .07992 -0.95106 .30902 Mabsadd L
.20664 .07992 -0.36579 -0.11885 Mabsadd L
.20664 .07992 -0.58778 -0.80902 Mabsadd L
.20664 .07992 0 -0.38461 Mabsadd L
.20664 .07992 .58779 -0.80902 Mabsadd L
.20664 .07992 .36579 -0.11885 Mabsadd L
.20664 .07992 .95106 .30902 Mabsadd L
.20664 .07992 .22607 .31116 Mabsadd L
.20664 .07992 0 1 Mabsadd L closepath F
.21033 .07992 0 1 Mabsadd m
.21033 .07992 -0.22607 .31116 Mabsadd L
.21033 .07992 -0.95106 .30902 Mabsadd L
.21033 .07992 -0.36579 -0.11885 Mabsadd L
.21033 .07992 -0.58778 -0.80902 Mabsadd L
.21033 .07992 0 -0.38461 Mabsadd L
.21033 .07992 .58779 -0.80902 Mabsadd L
.21033 .07992 .36579 -0.11885 Mabsadd L
.21033 .07992 .95106 .30902 Mabsadd L
.21033 .07992 .22607 .31116 Mabsadd L
.21033 .07992 0 1 Mabsadd L closepath F
.21402 .07993 0 1 Mabsadd m
.21402 .07993 -0.22607 .31116 Mabsadd L
.21402 .07993 -0.95106 .30902 Mabsadd L
.21402 .07993 -0.36579 -0.11885 Mabsadd L
.21402 .07993 -0.58778 -0.80902 Mabsadd L
.21402 .07993 0 -0.38461 Mabsadd L
.21402 .07993 .58779 -0.80902 Mabsadd L
.21402 .07993 .36579 -0.11885 Mabsadd L
.21402 .07993 .95106 .30902 Mabsadd L
.21402 .07993 .22607 .31116 Mabsadd L
.21402 .07993 0 1 Mabsadd L closepath F
.21771 .07992 0 1 Mabsadd m
.21771 .07992 -0.22607 .31116 Mabsadd L
.21771 .07992 -0.95106 .30902 Mabsadd L
.21771 .07992 -0.36579 -0.11885 Mabsadd L
.21771 .07992 -0.58778 -0.80902 Mabsadd L
.21771 .07992 0 -0.38461 Mabsadd L
.21771 .07992 .58779 -0.80902 Mabsadd L
.21771 .07992 .36579 -0.11885 Mabsadd L
.21771 .07992 .95106 .30902 Mabsadd L
.21771 .07992 .22607 .31116 Mabsadd L
.21771 .07992 0 1 Mabsadd L closepath F
.2214 .07997 0 1 Mabsadd m
.2214 .07997 -0.22607 .31116 Mabsadd L
.2214 .07997 -0.95106 .30902 Mabsadd L
.2214 .07997 -0.36579 -0.11885 Mabsadd L
.2214 .07997 -0.58778 -0.80902 Mabsadd L
.2214 .07997 0 -0.38461 Mabsadd L
.2214 .07997 .58779 -0.80902 Mabsadd L
.2214 .07997 .36579 -0.11885 Mabsadd L
.2214 .07997 .95106 .30902 Mabsadd L
.2214 .07997 .22607 .31116 Mabsadd L
.2214 .07997 0 1 Mabsadd L closepath F
.22509 .07999 0 1 Mabsadd m
.22509 .07999 -0.22607 .31116 Mabsadd L
.22509 .07999 -0.95106 .30902 Mabsadd L
.22509 .07999 -0.36579 -0.11885 Mabsadd L
.22509 .07999 -0.58778 -0.80902 Mabsadd L
.22509 .07999 0 -0.38461 Mabsadd L
.22509 .07999 .58779 -0.80902 Mabsadd L
.22509 .07999 .36579 -0.11885 Mabsadd L
.22509 .07999 .95106 .30902 Mabsadd L
.22509 .07999 .22607 .31116 Mabsadd L
.22509 .07999 0 1 Mabsadd L closepath F
.22878 .07997 0 1 Mabsadd m
.22878 .07997 -0.22607 .31116 Mabsadd L
.22878 .07997 -0.95106 .30902 Mabsadd L
.22878 .07997 -0.36579 -0.11885 Mabsadd L
.22878 .07997 -0.58778 -0.80902 Mabsadd L
.22878 .07997 0 -0.38461 Mabsadd L
.22878 .07997 .58779 -0.80902 Mabsadd L
.22878 .07997 .36579 -0.11885 Mabsadd L
.22878 .07997 .95106 .30902 Mabsadd L
.22878 .07997 .22607 .31116 Mabsadd L
.22878 .07997 0 1 Mabsadd L closepath F
.23247 .07997 0 1 Mabsadd m
.23247 .07997 -0.22607 .31116 Mabsadd L
.23247 .07997 -0.95106 .30902 Mabsadd L
.23247 .07997 -0.36579 -0.11885 Mabsadd L
.23247 .07997 -0.58778 -0.80902 Mabsadd L
.23247 .07997 0 -0.38461 Mabsadd L
.23247 .07997 .58779 -0.80902 Mabsadd L
.23247 .07997 .36579 -0.11885 Mabsadd L
.23247 .07997 .95106 .30902 Mabsadd L
.23247 .07997 .22607 .31116 Mabsadd L
.23247 .07997 0 1 Mabsadd L closepath F
.23616 .07997 0 1 Mabsadd m
.23616 .07997 -0.22607 .31116 Mabsadd L
.23616 .07997 -0.95106 .30902 Mabsadd L
.23616 .07997 -0.36579 -0.11885 Mabsadd L
.23616 .07997 -0.58778 -0.80902 Mabsadd L
.23616 .07997 0 -0.38461 Mabsadd L
.23616 .07997 .58779 -0.80902 Mabsadd L
.23616 .07997 .36579 -0.11885 Mabsadd L
.23616 .07997 .95106 .30902 Mabsadd L
.23616 .07997 .22607 .31116 Mabsadd L
.23616 .07997 0 1 Mabsadd L closepath F
.23985 .07996 0 1 Mabsadd m
.23985 .07996 -0.22607 .31116 Mabsadd L
.23985 .07996 -0.95106 .30902 Mabsadd L
.23985 .07996 -0.36579 -0.11885 Mabsadd L
.23985 .07996 -0.58778 -0.80902 Mabsadd L
.23985 .07996 0 -0.38461 Mabsadd L
.23985 .07996 .58779 -0.80902 Mabsadd L
.23985 .07996 .36579 -0.11885 Mabsadd L
.23985 .07996 .95106 .30902 Mabsadd L
.23985 .07996 .22607 .31116 Mabsadd L
.23985 .07996 0 1 Mabsadd L closepath F
.24354 .07997 0 1 Mabsadd m
.24354 .07997 -0.22607 .31116 Mabsadd L
.24354 .07997 -0.95106 .30902 Mabsadd L
.24354 .07997 -0.36579 -0.11885 Mabsadd L
.24354 .07997 -0.58778 -0.80902 Mabsadd L
.24354 .07997 0 -0.38461 Mabsadd L
.24354 .07997 .58779 -0.80902 Mabsadd L
.24354 .07997 .36579 -0.11885 Mabsadd L
.24354 .07997 .95106 .30902 Mabsadd L
.24354 .07997 .22607 .31116 Mabsadd L
.24354 .07997 0 1 Mabsadd L closepath F
.24723 .07997 0 1 Mabsadd m
.24723 .07997 -0.22607 .31116 Mabsadd L
.24723 .07997 -0.95106 .30902 Mabsadd L
.24723 .07997 -0.36579 -0.11885 Mabsadd L
.24723 .07997 -0.58778 -0.80902 Mabsadd L
.24723 .07997 0 -0.38461 Mabsadd L
.24723 .07997 .58779 -0.80902 Mabsadd L
.24723 .07997 .36579 -0.11885 Mabsadd L
.24723 .07997 .95106 .30902 Mabsadd L
.24723 .07997 .22607 .31116 Mabsadd L
.24723 .07997 0 1 Mabsadd L closepath F
.25092 .07997 0 1 Mabsadd m
.25092 .07997 -0.22607 .31116 Mabsadd L
.25092 .07997 -0.95106 .30902 Mabsadd L
.25092 .07997 -0.36579 -0.11885 Mabsadd L
.25092 .07997 -0.58778 -0.80902 Mabsadd L
.25092 .07997 0 -0.38461 Mabsadd L
.25092 .07997 .58779 -0.80902 Mabsadd L
.25092 .07997 .36579 -0.11885 Mabsadd L
.25092 .07997 .95106 .30902 Mabsadd L
.25092 .07997 .22607 .31116 Mabsadd L
.25092 .07997 0 1 Mabsadd L closepath F
.25461 .07992 0 1 Mabsadd m
.25461 .07992 -0.22607 .31116 Mabsadd L
.25461 .07992 -0.95106 .30902 Mabsadd L
.25461 .07992 -0.36579 -0.11885 Mabsadd L
.25461 .07992 -0.58778 -0.80902 Mabsadd L
.25461 .07992 0 -0.38461 Mabsadd L
.25461 .07992 .58779 -0.80902 Mabsadd L
.25461 .07992 .36579 -0.11885 Mabsadd L
.25461 .07992 .95106 .30902 Mabsadd L
.25461 .07992 .22607 .31116 Mabsadd L
.25461 .07992 0 1 Mabsadd L closepath F
.2583 .07992 0 1 Mabsadd m
.2583 .07992 -0.22607 .31116 Mabsadd L
.2583 .07992 -0.95106 .30902 Mabsadd L
.2583 .07992 -0.36579 -0.11885 Mabsadd L
.2583 .07992 -0.58778 -0.80902 Mabsadd L
.2583 .07992 0 -0.38461 Mabsadd L
.2583 .07992 .58779 -0.80902 Mabsadd L
.2583 .07992 .36579 -0.11885 Mabsadd L
.2583 .07992 .95106 .30902 Mabsadd L
.2583 .07992 .22607 .31116 Mabsadd L
.2583 .07992 0 1 Mabsadd L closepath F
.26199 .07992 0 1 Mabsadd m
.26199 .07992 -0.22607 .31116 Mabsadd L
.26199 .07992 -0.95106 .30902 Mabsadd L
.26199 .07992 -0.36579 -0.11885 Mabsadd L
.26199 .07992 -0.58778 -0.80902 Mabsadd L
.26199 .07992 0 -0.38461 Mabsadd L
.26199 .07992 .58779 -0.80902 Mabsadd L
.26199 .07992 .36579 -0.11885 Mabsadd L
.26199 .07992 .95106 .30902 Mabsadd L
.26199 .07992 .22607 .31116 Mabsadd L
.26199 .07992 0 1 Mabsadd L closepath F
.26568 .07997 0 1 Mabsadd m
.26568 .07997 -0.22607 .31116 Mabsadd L
.26568 .07997 -0.95106 .30902 Mabsadd L
.26568 .07997 -0.36579 -0.11885 Mabsadd L
.26568 .07997 -0.58778 -0.80902 Mabsadd L
.26568 .07997 0 -0.38461 Mabsadd L
.26568 .07997 .58779 -0.80902 Mabsadd L
.26568 .07997 .36579 -0.11885 Mabsadd L
.26568 .07997 .95106 .30902 Mabsadd L
.26568 .07997 .22607 .31116 Mabsadd L
.26568 .07997 0 1 Mabsadd L closepath F
.26937 .07992 0 1 Mabsadd m
.26937 .07992 -0.22607 .31116 Mabsadd L
.26937 .07992 -0.95106 .30902 Mabsadd L
.26937 .07992 -0.36579 -0.11885 Mabsadd L
.26937 .07992 -0.58778 -0.80902 Mabsadd L
.26937 .07992 0 -0.38461 Mabsadd L
.26937 .07992 .58779 -0.80902 Mabsadd L
.26937 .07992 .36579 -0.11885 Mabsadd L
.26937 .07992 .95106 .30902 Mabsadd L
.26937 .07992 .22607 .31116 Mabsadd L
.26937 .07992 0 1 Mabsadd L closepath F
.27306 .07992 0 1 Mabsadd m
.27306 .07992 -0.22607 .31116 Mabsadd L
.27306 .07992 -0.95106 .30902 Mabsadd L
.27306 .07992 -0.36579 -0.11885 Mabsadd L
.27306 .07992 -0.58778 -0.80902 Mabsadd L
.27306 .07992 0 -0.38461 Mabsadd L
.27306 .07992 .58779 -0.80902 Mabsadd L
.27306 .07992 .36579 -0.11885 Mabsadd L
.27306 .07992 .95106 .30902 Mabsadd L
.27306 .07992 .22607 .31116 Mabsadd L
.27306 .07992 0 1 Mabsadd L closepath F
.27675 .07992 0 1 Mabsadd m
.27675 .07992 -0.22607 .31116 Mabsadd L
.27675 .07992 -0.95106 .30902 Mabsadd L
.27675 .07992 -0.36579 -0.11885 Mabsadd L
.27675 .07992 -0.58778 -0.80902 Mabsadd L
.27675 .07992 0 -0.38461 Mabsadd L
.27675 .07992 .58779 -0.80902 Mabsadd L
.27675 .07992 .36579 -0.11885 Mabsadd L
.27675 .07992 .95106 .30902 Mabsadd L
.27675 .07992 .22607 .31116 Mabsadd L
.27675 .07992 0 1 Mabsadd L closepath F
.28044 .07992 0 1 Mabsadd m
.28044 .07992 -0.22607 .31116 Mabsadd L
.28044 .07992 -0.95106 .30902 Mabsadd L
.28044 .07992 -0.36579 -0.11885 Mabsadd L
.28044 .07992 -0.58778 -0.80902 Mabsadd L
.28044 .07992 0 -0.38461 Mabsadd L
.28044 .07992 .58779 -0.80902 Mabsadd L
.28044 .07992 .36579 -0.11885 Mabsadd L
.28044 .07992 .95106 .30902 Mabsadd L
.28044 .07992 .22607 .31116 Mabsadd L
.28044 .07992 0 1 Mabsadd L closepath F
.28413 .07992 0 1 Mabsadd m
.28413 .07992 -0.22607 .31116 Mabsadd L
.28413 .07992 -0.95106 .30902 Mabsadd L
.28413 .07992 -0.36579 -0.11885 Mabsadd L
.28413 .07992 -0.58778 -0.80902 Mabsadd L
.28413 .07992 0 -0.38461 Mabsadd L
.28413 .07992 .58779 -0.80902 Mabsadd L
.28413 .07992 .36579 -0.11885 Mabsadd L
.28413 .07992 .95106 .30902 Mabsadd L
.28413 .07992 .22607 .31116 Mabsadd L
.28413 .07992 0 1 Mabsadd L closepath F
.28782 .07992 0 1 Mabsadd m
.28782 .07992 -0.22607 .31116 Mabsadd L
.28782 .07992 -0.95106 .30902 Mabsadd L
.28782 .07992 -0.36579 -0.11885 Mabsadd L
.28782 .07992 -0.58778 -0.80902 Mabsadd L
.28782 .07992 0 -0.38461 Mabsadd L
.28782 .07992 .58779 -0.80902 Mabsadd L
.28782 .07992 .36579 -0.11885 Mabsadd L
.28782 .07992 .95106 .30902 Mabsadd L
.28782 .07992 .22607 .31116 Mabsadd L
.28782 .07992 0 1 Mabsadd L closepath F
.29151 .07992 0 1 Mabsadd m
.29151 .07992 -0.22607 .31116 Mabsadd L
.29151 .07992 -0.95106 .30902 Mabsadd L
.29151 .07992 -0.36579 -0.11885 Mabsadd L
.29151 .07992 -0.58778 -0.80902 Mabsadd L
.29151 .07992 0 -0.38461 Mabsadd L
.29151 .07992 .58779 -0.80902 Mabsadd L
.29151 .07992 .36579 -0.11885 Mabsadd L
.29151 .07992 .95106 .30902 Mabsadd L
.29151 .07992 .22607 .31116 Mabsadd L
.29151 .07992 0 1 Mabsadd L closepath F
.2952 .07992 0 1 Mabsadd m
.2952 .07992 -0.22607 .31116 Mabsadd L
.2952 .07992 -0.95106 .30902 Mabsadd L
.2952 .07992 -0.36579 -0.11885 Mabsadd L
.2952 .07992 -0.58778 -0.80902 Mabsadd L
.2952 .07992 0 -0.38461 Mabsadd L
.2952 .07992 .58779 -0.80902 Mabsadd L
.2952 .07992 .36579 -0.11885 Mabsadd L
.2952 .07992 .95106 .30902 Mabsadd L
.2952 .07992 .22607 .31116 Mabsadd L
.2952 .07992 0 1 Mabsadd L closepath F
.29889 .07992 0 1 Mabsadd m
.29889 .07992 -0.22607 .31116 Mabsadd L
.29889 .07992 -0.95106 .30902 Mabsadd L
.29889 .07992 -0.36579 -0.11885 Mabsadd L
.29889 .07992 -0.58778 -0.80902 Mabsadd L
.29889 .07992 0 -0.38461 Mabsadd L
.29889 .07992 .58779 -0.80902 Mabsadd L
.29889 .07992 .36579 -0.11885 Mabsadd L
.29889 .07992 .95106 .30902 Mabsadd L
.29889 .07992 .22607 .31116 Mabsadd L
.29889 .07992 0 1 Mabsadd L closepath F
.30258 .07997 0 1 Mabsadd m
.30258 .07997 -0.22607 .31116 Mabsadd L
.30258 .07997 -0.95106 .30902 Mabsadd L
.30258 .07997 -0.36579 -0.11885 Mabsadd L
.30258 .07997 -0.58778 -0.80902 Mabsadd L
.30258 .07997 0 -0.38461 Mabsadd L
.30258 .07997 .58779 -0.80902 Mabsadd L
.30258 .07997 .36579 -0.11885 Mabsadd L
.30258 .07997 .95106 .30902 Mabsadd L
.30258 .07997 .22607 .31116 Mabsadd L
.30258 .07997 0 1 Mabsadd L closepath F
.30627 .07998 0 1 Mabsadd m
.30627 .07998 -0.22607 .31116 Mabsadd L
.30627 .07998 -0.95106 .30902 Mabsadd L
.30627 .07998 -0.36579 -0.11885 Mabsadd L
.30627 .07998 -0.58778 -0.80902 Mabsadd L
.30627 .07998 0 -0.38461 Mabsadd L
.30627 .07998 .58779 -0.80902 Mabsadd L
.30627 .07998 .36579 -0.11885 Mabsadd L
.30627 .07998 .95106 .30902 Mabsadd L
.30627 .07998 .22607 .31116 Mabsadd L
.30627 .07998 0 1 Mabsadd L closepath F
.30996 .07997 0 1 Mabsadd m
.30996 .07997 -0.22607 .31116 Mabsadd L
.30996 .07997 -0.95106 .30902 Mabsadd L
.30996 .07997 -0.36579 -0.11885 Mabsadd L
.30996 .07997 -0.58778 -0.80902 Mabsadd L
.30996 .07997 0 -0.38461 Mabsadd L
.30996 .07997 .58779 -0.80902 Mabsadd L
.30996 .07997 .36579 -0.11885 Mabsadd L
.30996 .07997 .95106 .30902 Mabsadd L
.30996 .07997 .22607 .31116 Mabsadd L
.30996 .07997 0 1 Mabsadd L closepath F
.31365 .07992 0 1 Mabsadd m
.31365 .07992 -0.22607 .31116 Mabsadd L
.31365 .07992 -0.95106 .30902 Mabsadd L
.31365 .07992 -0.36579 -0.11885 Mabsadd L
.31365 .07992 -0.58778 -0.80902 Mabsadd L
.31365 .07992 0 -0.38461 Mabsadd L
.31365 .07992 .58779 -0.80902 Mabsadd L
.31365 .07992 .36579 -0.11885 Mabsadd L
.31365 .07992 .95106 .30902 Mabsadd L
.31365 .07992 .22607 .31116 Mabsadd L
.31365 .07992 0 1 Mabsadd L closepath F
.31734 .07992 0 1 Mabsadd m
.31734 .07992 -0.22607 .31116 Mabsadd L
.31734 .07992 -0.95106 .30902 Mabsadd L
.31734 .07992 -0.36579 -0.11885 Mabsadd L
.31734 .07992 -0.58778 -0.80902 Mabsadd L
.31734 .07992 0 -0.38461 Mabsadd L
.31734 .07992 .58779 -0.80902 Mabsadd L
.31734 .07992 .36579 -0.11885 Mabsadd L
.31734 .07992 .95106 .30902 Mabsadd L
.31734 .07992 .22607 .31116 Mabsadd L
.31734 .07992 0 1 Mabsadd L closepath F
.32103 .07992 0 1 Mabsadd m
.32103 .07992 -0.22607 .31116 Mabsadd L
.32103 .07992 -0.95106 .30902 Mabsadd L
.32103 .07992 -0.36579 -0.11885 Mabsadd L
.32103 .07992 -0.58778 -0.80902 Mabsadd L
.32103 .07992 0 -0.38461 Mabsadd L
.32103 .07992 .58779 -0.80902 Mabsadd L
.32103 .07992 .36579 -0.11885 Mabsadd L
.32103 .07992 .95106 .30902 Mabsadd L
.32103 .07992 .22607 .31116 Mabsadd L
.32103 .07992 0 1 Mabsadd L closepath F
.32472 .07992 0 1 Mabsadd m
.32472 .07992 -0.22607 .31116 Mabsadd L
.32472 .07992 -0.95106 .30902 Mabsadd L
.32472 .07992 -0.36579 -0.11885 Mabsadd L
.32472 .07992 -0.58778 -0.80902 Mabsadd L
.32472 .07992 0 -0.38461 Mabsadd L
.32472 .07992 .58779 -0.80902 Mabsadd L
.32472 .07992 .36579 -0.11885 Mabsadd L
.32472 .07992 .95106 .30902 Mabsadd L
.32472 .07992 .22607 .31116 Mabsadd L
.32472 .07992 0 1 Mabsadd L closepath F
.32841 .07993 0 1 Mabsadd m
.32841 .07993 -0.22607 .31116 Mabsadd L
.32841 .07993 -0.95106 .30902 Mabsadd L
.32841 .07993 -0.36579 -0.11885 Mabsadd L
.32841 .07993 -0.58778 -0.80902 Mabsadd L
.32841 .07993 0 -0.38461 Mabsadd L
.32841 .07993 .58779 -0.80902 Mabsadd L
.32841 .07993 .36579 -0.11885 Mabsadd L
.32841 .07993 .95106 .30902 Mabsadd L
.32841 .07993 .22607 .31116 Mabsadd L
.32841 .07993 0 1 Mabsadd L closepath F
.3321 .07992 0 1 Mabsadd m
.3321 .07992 -0.22607 .31116 Mabsadd L
.3321 .07992 -0.95106 .30902 Mabsadd L
.3321 .07992 -0.36579 -0.11885 Mabsadd L
.3321 .07992 -0.58778 -0.80902 Mabsadd L
.3321 .07992 0 -0.38461 Mabsadd L
.3321 .07992 .58779 -0.80902 Mabsadd L
.3321 .07992 .36579 -0.11885 Mabsadd L
.3321 .07992 .95106 .30902 Mabsadd L
.3321 .07992 .22607 .31116 Mabsadd L
.3321 .07992 0 1 Mabsadd L closepath F
.33579 .07992 0 1 Mabsadd m
.33579 .07992 -0.22607 .31116 Mabsadd L
.33579 .07992 -0.95106 .30902 Mabsadd L
.33579 .07992 -0.36579 -0.11885 Mabsadd L
.33579 .07992 -0.58778 -0.80902 Mabsadd L
.33579 .07992 0 -0.38461 Mabsadd L
.33579 .07992 .58779 -0.80902 Mabsadd L
.33579 .07992 .36579 -0.11885 Mabsadd L
.33579 .07992 .95106 .30902 Mabsadd L
.33579 .07992 .22607 .31116 Mabsadd L
.33579 .07992 0 1 Mabsadd L closepath F
.33948 .07992 0 1 Mabsadd m
.33948 .07992 -0.22607 .31116 Mabsadd L
.33948 .07992 -0.95106 .30902 Mabsadd L
.33948 .07992 -0.36579 -0.11885 Mabsadd L
.33948 .07992 -0.58778 -0.80902 Mabsadd L
.33948 .07992 0 -0.38461 Mabsadd L
.33948 .07992 .58779 -0.80902 Mabsadd L
.33948 .07992 .36579 -0.11885 Mabsadd L
.33948 .07992 .95106 .30902 Mabsadd L
.33948 .07992 .22607 .31116 Mabsadd L
.33948 .07992 0 1 Mabsadd L closepath F
.34317 .07992 0 1 Mabsadd m
.34317 .07992 -0.22607 .31116 Mabsadd L
.34317 .07992 -0.95106 .30902 Mabsadd L
.34317 .07992 -0.36579 -0.11885 Mabsadd L
.34317 .07992 -0.58778 -0.80902 Mabsadd L
.34317 .07992 0 -0.38461 Mabsadd L
.34317 .07992 .58779 -0.80902 Mabsadd L
.34317 .07992 .36579 -0.11885 Mabsadd L
.34317 .07992 .95106 .30902 Mabsadd L
.34317 .07992 .22607 .31116 Mabsadd L
.34317 .07992 0 1 Mabsadd L closepath F
.34686 .07992 0 1 Mabsadd m
.34686 .07992 -0.22607 .31116 Mabsadd L
.34686 .07992 -0.95106 .30902 Mabsadd L
.34686 .07992 -0.36579 -0.11885 Mabsadd L
.34686 .07992 -0.58778 -0.80902 Mabsadd L
.34686 .07992 0 -0.38461 Mabsadd L
.34686 .07992 .58779 -0.80902 Mabsadd L
.34686 .07992 .36579 -0.11885 Mabsadd L
.34686 .07992 .95106 .30902 Mabsadd L
.34686 .07992 .22607 .31116 Mabsadd L
.34686 .07992 0 1 Mabsadd L closepath F
.35055 .07992 0 1 Mabsadd m
.35055 .07992 -0.22607 .31116 Mabsadd L
.35055 .07992 -0.95106 .30902 Mabsadd L
.35055 .07992 -0.36579 -0.11885 Mabsadd L
.35055 .07992 -0.58778 -0.80902 Mabsadd L
.35055 .07992 0 -0.38461 Mabsadd L
.35055 .07992 .58779 -0.80902 Mabsadd L
.35055 .07992 .36579 -0.11885 Mabsadd L
.35055 .07992 .95106 .30902 Mabsadd L
.35055 .07992 .22607 .31116 Mabsadd L
.35055 .07992 0 1 Mabsadd L closepath F
.35424 .07992 0 1 Mabsadd m
.35424 .07992 -0.22607 .31116 Mabsadd L
.35424 .07992 -0.95106 .30902 Mabsadd L
.35424 .07992 -0.36579 -0.11885 Mabsadd L
.35424 .07992 -0.58778 -0.80902 Mabsadd L
.35424 .07992 0 -0.38461 Mabsadd L
.35424 .07992 .58779 -0.80902 Mabsadd L
.35424 .07992 .36579 -0.11885 Mabsadd L
.35424 .07992 .95106 .30902 Mabsadd L
.35424 .07992 .22607 .31116 Mabsadd L
.35424 .07992 0 1 Mabsadd L closepath F
.35793 .07992 0 1 Mabsadd m
.35793 .07992 -0.22607 .31116 Mabsadd L
.35793 .07992 -0.95106 .30902 Mabsadd L
.35793 .07992 -0.36579 -0.11885 Mabsadd L
.35793 .07992 -0.58778 -0.80902 Mabsadd L
.35793 .07992 0 -0.38461 Mabsadd L
.35793 .07992 .58779 -0.80902 Mabsadd L
.35793 .07992 .36579 -0.11885 Mabsadd L
.35793 .07992 .95106 .30902 Mabsadd L
.35793 .07992 .22607 .31116 Mabsadd L
.35793 .07992 0 1 Mabsadd L closepath F
.36162 .07992 0 1 Mabsadd m
.36162 .07992 -0.22607 .31116 Mabsadd L
.36162 .07992 -0.95106 .30902 Mabsadd L
.36162 .07992 -0.36579 -0.11885 Mabsadd L
.36162 .07992 -0.58778 -0.80902 Mabsadd L
.36162 .07992 0 -0.38461 Mabsadd L
.36162 .07992 .58779 -0.80902 Mabsadd L
.36162 .07992 .36579 -0.11885 Mabsadd L
.36162 .07992 .95106 .30902 Mabsadd L
.36162 .07992 .22607 .31116 Mabsadd L
.36162 .07992 0 1 Mabsadd L closepath F
.36531 .07992 0 1 Mabsadd m
.36531 .07992 -0.22607 .31116 Mabsadd L
.36531 .07992 -0.95106 .30902 Mabsadd L
.36531 .07992 -0.36579 -0.11885 Mabsadd L
.36531 .07992 -0.58778 -0.80902 Mabsadd L
.36531 .07992 0 -0.38461 Mabsadd L
.36531 .07992 .58779 -0.80902 Mabsadd L
.36531 .07992 .36579 -0.11885 Mabsadd L
.36531 .07992 .95106 .30902 Mabsadd L
.36531 .07992 .22607 .31116 Mabsadd L
.36531 .07992 0 1 Mabsadd L closepath F
.369 .07992 0 1 Mabsadd m
.369 .07992 -0.22607 .31116 Mabsadd L
.369 .07992 -0.95106 .30902 Mabsadd L
.369 .07992 -0.36579 -0.11885 Mabsadd L
.369 .07992 -0.58778 -0.80902 Mabsadd L
.369 .07992 0 -0.38461 Mabsadd L
.369 .07992 .58779 -0.80902 Mabsadd L
.369 .07992 .36579 -0.11885 Mabsadd L
.369 .07992 .95106 .30902 Mabsadd L
.369 .07992 .22607 .31116 Mabsadd L
.369 .07992 0 1 Mabsadd L closepath F
.37269 .07992 0 1 Mabsadd m
.37269 .07992 -0.22607 .31116 Mabsadd L
.37269 .07992 -0.95106 .30902 Mabsadd L
.37269 .07992 -0.36579 -0.11885 Mabsadd L
.37269 .07992 -0.58778 -0.80902 Mabsadd L
.37269 .07992 0 -0.38461 Mabsadd L
.37269 .07992 .58779 -0.80902 Mabsadd L
.37269 .07992 .36579 -0.11885 Mabsadd L
.37269 .07992 .95106 .30902 Mabsadd L
.37269 .07992 .22607 .31116 Mabsadd L
.37269 .07992 0 1 Mabsadd L closepath F
.37638 .07997 0 1 Mabsadd m
.37638 .07997 -0.22607 .31116 Mabsadd L
.37638 .07997 -0.95106 .30902 Mabsadd L
.37638 .07997 -0.36579 -0.11885 Mabsadd L
.37638 .07997 -0.58778 -0.80902 Mabsadd L
.37638 .07997 0 -0.38461 Mabsadd L
.37638 .07997 .58779 -0.80902 Mabsadd L
.37638 .07997 .36579 -0.11885 Mabsadd L
.37638 .07997 .95106 .30902 Mabsadd L
.37638 .07997 .22607 .31116 Mabsadd L
.37638 .07997 0 1 Mabsadd L closepath F
.38007 .08002 0 1 Mabsadd m
.38007 .08002 -0.22607 .31116 Mabsadd L
.38007 .08002 -0.95106 .30902 Mabsadd L
.38007 .08002 -0.36579 -0.11885 Mabsadd L
.38007 .08002 -0.58778 -0.80902 Mabsadd L
.38007 .08002 0 -0.38461 Mabsadd L
.38007 .08002 .58779 -0.80902 Mabsadd L
.38007 .08002 .36579 -0.11885 Mabsadd L
.38007 .08002 .95106 .30902 Mabsadd L
.38007 .08002 .22607 .31116 Mabsadd L
.38007 .08002 0 1 Mabsadd L closepath F
.38376 .08002 0 1 Mabsadd m
.38376 .08002 -0.22607 .31116 Mabsadd L
.38376 .08002 -0.95106 .30902 Mabsadd L
.38376 .08002 -0.36579 -0.11885 Mabsadd L
.38376 .08002 -0.58778 -0.80902 Mabsadd L
.38376 .08002 0 -0.38461 Mabsadd L
.38376 .08002 .58779 -0.80902 Mabsadd L
.38376 .08002 .36579 -0.11885 Mabsadd L
.38376 .08002 .95106 .30902 Mabsadd L
.38376 .08002 .22607 .31116 Mabsadd L
.38376 .08002 0 1 Mabsadd L closepath F
.38745 .08003 0 1 Mabsadd m
.38745 .08003 -0.22607 .31116 Mabsadd L
.38745 .08003 -0.95106 .30902 Mabsadd L
.38745 .08003 -0.36579 -0.11885 Mabsadd L
.38745 .08003 -0.58778 -0.80902 Mabsadd L
.38745 .08003 0 -0.38461 Mabsadd L
.38745 .08003 .58779 -0.80902 Mabsadd L
.38745 .08003 .36579 -0.11885 Mabsadd L
.38745 .08003 .95106 .30902 Mabsadd L
.38745 .08003 .22607 .31116 Mabsadd L
.38745 .08003 0 1 Mabsadd L closepath F
.39114 .07997 0 1 Mabsadd m
.39114 .07997 -0.22607 .31116 Mabsadd L
.39114 .07997 -0.95106 .30902 Mabsadd L
.39114 .07997 -0.36579 -0.11885 Mabsadd L
.39114 .07997 -0.58778 -0.80902 Mabsadd L
.39114 .07997 0 -0.38461 Mabsadd L
.39114 .07997 .58779 -0.80902 Mabsadd L
.39114 .07997 .36579 -0.11885 Mabsadd L
.39114 .07997 .95106 .30902 Mabsadd L
.39114 .07997 .22607 .31116 Mabsadd L
.39114 .07997 0 1 Mabsadd L closepath F
.39483 .07997 0 1 Mabsadd m
.39483 .07997 -0.22607 .31116 Mabsadd L
.39483 .07997 -0.95106 .30902 Mabsadd L
.39483 .07997 -0.36579 -0.11885 Mabsadd L
.39483 .07997 -0.58778 -0.80902 Mabsadd L
.39483 .07997 0 -0.38461 Mabsadd L
.39483 .07997 .58779 -0.80902 Mabsadd L
.39483 .07997 .36579 -0.11885 Mabsadd L
.39483 .07997 .95106 .30902 Mabsadd L
.39483 .07997 .22607 .31116 Mabsadd L
.39483 .07997 0 1 Mabsadd L closepath F
.39852 .07997 0 1 Mabsadd m
.39852 .07997 -0.22607 .31116 Mabsadd L
.39852 .07997 -0.95106 .30902 Mabsadd L
.39852 .07997 -0.36579 -0.11885 Mabsadd L
.39852 .07997 -0.58778 -0.80902 Mabsadd L
.39852 .07997 0 -0.38461 Mabsadd L
.39852 .07997 .58779 -0.80902 Mabsadd L
.39852 .07997 .36579 -0.11885 Mabsadd L
.39852 .07997 .95106 .30902 Mabsadd L
.39852 .07997 .22607 .31116 Mabsadd L
.39852 .07997 0 1 Mabsadd L closepath F
.40221 .07992 0 1 Mabsadd m
.40221 .07992 -0.22607 .31116 Mabsadd L
.40221 .07992 -0.95106 .30902 Mabsadd L
.40221 .07992 -0.36579 -0.11885 Mabsadd L
.40221 .07992 -0.58778 -0.80902 Mabsadd L
.40221 .07992 0 -0.38461 Mabsadd L
.40221 .07992 .58779 -0.80902 Mabsadd L
.40221 .07992 .36579 -0.11885 Mabsadd L
.40221 .07992 .95106 .30902 Mabsadd L
.40221 .07992 .22607 .31116 Mabsadd L
.40221 .07992 0 1 Mabsadd L closepath F
.4059 .07992 0 1 Mabsadd m
.4059 .07992 -0.22607 .31116 Mabsadd L
.4059 .07992 -0.95106 .30902 Mabsadd L
.4059 .07992 -0.36579 -0.11885 Mabsadd L
.4059 .07992 -0.58778 -0.80902 Mabsadd L
.4059 .07992 0 -0.38461 Mabsadd L
.4059 .07992 .58779 -0.80902 Mabsadd L
.4059 .07992 .36579 -0.11885 Mabsadd L
.4059 .07992 .95106 .30902 Mabsadd L
.4059 .07992 .22607 .31116 Mabsadd L
.4059 .07992 0 1 Mabsadd L closepath F
.40959 .07992 0 1 Mabsadd m
.40959 .07992 -0.22607 .31116 Mabsadd L
.40959 .07992 -0.95106 .30902 Mabsadd L
.40959 .07992 -0.36579 -0.11885 Mabsadd L
.40959 .07992 -0.58778 -0.80902 Mabsadd L
.40959 .07992 0 -0.38461 Mabsadd L
.40959 .07992 .58779 -0.80902 Mabsadd L
.40959 .07992 .36579 -0.11885 Mabsadd L
.40959 .07992 .95106 .30902 Mabsadd L
.40959 .07992 .22607 .31116 Mabsadd L
.40959 .07992 0 1 Mabsadd L closepath F
.41328 .07992 0 1 Mabsadd m
.41328 .07992 -0.22607 .31116 Mabsadd L
.41328 .07992 -0.95106 .30902 Mabsadd L
.41328 .07992 -0.36579 -0.11885 Mabsadd L
.41328 .07992 -0.58778 -0.80902 Mabsadd L
.41328 .07992 0 -0.38461 Mabsadd L
.41328 .07992 .58779 -0.80902 Mabsadd L
.41328 .07992 .36579 -0.11885 Mabsadd L
.41328 .07992 .95106 .30902 Mabsadd L
.41328 .07992 .22607 .31116 Mabsadd L
.41328 .07992 0 1 Mabsadd L closepath F
.41697 .07997 0 1 Mabsadd m
.41697 .07997 -0.22607 .31116 Mabsadd L
.41697 .07997 -0.95106 .30902 Mabsadd L
.41697 .07997 -0.36579 -0.11885 Mabsadd L
.41697 .07997 -0.58778 -0.80902 Mabsadd L
.41697 .07997 0 -0.38461 Mabsadd L
.41697 .07997 .58779 -0.80902 Mabsadd L
.41697 .07997 .36579 -0.11885 Mabsadd L
.41697 .07997 .95106 .30902 Mabsadd L
.41697 .07997 .22607 .31116 Mabsadd L
.41697 .07997 0 1 Mabsadd L closepath F
.42066 .07997 0 1 Mabsadd m
.42066 .07997 -0.22607 .31116 Mabsadd L
.42066 .07997 -0.95106 .30902 Mabsadd L
.42066 .07997 -0.36579 -0.11885 Mabsadd L
.42066 .07997 -0.58778 -0.80902 Mabsadd L
.42066 .07997 0 -0.38461 Mabsadd L
.42066 .07997 .58779 -0.80902 Mabsadd L
.42066 .07997 .36579 -0.11885 Mabsadd L
.42066 .07997 .95106 .30902 Mabsadd L
.42066 .07997 .22607 .31116 Mabsadd L
.42066 .07997 0 1 Mabsadd L closepath F
.42435 .07998 0 1 Mabsadd m
.42435 .07998 -0.22607 .31116 Mabsadd L
.42435 .07998 -0.95106 .30902 Mabsadd L
.42435 .07998 -0.36579 -0.11885 Mabsadd L
.42435 .07998 -0.58778 -0.80902 Mabsadd L
.42435 .07998 0 -0.38461 Mabsadd L
.42435 .07998 .58779 -0.80902 Mabsadd L
.42435 .07998 .36579 -0.11885 Mabsadd L
.42435 .07998 .95106 .30902 Mabsadd L
.42435 .07998 .22607 .31116 Mabsadd L
.42435 .07998 0 1 Mabsadd L closepath F
.42804 .07992 0 1 Mabsadd m
.42804 .07992 -0.22607 .31116 Mabsadd L
.42804 .07992 -0.95106 .30902 Mabsadd L
.42804 .07992 -0.36579 -0.11885 Mabsadd L
.42804 .07992 -0.58778 -0.80902 Mabsadd L
.42804 .07992 0 -0.38461 Mabsadd L
.42804 .07992 .58779 -0.80902 Mabsadd L
.42804 .07992 .36579 -0.11885 Mabsadd L
.42804 .07992 .95106 .30902 Mabsadd L
.42804 .07992 .22607 .31116 Mabsadd L
.42804 .07992 0 1 Mabsadd L closepath F
.43173 .07992 0 1 Mabsadd m
.43173 .07992 -0.22607 .31116 Mabsadd L
.43173 .07992 -0.95106 .30902 Mabsadd L
.43173 .07992 -0.36579 -0.11885 Mabsadd L
.43173 .07992 -0.58778 -0.80902 Mabsadd L
.43173 .07992 0 -0.38461 Mabsadd L
.43173 .07992 .58779 -0.80902 Mabsadd L
.43173 .07992 .36579 -0.11885 Mabsadd L
.43173 .07992 .95106 .30902 Mabsadd L
.43173 .07992 .22607 .31116 Mabsadd L
.43173 .07992 0 1 Mabsadd L closepath F
.43542 .07992 0 1 Mabsadd m
.43542 .07992 -0.22607 .31116 Mabsadd L
.43542 .07992 -0.95106 .30902 Mabsadd L
.43542 .07992 -0.36579 -0.11885 Mabsadd L
.43542 .07992 -0.58778 -0.80902 Mabsadd L
.43542 .07992 0 -0.38461 Mabsadd L
.43542 .07992 .58779 -0.80902 Mabsadd L
.43542 .07992 .36579 -0.11885 Mabsadd L
.43542 .07992 .95106 .30902 Mabsadd L
.43542 .07992 .22607 .31116 Mabsadd L
.43542 .07992 0 1 Mabsadd L closepath F
.43911 .07992 0 1 Mabsadd m
.43911 .07992 -0.22607 .31116 Mabsadd L
.43911 .07992 -0.95106 .30902 Mabsadd L
.43911 .07992 -0.36579 -0.11885 Mabsadd L
.43911 .07992 -0.58778 -0.80902 Mabsadd L
.43911 .07992 0 -0.38461 Mabsadd L
.43911 .07992 .58779 -0.80902 Mabsadd L
.43911 .07992 .36579 -0.11885 Mabsadd L
.43911 .07992 .95106 .30902 Mabsadd L
.43911 .07992 .22607 .31116 Mabsadd L
.43911 .07992 0 1 Mabsadd L closepath F
.4428 .07992 0 1 Mabsadd m
.4428 .07992 -0.22607 .31116 Mabsadd L
.4428 .07992 -0.95106 .30902 Mabsadd L
.4428 .07992 -0.36579 -0.11885 Mabsadd L
.4428 .07992 -0.58778 -0.80902 Mabsadd L
.4428 .07992 0 -0.38461 Mabsadd L
.4428 .07992 .58779 -0.80902 Mabsadd L
.4428 .07992 .36579 -0.11885 Mabsadd L
.4428 .07992 .95106 .30902 Mabsadd L
.4428 .07992 .22607 .31116 Mabsadd L
.4428 .07992 0 1 Mabsadd L closepath F
.44649 .07992 0 1 Mabsadd m
.44649 .07992 -0.22607 .31116 Mabsadd L
.44649 .07992 -0.95106 .30902 Mabsadd L
.44649 .07992 -0.36579 -0.11885 Mabsadd L
.44649 .07992 -0.58778 -0.80902 Mabsadd L
.44649 .07992 0 -0.38461 Mabsadd L
.44649 .07992 .58779 -0.80902 Mabsadd L
.44649 .07992 .36579 -0.11885 Mabsadd L
.44649 .07992 .95106 .30902 Mabsadd L
.44649 .07992 .22607 .31116 Mabsadd L
.44649 .07992 0 1 Mabsadd L closepath F
.45018 .07992 0 1 Mabsadd m
.45018 .07992 -0.22607 .31116 Mabsadd L
.45018 .07992 -0.95106 .30902 Mabsadd L
.45018 .07992 -0.36579 -0.11885 Mabsadd L
.45018 .07992 -0.58778 -0.80902 Mabsadd L
.45018 .07992 0 -0.38461 Mabsadd L
.45018 .07992 .58779 -0.80902 Mabsadd L
.45018 .07992 .36579 -0.11885 Mabsadd L
.45018 .07992 .95106 .30902 Mabsadd L
.45018 .07992 .22607 .31116 Mabsadd L
.45018 .07992 0 1 Mabsadd L closepath F
.45387 .07992 0 1 Mabsadd m
.45387 .07992 -0.22607 .31116 Mabsadd L
.45387 .07992 -0.95106 .30902 Mabsadd L
.45387 .07992 -0.36579 -0.11885 Mabsadd L
.45387 .07992 -0.58778 -0.80902 Mabsadd L
.45387 .07992 0 -0.38461 Mabsadd L
.45387 .07992 .58779 -0.80902 Mabsadd L
.45387 .07992 .36579 -0.11885 Mabsadd L
.45387 .07992 .95106 .30902 Mabsadd L
.45387 .07992 .22607 .31116 Mabsadd L
.45387 .07992 0 1 Mabsadd L closepath F
.45756 .07992 0 1 Mabsadd m
.45756 .07992 -0.22607 .31116 Mabsadd L
.45756 .07992 -0.95106 .30902 Mabsadd L
.45756 .07992 -0.36579 -0.11885 Mabsadd L
.45756 .07992 -0.58778 -0.80902 Mabsadd L
.45756 .07992 0 -0.38461 Mabsadd L
.45756 .07992 .58779 -0.80902 Mabsadd L
.45756 .07992 .36579 -0.11885 Mabsadd L
.45756 .07992 .95106 .30902 Mabsadd L
.45756 .07992 .22607 .31116 Mabsadd L
.45756 .07992 0 1 Mabsadd L closepath F
.46125 .07992 0 1 Mabsadd m
.46125 .07992 -0.22607 .31116 Mabsadd L
.46125 .07992 -0.95106 .30902 Mabsadd L
.46125 .07992 -0.36579 -0.11885 Mabsadd L
.46125 .07992 -0.58778 -0.80902 Mabsadd L
.46125 .07992 0 -0.38461 Mabsadd L
.46125 .07992 .58779 -0.80902 Mabsadd L
.46125 .07992 .36579 -0.11885 Mabsadd L
.46125 .07992 .95106 .30902 Mabsadd L
.46125 .07992 .22607 .31116 Mabsadd L
.46125 .07992 0 1 Mabsadd L closepath F
.46494 .07992 0 1 Mabsadd m
.46494 .07992 -0.22607 .31116 Mabsadd L
.46494 .07992 -0.95106 .30902 Mabsadd L
.46494 .07992 -0.36579 -0.11885 Mabsadd L
.46494 .07992 -0.58778 -0.80902 Mabsadd L
.46494 .07992 0 -0.38461 Mabsadd L
.46494 .07992 .58779 -0.80902 Mabsadd L
.46494 .07992 .36579 -0.11885 Mabsadd L
.46494 .07992 .95106 .30902 Mabsadd L
.46494 .07992 .22607 .31116 Mabsadd L
.46494 .07992 0 1 Mabsadd L closepath F
.46863 .07992 0 1 Mabsadd m
.46863 .07992 -0.22607 .31116 Mabsadd L
.46863 .07992 -0.95106 .30902 Mabsadd L
.46863 .07992 -0.36579 -0.11885 Mabsadd L
.46863 .07992 -0.58778 -0.80902 Mabsadd L
.46863 .07992 0 -0.38461 Mabsadd L
.46863 .07992 .58779 -0.80902 Mabsadd L
.46863 .07992 .36579 -0.11885 Mabsadd L
.46863 .07992 .95106 .30902 Mabsadd L
.46863 .07992 .22607 .31116 Mabsadd L
.46863 .07992 0 1 Mabsadd L closepath F
.47232 .07992 0 1 Mabsadd m
.47232 .07992 -0.22607 .31116 Mabsadd L
.47232 .07992 -0.95106 .30902 Mabsadd L
.47232 .07992 -0.36579 -0.11885 Mabsadd L
.47232 .07992 -0.58778 -0.80902 Mabsadd L
.47232 .07992 0 -0.38461 Mabsadd L
.47232 .07992 .58779 -0.80902 Mabsadd L
.47232 .07992 .36579 -0.11885 Mabsadd L
.47232 .07992 .95106 .30902 Mabsadd L
.47232 .07992 .22607 .31116 Mabsadd L
.47232 .07992 0 1 Mabsadd L closepath F
.47601 .07992 0 1 Mabsadd m
.47601 .07992 -0.22607 .31116 Mabsadd L
.47601 .07992 -0.95106 .30902 Mabsadd L
.47601 .07992 -0.36579 -0.11885 Mabsadd L
.47601 .07992 -0.58778 -0.80902 Mabsadd L
.47601 .07992 0 -0.38461 Mabsadd L
.47601 .07992 .58779 -0.80902 Mabsadd L
.47601 .07992 .36579 -0.11885 Mabsadd L
.47601 .07992 .95106 .30902 Mabsadd L
.47601 .07992 .22607 .31116 Mabsadd L
.47601 .07992 0 1 Mabsadd L closepath F
.4797 .07992 0 1 Mabsadd m
.4797 .07992 -0.22607 .31116 Mabsadd L
.4797 .07992 -0.95106 .30902 Mabsadd L
.4797 .07992 -0.36579 -0.11885 Mabsadd L
.4797 .07992 -0.58778 -0.80902 Mabsadd L
.4797 .07992 0 -0.38461 Mabsadd L
.4797 .07992 .58779 -0.80902 Mabsadd L
.4797 .07992 .36579 -0.11885 Mabsadd L
.4797 .07992 .95106 .30902 Mabsadd L
.4797 .07992 .22607 .31116 Mabsadd L
.4797 .07992 0 1 Mabsadd L closepath F
.48339 .07992 0 1 Mabsadd m
.48339 .07992 -0.22607 .31116 Mabsadd L
.48339 .07992 -0.95106 .30902 Mabsadd L
.48339 .07992 -0.36579 -0.11885 Mabsadd L
.48339 .07992 -0.58778 -0.80902 Mabsadd L
.48339 .07992 0 -0.38461 Mabsadd L
.48339 .07992 .58779 -0.80902 Mabsadd L
.48339 .07992 .36579 -0.11885 Mabsadd L
.48339 .07992 .95106 .30902 Mabsadd L
.48339 .07992 .22607 .31116 Mabsadd L
.48339 .07992 0 1 Mabsadd L closepath F
.48708 .07997 0 1 Mabsadd m
.48708 .07997 -0.22607 .31116 Mabsadd L
.48708 .07997 -0.95106 .30902 Mabsadd L
.48708 .07997 -0.36579 -0.11885 Mabsadd L
.48708 .07997 -0.58778 -0.80902 Mabsadd L
.48708 .07997 0 -0.38461 Mabsadd L
.48708 .07997 .58779 -0.80902 Mabsadd L
.48708 .07997 .36579 -0.11885 Mabsadd L
.48708 .07997 .95106 .30902 Mabsadd L
.48708 .07997 .22607 .31116 Mabsadd L
.48708 .07997 0 1 Mabsadd L closepath F
.49077 .07997 0 1 Mabsadd m
.49077 .07997 -0.22607 .31116 Mabsadd L
.49077 .07997 -0.95106 .30902 Mabsadd L
.49077 .07997 -0.36579 -0.11885 Mabsadd L
.49077 .07997 -0.58778 -0.80902 Mabsadd L
.49077 .07997 0 -0.38461 Mabsadd L
.49077 .07997 .58779 -0.80902 Mabsadd L
.49077 .07997 .36579 -0.11885 Mabsadd L
.49077 .07997 .95106 .30902 Mabsadd L
.49077 .07997 .22607 .31116 Mabsadd L
.49077 .07997 0 1 Mabsadd L closepath F
.49446 .07997 0 1 Mabsadd m
.49446 .07997 -0.22607 .31116 Mabsadd L
.49446 .07997 -0.95106 .30902 Mabsadd L
.49446 .07997 -0.36579 -0.11885 Mabsadd L
.49446 .07997 -0.58778 -0.80902 Mabsadd L
.49446 .07997 0 -0.38461 Mabsadd L
.49446 .07997 .58779 -0.80902 Mabsadd L
.49446 .07997 .36579 -0.11885 Mabsadd L
.49446 .07997 .95106 .30902 Mabsadd L
.49446 .07997 .22607 .31116 Mabsadd L
.49446 .07997 0 1 Mabsadd L closepath F
.49815 .08002 0 1 Mabsadd m
.49815 .08002 -0.22607 .31116 Mabsadd L
.49815 .08002 -0.95106 .30902 Mabsadd L
.49815 .08002 -0.36579 -0.11885 Mabsadd L
.49815 .08002 -0.58778 -0.80902 Mabsadd L
.49815 .08002 0 -0.38461 Mabsadd L
.49815 .08002 .58779 -0.80902 Mabsadd L
.49815 .08002 .36579 -0.11885 Mabsadd L
.49815 .08002 .95106 .30902 Mabsadd L
.49815 .08002 .22607 .31116 Mabsadd L
.49815 .08002 0 1 Mabsadd L closepath F
.50185 .08 0 1 Mabsadd m
.50185 .08 -0.22607 .31116 Mabsadd L
.50185 .08 -0.95106 .30902 Mabsadd L
.50185 .08 -0.36579 -0.11885 Mabsadd L
.50185 .08 -0.58778 -0.80902 Mabsadd L
.50185 .08 0 -0.38461 Mabsadd L
.50185 .08 .58779 -0.80902 Mabsadd L
.50185 .08 .36579 -0.11885 Mabsadd L
.50185 .08 .95106 .30902 Mabsadd L
.50185 .08 .22607 .31116 Mabsadd L
.50185 .08 0 1 Mabsadd L closepath F
.50554 .07997 0 1 Mabsadd m
.50554 .07997 -0.22607 .31116 Mabsadd L
.50554 .07997 -0.95106 .30902 Mabsadd L
.50554 .07997 -0.36579 -0.11885 Mabsadd L
.50554 .07997 -0.58778 -0.80902 Mabsadd L
.50554 .07997 0 -0.38461 Mabsadd L
.50554 .07997 .58779 -0.80902 Mabsadd L
.50554 .07997 .36579 -0.11885 Mabsadd L
.50554 .07997 .95106 .30902 Mabsadd L
.50554 .07997 .22607 .31116 Mabsadd L
.50554 .07997 0 1 Mabsadd L closepath F
.50923 .07992 0 1 Mabsadd m
.50923 .07992 -0.22607 .31116 Mabsadd L
.50923 .07992 -0.95106 .30902 Mabsadd L
.50923 .07992 -0.36579 -0.11885 Mabsadd L
.50923 .07992 -0.58778 -0.80902 Mabsadd L
.50923 .07992 0 -0.38461 Mabsadd L
.50923 .07992 .58779 -0.80902 Mabsadd L
.50923 .07992 .36579 -0.11885 Mabsadd L
.50923 .07992 .95106 .30902 Mabsadd L
.50923 .07992 .22607 .31116 Mabsadd L
.50923 .07992 0 1 Mabsadd L closepath F
.51292 .07992 0 1 Mabsadd m
.51292 .07992 -0.22607 .31116 Mabsadd L
.51292 .07992 -0.95106 .30902 Mabsadd L
.51292 .07992 -0.36579 -0.11885 Mabsadd L
.51292 .07992 -0.58778 -0.80902 Mabsadd L
.51292 .07992 0 -0.38461 Mabsadd L
.51292 .07992 .58779 -0.80902 Mabsadd L
.51292 .07992 .36579 -0.11885 Mabsadd L
.51292 .07992 .95106 .30902 Mabsadd L
.51292 .07992 .22607 .31116 Mabsadd L
.51292 .07992 0 1 Mabsadd L closepath F
.51661 .07995 0 1 Mabsadd m
.51661 .07995 -0.22607 .31116 Mabsadd L
.51661 .07995 -0.95106 .30902 Mabsadd L
.51661 .07995 -0.36579 -0.11885 Mabsadd L
.51661 .07995 -0.58778 -0.80902 Mabsadd L
.51661 .07995 0 -0.38461 Mabsadd L
.51661 .07995 .58779 -0.80902 Mabsadd L
.51661 .07995 .36579 -0.11885 Mabsadd L
.51661 .07995 .95106 .30902 Mabsadd L
.51661 .07995 .22607 .31116 Mabsadd L
.51661 .07995 0 1 Mabsadd L closepath F
.5203 .07992 0 1 Mabsadd m
.5203 .07992 -0.22607 .31116 Mabsadd L
.5203 .07992 -0.95106 .30902 Mabsadd L
.5203 .07992 -0.36579 -0.11885 Mabsadd L
.5203 .07992 -0.58778 -0.80902 Mabsadd L
.5203 .07992 0 -0.38461 Mabsadd L
.5203 .07992 .58779 -0.80902 Mabsadd L
.5203 .07992 .36579 -0.11885 Mabsadd L
.5203 .07992 .95106 .30902 Mabsadd L
.5203 .07992 .22607 .31116 Mabsadd L
.5203 .07992 0 1 Mabsadd L closepath F
.52399 .07992 0 1 Mabsadd m
.52399 .07992 -0.22607 .31116 Mabsadd L
.52399 .07992 -0.95106 .30902 Mabsadd L
.52399 .07992 -0.36579 -0.11885 Mabsadd L
.52399 .07992 -0.58778 -0.80902 Mabsadd L
.52399 .07992 0 -0.38461 Mabsadd L
.52399 .07992 .58779 -0.80902 Mabsadd L
.52399 .07992 .36579 -0.11885 Mabsadd L
.52399 .07992 .95106 .30902 Mabsadd L
.52399 .07992 .22607 .31116 Mabsadd L
.52399 .07992 0 1 Mabsadd L closepath F
.52768 .07992 0 1 Mabsadd m
.52768 .07992 -0.22607 .31116 Mabsadd L
.52768 .07992 -0.95106 .30902 Mabsadd L
.52768 .07992 -0.36579 -0.11885 Mabsadd L
.52768 .07992 -0.58778 -0.80902 Mabsadd L
.52768 .07992 0 -0.38461 Mabsadd L
.52768 .07992 .58779 -0.80902 Mabsadd L
.52768 .07992 .36579 -0.11885 Mabsadd L
.52768 .07992 .95106 .30902 Mabsadd L
.52768 .07992 .22607 .31116 Mabsadd L
.52768 .07992 0 1 Mabsadd L closepath F
.53137 .07992 0 1 Mabsadd m
.53137 .07992 -0.22607 .31116 Mabsadd L
.53137 .07992 -0.95106 .30902 Mabsadd L
.53137 .07992 -0.36579 -0.11885 Mabsadd L
.53137 .07992 -0.58778 -0.80902 Mabsadd L
.53137 .07992 0 -0.38461 Mabsadd L
.53137 .07992 .58779 -0.80902 Mabsadd L
.53137 .07992 .36579 -0.11885 Mabsadd L
.53137 .07992 .95106 .30902 Mabsadd L
.53137 .07992 .22607 .31116 Mabsadd L
.53137 .07992 0 1 Mabsadd L closepath F
.53506 .07992 0 1 Mabsadd m
.53506 .07992 -0.22607 .31116 Mabsadd L
.53506 .07992 -0.95106 .30902 Mabsadd L
.53506 .07992 -0.36579 -0.11885 Mabsadd L
.53506 .07992 -0.58778 -0.80902 Mabsadd L
.53506 .07992 0 -0.38461 Mabsadd L
.53506 .07992 .58779 -0.80902 Mabsadd L
.53506 .07992 .36579 -0.11885 Mabsadd L
.53506 .07992 .95106 .30902 Mabsadd L
.53506 .07992 .22607 .31116 Mabsadd L
.53506 .07992 0 1 Mabsadd L closepath F
.53875 .07992 0 1 Mabsadd m
.53875 .07992 -0.22607 .31116 Mabsadd L
.53875 .07992 -0.95106 .30902 Mabsadd L
.53875 .07992 -0.36579 -0.11885 Mabsadd L
.53875 .07992 -0.58778 -0.80902 Mabsadd L
.53875 .07992 0 -0.38461 Mabsadd L
.53875 .07992 .58779 -0.80902 Mabsadd L
.53875 .07992 .36579 -0.11885 Mabsadd L
.53875 .07992 .95106 .30902 Mabsadd L
.53875 .07992 .22607 .31116 Mabsadd L
.53875 .07992 0 1 Mabsadd L closepath F
.54244 .07992 0 1 Mabsadd m
.54244 .07992 -0.22607 .31116 Mabsadd L
.54244 .07992 -0.95106 .30902 Mabsadd L
.54244 .07992 -0.36579 -0.11885 Mabsadd L
.54244 .07992 -0.58778 -0.80902 Mabsadd L
.54244 .07992 0 -0.38461 Mabsadd L
.54244 .07992 .58779 -0.80902 Mabsadd L
.54244 .07992 .36579 -0.11885 Mabsadd L
.54244 .07992 .95106 .30902 Mabsadd L
.54244 .07992 .22607 .31116 Mabsadd L
.54244 .07992 0 1 Mabsadd L closepath F
.54613 .07995 0 1 Mabsadd m
.54613 .07995 -0.22607 .31116 Mabsadd L
.54613 .07995 -0.95106 .30902 Mabsadd L
.54613 .07995 -0.36579 -0.11885 Mabsadd L
.54613 .07995 -0.58778 -0.80902 Mabsadd L
.54613 .07995 0 -0.38461 Mabsadd L
.54613 .07995 .58779 -0.80902 Mabsadd L
.54613 .07995 .36579 -0.11885 Mabsadd L
.54613 .07995 .95106 .30902 Mabsadd L
.54613 .07995 .22607 .31116 Mabsadd L
.54613 .07995 0 1 Mabsadd L closepath F
.54982 .07992 0 1 Mabsadd m
.54982 .07992 -0.22607 .31116 Mabsadd L
.54982 .07992 -0.95106 .30902 Mabsadd L
.54982 .07992 -0.36579 -0.11885 Mabsadd L
.54982 .07992 -0.58778 -0.80902 Mabsadd L
.54982 .07992 0 -0.38461 Mabsadd L
.54982 .07992 .58779 -0.80902 Mabsadd L
.54982 .07992 .36579 -0.11885 Mabsadd L
.54982 .07992 .95106 .30902 Mabsadd L
.54982 .07992 .22607 .31116 Mabsadd L
.54982 .07992 0 1 Mabsadd L closepath F
.55351 .07992 0 1 Mabsadd m
.55351 .07992 -0.22607 .31116 Mabsadd L
.55351 .07992 -0.95106 .30902 Mabsadd L
.55351 .07992 -0.36579 -0.11885 Mabsadd L
.55351 .07992 -0.58778 -0.80902 Mabsadd L
.55351 .07992 0 -0.38461 Mabsadd L
.55351 .07992 .58779 -0.80902 Mabsadd L
.55351 .07992 .36579 -0.11885 Mabsadd L
.55351 .07992 .95106 .30902 Mabsadd L
.55351 .07992 .22607 .31116 Mabsadd L
.55351 .07992 0 1 Mabsadd L closepath F
.5572 .07993 0 1 Mabsadd m
.5572 .07993 -0.22607 .31116 Mabsadd L
.5572 .07993 -0.95106 .30902 Mabsadd L
.5572 .07993 -0.36579 -0.11885 Mabsadd L
.5572 .07993 -0.58778 -0.80902 Mabsadd L
.5572 .07993 0 -0.38461 Mabsadd L
.5572 .07993 .58779 -0.80902 Mabsadd L
.5572 .07993 .36579 -0.11885 Mabsadd L
.5572 .07993 .95106 .30902 Mabsadd L
.5572 .07993 .22607 .31116 Mabsadd L
.5572 .07993 0 1 Mabsadd L closepath F
.56089 .07993 0 1 Mabsadd m
.56089 .07993 -0.22607 .31116 Mabsadd L
.56089 .07993 -0.95106 .30902 Mabsadd L
.56089 .07993 -0.36579 -0.11885 Mabsadd L
.56089 .07993 -0.58778 -0.80902 Mabsadd L
.56089 .07993 0 -0.38461 Mabsadd L
.56089 .07993 .58779 -0.80902 Mabsadd L
.56089 .07993 .36579 -0.11885 Mabsadd L
.56089 .07993 .95106 .30902 Mabsadd L
.56089 .07993 .22607 .31116 Mabsadd L
.56089 .07993 0 1 Mabsadd L closepath F
.56458 .07992 0 1 Mabsadd m
.56458 .07992 -0.22607 .31116 Mabsadd L
.56458 .07992 -0.95106 .30902 Mabsadd L
.56458 .07992 -0.36579 -0.11885 Mabsadd L
.56458 .07992 -0.58778 -0.80902 Mabsadd L
.56458 .07992 0 -0.38461 Mabsadd L
.56458 .07992 .58779 -0.80902 Mabsadd L
.56458 .07992 .36579 -0.11885 Mabsadd L
.56458 .07992 .95106 .30902 Mabsadd L
.56458 .07992 .22607 .31116 Mabsadd L
.56458 .07992 0 1 Mabsadd L closepath F
.56827 .07997 0 1 Mabsadd m
.56827 .07997 -0.22607 .31116 Mabsadd L
.56827 .07997 -0.95106 .30902 Mabsadd L
.56827 .07997 -0.36579 -0.11885 Mabsadd L
.56827 .07997 -0.58778 -0.80902 Mabsadd L
.56827 .07997 0 -0.38461 Mabsadd L
.56827 .07997 .58779 -0.80902 Mabsadd L
.56827 .07997 .36579 -0.11885 Mabsadd L
.56827 .07997 .95106 .30902 Mabsadd L
.56827 .07997 .22607 .31116 Mabsadd L
.56827 .07997 0 1 Mabsadd L closepath F
.57196 .07997 0 1 Mabsadd m
.57196 .07997 -0.22607 .31116 Mabsadd L
.57196 .07997 -0.95106 .30902 Mabsadd L
.57196 .07997 -0.36579 -0.11885 Mabsadd L
.57196 .07997 -0.58778 -0.80902 Mabsadd L
.57196 .07997 0 -0.38461 Mabsadd L
.57196 .07997 .58779 -0.80902 Mabsadd L
.57196 .07997 .36579 -0.11885 Mabsadd L
.57196 .07997 .95106 .30902 Mabsadd L
.57196 .07997 .22607 .31116 Mabsadd L
.57196 .07997 0 1 Mabsadd L closepath F
.57565 .07997 0 1 Mabsadd m
.57565 .07997 -0.22607 .31116 Mabsadd L
.57565 .07997 -0.95106 .30902 Mabsadd L
.57565 .07997 -0.36579 -0.11885 Mabsadd L
.57565 .07997 -0.58778 -0.80902 Mabsadd L
.57565 .07997 0 -0.38461 Mabsadd L
.57565 .07997 .58779 -0.80902 Mabsadd L
.57565 .07997 .36579 -0.11885 Mabsadd L
.57565 .07997 .95106 .30902 Mabsadd L
.57565 .07997 .22607 .31116 Mabsadd L
.57565 .07997 0 1 Mabsadd L closepath F
.57934 .07992 0 1 Mabsadd m
.57934 .07992 -0.22607 .31116 Mabsadd L
.57934 .07992 -0.95106 .30902 Mabsadd L
.57934 .07992 -0.36579 -0.11885 Mabsadd L
.57934 .07992 -0.58778 -0.80902 Mabsadd L
.57934 .07992 0 -0.38461 Mabsadd L
.57934 .07992 .58779 -0.80902 Mabsadd L
.57934 .07992 .36579 -0.11885 Mabsadd L
.57934 .07992 .95106 .30902 Mabsadd L
.57934 .07992 .22607 .31116 Mabsadd L
.57934 .07992 0 1 Mabsadd L closepath F
.58303 .07992 0 1 Mabsadd m
.58303 .07992 -0.22607 .31116 Mabsadd L
.58303 .07992 -0.95106 .30902 Mabsadd L
.58303 .07992 -0.36579 -0.11885 Mabsadd L
.58303 .07992 -0.58778 -0.80902 Mabsadd L
.58303 .07992 0 -0.38461 Mabsadd L
.58303 .07992 .58779 -0.80902 Mabsadd L
.58303 .07992 .36579 -0.11885 Mabsadd L
.58303 .07992 .95106 .30902 Mabsadd L
.58303 .07992 .22607 .31116 Mabsadd L
.58303 .07992 0 1 Mabsadd L closepath F
.58672 .07992 0 1 Mabsadd m
.58672 .07992 -0.22607 .31116 Mabsadd L
.58672 .07992 -0.95106 .30902 Mabsadd L
.58672 .07992 -0.36579 -0.11885 Mabsadd L
.58672 .07992 -0.58778 -0.80902 Mabsadd L
.58672 .07992 0 -0.38461 Mabsadd L
.58672 .07992 .58779 -0.80902 Mabsadd L
.58672 .07992 .36579 -0.11885 Mabsadd L
.58672 .07992 .95106 .30902 Mabsadd L
.58672 .07992 .22607 .31116 Mabsadd L
.58672 .07992 0 1 Mabsadd L closepath F
.59041 .07992 0 1 Mabsadd m
.59041 .07992 -0.22607 .31116 Mabsadd L
.59041 .07992 -0.95106 .30902 Mabsadd L
.59041 .07992 -0.36579 -0.11885 Mabsadd L
.59041 .07992 -0.58778 -0.80902 Mabsadd L
.59041 .07992 0 -0.38461 Mabsadd L
.59041 .07992 .58779 -0.80902 Mabsadd L
.59041 .07992 .36579 -0.11885 Mabsadd L
.59041 .07992 .95106 .30902 Mabsadd L
.59041 .07992 .22607 .31116 Mabsadd L
.59041 .07992 0 1 Mabsadd L closepath F
.5941 .07992 0 1 Mabsadd m
.5941 .07992 -0.22607 .31116 Mabsadd L
.5941 .07992 -0.95106 .30902 Mabsadd L
.5941 .07992 -0.36579 -0.11885 Mabsadd L
.5941 .07992 -0.58778 -0.80902 Mabsadd L
.5941 .07992 0 -0.38461 Mabsadd L
.5941 .07992 .58779 -0.80902 Mabsadd L
.5941 .07992 .36579 -0.11885 Mabsadd L
.5941 .07992 .95106 .30902 Mabsadd L
.5941 .07992 .22607 .31116 Mabsadd L
.5941 .07992 0 1 Mabsadd L closepath F
.59779 .07992 0 1 Mabsadd m
.59779 .07992 -0.22607 .31116 Mabsadd L
.59779 .07992 -0.95106 .30902 Mabsadd L
.59779 .07992 -0.36579 -0.11885 Mabsadd L
.59779 .07992 -0.58778 -0.80902 Mabsadd L
.59779 .07992 0 -0.38461 Mabsadd L
.59779 .07992 .58779 -0.80902 Mabsadd L
.59779 .07992 .36579 -0.11885 Mabsadd L
.59779 .07992 .95106 .30902 Mabsadd L
.59779 .07992 .22607 .31116 Mabsadd L
.59779 .07992 0 1 Mabsadd L closepath F
.60148 .07992 0 1 Mabsadd m
.60148 .07992 -0.22607 .31116 Mabsadd L
.60148 .07992 -0.95106 .30902 Mabsadd L
.60148 .07992 -0.36579 -0.11885 Mabsadd L
.60148 .07992 -0.58778 -0.80902 Mabsadd L
.60148 .07992 0 -0.38461 Mabsadd L
.60148 .07992 .58779 -0.80902 Mabsadd L
.60148 .07992 .36579 -0.11885 Mabsadd L
.60148 .07992 .95106 .30902 Mabsadd L
.60148 .07992 .22607 .31116 Mabsadd L
.60148 .07992 0 1 Mabsadd L closepath F
.60517 .07992 0 1 Mabsadd m
.60517 .07992 -0.22607 .31116 Mabsadd L
.60517 .07992 -0.95106 .30902 Mabsadd L
.60517 .07992 -0.36579 -0.11885 Mabsadd L
.60517 .07992 -0.58778 -0.80902 Mabsadd L
.60517 .07992 0 -0.38461 Mabsadd L
.60517 .07992 .58779 -0.80902 Mabsadd L
.60517 .07992 .36579 -0.11885 Mabsadd L
.60517 .07992 .95106 .30902 Mabsadd L
.60517 .07992 .22607 .31116 Mabsadd L
.60517 .07992 0 1 Mabsadd L closepath F
.60886 .07992 0 1 Mabsadd m
.60886 .07992 -0.22607 .31116 Mabsadd L
.60886 .07992 -0.95106 .30902 Mabsadd L
.60886 .07992 -0.36579 -0.11885 Mabsadd L
.60886 .07992 -0.58778 -0.80902 Mabsadd L
.60886 .07992 0 -0.38461 Mabsadd L
.60886 .07992 .58779 -0.80902 Mabsadd L
.60886 .07992 .36579 -0.11885 Mabsadd L
.60886 .07992 .95106 .30902 Mabsadd L
.60886 .07992 .22607 .31116 Mabsadd L
.60886 .07992 0 1 Mabsadd L closepath F
.61255 .07992 0 1 Mabsadd m
.61255 .07992 -0.22607 .31116 Mabsadd L
.61255 .07992 -0.95106 .30902 Mabsadd L
.61255 .07992 -0.36579 -0.11885 Mabsadd L
.61255 .07992 -0.58778 -0.80902 Mabsadd L
.61255 .07992 0 -0.38461 Mabsadd L
.61255 .07992 .58779 -0.80902 Mabsadd L
.61255 .07992 .36579 -0.11885 Mabsadd L
.61255 .07992 .95106 .30902 Mabsadd L
.61255 .07992 .22607 .31116 Mabsadd L
.61255 .07992 0 1 Mabsadd L closepath F
.61624 .07992 0 1 Mabsadd m
.61624 .07992 -0.22607 .31116 Mabsadd L
.61624 .07992 -0.95106 .30902 Mabsadd L
.61624 .07992 -0.36579 -0.11885 Mabsadd L
.61624 .07992 -0.58778 -0.80902 Mabsadd L
.61624 .07992 0 -0.38461 Mabsadd L
.61624 .07992 .58779 -0.80902 Mabsadd L
.61624 .07992 .36579 -0.11885 Mabsadd L
.61624 .07992 .95106 .30902 Mabsadd L
.61624 .07992 .22607 .31116 Mabsadd L
.61624 .07992 0 1 Mabsadd L closepath F
.61993 .07992 0 1 Mabsadd m
.61993 .07992 -0.22607 .31116 Mabsadd L
.61993 .07992 -0.95106 .30902 Mabsadd L
.61993 .07992 -0.36579 -0.11885 Mabsadd L
.61993 .07992 -0.58778 -0.80902 Mabsadd L
.61993 .07992 0 -0.38461 Mabsadd L
.61993 .07992 .58779 -0.80902 Mabsadd L
.61993 .07992 .36579 -0.11885 Mabsadd L
.61993 .07992 .95106 .30902 Mabsadd L
.61993 .07992 .22607 .31116 Mabsadd L
.61993 .07992 0 1 Mabsadd L closepath F
.62362 .07992 0 1 Mabsadd m
.62362 .07992 -0.22607 .31116 Mabsadd L
.62362 .07992 -0.95106 .30902 Mabsadd L
.62362 .07992 -0.36579 -0.11885 Mabsadd L
.62362 .07992 -0.58778 -0.80902 Mabsadd L
.62362 .07992 0 -0.38461 Mabsadd L
.62362 .07992 .58779 -0.80902 Mabsadd L
.62362 .07992 .36579 -0.11885 Mabsadd L
.62362 .07992 .95106 .30902 Mabsadd L
.62362 .07992 .22607 .31116 Mabsadd L
.62362 .07992 0 1 Mabsadd L closepath F
.62731 .07992 0 1 Mabsadd m
.62731 .07992 -0.22607 .31116 Mabsadd L
.62731 .07992 -0.95106 .30902 Mabsadd L
.62731 .07992 -0.36579 -0.11885 Mabsadd L
.62731 .07992 -0.58778 -0.80902 Mabsadd L
.62731 .07992 0 -0.38461 Mabsadd L
.62731 .07992 .58779 -0.80902 Mabsadd L
.62731 .07992 .36579 -0.11885 Mabsadd L
.62731 .07992 .95106 .30902 Mabsadd L
.62731 .07992 .22607 .31116 Mabsadd L
.62731 .07992 0 1 Mabsadd L closepath F
.631 .07992 0 1 Mabsadd m
.631 .07992 -0.22607 .31116 Mabsadd L
.631 .07992 -0.95106 .30902 Mabsadd L
.631 .07992 -0.36579 -0.11885 Mabsadd L
.631 .07992 -0.58778 -0.80902 Mabsadd L
.631 .07992 0 -0.38461 Mabsadd L
.631 .07992 .58779 -0.80902 Mabsadd L
.631 .07992 .36579 -0.11885 Mabsadd L
.631 .07992 .95106 .30902 Mabsadd L
.631 .07992 .22607 .31116 Mabsadd L
.631 .07992 0 1 Mabsadd L closepath F
.63469 .07992 0 1 Mabsadd m
.63469 .07992 -0.22607 .31116 Mabsadd L
.63469 .07992 -0.95106 .30902 Mabsadd L
.63469 .07992 -0.36579 -0.11885 Mabsadd L
.63469 .07992 -0.58778 -0.80902 Mabsadd L
.63469 .07992 0 -0.38461 Mabsadd L
.63469 .07992 .58779 -0.80902 Mabsadd L
.63469 .07992 .36579 -0.11885 Mabsadd L
.63469 .07992 .95106 .30902 Mabsadd L
.63469 .07992 .22607 .31116 Mabsadd L
.63469 .07992 0 1 Mabsadd L closepath F
.63838 .07997 0 1 Mabsadd m
.63838 .07997 -0.22607 .31116 Mabsadd L
.63838 .07997 -0.95106 .30902 Mabsadd L
.63838 .07997 -0.36579 -0.11885 Mabsadd L
.63838 .07997 -0.58778 -0.80902 Mabsadd L
.63838 .07997 0 -0.38461 Mabsadd L
.63838 .07997 .58779 -0.80902 Mabsadd L
.63838 .07997 .36579 -0.11885 Mabsadd L
.63838 .07997 .95106 .30902 Mabsadd L
.63838 .07997 .22607 .31116 Mabsadd L
.63838 .07997 0 1 Mabsadd L closepath F
.64207 .08008 0 1 Mabsadd m
.64207 .08008 -0.22607 .31116 Mabsadd L
.64207 .08008 -0.95106 .30902 Mabsadd L
.64207 .08008 -0.36579 -0.11885 Mabsadd L
.64207 .08008 -0.58778 -0.80902 Mabsadd L
.64207 .08008 0 -0.38461 Mabsadd L
.64207 .08008 .58779 -0.80902 Mabsadd L
.64207 .08008 .36579 -0.11885 Mabsadd L
.64207 .08008 .95106 .30902 Mabsadd L
.64207 .08008 .22607 .31116 Mabsadd L
.64207 .08008 0 1 Mabsadd L closepath F
.64576 .08002 0 1 Mabsadd m
.64576 .08002 -0.22607 .31116 Mabsadd L
.64576 .08002 -0.95106 .30902 Mabsadd L
.64576 .08002 -0.36579 -0.11885 Mabsadd L
.64576 .08002 -0.58778 -0.80902 Mabsadd L
.64576 .08002 0 -0.38461 Mabsadd L
.64576 .08002 .58779 -0.80902 Mabsadd L
.64576 .08002 .36579 -0.11885 Mabsadd L
.64576 .08002 .95106 .30902 Mabsadd L
.64576 .08002 .22607 .31116 Mabsadd L
.64576 .08002 0 1 Mabsadd L closepath F
.64945 .08002 0 1 Mabsadd m
.64945 .08002 -0.22607 .31116 Mabsadd L
.64945 .08002 -0.95106 .30902 Mabsadd L
.64945 .08002 -0.36579 -0.11885 Mabsadd L
.64945 .08002 -0.58778 -0.80902 Mabsadd L
.64945 .08002 0 -0.38461 Mabsadd L
.64945 .08002 .58779 -0.80902 Mabsadd L
.64945 .08002 .36579 -0.11885 Mabsadd L
.64945 .08002 .95106 .30902 Mabsadd L
.64945 .08002 .22607 .31116 Mabsadd L
.64945 .08002 0 1 Mabsadd L closepath F
.65314 .08003 0 1 Mabsadd m
.65314 .08003 -0.22607 .31116 Mabsadd L
.65314 .08003 -0.95106 .30902 Mabsadd L
.65314 .08003 -0.36579 -0.11885 Mabsadd L
.65314 .08003 -0.58778 -0.80902 Mabsadd L
.65314 .08003 0 -0.38461 Mabsadd L
.65314 .08003 .58779 -0.80902 Mabsadd L
.65314 .08003 .36579 -0.11885 Mabsadd L
.65314 .08003 .95106 .30902 Mabsadd L
.65314 .08003 .22607 .31116 Mabsadd L
.65314 .08003 0 1 Mabsadd L closepath F
.65683 .07998 0 1 Mabsadd m
.65683 .07998 -0.22607 .31116 Mabsadd L
.65683 .07998 -0.95106 .30902 Mabsadd L
.65683 .07998 -0.36579 -0.11885 Mabsadd L
.65683 .07998 -0.58778 -0.80902 Mabsadd L
.65683 .07998 0 -0.38461 Mabsadd L
.65683 .07998 .58779 -0.80902 Mabsadd L
.65683 .07998 .36579 -0.11885 Mabsadd L
.65683 .07998 .95106 .30902 Mabsadd L
.65683 .07998 .22607 .31116 Mabsadd L
.65683 .07998 0 1 Mabsadd L closepath F
.66052 .07997 0 1 Mabsadd m
.66052 .07997 -0.22607 .31116 Mabsadd L
.66052 .07997 -0.95106 .30902 Mabsadd L
.66052 .07997 -0.36579 -0.11885 Mabsadd L
.66052 .07997 -0.58778 -0.80902 Mabsadd L
.66052 .07997 0 -0.38461 Mabsadd L
.66052 .07997 .58779 -0.80902 Mabsadd L
.66052 .07997 .36579 -0.11885 Mabsadd L
.66052 .07997 .95106 .30902 Mabsadd L
.66052 .07997 .22607 .31116 Mabsadd L
.66052 .07997 0 1 Mabsadd L closepath F
.66421 .07997 0 1 Mabsadd m
.66421 .07997 -0.22607 .31116 Mabsadd L
.66421 .07997 -0.95106 .30902 Mabsadd L
.66421 .07997 -0.36579 -0.11885 Mabsadd L
.66421 .07997 -0.58778 -0.80902 Mabsadd L
.66421 .07997 0 -0.38461 Mabsadd L
.66421 .07997 .58779 -0.80902 Mabsadd L
.66421 .07997 .36579 -0.11885 Mabsadd L
.66421 .07997 .95106 .30902 Mabsadd L
.66421 .07997 .22607 .31116 Mabsadd L
.66421 .07997 0 1 Mabsadd L closepath F
.6679 .07992 0 1 Mabsadd m
.6679 .07992 -0.22607 .31116 Mabsadd L
.6679 .07992 -0.95106 .30902 Mabsadd L
.6679 .07992 -0.36579 -0.11885 Mabsadd L
.6679 .07992 -0.58778 -0.80902 Mabsadd L
.6679 .07992 0 -0.38461 Mabsadd L
.6679 .07992 .58779 -0.80902 Mabsadd L
.6679 .07992 .36579 -0.11885 Mabsadd L
.6679 .07992 .95106 .30902 Mabsadd L
.6679 .07992 .22607 .31116 Mabsadd L
.6679 .07992 0 1 Mabsadd L closepath F
.67159 .07992 0 1 Mabsadd m
.67159 .07992 -0.22607 .31116 Mabsadd L
.67159 .07992 -0.95106 .30902 Mabsadd L
.67159 .07992 -0.36579 -0.11885 Mabsadd L
.67159 .07992 -0.58778 -0.80902 Mabsadd L
.67159 .07992 0 -0.38461 Mabsadd L
.67159 .07992 .58779 -0.80902 Mabsadd L
.67159 .07992 .36579 -0.11885 Mabsadd L
.67159 .07992 .95106 .30902 Mabsadd L
.67159 .07992 .22607 .31116 Mabsadd L
.67159 .07992 0 1 Mabsadd L closepath F
.67528 .07998 0 1 Mabsadd m
.67528 .07998 -0.22607 .31116 Mabsadd L
.67528 .07998 -0.95106 .30902 Mabsadd L
.67528 .07998 -0.36579 -0.11885 Mabsadd L
.67528 .07998 -0.58778 -0.80902 Mabsadd L
.67528 .07998 0 -0.38461 Mabsadd L
.67528 .07998 .58779 -0.80902 Mabsadd L
.67528 .07998 .36579 -0.11885 Mabsadd L
.67528 .07998 .95106 .30902 Mabsadd L
.67528 .07998 .22607 .31116 Mabsadd L
.67528 .07998 0 1 Mabsadd L closepath F
.67897 .07997 0 1 Mabsadd m
.67897 .07997 -0.22607 .31116 Mabsadd L
.67897 .07997 -0.95106 .30902 Mabsadd L
.67897 .07997 -0.36579 -0.11885 Mabsadd L
.67897 .07997 -0.58778 -0.80902 Mabsadd L
.67897 .07997 0 -0.38461 Mabsadd L
.67897 .07997 .58779 -0.80902 Mabsadd L
.67897 .07997 .36579 -0.11885 Mabsadd L
.67897 .07997 .95106 .30902 Mabsadd L
.67897 .07997 .22607 .31116 Mabsadd L
.67897 .07997 0 1 Mabsadd L closepath F
.68266 .07992 0 1 Mabsadd m
.68266 .07992 -0.22607 .31116 Mabsadd L
.68266 .07992 -0.95106 .30902 Mabsadd L
.68266 .07992 -0.36579 -0.11885 Mabsadd L
.68266 .07992 -0.58778 -0.80902 Mabsadd L
.68266 .07992 0 -0.38461 Mabsadd L
.68266 .07992 .58779 -0.80902 Mabsadd L
.68266 .07992 .36579 -0.11885 Mabsadd L
.68266 .07992 .95106 .30902 Mabsadd L
.68266 .07992 .22607 .31116 Mabsadd L
.68266 .07992 0 1 Mabsadd L closepath F
.68635 .07992 0 1 Mabsadd m
.68635 .07992 -0.22607 .31116 Mabsadd L
.68635 .07992 -0.95106 .30902 Mabsadd L
.68635 .07992 -0.36579 -0.11885 Mabsadd L
.68635 .07992 -0.58778 -0.80902 Mabsadd L
.68635 .07992 0 -0.38461 Mabsadd L
.68635 .07992 .58779 -0.80902 Mabsadd L
.68635 .07992 .36579 -0.11885 Mabsadd L
.68635 .07992 .95106 .30902 Mabsadd L
.68635 .07992 .22607 .31116 Mabsadd L
.68635 .07992 0 1 Mabsadd L closepath F
.69004 .07997 0 1 Mabsadd m
.69004 .07997 -0.22607 .31116 Mabsadd L
.69004 .07997 -0.95106 .30902 Mabsadd L
.69004 .07997 -0.36579 -0.11885 Mabsadd L
.69004 .07997 -0.58778 -0.80902 Mabsadd L
.69004 .07997 0 -0.38461 Mabsadd L
.69004 .07997 .58779 -0.80902 Mabsadd L
.69004 .07997 .36579 -0.11885 Mabsadd L
.69004 .07997 .95106 .30902 Mabsadd L
.69004 .07997 .22607 .31116 Mabsadd L
.69004 .07997 0 1 Mabsadd L closepath F
.69373 .07992 0 1 Mabsadd m
.69373 .07992 -0.22607 .31116 Mabsadd L
.69373 .07992 -0.95106 .30902 Mabsadd L
.69373 .07992 -0.36579 -0.11885 Mabsadd L
.69373 .07992 -0.58778 -0.80902 Mabsadd L
.69373 .07992 0 -0.38461 Mabsadd L
.69373 .07992 .58779 -0.80902 Mabsadd L
.69373 .07992 .36579 -0.11885 Mabsadd L
.69373 .07992 .95106 .30902 Mabsadd L
.69373 .07992 .22607 .31116 Mabsadd L
.69373 .07992 0 1 Mabsadd L closepath F
.69742 .07994 0 1 Mabsadd m
.69742 .07994 -0.22607 .31116 Mabsadd L
.69742 .07994 -0.95106 .30902 Mabsadd L
.69742 .07994 -0.36579 -0.11885 Mabsadd L
.69742 .07994 -0.58778 -0.80902 Mabsadd L
.69742 .07994 0 -0.38461 Mabsadd L
.69742 .07994 .58779 -0.80902 Mabsadd L
.69742 .07994 .36579 -0.11885 Mabsadd L
.69742 .07994 .95106 .30902 Mabsadd L
.69742 .07994 .22607 .31116 Mabsadd L
.69742 .07994 0 1 Mabsadd L closepath F
.70111 .07992 0 1 Mabsadd m
.70111 .07992 -0.22607 .31116 Mabsadd L
.70111 .07992 -0.95106 .30902 Mabsadd L
.70111 .07992 -0.36579 -0.11885 Mabsadd L
.70111 .07992 -0.58778 -0.80902 Mabsadd L
.70111 .07992 0 -0.38461 Mabsadd L
.70111 .07992 .58779 -0.80902 Mabsadd L
.70111 .07992 .36579 -0.11885 Mabsadd L
.70111 .07992 .95106 .30902 Mabsadd L
.70111 .07992 .22607 .31116 Mabsadd L
.70111 .07992 0 1 Mabsadd L closepath F
.7048 .07992 0 1 Mabsadd m
.7048 .07992 -0.22607 .31116 Mabsadd L
.7048 .07992 -0.95106 .30902 Mabsadd L
.7048 .07992 -0.36579 -0.11885 Mabsadd L
.7048 .07992 -0.58778 -0.80902 Mabsadd L
.7048 .07992 0 -0.38461 Mabsadd L
.7048 .07992 .58779 -0.80902 Mabsadd L
.7048 .07992 .36579 -0.11885 Mabsadd L
.7048 .07992 .95106 .30902 Mabsadd L
.7048 .07992 .22607 .31116 Mabsadd L
.7048 .07992 0 1 Mabsadd L closepath F
.70849 .07992 0 1 Mabsadd m
.70849 .07992 -0.22607 .31116 Mabsadd L
.70849 .07992 -0.95106 .30902 Mabsadd L
.70849 .07992 -0.36579 -0.11885 Mabsadd L
.70849 .07992 -0.58778 -0.80902 Mabsadd L
.70849 .07992 0 -0.38461 Mabsadd L
.70849 .07992 .58779 -0.80902 Mabsadd L
.70849 .07992 .36579 -0.11885 Mabsadd L
.70849 .07992 .95106 .30902 Mabsadd L
.70849 .07992 .22607 .31116 Mabsadd L
.70849 .07992 0 1 Mabsadd L closepath F
.71218 .07997 0 1 Mabsadd m
.71218 .07997 -0.22607 .31116 Mabsadd L
.71218 .07997 -0.95106 .30902 Mabsadd L
.71218 .07997 -0.36579 -0.11885 Mabsadd L
.71218 .07997 -0.58778 -0.80902 Mabsadd L
.71218 .07997 0 -0.38461 Mabsadd L
.71218 .07997 .58779 -0.80902 Mabsadd L
.71218 .07997 .36579 -0.11885 Mabsadd L
.71218 .07997 .95106 .30902 Mabsadd L
.71218 .07997 .22607 .31116 Mabsadd L
.71218 .07997 0 1 Mabsadd L closepath F
.71587 .07992 0 1 Mabsadd m
.71587 .07992 -0.22607 .31116 Mabsadd L
.71587 .07992 -0.95106 .30902 Mabsadd L
.71587 .07992 -0.36579 -0.11885 Mabsadd L
.71587 .07992 -0.58778 -0.80902 Mabsadd L
.71587 .07992 0 -0.38461 Mabsadd L
.71587 .07992 .58779 -0.80902 Mabsadd L
.71587 .07992 .36579 -0.11885 Mabsadd L
.71587 .07992 .95106 .30902 Mabsadd L
.71587 .07992 .22607 .31116 Mabsadd L
.71587 .07992 0 1 Mabsadd L closepath F
.71956 .07992 0 1 Mabsadd m
.71956 .07992 -0.22607 .31116 Mabsadd L
.71956 .07992 -0.95106 .30902 Mabsadd L
.71956 .07992 -0.36579 -0.11885 Mabsadd L
.71956 .07992 -0.58778 -0.80902 Mabsadd L
.71956 .07992 0 -0.38461 Mabsadd L
.71956 .07992 .58779 -0.80902 Mabsadd L
.71956 .07992 .36579 -0.11885 Mabsadd L
.71956 .07992 .95106 .30902 Mabsadd L
.71956 .07992 .22607 .31116 Mabsadd L
.71956 .07992 0 1 Mabsadd L closepath F
.72325 .07992 0 1 Mabsadd m
.72325 .07992 -0.22607 .31116 Mabsadd L
.72325 .07992 -0.95106 .30902 Mabsadd L
.72325 .07992 -0.36579 -0.11885 Mabsadd L
.72325 .07992 -0.58778 -0.80902 Mabsadd L
.72325 .07992 0 -0.38461 Mabsadd L
.72325 .07992 .58779 -0.80902 Mabsadd L
.72325 .07992 .36579 -0.11885 Mabsadd L
.72325 .07992 .95106 .30902 Mabsadd L
.72325 .07992 .22607 .31116 Mabsadd L
.72325 .07992 0 1 Mabsadd L closepath F
.72694 .07992 0 1 Mabsadd m
.72694 .07992 -0.22607 .31116 Mabsadd L
.72694 .07992 -0.95106 .30902 Mabsadd L
.72694 .07992 -0.36579 -0.11885 Mabsadd L
.72694 .07992 -0.58778 -0.80902 Mabsadd L
.72694 .07992 0 -0.38461 Mabsadd L
.72694 .07992 .58779 -0.80902 Mabsadd L
.72694 .07992 .36579 -0.11885 Mabsadd L
.72694 .07992 .95106 .30902 Mabsadd L
.72694 .07992 .22607 .31116 Mabsadd L
.72694 .07992 0 1 Mabsadd L closepath F
.73063 .07996 0 1 Mabsadd m
.73063 .07996 -0.22607 .31116 Mabsadd L
.73063 .07996 -0.95106 .30902 Mabsadd L
.73063 .07996 -0.36579 -0.11885 Mabsadd L
.73063 .07996 -0.58778 -0.80902 Mabsadd L
.73063 .07996 0 -0.38461 Mabsadd L
.73063 .07996 .58779 -0.80902 Mabsadd L
.73063 .07996 .36579 -0.11885 Mabsadd L
.73063 .07996 .95106 .30902 Mabsadd L
.73063 .07996 .22607 .31116 Mabsadd L
.73063 .07996 0 1 Mabsadd L closepath F
.73432 .07992 0 1 Mabsadd m
.73432 .07992 -0.22607 .31116 Mabsadd L
.73432 .07992 -0.95106 .30902 Mabsadd L
.73432 .07992 -0.36579 -0.11885 Mabsadd L
.73432 .07992 -0.58778 -0.80902 Mabsadd L
.73432 .07992 0 -0.38461 Mabsadd L
.73432 .07992 .58779 -0.80902 Mabsadd L
.73432 .07992 .36579 -0.11885 Mabsadd L
.73432 .07992 .95106 .30902 Mabsadd L
.73432 .07992 .22607 .31116 Mabsadd L
.73432 .07992 0 1 Mabsadd L closepath F
.73801 .07993 0 1 Mabsadd m
.73801 .07993 -0.22607 .31116 Mabsadd L
.73801 .07993 -0.95106 .30902 Mabsadd L
.73801 .07993 -0.36579 -0.11885 Mabsadd L
.73801 .07993 -0.58778 -0.80902 Mabsadd L
.73801 .07993 0 -0.38461 Mabsadd L
.73801 .07993 .58779 -0.80902 Mabsadd L
.73801 .07993 .36579 -0.11885 Mabsadd L
.73801 .07993 .95106 .30902 Mabsadd L
.73801 .07993 .22607 .31116 Mabsadd L
.73801 .07993 0 1 Mabsadd L closepath F
.7417 .07992 0 1 Mabsadd m
.7417 .07992 -0.22607 .31116 Mabsadd L
.7417 .07992 -0.95106 .30902 Mabsadd L
.7417 .07992 -0.36579 -0.11885 Mabsadd L
.7417 .07992 -0.58778 -0.80902 Mabsadd L
.7417 .07992 0 -0.38461 Mabsadd L
.7417 .07992 .58779 -0.80902 Mabsadd L
.7417 .07992 .36579 -0.11885 Mabsadd L
.7417 .07992 .95106 .30902 Mabsadd L
.7417 .07992 .22607 .31116 Mabsadd L
.7417 .07992 0 1 Mabsadd L closepath F
.74539 .07992 0 1 Mabsadd m
.74539 .07992 -0.22607 .31116 Mabsadd L
.74539 .07992 -0.95106 .30902 Mabsadd L
.74539 .07992 -0.36579 -0.11885 Mabsadd L
.74539 .07992 -0.58778 -0.80902 Mabsadd L
.74539 .07992 0 -0.38461 Mabsadd L
.74539 .07992 .58779 -0.80902 Mabsadd L
.74539 .07992 .36579 -0.11885 Mabsadd L
.74539 .07992 .95106 .30902 Mabsadd L
.74539 .07992 .22607 .31116 Mabsadd L
.74539 .07992 0 1 Mabsadd L closepath F
.74908 .07992 0 1 Mabsadd m
.74908 .07992 -0.22607 .31116 Mabsadd L
.74908 .07992 -0.95106 .30902 Mabsadd L
.74908 .07992 -0.36579 -0.11885 Mabsadd L
.74908 .07992 -0.58778 -0.80902 Mabsadd L
.74908 .07992 0 -0.38461 Mabsadd L
.74908 .07992 .58779 -0.80902 Mabsadd L
.74908 .07992 .36579 -0.11885 Mabsadd L
.74908 .07992 .95106 .30902 Mabsadd L
.74908 .07992 .22607 .31116 Mabsadd L
.74908 .07992 0 1 Mabsadd L closepath F
.75277 .07992 0 1 Mabsadd m
.75277 .07992 -0.22607 .31116 Mabsadd L
.75277 .07992 -0.95106 .30902 Mabsadd L
.75277 .07992 -0.36579 -0.11885 Mabsadd L
.75277 .07992 -0.58778 -0.80902 Mabsadd L
.75277 .07992 0 -0.38461 Mabsadd L
.75277 .07992 .58779 -0.80902 Mabsadd L
.75277 .07992 .36579 -0.11885 Mabsadd L
.75277 .07992 .95106 .30902 Mabsadd L
.75277 .07992 .22607 .31116 Mabsadd L
.75277 .07992 0 1 Mabsadd L closepath F
.75646 .07992 0 1 Mabsadd m
.75646 .07992 -0.22607 .31116 Mabsadd L
.75646 .07992 -0.95106 .30902 Mabsadd L
.75646 .07992 -0.36579 -0.11885 Mabsadd L
.75646 .07992 -0.58778 -0.80902 Mabsadd L
.75646 .07992 0 -0.38461 Mabsadd L
.75646 .07992 .58779 -0.80902 Mabsadd L
.75646 .07992 .36579 -0.11885 Mabsadd L
.75646 .07992 .95106 .30902 Mabsadd L
.75646 .07992 .22607 .31116 Mabsadd L
.75646 .07992 0 1 Mabsadd L closepath F
.76015 .07992 0 1 Mabsadd m
.76015 .07992 -0.22607 .31116 Mabsadd L
.76015 .07992 -0.95106 .30902 Mabsadd L
.76015 .07992 -0.36579 -0.11885 Mabsadd L
.76015 .07992 -0.58778 -0.80902 Mabsadd L
.76015 .07992 0 -0.38461 Mabsadd L
.76015 .07992 .58779 -0.80902 Mabsadd L
.76015 .07992 .36579 -0.11885 Mabsadd L
.76015 .07992 .95106 .30902 Mabsadd L
.76015 .07992 .22607 .31116 Mabsadd L
.76015 .07992 0 1 Mabsadd L closepath F
.76384 .07992 0 1 Mabsadd m
.76384 .07992 -0.22607 .31116 Mabsadd L
.76384 .07992 -0.95106 .30902 Mabsadd L
.76384 .07992 -0.36579 -0.11885 Mabsadd L
.76384 .07992 -0.58778 -0.80902 Mabsadd L
.76384 .07992 0 -0.38461 Mabsadd L
.76384 .07992 .58779 -0.80902 Mabsadd L
.76384 .07992 .36579 -0.11885 Mabsadd L
.76384 .07992 .95106 .30902 Mabsadd L
.76384 .07992 .22607 .31116 Mabsadd L
.76384 .07992 0 1 Mabsadd L closepath F
.76753 .07992 0 1 Mabsadd m
.76753 .07992 -0.22607 .31116 Mabsadd L
.76753 .07992 -0.95106 .30902 Mabsadd L
.76753 .07992 -0.36579 -0.11885 Mabsadd L
.76753 .07992 -0.58778 -0.80902 Mabsadd L
.76753 .07992 0 -0.38461 Mabsadd L
.76753 .07992 .58779 -0.80902 Mabsadd L
.76753 .07992 .36579 -0.11885 Mabsadd L
.76753 .07992 .95106 .30902 Mabsadd L
.76753 .07992 .22607 .31116 Mabsadd L
.76753 .07992 0 1 Mabsadd L closepath F
.77122 .07994 0 1 Mabsadd m
.77122 .07994 -0.22607 .31116 Mabsadd L
.77122 .07994 -0.95106 .30902 Mabsadd L
.77122 .07994 -0.36579 -0.11885 Mabsadd L
.77122 .07994 -0.58778 -0.80902 Mabsadd L
.77122 .07994 0 -0.38461 Mabsadd L
.77122 .07994 .58779 -0.80902 Mabsadd L
.77122 .07994 .36579 -0.11885 Mabsadd L
.77122 .07994 .95106 .30902 Mabsadd L
.77122 .07994 .22607 .31116 Mabsadd L
.77122 .07994 0 1 Mabsadd L closepath F
.77491 .07992 0 1 Mabsadd m
.77491 .07992 -0.22607 .31116 Mabsadd L
.77491 .07992 -0.95106 .30902 Mabsadd L
.77491 .07992 -0.36579 -0.11885 Mabsadd L
.77491 .07992 -0.58778 -0.80902 Mabsadd L
.77491 .07992 0 -0.38461 Mabsadd L
.77491 .07992 .58779 -0.80902 Mabsadd L
.77491 .07992 .36579 -0.11885 Mabsadd L
.77491 .07992 .95106 .30902 Mabsadd L
.77491 .07992 .22607 .31116 Mabsadd L
.77491 .07992 0 1 Mabsadd L closepath F
.7786 .07992 0 1 Mabsadd m
.7786 .07992 -0.22607 .31116 Mabsadd L
.7786 .07992 -0.95106 .30902 Mabsadd L
.7786 .07992 -0.36579 -0.11885 Mabsadd L
.7786 .07992 -0.58778 -0.80902 Mabsadd L
.7786 .07992 0 -0.38461 Mabsadd L
.7786 .07992 .58779 -0.80902 Mabsadd L
.7786 .07992 .36579 -0.11885 Mabsadd L
.7786 .07992 .95106 .30902 Mabsadd L
.7786 .07992 .22607 .31116 Mabsadd L
.7786 .07992 0 1 Mabsadd L closepath F
.78229 .07992 0 1 Mabsadd m
.78229 .07992 -0.22607 .31116 Mabsadd L
.78229 .07992 -0.95106 .30902 Mabsadd L
.78229 .07992 -0.36579 -0.11885 Mabsadd L
.78229 .07992 -0.58778 -0.80902 Mabsadd L
.78229 .07992 0 -0.38461 Mabsadd L
.78229 .07992 .58779 -0.80902 Mabsadd L
.78229 .07992 .36579 -0.11885 Mabsadd L
.78229 .07992 .95106 .30902 Mabsadd L
.78229 .07992 .22607 .31116 Mabsadd L
.78229 .07992 0 1 Mabsadd L closepath F
.78598 .07992 0 1 Mabsadd m
.78598 .07992 -0.22607 .31116 Mabsadd L
.78598 .07992 -0.95106 .30902 Mabsadd L
.78598 .07992 -0.36579 -0.11885 Mabsadd L
.78598 .07992 -0.58778 -0.80902 Mabsadd L
.78598 .07992 0 -0.38461 Mabsadd L
.78598 .07992 .58779 -0.80902 Mabsadd L
.78598 .07992 .36579 -0.11885 Mabsadd L
.78598 .07992 .95106 .30902 Mabsadd L
.78598 .07992 .22607 .31116 Mabsadd L
.78598 .07992 0 1 Mabsadd L closepath F
.78967 .07992 0 1 Mabsadd m
.78967 .07992 -0.22607 .31116 Mabsadd L
.78967 .07992 -0.95106 .30902 Mabsadd L
.78967 .07992 -0.36579 -0.11885 Mabsadd L
.78967 .07992 -0.58778 -0.80902 Mabsadd L
.78967 .07992 0 -0.38461 Mabsadd L
.78967 .07992 .58779 -0.80902 Mabsadd L
.78967 .07992 .36579 -0.11885 Mabsadd L
.78967 .07992 .95106 .30902 Mabsadd L
.78967 .07992 .22607 .31116 Mabsadd L
.78967 .07992 0 1 Mabsadd L closepath F
.79336 .07992 0 1 Mabsadd m
.79336 .07992 -0.22607 .31116 Mabsadd L
.79336 .07992 -0.95106 .30902 Mabsadd L
.79336 .07992 -0.36579 -0.11885 Mabsadd L
.79336 .07992 -0.58778 -0.80902 Mabsadd L
.79336 .07992 0 -0.38461 Mabsadd L
.79336 .07992 .58779 -0.80902 Mabsadd L
.79336 .07992 .36579 -0.11885 Mabsadd L
.79336 .07992 .95106 .30902 Mabsadd L
.79336 .07992 .22607 .31116 Mabsadd L
.79336 .07992 0 1 Mabsadd L closepath F
.79705 .07992 0 1 Mabsadd m
.79705 .07992 -0.22607 .31116 Mabsadd L
.79705 .07992 -0.95106 .30902 Mabsadd L
.79705 .07992 -0.36579 -0.11885 Mabsadd L
.79705 .07992 -0.58778 -0.80902 Mabsadd L
.79705 .07992 0 -0.38461 Mabsadd L
.79705 .07992 .58779 -0.80902 Mabsadd L
.79705 .07992 .36579 -0.11885 Mabsadd L
.79705 .07992 .95106 .30902 Mabsadd L
.79705 .07992 .22607 .31116 Mabsadd L
.79705 .07992 0 1 Mabsadd L closepath F
.80074 .07992 0 1 Mabsadd m
.80074 .07992 -0.22607 .31116 Mabsadd L
.80074 .07992 -0.95106 .30902 Mabsadd L
.80074 .07992 -0.36579 -0.11885 Mabsadd L
.80074 .07992 -0.58778 -0.80902 Mabsadd L
.80074 .07992 0 -0.38461 Mabsadd L
.80074 .07992 .58779 -0.80902 Mabsadd L
.80074 .07992 .36579 -0.11885 Mabsadd L
.80074 .07992 .95106 .30902 Mabsadd L
.80074 .07992 .22607 .31116 Mabsadd L
.80074 .07992 0 1 Mabsadd L closepath F
.80443 .07994 0 1 Mabsadd m
.80443 .07994 -0.22607 .31116 Mabsadd L
.80443 .07994 -0.95106 .30902 Mabsadd L
.80443 .07994 -0.36579 -0.11885 Mabsadd L
.80443 .07994 -0.58778 -0.80902 Mabsadd L
.80443 .07994 0 -0.38461 Mabsadd L
.80443 .07994 .58779 -0.80902 Mabsadd L
.80443 .07994 .36579 -0.11885 Mabsadd L
.80443 .07994 .95106 .30902 Mabsadd L
.80443 .07994 .22607 .31116 Mabsadd L
.80443 .07994 0 1 Mabsadd L closepath F
.80812 .07997 0 1 Mabsadd m
.80812 .07997 -0.22607 .31116 Mabsadd L
.80812 .07997 -0.95106 .30902 Mabsadd L
.80812 .07997 -0.36579 -0.11885 Mabsadd L
.80812 .07997 -0.58778 -0.80902 Mabsadd L
.80812 .07997 0 -0.38461 Mabsadd L
.80812 .07997 .58779 -0.80902 Mabsadd L
.80812 .07997 .36579 -0.11885 Mabsadd L
.80812 .07997 .95106 .30902 Mabsadd L
.80812 .07997 .22607 .31116 Mabsadd L
.80812 .07997 0 1 Mabsadd L closepath F
.81181 .07992 0 1 Mabsadd m
.81181 .07992 -0.22607 .31116 Mabsadd L
.81181 .07992 -0.95106 .30902 Mabsadd L
.81181 .07992 -0.36579 -0.11885 Mabsadd L
.81181 .07992 -0.58778 -0.80902 Mabsadd L
.81181 .07992 0 -0.38461 Mabsadd L
.81181 .07992 .58779 -0.80902 Mabsadd L
.81181 .07992 .36579 -0.11885 Mabsadd L
.81181 .07992 .95106 .30902 Mabsadd L
.81181 .07992 .22607 .31116 Mabsadd L
.81181 .07992 0 1 Mabsadd L closepath F
.8155 .07992 0 1 Mabsadd m
.8155 .07992 -0.22607 .31116 Mabsadd L
.8155 .07992 -0.95106 .30902 Mabsadd L
.8155 .07992 -0.36579 -0.11885 Mabsadd L
.8155 .07992 -0.58778 -0.80902 Mabsadd L
.8155 .07992 0 -0.38461 Mabsadd L
.8155 .07992 .58779 -0.80902 Mabsadd L
.8155 .07992 .36579 -0.11885 Mabsadd L
.8155 .07992 .95106 .30902 Mabsadd L
.8155 .07992 .22607 .31116 Mabsadd L
.8155 .07992 0 1 Mabsadd L closepath F
.81919 .07992 0 1 Mabsadd m
.81919 .07992 -0.22607 .31116 Mabsadd L
.81919 .07992 -0.95106 .30902 Mabsadd L
.81919 .07992 -0.36579 -0.11885 Mabsadd L
.81919 .07992 -0.58778 -0.80902 Mabsadd L
.81919 .07992 0 -0.38461 Mabsadd L
.81919 .07992 .58779 -0.80902 Mabsadd L
.81919 .07992 .36579 -0.11885 Mabsadd L
.81919 .07992 .95106 .30902 Mabsadd L
.81919 .07992 .22607 .31116 Mabsadd L
.81919 .07992 0 1 Mabsadd L closepath F
.82288 .07992 0 1 Mabsadd m
.82288 .07992 -0.22607 .31116 Mabsadd L
.82288 .07992 -0.95106 .30902 Mabsadd L
.82288 .07992 -0.36579 -0.11885 Mabsadd L
.82288 .07992 -0.58778 -0.80902 Mabsadd L
.82288 .07992 0 -0.38461 Mabsadd L
.82288 .07992 .58779 -0.80902 Mabsadd L
.82288 .07992 .36579 -0.11885 Mabsadd L
.82288 .07992 .95106 .30902 Mabsadd L
.82288 .07992 .22607 .31116 Mabsadd L
.82288 .07992 0 1 Mabsadd L closepath F
.82657 .07992 0 1 Mabsadd m
.82657 .07992 -0.22607 .31116 Mabsadd L
.82657 .07992 -0.95106 .30902 Mabsadd L
.82657 .07992 -0.36579 -0.11885 Mabsadd L
.82657 .07992 -0.58778 -0.80902 Mabsadd L
.82657 .07992 0 -0.38461 Mabsadd L
.82657 .07992 .58779 -0.80902 Mabsadd L
.82657 .07992 .36579 -0.11885 Mabsadd L
.82657 .07992 .95106 .30902 Mabsadd L
.82657 .07992 .22607 .31116 Mabsadd L
.82657 .07992 0 1 Mabsadd L closepath F
.83026 .07998 0 1 Mabsadd m
.83026 .07998 -0.22607 .31116 Mabsadd L
.83026 .07998 -0.95106 .30902 Mabsadd L
.83026 .07998 -0.36579 -0.11885 Mabsadd L
.83026 .07998 -0.58778 -0.80902 Mabsadd L
.83026 .07998 0 -0.38461 Mabsadd L
.83026 .07998 .58779 -0.80902 Mabsadd L
.83026 .07998 .36579 -0.11885 Mabsadd L
.83026 .07998 .95106 .30902 Mabsadd L
.83026 .07998 .22607 .31116 Mabsadd L
.83026 .07998 0 1 Mabsadd L closepath F
.83395 .07992 0 1 Mabsadd m
.83395 .07992 -0.22607 .31116 Mabsadd L
.83395 .07992 -0.95106 .30902 Mabsadd L
.83395 .07992 -0.36579 -0.11885 Mabsadd L
.83395 .07992 -0.58778 -0.80902 Mabsadd L
.83395 .07992 0 -0.38461 Mabsadd L
.83395 .07992 .58779 -0.80902 Mabsadd L
.83395 .07992 .36579 -0.11885 Mabsadd L
.83395 .07992 .95106 .30902 Mabsadd L
.83395 .07992 .22607 .31116 Mabsadd L
.83395 .07992 0 1 Mabsadd L closepath F
.83764 .07992 0 1 Mabsadd m
.83764 .07992 -0.22607 .31116 Mabsadd L
.83764 .07992 -0.95106 .30902 Mabsadd L
.83764 .07992 -0.36579 -0.11885 Mabsadd L
.83764 .07992 -0.58778 -0.80902 Mabsadd L
.83764 .07992 0 -0.38461 Mabsadd L
.83764 .07992 .58779 -0.80902 Mabsadd L
.83764 .07992 .36579 -0.11885 Mabsadd L
.83764 .07992 .95106 .30902 Mabsadd L
.83764 .07992 .22607 .31116 Mabsadd L
.83764 .07992 0 1 Mabsadd L closepath F
.84133 .07992 0 1 Mabsadd m
.84133 .07992 -0.22607 .31116 Mabsadd L
.84133 .07992 -0.95106 .30902 Mabsadd L
.84133 .07992 -0.36579 -0.11885 Mabsadd L
.84133 .07992 -0.58778 -0.80902 Mabsadd L
.84133 .07992 0 -0.38461 Mabsadd L
.84133 .07992 .58779 -0.80902 Mabsadd L
.84133 .07992 .36579 -0.11885 Mabsadd L
.84133 .07992 .95106 .30902 Mabsadd L
.84133 .07992 .22607 .31116 Mabsadd L
.84133 .07992 0 1 Mabsadd L closepath F
.84502 .07992 0 1 Mabsadd m
.84502 .07992 -0.22607 .31116 Mabsadd L
.84502 .07992 -0.95106 .30902 Mabsadd L
.84502 .07992 -0.36579 -0.11885 Mabsadd L
.84502 .07992 -0.58778 -0.80902 Mabsadd L
.84502 .07992 0 -0.38461 Mabsadd L
.84502 .07992 .58779 -0.80902 Mabsadd L
.84502 .07992 .36579 -0.11885 Mabsadd L
.84502 .07992 .95106 .30902 Mabsadd L
.84502 .07992 .22607 .31116 Mabsadd L
.84502 .07992 0 1 Mabsadd L closepath F
.84871 .07992 0 1 Mabsadd m
.84871 .07992 -0.22607 .31116 Mabsadd L
.84871 .07992 -0.95106 .30902 Mabsadd L
.84871 .07992 -0.36579 -0.11885 Mabsadd L
.84871 .07992 -0.58778 -0.80902 Mabsadd L
.84871 .07992 0 -0.38461 Mabsadd L
.84871 .07992 .58779 -0.80902 Mabsadd L
.84871 .07992 .36579 -0.11885 Mabsadd L
.84871 .07992 .95106 .30902 Mabsadd L
.84871 .07992 .22607 .31116 Mabsadd L
.84871 .07992 0 1 Mabsadd L closepath F
.8524 .07992 0 1 Mabsadd m
.8524 .07992 -0.22607 .31116 Mabsadd L
.8524 .07992 -0.95106 .30902 Mabsadd L
.8524 .07992 -0.36579 -0.11885 Mabsadd L
.8524 .07992 -0.58778 -0.80902 Mabsadd L
.8524 .07992 0 -0.38461 Mabsadd L
.8524 .07992 .58779 -0.80902 Mabsadd L
.8524 .07992 .36579 -0.11885 Mabsadd L
.8524 .07992 .95106 .30902 Mabsadd L
.8524 .07992 .22607 .31116 Mabsadd L
.8524 .07992 0 1 Mabsadd L closepath F
.85609 .07992 0 1 Mabsadd m
.85609 .07992 -0.22607 .31116 Mabsadd L
.85609 .07992 -0.95106 .30902 Mabsadd L
.85609 .07992 -0.36579 -0.11885 Mabsadd L
.85609 .07992 -0.58778 -0.80902 Mabsadd L
.85609 .07992 0 -0.38461 Mabsadd L
.85609 .07992 .58779 -0.80902 Mabsadd L
.85609 .07992 .36579 -0.11885 Mabsadd L
.85609 .07992 .95106 .30902 Mabsadd L
.85609 .07992 .22607 .31116 Mabsadd L
.85609 .07992 0 1 Mabsadd L closepath F
.85978 .07992 0 1 Mabsadd m
.85978 .07992 -0.22607 .31116 Mabsadd L
.85978 .07992 -0.95106 .30902 Mabsadd L
.85978 .07992 -0.36579 -0.11885 Mabsadd L
.85978 .07992 -0.58778 -0.80902 Mabsadd L
.85978 .07992 0 -0.38461 Mabsadd L
.85978 .07992 .58779 -0.80902 Mabsadd L
.85978 .07992 .36579 -0.11885 Mabsadd L
.85978 .07992 .95106 .30902 Mabsadd L
.85978 .07992 .22607 .31116 Mabsadd L
.85978 .07992 0 1 Mabsadd L closepath F
.86347 .07995 0 1 Mabsadd m
.86347 .07995 -0.22607 .31116 Mabsadd L
.86347 .07995 -0.95106 .30902 Mabsadd L
.86347 .07995 -0.36579 -0.11885 Mabsadd L
.86347 .07995 -0.58778 -0.80902 Mabsadd L
.86347 .07995 0 -0.38461 Mabsadd L
.86347 .07995 .58779 -0.80902 Mabsadd L
.86347 .07995 .36579 -0.11885 Mabsadd L
.86347 .07995 .95106 .30902 Mabsadd L
.86347 .07995 .22607 .31116 Mabsadd L
.86347 .07995 0 1 Mabsadd L closepath F
.86716 .07997 0 1 Mabsadd m
.86716 .07997 -0.22607 .31116 Mabsadd L
.86716 .07997 -0.95106 .30902 Mabsadd L
.86716 .07997 -0.36579 -0.11885 Mabsadd L
.86716 .07997 -0.58778 -0.80902 Mabsadd L
.86716 .07997 0 -0.38461 Mabsadd L
.86716 .07997 .58779 -0.80902 Mabsadd L
.86716 .07997 .36579 -0.11885 Mabsadd L
.86716 .07997 .95106 .30902 Mabsadd L
.86716 .07997 .22607 .31116 Mabsadd L
.86716 .07997 0 1 Mabsadd L closepath F
.87085 .07997 0 1 Mabsadd m
.87085 .07997 -0.22607 .31116 Mabsadd L
.87085 .07997 -0.95106 .30902 Mabsadd L
.87085 .07997 -0.36579 -0.11885 Mabsadd L
.87085 .07997 -0.58778 -0.80902 Mabsadd L
.87085 .07997 0 -0.38461 Mabsadd L
.87085 .07997 .58779 -0.80902 Mabsadd L
.87085 .07997 .36579 -0.11885 Mabsadd L
.87085 .07997 .95106 .30902 Mabsadd L
.87085 .07997 .22607 .31116 Mabsadd L
.87085 .07997 0 1 Mabsadd L closepath F
.87454 .07992 0 1 Mabsadd m
.87454 .07992 -0.22607 .31116 Mabsadd L
.87454 .07992 -0.95106 .30902 Mabsadd L
.87454 .07992 -0.36579 -0.11885 Mabsadd L
.87454 .07992 -0.58778 -0.80902 Mabsadd L
.87454 .07992 0 -0.38461 Mabsadd L
.87454 .07992 .58779 -0.80902 Mabsadd L
.87454 .07992 .36579 -0.11885 Mabsadd L
.87454 .07992 .95106 .30902 Mabsadd L
.87454 .07992 .22607 .31116 Mabsadd L
.87454 .07992 0 1 Mabsadd L closepath F
.87823 .07992 0 1 Mabsadd m
.87823 .07992 -0.22607 .31116 Mabsadd L
.87823 .07992 -0.95106 .30902 Mabsadd L
.87823 .07992 -0.36579 -0.11885 Mabsadd L
.87823 .07992 -0.58778 -0.80902 Mabsadd L
.87823 .07992 0 -0.38461 Mabsadd L
.87823 .07992 .58779 -0.80902 Mabsadd L
.87823 .07992 .36579 -0.11885 Mabsadd L
.87823 .07992 .95106 .30902 Mabsadd L
.87823 .07992 .22607 .31116 Mabsadd L
.87823 .07992 0 1 Mabsadd L closepath F
.88192 .07992 0 1 Mabsadd m
.88192 .07992 -0.22607 .31116 Mabsadd L
.88192 .07992 -0.95106 .30902 Mabsadd L
.88192 .07992 -0.36579 -0.11885 Mabsadd L
.88192 .07992 -0.58778 -0.80902 Mabsadd L
.88192 .07992 0 -0.38461 Mabsadd L
.88192 .07992 .58779 -0.80902 Mabsadd L
.88192 .07992 .36579 -0.11885 Mabsadd L
.88192 .07992 .95106 .30902 Mabsadd L
.88192 .07992 .22607 .31116 Mabsadd L
.88192 .07992 0 1 Mabsadd L closepath F
.88561 .07992 0 1 Mabsadd m
.88561 .07992 -0.22607 .31116 Mabsadd L
.88561 .07992 -0.95106 .30902 Mabsadd L
.88561 .07992 -0.36579 -0.11885 Mabsadd L
.88561 .07992 -0.58778 -0.80902 Mabsadd L
.88561 .07992 0 -0.38461 Mabsadd L
.88561 .07992 .58779 -0.80902 Mabsadd L
.88561 .07992 .36579 -0.11885 Mabsadd L
.88561 .07992 .95106 .30902 Mabsadd L
.88561 .07992 .22607 .31116 Mabsadd L
.88561 .07992 0 1 Mabsadd L closepath F
.8893 .07992 0 1 Mabsadd m
.8893 .07992 -0.22607 .31116 Mabsadd L
.8893 .07992 -0.95106 .30902 Mabsadd L
.8893 .07992 -0.36579 -0.11885 Mabsadd L
.8893 .07992 -0.58778 -0.80902 Mabsadd L
.8893 .07992 0 -0.38461 Mabsadd L
.8893 .07992 .58779 -0.80902 Mabsadd L
.8893 .07992 .36579 -0.11885 Mabsadd L
.8893 .07992 .95106 .30902 Mabsadd L
.8893 .07992 .22607 .31116 Mabsadd L
.8893 .07992 0 1 Mabsadd L closepath F
.89299 .07993 0 1 Mabsadd m
.89299 .07993 -0.22607 .31116 Mabsadd L
.89299 .07993 -0.95106 .30902 Mabsadd L
.89299 .07993 -0.36579 -0.11885 Mabsadd L
.89299 .07993 -0.58778 -0.80902 Mabsadd L
.89299 .07993 0 -0.38461 Mabsadd L
.89299 .07993 .58779 -0.80902 Mabsadd L
.89299 .07993 .36579 -0.11885 Mabsadd L
.89299 .07993 .95106 .30902 Mabsadd L
.89299 .07993 .22607 .31116 Mabsadd L
.89299 .07993 0 1 Mabsadd L closepath F
.89668 .07992 0 1 Mabsadd m
.89668 .07992 -0.22607 .31116 Mabsadd L
.89668 .07992 -0.95106 .30902 Mabsadd L
.89668 .07992 -0.36579 -0.11885 Mabsadd L
.89668 .07992 -0.58778 -0.80902 Mabsadd L
.89668 .07992 0 -0.38461 Mabsadd L
.89668 .07992 .58779 -0.80902 Mabsadd L
.89668 .07992 .36579 -0.11885 Mabsadd L
.89668 .07992 .95106 .30902 Mabsadd L
.89668 .07992 .22607 .31116 Mabsadd L
.89668 .07992 0 1 Mabsadd L closepath F
.90037 .07992 0 1 Mabsadd m
.90037 .07992 -0.22607 .31116 Mabsadd L
.90037 .07992 -0.95106 .30902 Mabsadd L
.90037 .07992 -0.36579 -0.11885 Mabsadd L
.90037 .07992 -0.58778 -0.80902 Mabsadd L
.90037 .07992 0 -0.38461 Mabsadd L
.90037 .07992 .58779 -0.80902 Mabsadd L
.90037 .07992 .36579 -0.11885 Mabsadd L
.90037 .07992 .95106 .30902 Mabsadd L
.90037 .07992 .22607 .31116 Mabsadd L
.90037 .07992 0 1 Mabsadd L closepath F
.90406 .07992 0 1 Mabsadd m
.90406 .07992 -0.22607 .31116 Mabsadd L
.90406 .07992 -0.95106 .30902 Mabsadd L
.90406 .07992 -0.36579 -0.11885 Mabsadd L
.90406 .07992 -0.58778 -0.80902 Mabsadd L
.90406 .07992 0 -0.38461 Mabsadd L
.90406 .07992 .58779 -0.80902 Mabsadd L
.90406 .07992 .36579 -0.11885 Mabsadd L
.90406 .07992 .95106 .30902 Mabsadd L
.90406 .07992 .22607 .31116 Mabsadd L
.90406 .07992 0 1 Mabsadd L closepath F
.90775 .07992 0 1 Mabsadd m
.90775 .07992 -0.22607 .31116 Mabsadd L
.90775 .07992 -0.95106 .30902 Mabsadd L
.90775 .07992 -0.36579 -0.11885 Mabsadd L
.90775 .07992 -0.58778 -0.80902 Mabsadd L
.90775 .07992 0 -0.38461 Mabsadd L
.90775 .07992 .58779 -0.80902 Mabsadd L
.90775 .07992 .36579 -0.11885 Mabsadd L
.90775 .07992 .95106 .30902 Mabsadd L
.90775 .07992 .22607 .31116 Mabsadd L
.90775 .07992 0 1 Mabsadd L closepath F
.91144 .07992 0 1 Mabsadd m
.91144 .07992 -0.22607 .31116 Mabsadd L
.91144 .07992 -0.95106 .30902 Mabsadd L
.91144 .07992 -0.36579 -0.11885 Mabsadd L
.91144 .07992 -0.58778 -0.80902 Mabsadd L
.91144 .07992 0 -0.38461 Mabsadd L
.91144 .07992 .58779 -0.80902 Mabsadd L
.91144 .07992 .36579 -0.11885 Mabsadd L
.91144 .07992 .95106 .30902 Mabsadd L
.91144 .07992 .22607 .31116 Mabsadd L
.91144 .07992 0 1 Mabsadd L closepath F
.91513 .07992 0 1 Mabsadd m
.91513 .07992 -0.22607 .31116 Mabsadd L
.91513 .07992 -0.95106 .30902 Mabsadd L
.91513 .07992 -0.36579 -0.11885 Mabsadd L
.91513 .07992 -0.58778 -0.80902 Mabsadd L
.91513 .07992 0 -0.38461 Mabsadd L
.91513 .07992 .58779 -0.80902 Mabsadd L
.91513 .07992 .36579 -0.11885 Mabsadd L
.91513 .07992 .95106 .30902 Mabsadd L
.91513 .07992 .22607 .31116 Mabsadd L
.91513 .07992 0 1 Mabsadd L closepath F
.91882 .07992 0 1 Mabsadd m
.91882 .07992 -0.22607 .31116 Mabsadd L
.91882 .07992 -0.95106 .30902 Mabsadd L
.91882 .07992 -0.36579 -0.11885 Mabsadd L
.91882 .07992 -0.58778 -0.80902 Mabsadd L
.91882 .07992 0 -0.38461 Mabsadd L
.91882 .07992 .58779 -0.80902 Mabsadd L
.91882 .07992 .36579 -0.11885 Mabsadd L
.91882 .07992 .95106 .30902 Mabsadd L
.91882 .07992 .22607 .31116 Mabsadd L
.91882 .07992 0 1 Mabsadd L closepath F
.92251 .07998 0 1 Mabsadd m
.92251 .07998 -0.22607 .31116 Mabsadd L
.92251 .07998 -0.95106 .30902 Mabsadd L
.92251 .07998 -0.36579 -0.11885 Mabsadd L
.92251 .07998 -0.58778 -0.80902 Mabsadd L
.92251 .07998 0 -0.38461 Mabsadd L
.92251 .07998 .58779 -0.80902 Mabsadd L
.92251 .07998 .36579 -0.11885 Mabsadd L
.92251 .07998 .95106 .30902 Mabsadd L
.92251 .07998 .22607 .31116 Mabsadd L
.92251 .07998 0 1 Mabsadd L closepath F
.9262 .07997 0 1 Mabsadd m
.9262 .07997 -0.22607 .31116 Mabsadd L
.9262 .07997 -0.95106 .30902 Mabsadd L
.9262 .07997 -0.36579 -0.11885 Mabsadd L
.9262 .07997 -0.58778 -0.80902 Mabsadd L
.9262 .07997 0 -0.38461 Mabsadd L
.9262 .07997 .58779 -0.80902 Mabsadd L
.9262 .07997 .36579 -0.11885 Mabsadd L
.9262 .07997 .95106 .30902 Mabsadd L
.9262 .07997 .22607 .31116 Mabsadd L
.9262 .07997 0 1 Mabsadd L closepath F
.92989 .08003 0 1 Mabsadd m
.92989 .08003 -0.22607 .31116 Mabsadd L
.92989 .08003 -0.95106 .30902 Mabsadd L
.92989 .08003 -0.36579 -0.11885 Mabsadd L
.92989 .08003 -0.58778 -0.80902 Mabsadd L
.92989 .08003 0 -0.38461 Mabsadd L
.92989 .08003 .58779 -0.80902 Mabsadd L
.92989 .08003 .36579 -0.11885 Mabsadd L
.92989 .08003 .95106 .30902 Mabsadd L
.92989 .08003 .22607 .31116 Mabsadd L
.92989 .08003 0 1 Mabsadd L closepath F
.93358 .07997 0 1 Mabsadd m
.93358 .07997 -0.22607 .31116 Mabsadd L
.93358 .07997 -0.95106 .30902 Mabsadd L
.93358 .07997 -0.36579 -0.11885 Mabsadd L
.93358 .07997 -0.58778 -0.80902 Mabsadd L
.93358 .07997 0 -0.38461 Mabsadd L
.93358 .07997 .58779 -0.80902 Mabsadd L
.93358 .07997 .36579 -0.11885 Mabsadd L
.93358 .07997 .95106 .30902 Mabsadd L
.93358 .07997 .22607 .31116 Mabsadd L
.93358 .07997 0 1 Mabsadd L closepath F
.93727 .07997 0 1 Mabsadd m
.93727 .07997 -0.22607 .31116 Mabsadd L
.93727 .07997 -0.95106 .30902 Mabsadd L
.93727 .07997 -0.36579 -0.11885 Mabsadd L
.93727 .07997 -0.58778 -0.80902 Mabsadd L
.93727 .07997 0 -0.38461 Mabsadd L
.93727 .07997 .58779 -0.80902 Mabsadd L
.93727 .07997 .36579 -0.11885 Mabsadd L
.93727 .07997 .95106 .30902 Mabsadd L
.93727 .07997 .22607 .31116 Mabsadd L
.93727 .07997 0 1 Mabsadd L closepath F
.94096 .08003 0 1 Mabsadd m
.94096 .08003 -0.22607 .31116 Mabsadd L
.94096 .08003 -0.95106 .30902 Mabsadd L
.94096 .08003 -0.36579 -0.11885 Mabsadd L
.94096 .08003 -0.58778 -0.80902 Mabsadd L
.94096 .08003 0 -0.38461 Mabsadd L
.94096 .08003 .58779 -0.80902 Mabsadd L
.94096 .08003 .36579 -0.11885 Mabsadd L
.94096 .08003 .95106 .30902 Mabsadd L
.94096 .08003 .22607 .31116 Mabsadd L
.94096 .08003 0 1 Mabsadd L closepath F
.94465 .08004 0 1 Mabsadd m
.94465 .08004 -0.22607 .31116 Mabsadd L
.94465 .08004 -0.95106 .30902 Mabsadd L
.94465 .08004 -0.36579 -0.11885 Mabsadd L
.94465 .08004 -0.58778 -0.80902 Mabsadd L
.94465 .08004 0 -0.38461 Mabsadd L
.94465 .08004 .58779 -0.80902 Mabsadd L
.94465 .08004 .36579 -0.11885 Mabsadd L
.94465 .08004 .95106 .30902 Mabsadd L
.94465 .08004 .22607 .31116 Mabsadd L
.94465 .08004 0 1 Mabsadd L closepath F
.94834 .07997 0 1 Mabsadd m
.94834 .07997 -0.22607 .31116 Mabsadd L
.94834 .07997 -0.95106 .30902 Mabsadd L
.94834 .07997 -0.36579 -0.11885 Mabsadd L
.94834 .07997 -0.58778 -0.80902 Mabsadd L
.94834 .07997 0 -0.38461 Mabsadd L
.94834 .07997 .58779 -0.80902 Mabsadd L
.94834 .07997 .36579 -0.11885 Mabsadd L
.94834 .07997 .95106 .30902 Mabsadd L
.94834 .07997 .22607 .31116 Mabsadd L
.94834 .07997 0 1 Mabsadd L closepath F
.95203 .08002 0 1 Mabsadd m
.95203 .08002 -0.22607 .31116 Mabsadd L
.95203 .08002 -0.95106 .30902 Mabsadd L
.95203 .08002 -0.36579 -0.11885 Mabsadd L
.95203 .08002 -0.58778 -0.80902 Mabsadd L
.95203 .08002 0 -0.38461 Mabsadd L
.95203 .08002 .58779 -0.80902 Mabsadd L
.95203 .08002 .36579 -0.11885 Mabsadd L
.95203 .08002 .95106 .30902 Mabsadd L
.95203 .08002 .22607 .31116 Mabsadd L
.95203 .08002 0 1 Mabsadd L closepath F
.95572 .08002 0 1 Mabsadd m
.95572 .08002 -0.22607 .31116 Mabsadd L
.95572 .08002 -0.95106 .30902 Mabsadd L
.95572 .08002 -0.36579 -0.11885 Mabsadd L
.95572 .08002 -0.58778 -0.80902 Mabsadd L
.95572 .08002 0 -0.38461 Mabsadd L
.95572 .08002 .58779 -0.80902 Mabsadd L
.95572 .08002 .36579 -0.11885 Mabsadd L
.95572 .08002 .95106 .30902 Mabsadd L
.95572 .08002 .22607 .31116 Mabsadd L
.95572 .08002 0 1 Mabsadd L closepath F
.95941 .08002 0 1 Mabsadd m
.95941 .08002 -0.22607 .31116 Mabsadd L
.95941 .08002 -0.95106 .30902 Mabsadd L
.95941 .08002 -0.36579 -0.11885 Mabsadd L
.95941 .08002 -0.58778 -0.80902 Mabsadd L
.95941 .08002 0 -0.38461 Mabsadd L
.95941 .08002 .58779 -0.80902 Mabsadd L
.95941 .08002 .36579 -0.11885 Mabsadd L
.95941 .08002 .95106 .30902 Mabsadd L
.95941 .08002 .22607 .31116 Mabsadd L
.95941 .08002 0 1 Mabsadd L closepath F
.9631 .08002 0 1 Mabsadd m
.9631 .08002 -0.22607 .31116 Mabsadd L
.9631 .08002 -0.95106 .30902 Mabsadd L
.9631 .08002 -0.36579 -0.11885 Mabsadd L
.9631 .08002 -0.58778 -0.80902 Mabsadd L
.9631 .08002 0 -0.38461 Mabsadd L
.9631 .08002 .58779 -0.80902 Mabsadd L
.9631 .08002 .36579 -0.11885 Mabsadd L
.9631 .08002 .95106 .30902 Mabsadd L
.9631 .08002 .22607 .31116 Mabsadd L
.9631 .08002 0 1 Mabsadd L closepath F
.96679 .08002 0 1 Mabsadd m
.96679 .08002 -0.22607 .31116 Mabsadd L
.96679 .08002 -0.95106 .30902 Mabsadd L
.96679 .08002 -0.36579 -0.11885 Mabsadd L
.96679 .08002 -0.58778 -0.80902 Mabsadd L
.96679 .08002 0 -0.38461 Mabsadd L
.96679 .08002 .58779 -0.80902 Mabsadd L
.96679 .08002 .36579 -0.11885 Mabsadd L
.96679 .08002 .95106 .30902 Mabsadd L
.96679 .08002 .22607 .31116 Mabsadd L
.96679 .08002 0 1 Mabsadd L closepath F
.97048 .07997 0 1 Mabsadd m
.97048 .07997 -0.22607 .31116 Mabsadd L
.97048 .07997 -0.95106 .30902 Mabsadd L
.97048 .07997 -0.36579 -0.11885 Mabsadd L
.97048 .07997 -0.58778 -0.80902 Mabsadd L
.97048 .07997 0 -0.38461 Mabsadd L
.97048 .07997 .58779 -0.80902 Mabsadd L
.97048 .07997 .36579 -0.11885 Mabsadd L
.97048 .07997 .95106 .30902 Mabsadd L
.97048 .07997 .22607 .31116 Mabsadd L
.97048 .07997 0 1 Mabsadd L closepath F
.97417 .07997 0 1 Mabsadd m
.97417 .07997 -0.22607 .31116 Mabsadd L
.97417 .07997 -0.95106 .30902 Mabsadd L
.97417 .07997 -0.36579 -0.11885 Mabsadd L
.97417 .07997 -0.58778 -0.80902 Mabsadd L
.97417 .07997 0 -0.38461 Mabsadd L
.97417 .07997 .58779 -0.80902 Mabsadd L
.97417 .07997 .36579 -0.11885 Mabsadd L
.97417 .07997 .95106 .30902 Mabsadd L
.97417 .07997 .22607 .31116 Mabsadd L
.97417 .07997 0 1 Mabsadd L closepath F
.97786 .07997 0 1 Mabsadd m
.97786 .07997 -0.22607 .31116 Mabsadd L
.97786 .07997 -0.95106 .30902 Mabsadd L
.97786 .07997 -0.36579 -0.11885 Mabsadd L
.97786 .07997 -0.58778 -0.80902 Mabsadd L
.97786 .07997 0 -0.38461 Mabsadd L
.97786 .07997 .58779 -0.80902 Mabsadd L
.97786 .07997 .36579 -0.11885 Mabsadd L
.97786 .07997 .95106 .30902 Mabsadd L
.97786 .07997 .22607 .31116 Mabsadd L
.97786 .07997 0 1 Mabsadd L closepath F
.98155 .07993 0 1 Mabsadd m
.98155 .07993 -0.22607 .31116 Mabsadd L
.98155 .07993 -0.95106 .30902 Mabsadd L
.98155 .07993 -0.36579 -0.11885 Mabsadd L
.98155 .07993 -0.58778 -0.80902 Mabsadd L
.98155 .07993 0 -0.38461 Mabsadd L
.98155 .07993 .58779 -0.80902 Mabsadd L
.98155 .07993 .36579 -0.11885 Mabsadd L
.98155 .07993 .95106 .30902 Mabsadd L
.98155 .07993 .22607 .31116 Mabsadd L
.98155 .07993 0 1 Mabsadd L closepath F
.98524 .07992 0 1 Mabsadd m
.98524 .07992 -0.22607 .31116 Mabsadd L
.98524 .07992 -0.95106 .30902 Mabsadd L
.98524 .07992 -0.36579 -0.11885 Mabsadd L
.98524 .07992 -0.58778 -0.80902 Mabsadd L
.98524 .07992 0 -0.38461 Mabsadd L
.98524 .07992 .58779 -0.80902 Mabsadd L
.98524 .07992 .36579 -0.11885 Mabsadd L
.98524 .07992 .95106 .30902 Mabsadd L
.98524 .07992 .22607 .31116 Mabsadd L
.98524 .07992 0 1 Mabsadd L closepath F
.98893 .07992 0 1 Mabsadd m
.98893 .07992 -0.22607 .31116 Mabsadd L
.98893 .07992 -0.95106 .30902 Mabsadd L
.98893 .07992 -0.36579 -0.11885 Mabsadd L
.98893 .07992 -0.58778 -0.80902 Mabsadd L
.98893 .07992 0 -0.38461 Mabsadd L
.98893 .07992 .58779 -0.80902 Mabsadd L
.98893 .07992 .36579 -0.11885 Mabsadd L
.98893 .07992 .95106 .30902 Mabsadd L
.98893 .07992 .22607 .31116 Mabsadd L
.98893 .07992 0 1 Mabsadd L closepath F
.99262 .07997 0 1 Mabsadd m
.99262 .07997 -0.22607 .31116 Mabsadd L
.99262 .07997 -0.95106 .30902 Mabsadd L
.99262 .07997 -0.36579 -0.11885 Mabsadd L
.99262 .07997 -0.58778 -0.80902 Mabsadd L
.99262 .07997 0 -0.38461 Mabsadd L
.99262 .07997 .58779 -0.80902 Mabsadd L
.99262 .07997 .36579 -0.11885 Mabsadd L
.99262 .07997 .95106 .30902 Mabsadd L
.99262 .07997 .22607 .31116 Mabsadd L
.99262 .07997 0 1 Mabsadd L closepath F
.99631 .08002 0 1 Mabsadd m
.99631 .08002 -0.22607 .31116 Mabsadd L
.99631 .08002 -0.95106 .30902 Mabsadd L
.99631 .08002 -0.36579 -0.11885 Mabsadd L
.99631 .08002 -0.58778 -0.80902 Mabsadd L
.99631 .08002 0 -0.38461 Mabsadd L
.99631 .08002 .58779 -0.80902 Mabsadd L
.99631 .08002 .36579 -0.11885 Mabsadd L
.99631 .08002 .95106 .30902 Mabsadd L
.99631 .08002 .22607 .31116 Mabsadd L
.99631 .08002 0 1 Mabsadd L closepath F
1 0 0 r
.0738 .55943 -0.75 0 Mabsadd m
.0738 .55943 0 1 Mabsadd L
.0738 .55943 .75 0 Mabsadd L
.0738 .55943 0 -1 Mabsadd L
.0738 .55943 -0.75 0 Mabsadd L closepath F
.07749 .42173 -0.75 0 Mabsadd m
.07749 .42173 0 1 Mabsadd L
.07749 .42173 .75 0 Mabsadd L
.07749 .42173 0 -1 Mabsadd L
.07749 .42173 -0.75 0 Mabsadd L closepath F
.08118 .41121 -0.75 0 Mabsadd m
.08118 .41121 0 1 Mabsadd L
.08118 .41121 .75 0 Mabsadd L
.08118 .41121 0 -1 Mabsadd L
.08118 .41121 -0.75 0 Mabsadd L closepath F
.08487 .40062 -0.75 0 Mabsadd m
.08487 .40062 0 1 Mabsadd L
.08487 .40062 .75 0 Mabsadd L
.08487 .40062 0 -1 Mabsadd L
.08487 .40062 -0.75 0 Mabsadd L closepath F
.08856 .3904 -0.75 0 Mabsadd m
.08856 .3904 0 1 Mabsadd L
.08856 .3904 .75 0 Mabsadd L
.08856 .3904 0 -1 Mabsadd L
.08856 .3904 -0.75 0 Mabsadd L closepath F
.09225 .38163 -0.75 0 Mabsadd m
.09225 .38163 0 1 Mabsadd L
.09225 .38163 .75 0 Mabsadd L
.09225 .38163 0 -1 Mabsadd L
.09225 .38163 -0.75 0 Mabsadd L closepath F
.09594 .37299 -0.75 0 Mabsadd m
.09594 .37299 0 1 Mabsadd L
.09594 .37299 .75 0 Mabsadd L
.09594 .37299 0 -1 Mabsadd L
.09594 .37299 -0.75 0 Mabsadd L closepath F
.09963 .36524 -0.75 0 Mabsadd m
.09963 .36524 0 1 Mabsadd L
.09963 .36524 .75 0 Mabsadd L
.09963 .36524 0 -1 Mabsadd L
.09963 .36524 -0.75 0 Mabsadd L closepath F
.10332 .35641 -0.75 0 Mabsadd m
.10332 .35641 0 1 Mabsadd L
.10332 .35641 .75 0 Mabsadd L
.10332 .35641 0 -1 Mabsadd L
.10332 .35641 -0.75 0 Mabsadd L closepath F
.10701 .34826 -0.75 0 Mabsadd m
.10701 .34826 0 1 Mabsadd L
.10701 .34826 .75 0 Mabsadd L
.10701 .34826 0 -1 Mabsadd L
.10701 .34826 -0.75 0 Mabsadd L closepath F
.1107 .34067 -0.75 0 Mabsadd m
.1107 .34067 0 1 Mabsadd L
.1107 .34067 .75 0 Mabsadd L
.1107 .34067 0 -1 Mabsadd L
.1107 .34067 -0.75 0 Mabsadd L closepath F
.11439 .33282 -0.75 0 Mabsadd m
.11439 .33282 0 1 Mabsadd L
.11439 .33282 .75 0 Mabsadd L
.11439 .33282 0 -1 Mabsadd L
.11439 .33282 -0.75 0 Mabsadd L closepath F
.11808 .32517 -0.75 0 Mabsadd m
.11808 .32517 0 1 Mabsadd L
.11808 .32517 .75 0 Mabsadd L
.11808 .32517 0 -1 Mabsadd L
.11808 .32517 -0.75 0 Mabsadd L closepath F
.12177 .31657 -0.75 0 Mabsadd m
.12177 .31657 0 1 Mabsadd L
.12177 .31657 .75 0 Mabsadd L
.12177 .31657 0 -1 Mabsadd L
.12177 .31657 -0.75 0 Mabsadd L closepath F
.12546 .30975 -0.75 0 Mabsadd m
.12546 .30975 0 1 Mabsadd L
.12546 .30975 .75 0 Mabsadd L
.12546 .30975 0 -1 Mabsadd L
.12546 .30975 -0.75 0 Mabsadd L closepath F
.12915 .3028 -0.75 0 Mabsadd m
.12915 .3028 0 1 Mabsadd L
.12915 .3028 .75 0 Mabsadd L
.12915 .3028 0 -1 Mabsadd L
.12915 .3028 -0.75 0 Mabsadd L closepath F
.13284 .297 -0.75 0 Mabsadd m
.13284 .297 0 1 Mabsadd L
.13284 .297 .75 0 Mabsadd L
.13284 .297 0 -1 Mabsadd L
.13284 .297 -0.75 0 Mabsadd L closepath F
.13653 .29009 -0.75 0 Mabsadd m
.13653 .29009 0 1 Mabsadd L
.13653 .29009 .75 0 Mabsadd L
.13653 .29009 0 -1 Mabsadd L
.13653 .29009 -0.75 0 Mabsadd L closepath F
.14022 .28478 -0.75 0 Mabsadd m
.14022 .28478 0 1 Mabsadd L
.14022 .28478 .75 0 Mabsadd L
.14022 .28478 0 -1 Mabsadd L
.14022 .28478 -0.75 0 Mabsadd L closepath F
.14391 .27946 -0.75 0 Mabsadd m
.14391 .27946 0 1 Mabsadd L
.14391 .27946 .75 0 Mabsadd L
.14391 .27946 0 -1 Mabsadd L
.14391 .27946 -0.75 0 Mabsadd L closepath F
.1476 .27383 -0.75 0 Mabsadd m
.1476 .27383 0 1 Mabsadd L
.1476 .27383 .75 0 Mabsadd L
.1476 .27383 0 -1 Mabsadd L
.1476 .27383 -0.75 0 Mabsadd L closepath F
.15129 .26733 -0.75 0 Mabsadd m
.15129 .26733 0 1 Mabsadd L
.15129 .26733 .75 0 Mabsadd L
.15129 .26733 0 -1 Mabsadd L
.15129 .26733 -0.75 0 Mabsadd L closepath F
.15498 .26123 -0.75 0 Mabsadd m
.15498 .26123 0 1 Mabsadd L
.15498 .26123 .75 0 Mabsadd L
.15498 .26123 0 -1 Mabsadd L
.15498 .26123 -0.75 0 Mabsadd L closepath F
.15867 .25599 -0.75 0 Mabsadd m
.15867 .25599 0 1 Mabsadd L
.15867 .25599 .75 0 Mabsadd L
.15867 .25599 0 -1 Mabsadd L
.15867 .25599 -0.75 0 Mabsadd L closepath F
.16236 .25092 -0.75 0 Mabsadd m
.16236 .25092 0 1 Mabsadd L
.16236 .25092 .75 0 Mabsadd L
.16236 .25092 0 -1 Mabsadd L
.16236 .25092 -0.75 0 Mabsadd L closepath F
.16605 .24559 -0.75 0 Mabsadd m
.16605 .24559 0 1 Mabsadd L
.16605 .24559 .75 0 Mabsadd L
.16605 .24559 0 -1 Mabsadd L
.16605 .24559 -0.75 0 Mabsadd L closepath F
.16974 .24085 -0.75 0 Mabsadd m
.16974 .24085 0 1 Mabsadd L
.16974 .24085 .75 0 Mabsadd L
.16974 .24085 0 -1 Mabsadd L
.16974 .24085 -0.75 0 Mabsadd L closepath F
.17343 .23683 -0.75 0 Mabsadd m
.17343 .23683 0 1 Mabsadd L
.17343 .23683 .75 0 Mabsadd L
.17343 .23683 0 -1 Mabsadd L
.17343 .23683 -0.75 0 Mabsadd L closepath F
.17712 .23222 -0.75 0 Mabsadd m
.17712 .23222 0 1 Mabsadd L
.17712 .23222 .75 0 Mabsadd L
.17712 .23222 0 -1 Mabsadd L
.17712 .23222 -0.75 0 Mabsadd L closepath F
.18081 .22762 -0.75 0 Mabsadd m
.18081 .22762 0 1 Mabsadd L
.18081 .22762 .75 0 Mabsadd L
.18081 .22762 0 -1 Mabsadd L
.18081 .22762 -0.75 0 Mabsadd L closepath F
.1845 .22292 -0.75 0 Mabsadd m
.1845 .22292 0 1 Mabsadd L
.1845 .22292 .75 0 Mabsadd L
.1845 .22292 0 -1 Mabsadd L
.1845 .22292 -0.75 0 Mabsadd L closepath F
.18819 .21872 -0.75 0 Mabsadd m
.18819 .21872 0 1 Mabsadd L
.18819 .21872 .75 0 Mabsadd L
.18819 .21872 0 -1 Mabsadd L
.18819 .21872 -0.75 0 Mabsadd L closepath F
.19188 .2144 -0.75 0 Mabsadd m
.19188 .2144 0 1 Mabsadd L
.19188 .2144 .75 0 Mabsadd L
.19188 .2144 0 -1 Mabsadd L
.19188 .2144 -0.75 0 Mabsadd L closepath F
.19557 .20989 -0.75 0 Mabsadd m
.19557 .20989 0 1 Mabsadd L
.19557 .20989 .75 0 Mabsadd L
.19557 .20989 0 -1 Mabsadd L
.19557 .20989 -0.75 0 Mabsadd L closepath F
.19926 .20676 -0.75 0 Mabsadd m
.19926 .20676 0 1 Mabsadd L
.19926 .20676 .75 0 Mabsadd L
.19926 .20676 0 -1 Mabsadd L
.19926 .20676 -0.75 0 Mabsadd L closepath F
.20295 .20322 -0.75 0 Mabsadd m
.20295 .20322 0 1 Mabsadd L
.20295 .20322 .75 0 Mabsadd L
.20295 .20322 0 -1 Mabsadd L
.20295 .20322 -0.75 0 Mabsadd L closepath F
.20664 .19953 -0.75 0 Mabsadd m
.20664 .19953 0 1 Mabsadd L
.20664 .19953 .75 0 Mabsadd L
.20664 .19953 0 -1 Mabsadd L
.20664 .19953 -0.75 0 Mabsadd L closepath F
.21033 .1964 -0.75 0 Mabsadd m
.21033 .1964 0 1 Mabsadd L
.21033 .1964 .75 0 Mabsadd L
.21033 .1964 0 -1 Mabsadd L
.21033 .1964 -0.75 0 Mabsadd L closepath F
.21402 .19276 -0.75 0 Mabsadd m
.21402 .19276 0 1 Mabsadd L
.21402 .19276 .75 0 Mabsadd L
.21402 .19276 0 -1 Mabsadd L
.21402 .19276 -0.75 0 Mabsadd L closepath F
.21771 .18976 -0.75 0 Mabsadd m
.21771 .18976 0 1 Mabsadd L
.21771 .18976 .75 0 Mabsadd L
.21771 .18976 0 -1 Mabsadd L
.21771 .18976 -0.75 0 Mabsadd L closepath F
.2214 .18666 -0.75 0 Mabsadd m
.2214 .18666 0 1 Mabsadd L
.2214 .18666 .75 0 Mabsadd L
.2214 .18666 0 -1 Mabsadd L
.2214 .18666 -0.75 0 Mabsadd L closepath F
.22509 .18291 -0.75 0 Mabsadd m
.22509 .18291 0 1 Mabsadd L
.22509 .18291 .75 0 Mabsadd L
.22509 .18291 0 -1 Mabsadd L
.22509 .18291 -0.75 0 Mabsadd L closepath F
.22878 .17978 -0.75 0 Mabsadd m
.22878 .17978 0 1 Mabsadd L
.22878 .17978 .75 0 Mabsadd L
.22878 .17978 0 -1 Mabsadd L
.22878 .17978 -0.75 0 Mabsadd L closepath F
.23247 .17707 -0.75 0 Mabsadd m
.23247 .17707 0 1 Mabsadd L
.23247 .17707 .75 0 Mabsadd L
.23247 .17707 0 -1 Mabsadd L
.23247 .17707 -0.75 0 Mabsadd L closepath F
.23616 .17489 -0.75 0 Mabsadd m
.23616 .17489 0 1 Mabsadd L
.23616 .17489 .75 0 Mabsadd L
.23616 .17489 0 -1 Mabsadd L
.23616 .17489 -0.75 0 Mabsadd L closepath F
.23985 .17208 -0.75 0 Mabsadd m
.23985 .17208 0 1 Mabsadd L
.23985 .17208 .75 0 Mabsadd L
.23985 .17208 0 -1 Mabsadd L
.23985 .17208 -0.75 0 Mabsadd L closepath F
.24354 .16967 -0.75 0 Mabsadd m
.24354 .16967 0 1 Mabsadd L
.24354 .16967 .75 0 Mabsadd L
.24354 .16967 0 -1 Mabsadd L
.24354 .16967 -0.75 0 Mabsadd L closepath F
.24723 .16772 -0.75 0 Mabsadd m
.24723 .16772 0 1 Mabsadd L
.24723 .16772 .75 0 Mabsadd L
.24723 .16772 0 -1 Mabsadd L
.24723 .16772 -0.75 0 Mabsadd L closepath F
.25092 .16533 -0.75 0 Mabsadd m
.25092 .16533 0 1 Mabsadd L
.25092 .16533 .75 0 Mabsadd L
.25092 .16533 0 -1 Mabsadd L
.25092 .16533 -0.75 0 Mabsadd L closepath F
.25461 .1625 -0.75 0 Mabsadd m
.25461 .1625 0 1 Mabsadd L
.25461 .1625 .75 0 Mabsadd L
.25461 .1625 0 -1 Mabsadd L
.25461 .1625 -0.75 0 Mabsadd L closepath F
.2583 .1606 -0.75 0 Mabsadd m
.2583 .1606 0 1 Mabsadd L
.2583 .1606 .75 0 Mabsadd L
.2583 .1606 0 -1 Mabsadd L
.2583 .1606 -0.75 0 Mabsadd L closepath F
.26199 .15788 -0.75 0 Mabsadd m
.26199 .15788 0 1 Mabsadd L
.26199 .15788 .75 0 Mabsadd L
.26199 .15788 0 -1 Mabsadd L
.26199 .15788 -0.75 0 Mabsadd L closepath F
.26568 .15605 -0.75 0 Mabsadd m
.26568 .15605 0 1 Mabsadd L
.26568 .15605 .75 0 Mabsadd L
.26568 .15605 0 -1 Mabsadd L
.26568 .15605 -0.75 0 Mabsadd L closepath F
.26937 .15373 -0.75 0 Mabsadd m
.26937 .15373 0 1 Mabsadd L
.26937 .15373 .75 0 Mabsadd L
.26937 .15373 0 -1 Mabsadd L
.26937 .15373 -0.75 0 Mabsadd L closepath F
.27306 .15152 -0.75 0 Mabsadd m
.27306 .15152 0 1 Mabsadd L
.27306 .15152 .75 0 Mabsadd L
.27306 .15152 0 -1 Mabsadd L
.27306 .15152 -0.75 0 Mabsadd L closepath F
.27675 .14938 -0.75 0 Mabsadd m
.27675 .14938 0 1 Mabsadd L
.27675 .14938 .75 0 Mabsadd L
.27675 .14938 0 -1 Mabsadd L
.27675 .14938 -0.75 0 Mabsadd L closepath F
.28044 .14742 -0.75 0 Mabsadd m
.28044 .14742 0 1 Mabsadd L
.28044 .14742 .75 0 Mabsadd L
.28044 .14742 0 -1 Mabsadd L
.28044 .14742 -0.75 0 Mabsadd L closepath F
.28413 .14547 -0.75 0 Mabsadd m
.28413 .14547 0 1 Mabsadd L
.28413 .14547 .75 0 Mabsadd L
.28413 .14547 0 -1 Mabsadd L
.28413 .14547 -0.75 0 Mabsadd L closepath F
.28782 .14357 -0.75 0 Mabsadd m
.28782 .14357 0 1 Mabsadd L
.28782 .14357 .75 0 Mabsadd L
.28782 .14357 0 -1 Mabsadd L
.28782 .14357 -0.75 0 Mabsadd L closepath F
.29151 .14187 -0.75 0 Mabsadd m
.29151 .14187 0 1 Mabsadd L
.29151 .14187 .75 0 Mabsadd L
.29151 .14187 0 -1 Mabsadd L
.29151 .14187 -0.75 0 Mabsadd L closepath F
.2952 .14051 -0.75 0 Mabsadd m
.2952 .14051 0 1 Mabsadd L
.2952 .14051 .75 0 Mabsadd L
.2952 .14051 0 -1 Mabsadd L
.2952 .14051 -0.75 0 Mabsadd L closepath F
.29889 .13915 -0.75 0 Mabsadd m
.29889 .13915 0 1 Mabsadd L
.29889 .13915 .75 0 Mabsadd L
.29889 .13915 0 -1 Mabsadd L
.29889 .13915 -0.75 0 Mabsadd L closepath F
.30258 .13683 -0.75 0 Mabsadd m
.30258 .13683 0 1 Mabsadd L
.30258 .13683 .75 0 Mabsadd L
.30258 .13683 0 -1 Mabsadd L
.30258 .13683 -0.75 0 Mabsadd L closepath F
.30627 .13524 -0.75 0 Mabsadd m
.30627 .13524 0 1 Mabsadd L
.30627 .13524 .75 0 Mabsadd L
.30627 .13524 0 -1 Mabsadd L
.30627 .13524 -0.75 0 Mabsadd L closepath F
.30996 .13331 -0.75 0 Mabsadd m
.30996 .13331 0 1 Mabsadd L
.30996 .13331 .75 0 Mabsadd L
.30996 .13331 0 -1 Mabsadd L
.30996 .13331 -0.75 0 Mabsadd L closepath F
.31365 .1315 -0.75 0 Mabsadd m
.31365 .1315 0 1 Mabsadd L
.31365 .1315 .75 0 Mabsadd L
.31365 .1315 0 -1 Mabsadd L
.31365 .1315 -0.75 0 Mabsadd L closepath F
.31734 .12995 -0.75 0 Mabsadd m
.31734 .12995 0 1 Mabsadd L
.31734 .12995 .75 0 Mabsadd L
.31734 .12995 0 -1 Mabsadd L
.31734 .12995 -0.75 0 Mabsadd L closepath F
.32103 .12843 -0.75 0 Mabsadd m
.32103 .12843 0 1 Mabsadd L
.32103 .12843 .75 0 Mabsadd L
.32103 .12843 0 -1 Mabsadd L
.32103 .12843 -0.75 0 Mabsadd L closepath F
.32472 .12687 -0.75 0 Mabsadd m
.32472 .12687 0 1 Mabsadd L
.32472 .12687 .75 0 Mabsadd L
.32472 .12687 0 -1 Mabsadd L
.32472 .12687 -0.75 0 Mabsadd L closepath F
.32841 .12536 -0.75 0 Mabsadd m
.32841 .12536 0 1 Mabsadd L
.32841 .12536 .75 0 Mabsadd L
.32841 .12536 0 -1 Mabsadd L
.32841 .12536 -0.75 0 Mabsadd L closepath F
.3321 .12393 -0.75 0 Mabsadd m
.3321 .12393 0 1 Mabsadd L
.3321 .12393 .75 0 Mabsadd L
.3321 .12393 0 -1 Mabsadd L
.3321 .12393 -0.75 0 Mabsadd L closepath F
.33579 .12221 -0.75 0 Mabsadd m
.33579 .12221 0 1 Mabsadd L
.33579 .12221 .75 0 Mabsadd L
.33579 .12221 0 -1 Mabsadd L
.33579 .12221 -0.75 0 Mabsadd L closepath F
.33948 .12079 -0.75 0 Mabsadd m
.33948 .12079 0 1 Mabsadd L
.33948 .12079 .75 0 Mabsadd L
.33948 .12079 0 -1 Mabsadd L
.33948 .12079 -0.75 0 Mabsadd L closepath F
.34317 .11927 -0.75 0 Mabsadd m
.34317 .11927 0 1 Mabsadd L
.34317 .11927 .75 0 Mabsadd L
.34317 .11927 0 -1 Mabsadd L
.34317 .11927 -0.75 0 Mabsadd L closepath F
.34686 .11819 -0.75 0 Mabsadd m
.34686 .11819 0 1 Mabsadd L
.34686 .11819 .75 0 Mabsadd L
.34686 .11819 0 -1 Mabsadd L
.34686 .11819 -0.75 0 Mabsadd L closepath F
.35055 .11711 -0.75 0 Mabsadd m
.35055 .11711 0 1 Mabsadd L
.35055 .11711 .75 0 Mabsadd L
.35055 .11711 0 -1 Mabsadd L
.35055 .11711 -0.75 0 Mabsadd L closepath F
.35424 .11563 -0.75 0 Mabsadd m
.35424 .11563 0 1 Mabsadd L
.35424 .11563 .75 0 Mabsadd L
.35424 .11563 0 -1 Mabsadd L
.35424 .11563 -0.75 0 Mabsadd L closepath F
.35793 .11478 -0.75 0 Mabsadd m
.35793 .11478 0 1 Mabsadd L
.35793 .11478 .75 0 Mabsadd L
.35793 .11478 0 -1 Mabsadd L
.35793 .11478 -0.75 0 Mabsadd L closepath F
.36162 .11396 -0.75 0 Mabsadd m
.36162 .11396 0 1 Mabsadd L
.36162 .11396 .75 0 Mabsadd L
.36162 .11396 0 -1 Mabsadd L
.36162 .11396 -0.75 0 Mabsadd L closepath F
.36531 .11296 -0.75 0 Mabsadd m
.36531 .11296 0 1 Mabsadd L
.36531 .11296 .75 0 Mabsadd L
.36531 .11296 0 -1 Mabsadd L
.36531 .11296 -0.75 0 Mabsadd L closepath F
.369 .11184 -0.75 0 Mabsadd m
.369 .11184 0 1 Mabsadd L
.369 .11184 .75 0 Mabsadd L
.369 .11184 0 -1 Mabsadd L
.369 .11184 -0.75 0 Mabsadd L closepath F
.37269 .11069 -0.75 0 Mabsadd m
.37269 .11069 0 1 Mabsadd L
.37269 .11069 .75 0 Mabsadd L
.37269 .11069 0 -1 Mabsadd L
.37269 .11069 -0.75 0 Mabsadd L closepath F
.37638 .10962 -0.75 0 Mabsadd m
.37638 .10962 0 1 Mabsadd L
.37638 .10962 .75 0 Mabsadd L
.37638 .10962 0 -1 Mabsadd L
.37638 .10962 -0.75 0 Mabsadd L closepath F
.38007 .10892 -0.75 0 Mabsadd m
.38007 .10892 0 1 Mabsadd L
.38007 .10892 .75 0 Mabsadd L
.38007 .10892 0 -1 Mabsadd L
.38007 .10892 -0.75 0 Mabsadd L closepath F
.38376 .10778 -0.75 0 Mabsadd m
.38376 .10778 0 1 Mabsadd L
.38376 .10778 .75 0 Mabsadd L
.38376 .10778 0 -1 Mabsadd L
.38376 .10778 -0.75 0 Mabsadd L closepath F
.38745 .10711 -0.75 0 Mabsadd m
.38745 .10711 0 1 Mabsadd L
.38745 .10711 .75 0 Mabsadd L
.38745 .10711 0 -1 Mabsadd L
.38745 .10711 -0.75 0 Mabsadd L closepath F
.39114 .10635 -0.75 0 Mabsadd m
.39114 .10635 0 1 Mabsadd L
.39114 .10635 .75 0 Mabsadd L
.39114 .10635 0 -1 Mabsadd L
.39114 .10635 -0.75 0 Mabsadd L closepath F
.39483 .10528 -0.75 0 Mabsadd m
.39483 .10528 0 1 Mabsadd L
.39483 .10528 .75 0 Mabsadd L
.39483 .10528 0 -1 Mabsadd L
.39483 .10528 -0.75 0 Mabsadd L closepath F
.39852 .10453 -0.75 0 Mabsadd m
.39852 .10453 0 1 Mabsadd L
.39852 .10453 .75 0 Mabsadd L
.39852 .10453 0 -1 Mabsadd L
.39852 .10453 -0.75 0 Mabsadd L closepath F
.40221 .10369 -0.75 0 Mabsadd m
.40221 .10369 0 1 Mabsadd L
.40221 .10369 .75 0 Mabsadd L
.40221 .10369 0 -1 Mabsadd L
.40221 .10369 -0.75 0 Mabsadd L closepath F
.4059 .10333 -0.75 0 Mabsadd m
.4059 .10333 0 1 Mabsadd L
.4059 .10333 .75 0 Mabsadd L
.4059 .10333 0 -1 Mabsadd L
.4059 .10333 -0.75 0 Mabsadd L closepath F
.40959 .10293 -0.75 0 Mabsadd m
.40959 .10293 0 1 Mabsadd L
.40959 .10293 .75 0 Mabsadd L
.40959 .10293 0 -1 Mabsadd L
.40959 .10293 -0.75 0 Mabsadd L closepath F
.41328 .10228 -0.75 0 Mabsadd m
.41328 .10228 0 1 Mabsadd L
.41328 .10228 .75 0 Mabsadd L
.41328 .10228 0 -1 Mabsadd L
.41328 .10228 -0.75 0 Mabsadd L closepath F
.41697 .10173 -0.75 0 Mabsadd m
.41697 .10173 0 1 Mabsadd L
.41697 .10173 .75 0 Mabsadd L
.41697 .10173 0 -1 Mabsadd L
.41697 .10173 -0.75 0 Mabsadd L closepath F
.42066 .10092 -0.75 0 Mabsadd m
.42066 .10092 0 1 Mabsadd L
.42066 .10092 .75 0 Mabsadd L
.42066 .10092 0 -1 Mabsadd L
.42066 .10092 -0.75 0 Mabsadd L closepath F
.42435 .10024 -0.75 0 Mabsadd m
.42435 .10024 0 1 Mabsadd L
.42435 .10024 .75 0 Mabsadd L
.42435 .10024 0 -1 Mabsadd L
.42435 .10024 -0.75 0 Mabsadd L closepath F
.42804 .09953 -0.75 0 Mabsadd m
.42804 .09953 0 1 Mabsadd L
.42804 .09953 .75 0 Mabsadd L
.42804 .09953 0 -1 Mabsadd L
.42804 .09953 -0.75 0 Mabsadd L closepath F
.43173 .09921 -0.75 0 Mabsadd m
.43173 .09921 0 1 Mabsadd L
.43173 .09921 .75 0 Mabsadd L
.43173 .09921 0 -1 Mabsadd L
.43173 .09921 -0.75 0 Mabsadd L closepath F
.43542 .09867 -0.75 0 Mabsadd m
.43542 .09867 0 1 Mabsadd L
.43542 .09867 .75 0 Mabsadd L
.43542 .09867 0 -1 Mabsadd L
.43542 .09867 -0.75 0 Mabsadd L closepath F
.43911 .09801 -0.75 0 Mabsadd m
.43911 .09801 0 1 Mabsadd L
.43911 .09801 .75 0 Mabsadd L
.43911 .09801 0 -1 Mabsadd L
.43911 .09801 -0.75 0 Mabsadd L closepath F
.4428 .09733 -0.75 0 Mabsadd m
.4428 .09733 0 1 Mabsadd L
.4428 .09733 .75 0 Mabsadd L
.4428 .09733 0 -1 Mabsadd L
.4428 .09733 -0.75 0 Mabsadd L closepath F
.44649 .09656 -0.75 0 Mabsadd m
.44649 .09656 0 1 Mabsadd L
.44649 .09656 .75 0 Mabsadd L
.44649 .09656 0 -1 Mabsadd L
.44649 .09656 -0.75 0 Mabsadd L closepath F
.45018 .09606 -0.75 0 Mabsadd m
.45018 .09606 0 1 Mabsadd L
.45018 .09606 .75 0 Mabsadd L
.45018 .09606 0 -1 Mabsadd L
.45018 .09606 -0.75 0 Mabsadd L closepath F
.45387 .09569 -0.75 0 Mabsadd m
.45387 .09569 0 1 Mabsadd L
.45387 .09569 .75 0 Mabsadd L
.45387 .09569 0 -1 Mabsadd L
.45387 .09569 -0.75 0 Mabsadd L closepath F
.45756 .09516 -0.75 0 Mabsadd m
.45756 .09516 0 1 Mabsadd L
.45756 .09516 .75 0 Mabsadd L
.45756 .09516 0 -1 Mabsadd L
.45756 .09516 -0.75 0 Mabsadd L closepath F
.46125 .09489 -0.75 0 Mabsadd m
.46125 .09489 0 1 Mabsadd L
.46125 .09489 .75 0 Mabsadd L
.46125 .09489 0 -1 Mabsadd L
.46125 .09489 -0.75 0 Mabsadd L closepath F
.46494 .09446 -0.75 0 Mabsadd m
.46494 .09446 0 1 Mabsadd L
.46494 .09446 .75 0 Mabsadd L
.46494 .09446 0 -1 Mabsadd L
.46494 .09446 -0.75 0 Mabsadd L closepath F
.46863 .09421 -0.75 0 Mabsadd m
.46863 .09421 0 1 Mabsadd L
.46863 .09421 .75 0 Mabsadd L
.46863 .09421 0 -1 Mabsadd L
.46863 .09421 -0.75 0 Mabsadd L closepath F
.47232 .09383 -0.75 0 Mabsadd m
.47232 .09383 0 1 Mabsadd L
.47232 .09383 .75 0 Mabsadd L
.47232 .09383 0 -1 Mabsadd L
.47232 .09383 -0.75 0 Mabsadd L closepath F
.47601 .09334 -0.75 0 Mabsadd m
.47601 .09334 0 1 Mabsadd L
.47601 .09334 .75 0 Mabsadd L
.47601 .09334 0 -1 Mabsadd L
.47601 .09334 -0.75 0 Mabsadd L closepath F
.4797 .09294 -0.75 0 Mabsadd m
.4797 .09294 0 1 Mabsadd L
.4797 .09294 .75 0 Mabsadd L
.4797 .09294 0 -1 Mabsadd L
.4797 .09294 -0.75 0 Mabsadd L closepath F
.48339 .09245 -0.75 0 Mabsadd m
.48339 .09245 0 1 Mabsadd L
.48339 .09245 .75 0 Mabsadd L
.48339 .09245 0 -1 Mabsadd L
.48339 .09245 -0.75 0 Mabsadd L closepath F
.48708 .09212 -0.75 0 Mabsadd m
.48708 .09212 0 1 Mabsadd L
.48708 .09212 .75 0 Mabsadd L
.48708 .09212 0 -1 Mabsadd L
.48708 .09212 -0.75 0 Mabsadd L closepath F
.49077 .0917 -0.75 0 Mabsadd m
.49077 .0917 0 1 Mabsadd L
.49077 .0917 .75 0 Mabsadd L
.49077 .0917 0 -1 Mabsadd L
.49077 .0917 -0.75 0 Mabsadd L closepath F
.49446 .09137 -0.75 0 Mabsadd m
.49446 .09137 0 1 Mabsadd L
.49446 .09137 .75 0 Mabsadd L
.49446 .09137 0 -1 Mabsadd L
.49446 .09137 -0.75 0 Mabsadd L closepath F
.49815 .0909 -0.75 0 Mabsadd m
.49815 .0909 0 1 Mabsadd L
.49815 .0909 .75 0 Mabsadd L
.49815 .0909 0 -1 Mabsadd L
.49815 .0909 -0.75 0 Mabsadd L closepath F
.50185 .09058 -0.75 0 Mabsadd m
.50185 .09058 0 1 Mabsadd L
.50185 .09058 .75 0 Mabsadd L
.50185 .09058 0 -1 Mabsadd L
.50185 .09058 -0.75 0 Mabsadd L closepath F
.50554 .09026 -0.75 0 Mabsadd m
.50554 .09026 0 1 Mabsadd L
.50554 .09026 .75 0 Mabsadd L
.50554 .09026 0 -1 Mabsadd L
.50554 .09026 -0.75 0 Mabsadd L closepath F
.50923 .08994 -0.75 0 Mabsadd m
.50923 .08994 0 1 Mabsadd L
.50923 .08994 .75 0 Mabsadd L
.50923 .08994 0 -1 Mabsadd L
.50923 .08994 -0.75 0 Mabsadd L closepath F
.51292 .08951 -0.75 0 Mabsadd m
.51292 .08951 0 1 Mabsadd L
.51292 .08951 .75 0 Mabsadd L
.51292 .08951 0 -1 Mabsadd L
.51292 .08951 -0.75 0 Mabsadd L closepath F
.51661 .0893 -0.75 0 Mabsadd m
.51661 .0893 0 1 Mabsadd L
.51661 .0893 .75 0 Mabsadd L
.51661 .0893 0 -1 Mabsadd L
.51661 .0893 -0.75 0 Mabsadd L closepath F
.5203 .08893 -0.75 0 Mabsadd m
.5203 .08893 0 1 Mabsadd L
.5203 .08893 .75 0 Mabsadd L
.5203 .08893 0 -1 Mabsadd L
.5203 .08893 -0.75 0 Mabsadd L closepath F
.52399 .08855 -0.75 0 Mabsadd m
.52399 .08855 0 1 Mabsadd L
.52399 .08855 .75 0 Mabsadd L
.52399 .08855 0 -1 Mabsadd L
.52399 .08855 -0.75 0 Mabsadd L closepath F
.52768 .0882 -0.75 0 Mabsadd m
.52768 .0882 0 1 Mabsadd L
.52768 .0882 .75 0 Mabsadd L
.52768 .0882 0 -1 Mabsadd L
.52768 .0882 -0.75 0 Mabsadd L closepath F
.53137 .08802 -0.75 0 Mabsadd m
.53137 .08802 0 1 Mabsadd L
.53137 .08802 .75 0 Mabsadd L
.53137 .08802 0 -1 Mabsadd L
.53137 .08802 -0.75 0 Mabsadd L closepath F
.53506 .0878 -0.75 0 Mabsadd m
.53506 .0878 0 1 Mabsadd L
.53506 .0878 .75 0 Mabsadd L
.53506 .0878 0 -1 Mabsadd L
.53506 .0878 -0.75 0 Mabsadd L closepath F
.53875 .08751 -0.75 0 Mabsadd m
.53875 .08751 0 1 Mabsadd L
.53875 .08751 .75 0 Mabsadd L
.53875 .08751 0 -1 Mabsadd L
.53875 .08751 -0.75 0 Mabsadd L closepath F
.54244 .08717 -0.75 0 Mabsadd m
.54244 .08717 0 1 Mabsadd L
.54244 .08717 .75 0 Mabsadd L
.54244 .08717 0 -1 Mabsadd L
.54244 .08717 -0.75 0 Mabsadd L closepath F
.54613 .087 -0.75 0 Mabsadd m
.54613 .087 0 1 Mabsadd L
.54613 .087 .75 0 Mabsadd L
.54613 .087 0 -1 Mabsadd L
.54613 .087 -0.75 0 Mabsadd L closepath F
.54982 .08669 -0.75 0 Mabsadd m
.54982 .08669 0 1 Mabsadd L
.54982 .08669 .75 0 Mabsadd L
.54982 .08669 0 -1 Mabsadd L
.54982 .08669 -0.75 0 Mabsadd L closepath F
.55351 .08643 -0.75 0 Mabsadd m
.55351 .08643 0 1 Mabsadd L
.55351 .08643 .75 0 Mabsadd L
.55351 .08643 0 -1 Mabsadd L
.55351 .08643 -0.75 0 Mabsadd L closepath F
.5572 .08618 -0.75 0 Mabsadd m
.5572 .08618 0 1 Mabsadd L
.5572 .08618 .75 0 Mabsadd L
.5572 .08618 0 -1 Mabsadd L
.5572 .08618 -0.75 0 Mabsadd L closepath F
.56089 .0859 -0.75 0 Mabsadd m
.56089 .0859 0 1 Mabsadd L
.56089 .0859 .75 0 Mabsadd L
.56089 .0859 0 -1 Mabsadd L
.56089 .0859 -0.75 0 Mabsadd L closepath F
.56458 .08562 -0.75 0 Mabsadd m
.56458 .08562 0 1 Mabsadd L
.56458 .08562 .75 0 Mabsadd L
.56458 .08562 0 -1 Mabsadd L
.56458 .08562 -0.75 0 Mabsadd L closepath F
.56827 .08551 -0.75 0 Mabsadd m
.56827 .08551 0 1 Mabsadd L
.56827 .08551 .75 0 Mabsadd L
.56827 .08551 0 -1 Mabsadd L
.56827 .08551 -0.75 0 Mabsadd L closepath F
.57196 .08541 -0.75 0 Mabsadd m
.57196 .08541 0 1 Mabsadd L
.57196 .08541 .75 0 Mabsadd L
.57196 .08541 0 -1 Mabsadd L
.57196 .08541 -0.75 0 Mabsadd L closepath F
.57565 .08531 -0.75 0 Mabsadd m
.57565 .08531 0 1 Mabsadd L
.57565 .08531 .75 0 Mabsadd L
.57565 .08531 0 -1 Mabsadd L
.57565 .08531 -0.75 0 Mabsadd L closepath F
.57934 .0853 -0.75 0 Mabsadd m
.57934 .0853 0 1 Mabsadd L
.57934 .0853 .75 0 Mabsadd L
.57934 .0853 0 -1 Mabsadd L
.57934 .0853 -0.75 0 Mabsadd L closepath F
.58303 .08514 -0.75 0 Mabsadd m
.58303 .08514 0 1 Mabsadd L
.58303 .08514 .75 0 Mabsadd L
.58303 .08514 0 -1 Mabsadd L
.58303 .08514 -0.75 0 Mabsadd L closepath F
.58672 .08477 -0.75 0 Mabsadd m
.58672 .08477 0 1 Mabsadd L
.58672 .08477 .75 0 Mabsadd L
.58672 .08477 0 -1 Mabsadd L
.58672 .08477 -0.75 0 Mabsadd L closepath F
.59041 .08466 -0.75 0 Mabsadd m
.59041 .08466 0 1 Mabsadd L
.59041 .08466 .75 0 Mabsadd L
.59041 .08466 0 -1 Mabsadd L
.59041 .08466 -0.75 0 Mabsadd L closepath F
.5941 .08466 -0.75 0 Mabsadd m
.5941 .08466 0 1 Mabsadd L
.5941 .08466 .75 0 Mabsadd L
.5941 .08466 0 -1 Mabsadd L
.5941 .08466 -0.75 0 Mabsadd L closepath F
.59779 .08456 -0.75 0 Mabsadd m
.59779 .08456 0 1 Mabsadd L
.59779 .08456 .75 0 Mabsadd L
.59779 .08456 0 -1 Mabsadd L
.59779 .08456 -0.75 0 Mabsadd L closepath F
.60148 .08439 -0.75 0 Mabsadd m
.60148 .08439 0 1 Mabsadd L
.60148 .08439 .75 0 Mabsadd L
.60148 .08439 0 -1 Mabsadd L
.60148 .08439 -0.75 0 Mabsadd L closepath F
.60517 .08418 -0.75 0 Mabsadd m
.60517 .08418 0 1 Mabsadd L
.60517 .08418 .75 0 Mabsadd L
.60517 .08418 0 -1 Mabsadd L
.60517 .08418 -0.75 0 Mabsadd L closepath F
.60886 .08413 -0.75 0 Mabsadd m
.60886 .08413 0 1 Mabsadd L
.60886 .08413 .75 0 Mabsadd L
.60886 .08413 0 -1 Mabsadd L
.60886 .08413 -0.75 0 Mabsadd L closepath F
.61255 .08397 -0.75 0 Mabsadd m
.61255 .08397 0 1 Mabsadd L
.61255 .08397 .75 0 Mabsadd L
.61255 .08397 0 -1 Mabsadd L
.61255 .08397 -0.75 0 Mabsadd L closepath F
.61624 .08379 -0.75 0 Mabsadd m
.61624 .08379 0 1 Mabsadd L
.61624 .08379 .75 0 Mabsadd L
.61624 .08379 0 -1 Mabsadd L
.61624 .08379 -0.75 0 Mabsadd L closepath F
.61993 .0837 -0.75 0 Mabsadd m
.61993 .0837 0 1 Mabsadd L
.61993 .0837 .75 0 Mabsadd L
.61993 .0837 0 -1 Mabsadd L
.61993 .0837 -0.75 0 Mabsadd L closepath F
.62362 .08359 -0.75 0 Mabsadd m
.62362 .08359 0 1 Mabsadd L
.62362 .08359 .75 0 Mabsadd L
.62362 .08359 0 -1 Mabsadd L
.62362 .08359 -0.75 0 Mabsadd L closepath F
.62731 .08359 -0.75 0 Mabsadd m
.62731 .08359 0 1 Mabsadd L
.62731 .08359 .75 0 Mabsadd L
.62731 .08359 0 -1 Mabsadd L
.62731 .08359 -0.75 0 Mabsadd L closepath F
.631 .08354 -0.75 0 Mabsadd m
.631 .08354 0 1 Mabsadd L
.631 .08354 .75 0 Mabsadd L
.631 .08354 0 -1 Mabsadd L
.631 .08354 -0.75 0 Mabsadd L closepath F
.63469 .08349 -0.75 0 Mabsadd m
.63469 .08349 0 1 Mabsadd L
.63469 .08349 .75 0 Mabsadd L
.63469 .08349 0 -1 Mabsadd L
.63469 .08349 -0.75 0 Mabsadd L closepath F
.63838 .08333 -0.75 0 Mabsadd m
.63838 .08333 0 1 Mabsadd L
.63838 .08333 .75 0 Mabsadd L
.63838 .08333 0 -1 Mabsadd L
.63838 .08333 -0.75 0 Mabsadd L closepath F
.64207 .08327 -0.75 0 Mabsadd m
.64207 .08327 0 1 Mabsadd L
.64207 .08327 .75 0 Mabsadd L
.64207 .08327 0 -1 Mabsadd L
.64207 .08327 -0.75 0 Mabsadd L closepath F
.64576 .08327 -0.75 0 Mabsadd m
.64576 .08327 0 1 Mabsadd L
.64576 .08327 .75 0 Mabsadd L
.64576 .08327 0 -1 Mabsadd L
.64576 .08327 -0.75 0 Mabsadd L closepath F
.64945 .08317 -0.75 0 Mabsadd m
.64945 .08317 0 1 Mabsadd L
.64945 .08317 .75 0 Mabsadd L
.64945 .08317 0 -1 Mabsadd L
.64945 .08317 -0.75 0 Mabsadd L closepath F
.65314 .08311 -0.75 0 Mabsadd m
.65314 .08311 0 1 Mabsadd L
.65314 .08311 .75 0 Mabsadd L
.65314 .08311 0 -1 Mabsadd L
.65314 .08311 -0.75 0 Mabsadd L closepath F
.65683 .08296 -0.75 0 Mabsadd m
.65683 .08296 0 1 Mabsadd L
.65683 .08296 .75 0 Mabsadd L
.65683 .08296 0 -1 Mabsadd L
.65683 .08296 -0.75 0 Mabsadd L closepath F
.66052 .0829 -0.75 0 Mabsadd m
.66052 .0829 0 1 Mabsadd L
.66052 .0829 .75 0 Mabsadd L
.66052 .0829 0 -1 Mabsadd L
.66052 .0829 -0.75 0 Mabsadd L closepath F
.66421 .0828 -0.75 0 Mabsadd m
.66421 .0828 0 1 Mabsadd L
.66421 .0828 .75 0 Mabsadd L
.66421 .0828 0 -1 Mabsadd L
.66421 .0828 -0.75 0 Mabsadd L closepath F
.6679 .0827 -0.75 0 Mabsadd m
.6679 .0827 0 1 Mabsadd L
.6679 .0827 .75 0 Mabsadd L
.6679 .0827 0 -1 Mabsadd L
.6679 .0827 -0.75 0 Mabsadd L closepath F
.67159 .08264 -0.75 0 Mabsadd m
.67159 .08264 0 1 Mabsadd L
.67159 .08264 .75 0 Mabsadd L
.67159 .08264 0 -1 Mabsadd L
.67159 .08264 -0.75 0 Mabsadd L closepath F
.67528 .08253 -0.75 0 Mabsadd m
.67528 .08253 0 1 Mabsadd L
.67528 .08253 .75 0 Mabsadd L
.67528 .08253 0 -1 Mabsadd L
.67528 .08253 -0.75 0 Mabsadd L closepath F
.67897 .08243 -0.75 0 Mabsadd m
.67897 .08243 0 1 Mabsadd L
.67897 .08243 .75 0 Mabsadd L
.67897 .08243 0 -1 Mabsadd L
.67897 .08243 -0.75 0 Mabsadd L closepath F
.68266 .08227 -0.75 0 Mabsadd m
.68266 .08227 0 1 Mabsadd L
.68266 .08227 .75 0 Mabsadd L
.68266 .08227 0 -1 Mabsadd L
.68266 .08227 -0.75 0 Mabsadd L closepath F
.68635 .08216 -0.75 0 Mabsadd m
.68635 .08216 0 1 Mabsadd L
.68635 .08216 .75 0 Mabsadd L
.68635 .08216 0 -1 Mabsadd L
.68635 .08216 -0.75 0 Mabsadd L closepath F
.69004 .08206 -0.75 0 Mabsadd m
.69004 .08206 0 1 Mabsadd L
.69004 .08206 .75 0 Mabsadd L
.69004 .08206 0 -1 Mabsadd L
.69004 .08206 -0.75 0 Mabsadd L closepath F
.69373 .08205 -0.75 0 Mabsadd m
.69373 .08205 0 1 Mabsadd L
.69373 .08205 .75 0 Mabsadd L
.69373 .08205 0 -1 Mabsadd L
.69373 .08205 -0.75 0 Mabsadd L closepath F
.69742 .08205 -0.75 0 Mabsadd m
.69742 .08205 0 1 Mabsadd L
.69742 .08205 .75 0 Mabsadd L
.69742 .08205 0 -1 Mabsadd L
.69742 .08205 -0.75 0 Mabsadd L closepath F
.70111 .082 -0.75 0 Mabsadd m
.70111 .082 0 1 Mabsadd L
.70111 .082 .75 0 Mabsadd L
.70111 .082 0 -1 Mabsadd L
.70111 .082 -0.75 0 Mabsadd L closepath F
.7048 .08194 -0.75 0 Mabsadd m
.7048 .08194 0 1 Mabsadd L
.7048 .08194 .75 0 Mabsadd L
.7048 .08194 0 -1 Mabsadd L
.7048 .08194 -0.75 0 Mabsadd L closepath F
.70849 .08184 -0.75 0 Mabsadd m
.70849 .08184 0 1 Mabsadd L
.70849 .08184 .75 0 Mabsadd L
.70849 .08184 0 -1 Mabsadd L
.70849 .08184 -0.75 0 Mabsadd L closepath F
.71218 .08178 -0.75 0 Mabsadd m
.71218 .08178 0 1 Mabsadd L
.71218 .08178 .75 0 Mabsadd L
.71218 .08178 0 -1 Mabsadd L
.71218 .08178 -0.75 0 Mabsadd L closepath F
.71587 .08168 -0.75 0 Mabsadd m
.71587 .08168 0 1 Mabsadd L
.71587 .08168 .75 0 Mabsadd L
.71587 .08168 0 -1 Mabsadd L
.71587 .08168 -0.75 0 Mabsadd L closepath F
.71956 .08162 -0.75 0 Mabsadd m
.71956 .08162 0 1 Mabsadd L
.71956 .08162 .75 0 Mabsadd L
.71956 .08162 0 -1 Mabsadd L
.71956 .08162 -0.75 0 Mabsadd L closepath F
.72325 .08162 -0.75 0 Mabsadd m
.72325 .08162 0 1 Mabsadd L
.72325 .08162 .75 0 Mabsadd L
.72325 .08162 0 -1 Mabsadd L
.72325 .08162 -0.75 0 Mabsadd L closepath F
.72694 .08152 -0.75 0 Mabsadd m
.72694 .08152 0 1 Mabsadd L
.72694 .08152 .75 0 Mabsadd L
.72694 .08152 0 -1 Mabsadd L
.72694 .08152 -0.75 0 Mabsadd L closepath F
.73063 .08146 -0.75 0 Mabsadd m
.73063 .08146 0 1 Mabsadd L
.73063 .08146 .75 0 Mabsadd L
.73063 .08146 0 -1 Mabsadd L
.73063 .08146 -0.75 0 Mabsadd L closepath F
.73432 .08141 -0.75 0 Mabsadd m
.73432 .08141 0 1 Mabsadd L
.73432 .08141 .75 0 Mabsadd L
.73432 .08141 0 -1 Mabsadd L
.73432 .08141 -0.75 0 Mabsadd L closepath F
.73801 .08136 -0.75 0 Mabsadd m
.73801 .08136 0 1 Mabsadd L
.73801 .08136 .75 0 Mabsadd L
.73801 .08136 0 -1 Mabsadd L
.73801 .08136 -0.75 0 Mabsadd L closepath F
.7417 .0813 -0.75 0 Mabsadd m
.7417 .0813 0 1 Mabsadd L
.7417 .0813 .75 0 Mabsadd L
.7417 .0813 0 -1 Mabsadd L
.7417 .0813 -0.75 0 Mabsadd L closepath F
.74539 .0813 -0.75 0 Mabsadd m
.74539 .0813 0 1 Mabsadd L
.74539 .0813 .75 0 Mabsadd L
.74539 .0813 0 -1 Mabsadd L
.74539 .0813 -0.75 0 Mabsadd L closepath F
.74908 .08125 -0.75 0 Mabsadd m
.74908 .08125 0 1 Mabsadd L
.74908 .08125 .75 0 Mabsadd L
.74908 .08125 0 -1 Mabsadd L
.74908 .08125 -0.75 0 Mabsadd L closepath F
.75277 .08125 -0.75 0 Mabsadd m
.75277 .08125 0 1 Mabsadd L
.75277 .08125 .75 0 Mabsadd L
.75277 .08125 0 -1 Mabsadd L
.75277 .08125 -0.75 0 Mabsadd L closepath F
.75646 .0812 -0.75 0 Mabsadd m
.75646 .0812 0 1 Mabsadd L
.75646 .0812 .75 0 Mabsadd L
.75646 .0812 0 -1 Mabsadd L
.75646 .0812 -0.75 0 Mabsadd L closepath F
.76015 .0812 -0.75 0 Mabsadd m
.76015 .0812 0 1 Mabsadd L
.76015 .0812 .75 0 Mabsadd L
.76015 .0812 0 -1 Mabsadd L
.76015 .0812 -0.75 0 Mabsadd L closepath F
.76384 .0811 -0.75 0 Mabsadd m
.76384 .0811 0 1 Mabsadd L
.76384 .0811 .75 0 Mabsadd L
.76384 .0811 0 -1 Mabsadd L
.76384 .0811 -0.75 0 Mabsadd L closepath F
.76753 .08109 -0.75 0 Mabsadd m
.76753 .08109 0 1 Mabsadd L
.76753 .08109 .75 0 Mabsadd L
.76753 .08109 0 -1 Mabsadd L
.76753 .08109 -0.75 0 Mabsadd L closepath F
.77122 .08098 -0.75 0 Mabsadd m
.77122 .08098 0 1 Mabsadd L
.77122 .08098 .75 0 Mabsadd L
.77122 .08098 0 -1 Mabsadd L
.77122 .08098 -0.75 0 Mabsadd L closepath F
.77491 .08098 -0.75 0 Mabsadd m
.77491 .08098 0 1 Mabsadd L
.77491 .08098 .75 0 Mabsadd L
.77491 .08098 0 -1 Mabsadd L
.77491 .08098 -0.75 0 Mabsadd L closepath F
.7786 .08098 -0.75 0 Mabsadd m
.7786 .08098 0 1 Mabsadd L
.7786 .08098 .75 0 Mabsadd L
.7786 .08098 0 -1 Mabsadd L
.7786 .08098 -0.75 0 Mabsadd L closepath F
.78229 .08098 -0.75 0 Mabsadd m
.78229 .08098 0 1 Mabsadd L
.78229 .08098 .75 0 Mabsadd L
.78229 .08098 0 -1 Mabsadd L
.78229 .08098 -0.75 0 Mabsadd L closepath F
.78598 .08088 -0.75 0 Mabsadd m
.78598 .08088 0 1 Mabsadd L
.78598 .08088 .75 0 Mabsadd L
.78598 .08088 0 -1 Mabsadd L
.78598 .08088 -0.75 0 Mabsadd L closepath F
.78967 .08082 -0.75 0 Mabsadd m
.78967 .08082 0 1 Mabsadd L
.78967 .08082 .75 0 Mabsadd L
.78967 .08082 0 -1 Mabsadd L
.78967 .08082 -0.75 0 Mabsadd L closepath F
.79336 .08082 -0.75 0 Mabsadd m
.79336 .08082 0 1 Mabsadd L
.79336 .08082 .75 0 Mabsadd L
.79336 .08082 0 -1 Mabsadd L
.79336 .08082 -0.75 0 Mabsadd L closepath F
.79705 .08082 -0.75 0 Mabsadd m
.79705 .08082 0 1 Mabsadd L
.79705 .08082 .75 0 Mabsadd L
.79705 .08082 0 -1 Mabsadd L
.79705 .08082 -0.75 0 Mabsadd L closepath F
.80074 .08082 -0.75 0 Mabsadd m
.80074 .08082 0 1 Mabsadd L
.80074 .08082 .75 0 Mabsadd L
.80074 .08082 0 -1 Mabsadd L
.80074 .08082 -0.75 0 Mabsadd L closepath F
.80443 .08077 -0.75 0 Mabsadd m
.80443 .08077 0 1 Mabsadd L
.80443 .08077 .75 0 Mabsadd L
.80443 .08077 0 -1 Mabsadd L
.80443 .08077 -0.75 0 Mabsadd L closepath F
.80812 .08077 -0.75 0 Mabsadd m
.80812 .08077 0 1 Mabsadd L
.80812 .08077 .75 0 Mabsadd L
.80812 .08077 0 -1 Mabsadd L
.80812 .08077 -0.75 0 Mabsadd L closepath F
.81181 .08077 -0.75 0 Mabsadd m
.81181 .08077 0 1 Mabsadd L
.81181 .08077 .75 0 Mabsadd L
.81181 .08077 0 -1 Mabsadd L
.81181 .08077 -0.75 0 Mabsadd L closepath F
.8155 .08072 -0.75 0 Mabsadd m
.8155 .08072 0 1 Mabsadd L
.8155 .08072 .75 0 Mabsadd L
.8155 .08072 0 -1 Mabsadd L
.8155 .08072 -0.75 0 Mabsadd L closepath F
.81919 .08072 -0.75 0 Mabsadd m
.81919 .08072 0 1 Mabsadd L
.81919 .08072 .75 0 Mabsadd L
.81919 .08072 0 -1 Mabsadd L
.81919 .08072 -0.75 0 Mabsadd L closepath F
.82288 .08072 -0.75 0 Mabsadd m
.82288 .08072 0 1 Mabsadd L
.82288 .08072 .75 0 Mabsadd L
.82288 .08072 0 -1 Mabsadd L
.82288 .08072 -0.75 0 Mabsadd L closepath F
.82657 .08066 -0.75 0 Mabsadd m
.82657 .08066 0 1 Mabsadd L
.82657 .08066 .75 0 Mabsadd L
.82657 .08066 0 -1 Mabsadd L
.82657 .08066 -0.75 0 Mabsadd L closepath F
.83026 .08066 -0.75 0 Mabsadd m
.83026 .08066 0 1 Mabsadd L
.83026 .08066 .75 0 Mabsadd L
.83026 .08066 0 -1 Mabsadd L
.83026 .08066 -0.75 0 Mabsadd L closepath F
.83395 .08066 -0.75 0 Mabsadd m
.83395 .08066 0 1 Mabsadd L
.83395 .08066 .75 0 Mabsadd L
.83395 .08066 0 -1 Mabsadd L
.83395 .08066 -0.75 0 Mabsadd L closepath F
.83764 .08066 -0.75 0 Mabsadd m
.83764 .08066 0 1 Mabsadd L
.83764 .08066 .75 0 Mabsadd L
.83764 .08066 0 -1 Mabsadd L
.83764 .08066 -0.75 0 Mabsadd L closepath F
.84133 .08066 -0.75 0 Mabsadd m
.84133 .08066 0 1 Mabsadd L
.84133 .08066 .75 0 Mabsadd L
.84133 .08066 0 -1 Mabsadd L
.84133 .08066 -0.75 0 Mabsadd L closepath F
.84502 .08066 -0.75 0 Mabsadd m
.84502 .08066 0 1 Mabsadd L
.84502 .08066 .75 0 Mabsadd L
.84502 .08066 0 -1 Mabsadd L
.84502 .08066 -0.75 0 Mabsadd L closepath F
.84871 .08066 -0.75 0 Mabsadd m
.84871 .08066 0 1 Mabsadd L
.84871 .08066 .75 0 Mabsadd L
.84871 .08066 0 -1 Mabsadd L
.84871 .08066 -0.75 0 Mabsadd L closepath F
.8524 .08066 -0.75 0 Mabsadd m
.8524 .08066 0 1 Mabsadd L
.8524 .08066 .75 0 Mabsadd L
.8524 .08066 0 -1 Mabsadd L
.8524 .08066 -0.75 0 Mabsadd L closepath F
.85609 .08066 -0.75 0 Mabsadd m
.85609 .08066 0 1 Mabsadd L
.85609 .08066 .75 0 Mabsadd L
.85609 .08066 0 -1 Mabsadd L
.85609 .08066 -0.75 0 Mabsadd L closepath F
.85978 .08061 -0.75 0 Mabsadd m
.85978 .08061 0 1 Mabsadd L
.85978 .08061 .75 0 Mabsadd L
.85978 .08061 0 -1 Mabsadd L
.85978 .08061 -0.75 0 Mabsadd L closepath F
.86347 .08061 -0.75 0 Mabsadd m
.86347 .08061 0 1 Mabsadd L
.86347 .08061 .75 0 Mabsadd L
.86347 .08061 0 -1 Mabsadd L
.86347 .08061 -0.75 0 Mabsadd L closepath F
.86716 .08061 -0.75 0 Mabsadd m
.86716 .08061 0 1 Mabsadd L
.86716 .08061 .75 0 Mabsadd L
.86716 .08061 0 -1 Mabsadd L
.86716 .08061 -0.75 0 Mabsadd L closepath F
.87085 .08052 -0.75 0 Mabsadd m
.87085 .08052 0 1 Mabsadd L
.87085 .08052 .75 0 Mabsadd L
.87085 .08052 0 -1 Mabsadd L
.87085 .08052 -0.75 0 Mabsadd L closepath F
.87454 .0805 -0.75 0 Mabsadd m
.87454 .0805 0 1 Mabsadd L
.87454 .0805 .75 0 Mabsadd L
.87454 .0805 0 -1 Mabsadd L
.87454 .0805 -0.75 0 Mabsadd L closepath F
.87823 .0805 -0.75 0 Mabsadd m
.87823 .0805 0 1 Mabsadd L
.87823 .0805 .75 0 Mabsadd L
.87823 .0805 0 -1 Mabsadd L
.87823 .0805 -0.75 0 Mabsadd L closepath F
.88192 .0805 -0.75 0 Mabsadd m
.88192 .0805 0 1 Mabsadd L
.88192 .0805 .75 0 Mabsadd L
.88192 .0805 0 -1 Mabsadd L
.88192 .0805 -0.75 0 Mabsadd L closepath F
.88561 .0805 -0.75 0 Mabsadd m
.88561 .0805 0 1 Mabsadd L
.88561 .0805 .75 0 Mabsadd L
.88561 .0805 0 -1 Mabsadd L
.88561 .0805 -0.75 0 Mabsadd L closepath F
.8893 .08045 -0.75 0 Mabsadd m
.8893 .08045 0 1 Mabsadd L
.8893 .08045 .75 0 Mabsadd L
.8893 .08045 0 -1 Mabsadd L
.8893 .08045 -0.75 0 Mabsadd L closepath F
.89299 .08045 -0.75 0 Mabsadd m
.89299 .08045 0 1 Mabsadd L
.89299 .08045 .75 0 Mabsadd L
.89299 .08045 0 -1 Mabsadd L
.89299 .08045 -0.75 0 Mabsadd L closepath F
.89668 .08045 -0.75 0 Mabsadd m
.89668 .08045 0 1 Mabsadd L
.89668 .08045 .75 0 Mabsadd L
.89668 .08045 0 -1 Mabsadd L
.89668 .08045 -0.75 0 Mabsadd L closepath F
.90037 .08045 -0.75 0 Mabsadd m
.90037 .08045 0 1 Mabsadd L
.90037 .08045 .75 0 Mabsadd L
.90037 .08045 0 -1 Mabsadd L
.90037 .08045 -0.75 0 Mabsadd L closepath F
.90406 .08045 -0.75 0 Mabsadd m
.90406 .08045 0 1 Mabsadd L
.90406 .08045 .75 0 Mabsadd L
.90406 .08045 0 -1 Mabsadd L
.90406 .08045 -0.75 0 Mabsadd L closepath F
.90775 .08045 -0.75 0 Mabsadd m
.90775 .08045 0 1 Mabsadd L
.90775 .08045 .75 0 Mabsadd L
.90775 .08045 0 -1 Mabsadd L
.90775 .08045 -0.75 0 Mabsadd L closepath F
.91144 .08034 -0.75 0 Mabsadd m
.91144 .08034 0 1 Mabsadd L
.91144 .08034 .75 0 Mabsadd L
.91144 .08034 0 -1 Mabsadd L
.91144 .08034 -0.75 0 Mabsadd L closepath F
.91513 .08034 -0.75 0 Mabsadd m
.91513 .08034 0 1 Mabsadd L
.91513 .08034 .75 0 Mabsadd L
.91513 .08034 0 -1 Mabsadd L
.91513 .08034 -0.75 0 Mabsadd L closepath F
.91882 .08034 -0.75 0 Mabsadd m
.91882 .08034 0 1 Mabsadd L
.91882 .08034 .75 0 Mabsadd L
.91882 .08034 0 -1 Mabsadd L
.91882 .08034 -0.75 0 Mabsadd L closepath F
.92251 .08034 -0.75 0 Mabsadd m
.92251 .08034 0 1 Mabsadd L
.92251 .08034 .75 0 Mabsadd L
.92251 .08034 0 -1 Mabsadd L
.92251 .08034 -0.75 0 Mabsadd L closepath F
.9262 .08034 -0.75 0 Mabsadd m
.9262 .08034 0 1 Mabsadd L
.9262 .08034 .75 0 Mabsadd L
.9262 .08034 0 -1 Mabsadd L
.9262 .08034 -0.75 0 Mabsadd L closepath F
.92989 .08034 -0.75 0 Mabsadd m
.92989 .08034 0 1 Mabsadd L
.92989 .08034 .75 0 Mabsadd L
.92989 .08034 0 -1 Mabsadd L
.92989 .08034 -0.75 0 Mabsadd L closepath F
.93358 .08034 -0.75 0 Mabsadd m
.93358 .08034 0 1 Mabsadd L
.93358 .08034 .75 0 Mabsadd L
.93358 .08034 0 -1 Mabsadd L
.93358 .08034 -0.75 0 Mabsadd L closepath F
.93727 .08034 -0.75 0 Mabsadd m
.93727 .08034 0 1 Mabsadd L
.93727 .08034 .75 0 Mabsadd L
.93727 .08034 0 -1 Mabsadd L
.93727 .08034 -0.75 0 Mabsadd L closepath F
.94096 .08034 -0.75 0 Mabsadd m
.94096 .08034 0 1 Mabsadd L
.94096 .08034 .75 0 Mabsadd L
.94096 .08034 0 -1 Mabsadd L
.94096 .08034 -0.75 0 Mabsadd L closepath F
.94465 .08029 -0.75 0 Mabsadd m
.94465 .08029 0 1 Mabsadd L
.94465 .08029 .75 0 Mabsadd L
.94465 .08029 0 -1 Mabsadd L
.94465 .08029 -0.75 0 Mabsadd L closepath F
.94834 .08029 -0.75 0 Mabsadd m
.94834 .08029 0 1 Mabsadd L
.94834 .08029 .75 0 Mabsadd L
.94834 .08029 0 -1 Mabsadd L
.94834 .08029 -0.75 0 Mabsadd L closepath F
.95203 .08029 -0.75 0 Mabsadd m
.95203 .08029 0 1 Mabsadd L
.95203 .08029 .75 0 Mabsadd L
.95203 .08029 0 -1 Mabsadd L
.95203 .08029 -0.75 0 Mabsadd L closepath F
.95572 .08029 -0.75 0 Mabsadd m
.95572 .08029 0 1 Mabsadd L
.95572 .08029 .75 0 Mabsadd L
.95572 .08029 0 -1 Mabsadd L
.95572 .08029 -0.75 0 Mabsadd L closepath F
.95941 .08029 -0.75 0 Mabsadd m
.95941 .08029 0 1 Mabsadd L
.95941 .08029 .75 0 Mabsadd L
.95941 .08029 0 -1 Mabsadd L
.95941 .08029 -0.75 0 Mabsadd L closepath F
.9631 .08029 -0.75 0 Mabsadd m
.9631 .08029 0 1 Mabsadd L
.9631 .08029 .75 0 Mabsadd L
.9631 .08029 0 -1 Mabsadd L
.9631 .08029 -0.75 0 Mabsadd L closepath F
.96679 .08024 -0.75 0 Mabsadd m
.96679 .08024 0 1 Mabsadd L
.96679 .08024 .75 0 Mabsadd L
.96679 .08024 0 -1 Mabsadd L
.96679 .08024 -0.75 0 Mabsadd L closepath F
.97048 .08018 -0.75 0 Mabsadd m
.97048 .08018 0 1 Mabsadd L
.97048 .08018 .75 0 Mabsadd L
.97048 .08018 0 -1 Mabsadd L
.97048 .08018 -0.75 0 Mabsadd L closepath F
.97417 .08018 -0.75 0 Mabsadd m
.97417 .08018 0 1 Mabsadd L
.97417 .08018 .75 0 Mabsadd L
.97417 .08018 0 -1 Mabsadd L
.97417 .08018 -0.75 0 Mabsadd L closepath F
.97786 .08018 -0.75 0 Mabsadd m
.97786 .08018 0 1 Mabsadd L
.97786 .08018 .75 0 Mabsadd L
.97786 .08018 0 -1 Mabsadd L
.97786 .08018 -0.75 0 Mabsadd L closepath F
.98155 .08013 -0.75 0 Mabsadd m
.98155 .08013 0 1 Mabsadd L
.98155 .08013 .75 0 Mabsadd L
.98155 .08013 0 -1 Mabsadd L
.98155 .08013 -0.75 0 Mabsadd L closepath F
.98524 .08013 -0.75 0 Mabsadd m
.98524 .08013 0 1 Mabsadd L
.98524 .08013 .75 0 Mabsadd L
.98524 .08013 0 -1 Mabsadd L
.98524 .08013 -0.75 0 Mabsadd L closepath F
.98893 .08013 -0.75 0 Mabsadd m
.98893 .08013 0 1 Mabsadd L
.98893 .08013 .75 0 Mabsadd L
.98893 .08013 0 -1 Mabsadd L
.98893 .08013 -0.75 0 Mabsadd L closepath F
.99262 .08013 -0.75 0 Mabsadd m
.99262 .08013 0 1 Mabsadd L
.99262 .08013 .75 0 Mabsadd L
.99262 .08013 0 -1 Mabsadd L
.99262 .08013 -0.75 0 Mabsadd L closepath F
.99631 .08013 -0.75 0 Mabsadd m
.99631 .08013 0 1 Mabsadd L
.99631 .08013 .75 0 Mabsadd L
.99631 .08013 0 -1 Mabsadd L
.99631 .08013 -0.75 0 Mabsadd L closepath F
0 0 0 r
.0738 .55943 -0.75 0 Mabsadd m
.0738 .55943 0 1 Mabsadd L
.0738 .55943 .75 0 Mabsadd L
.0738 .55943 0 -1 Mabsadd L
.0738 .55943 -0.75 0 Mabsadd L closepath F
.07749 .4306 -0.75 0 Mabsadd m
.07749 .4306 0 1 Mabsadd L
.07749 .4306 .75 0 Mabsadd L
.07749 .4306 0 -1 Mabsadd L
.07749 .4306 -0.75 0 Mabsadd L closepath F
.08118 .4306 -0.75 0 Mabsadd m
.08118 .4306 0 1 Mabsadd L
.08118 .4306 .75 0 Mabsadd L
.08118 .4306 0 -1 Mabsadd L
.08118 .4306 -0.75 0 Mabsadd L closepath F
.08487 .4306 -0.75 0 Mabsadd m
.08487 .4306 0 1 Mabsadd L
.08487 .4306 .75 0 Mabsadd L
.08487 .4306 0 -1 Mabsadd L
.08487 .4306 -0.75 0 Mabsadd L closepath F
.08856 .4306 -0.75 0 Mabsadd m
.08856 .4306 0 1 Mabsadd L
.08856 .4306 .75 0 Mabsadd L
.08856 .4306 0 -1 Mabsadd L
.08856 .4306 -0.75 0 Mabsadd L closepath F
.09225 .4306 -0.75 0 Mabsadd m
.09225 .4306 0 1 Mabsadd L
.09225 .4306 .75 0 Mabsadd L
.09225 .4306 0 -1 Mabsadd L
.09225 .4306 -0.75 0 Mabsadd L closepath F
.09594 .4306 -0.75 0 Mabsadd m
.09594 .4306 0 1 Mabsadd L
.09594 .4306 .75 0 Mabsadd L
.09594 .4306 0 -1 Mabsadd L
.09594 .4306 -0.75 0 Mabsadd L closepath F
.09963 .4306 -0.75 0 Mabsadd m
.09963 .4306 0 1 Mabsadd L
.09963 .4306 .75 0 Mabsadd L
.09963 .4306 0 -1 Mabsadd L
.09963 .4306 -0.75 0 Mabsadd L closepath F
.10332 .4306 -0.75 0 Mabsadd m
.10332 .4306 0 1 Mabsadd L
.10332 .4306 .75 0 Mabsadd L
.10332 .4306 0 -1 Mabsadd L
.10332 .4306 -0.75 0 Mabsadd L closepath F
.10701 .4306 -0.75 0 Mabsadd m
.10701 .4306 0 1 Mabsadd L
.10701 .4306 .75 0 Mabsadd L
.10701 .4306 0 -1 Mabsadd L
.10701 .4306 -0.75 0 Mabsadd L closepath F
.1107 .4306 -0.75 0 Mabsadd m
.1107 .4306 0 1 Mabsadd L
.1107 .4306 .75 0 Mabsadd L
.1107 .4306 0 -1 Mabsadd L
.1107 .4306 -0.75 0 Mabsadd L closepath F
.11439 .4306 -0.75 0 Mabsadd m
.11439 .4306 0 1 Mabsadd L
.11439 .4306 .75 0 Mabsadd L
.11439 .4306 0 -1 Mabsadd L
.11439 .4306 -0.75 0 Mabsadd L closepath F
.11808 .4306 -0.75 0 Mabsadd m
.11808 .4306 0 1 Mabsadd L
.11808 .4306 .75 0 Mabsadd L
.11808 .4306 0 -1 Mabsadd L
.11808 .4306 -0.75 0 Mabsadd L closepath F
.12177 .4306 -0.75 0 Mabsadd m
.12177 .4306 0 1 Mabsadd L
.12177 .4306 .75 0 Mabsadd L
.12177 .4306 0 -1 Mabsadd L
.12177 .4306 -0.75 0 Mabsadd L closepath F
.12546 .4306 -0.75 0 Mabsadd m
.12546 .4306 0 1 Mabsadd L
.12546 .4306 .75 0 Mabsadd L
.12546 .4306 0 -1 Mabsadd L
.12546 .4306 -0.75 0 Mabsadd L closepath F
.12915 .4306 -0.75 0 Mabsadd m
.12915 .4306 0 1 Mabsadd L
.12915 .4306 .75 0 Mabsadd L
.12915 .4306 0 -1 Mabsadd L
.12915 .4306 -0.75 0 Mabsadd L closepath F
.13284 .4306 -0.75 0 Mabsadd m
.13284 .4306 0 1 Mabsadd L
.13284 .4306 .75 0 Mabsadd L
.13284 .4306 0 -1 Mabsadd L
.13284 .4306 -0.75 0 Mabsadd L closepath F
.13653 .4306 -0.75 0 Mabsadd m
.13653 .4306 0 1 Mabsadd L
.13653 .4306 .75 0 Mabsadd L
.13653 .4306 0 -1 Mabsadd L
.13653 .4306 -0.75 0 Mabsadd L closepath F
.14022 .4306 -0.75 0 Mabsadd m
.14022 .4306 0 1 Mabsadd L
.14022 .4306 .75 0 Mabsadd L
.14022 .4306 0 -1 Mabsadd L
.14022 .4306 -0.75 0 Mabsadd L closepath F
.14391 .4306 -0.75 0 Mabsadd m
.14391 .4306 0 1 Mabsadd L
.14391 .4306 .75 0 Mabsadd L
.14391 .4306 0 -1 Mabsadd L
.14391 .4306 -0.75 0 Mabsadd L closepath F
.1476 .4306 -0.75 0 Mabsadd m
.1476 .4306 0 1 Mabsadd L
.1476 .4306 .75 0 Mabsadd L
.1476 .4306 0 -1 Mabsadd L
.1476 .4306 -0.75 0 Mabsadd L closepath F
.15129 .4306 -0.75 0 Mabsadd m
.15129 .4306 0 1 Mabsadd L
.15129 .4306 .75 0 Mabsadd L
.15129 .4306 0 -1 Mabsadd L
.15129 .4306 -0.75 0 Mabsadd L closepath F
.15498 .4306 -0.75 0 Mabsadd m
.15498 .4306 0 1 Mabsadd L
.15498 .4306 .75 0 Mabsadd L
.15498 .4306 0 -1 Mabsadd L
.15498 .4306 -0.75 0 Mabsadd L closepath F
.15867 .4306 -0.75 0 Mabsadd m
.15867 .4306 0 1 Mabsadd L
.15867 .4306 .75 0 Mabsadd L
.15867 .4306 0 -1 Mabsadd L
.15867 .4306 -0.75 0 Mabsadd L closepath F
.16236 .4306 -0.75 0 Mabsadd m
.16236 .4306 0 1 Mabsadd L
.16236 .4306 .75 0 Mabsadd L
.16236 .4306 0 -1 Mabsadd L
.16236 .4306 -0.75 0 Mabsadd L closepath F
.16605 .4306 -0.75 0 Mabsadd m
.16605 .4306 0 1 Mabsadd L
.16605 .4306 .75 0 Mabsadd L
.16605 .4306 0 -1 Mabsadd L
.16605 .4306 -0.75 0 Mabsadd L closepath F
.16974 .4306 -0.75 0 Mabsadd m
.16974 .4306 0 1 Mabsadd L
.16974 .4306 .75 0 Mabsadd L
.16974 .4306 0 -1 Mabsadd L
.16974 .4306 -0.75 0 Mabsadd L closepath F
.17343 .4306 -0.75 0 Mabsadd m
.17343 .4306 0 1 Mabsadd L
.17343 .4306 .75 0 Mabsadd L
.17343 .4306 0 -1 Mabsadd L
.17343 .4306 -0.75 0 Mabsadd L closepath F
.17712 .4306 -0.75 0 Mabsadd m
.17712 .4306 0 1 Mabsadd L
.17712 .4306 .75 0 Mabsadd L
.17712 .4306 0 -1 Mabsadd L
.17712 .4306 -0.75 0 Mabsadd L closepath F
.18081 .4306 -0.75 0 Mabsadd m
.18081 .4306 0 1 Mabsadd L
.18081 .4306 .75 0 Mabsadd L
.18081 .4306 0 -1 Mabsadd L
.18081 .4306 -0.75 0 Mabsadd L closepath F
.1845 .4306 -0.75 0 Mabsadd m
.1845 .4306 0 1 Mabsadd L
.1845 .4306 .75 0 Mabsadd L
.1845 .4306 0 -1 Mabsadd L
.1845 .4306 -0.75 0 Mabsadd L closepath F
.18819 .4306 -0.75 0 Mabsadd m
.18819 .4306 0 1 Mabsadd L
.18819 .4306 .75 0 Mabsadd L
.18819 .4306 0 -1 Mabsadd L
.18819 .4306 -0.75 0 Mabsadd L closepath F
.19188 .4306 -0.75 0 Mabsadd m
.19188 .4306 0 1 Mabsadd L
.19188 .4306 .75 0 Mabsadd L
.19188 .4306 0 -1 Mabsadd L
.19188 .4306 -0.75 0 Mabsadd L closepath F
.19557 .4306 -0.75 0 Mabsadd m
.19557 .4306 0 1 Mabsadd L
.19557 .4306 .75 0 Mabsadd L
.19557 .4306 0 -1 Mabsadd L
.19557 .4306 -0.75 0 Mabsadd L closepath F
.19926 .4306 -0.75 0 Mabsadd m
.19926 .4306 0 1 Mabsadd L
.19926 .4306 .75 0 Mabsadd L
.19926 .4306 0 -1 Mabsadd L
.19926 .4306 -0.75 0 Mabsadd L closepath F
.20295 .4306 -0.75 0 Mabsadd m
.20295 .4306 0 1 Mabsadd L
.20295 .4306 .75 0 Mabsadd L
.20295 .4306 0 -1 Mabsadd L
.20295 .4306 -0.75 0 Mabsadd L closepath F
.20664 .4306 -0.75 0 Mabsadd m
.20664 .4306 0 1 Mabsadd L
.20664 .4306 .75 0 Mabsadd L
.20664 .4306 0 -1 Mabsadd L
.20664 .4306 -0.75 0 Mabsadd L closepath F
.21033 .4306 -0.75 0 Mabsadd m
.21033 .4306 0 1 Mabsadd L
.21033 .4306 .75 0 Mabsadd L
.21033 .4306 0 -1 Mabsadd L
.21033 .4306 -0.75 0 Mabsadd L closepath F
.21402 .4306 -0.75 0 Mabsadd m
.21402 .4306 0 1 Mabsadd L
.21402 .4306 .75 0 Mabsadd L
.21402 .4306 0 -1 Mabsadd L
.21402 .4306 -0.75 0 Mabsadd L closepath F
.21771 .4306 -0.75 0 Mabsadd m
.21771 .4306 0 1 Mabsadd L
.21771 .4306 .75 0 Mabsadd L
.21771 .4306 0 -1 Mabsadd L
.21771 .4306 -0.75 0 Mabsadd L closepath F
.2214 .4306 -0.75 0 Mabsadd m
.2214 .4306 0 1 Mabsadd L
.2214 .4306 .75 0 Mabsadd L
.2214 .4306 0 -1 Mabsadd L
.2214 .4306 -0.75 0 Mabsadd L closepath F
.22509 .4306 -0.75 0 Mabsadd m
.22509 .4306 0 1 Mabsadd L
.22509 .4306 .75 0 Mabsadd L
.22509 .4306 0 -1 Mabsadd L
.22509 .4306 -0.75 0 Mabsadd L closepath F
.22878 .4306 -0.75 0 Mabsadd m
.22878 .4306 0 1 Mabsadd L
.22878 .4306 .75 0 Mabsadd L
.22878 .4306 0 -1 Mabsadd L
.22878 .4306 -0.75 0 Mabsadd L closepath F
.23247 .4306 -0.75 0 Mabsadd m
.23247 .4306 0 1 Mabsadd L
.23247 .4306 .75 0 Mabsadd L
.23247 .4306 0 -1 Mabsadd L
.23247 .4306 -0.75 0 Mabsadd L closepath F
.23616 .4306 -0.75 0 Mabsadd m
.23616 .4306 0 1 Mabsadd L
.23616 .4306 .75 0 Mabsadd L
.23616 .4306 0 -1 Mabsadd L
.23616 .4306 -0.75 0 Mabsadd L closepath F
.23985 .4306 -0.75 0 Mabsadd m
.23985 .4306 0 1 Mabsadd L
.23985 .4306 .75 0 Mabsadd L
.23985 .4306 0 -1 Mabsadd L
.23985 .4306 -0.75 0 Mabsadd L closepath F
.24354 .4306 -0.75 0 Mabsadd m
.24354 .4306 0 1 Mabsadd L
.24354 .4306 .75 0 Mabsadd L
.24354 .4306 0 -1 Mabsadd L
.24354 .4306 -0.75 0 Mabsadd L closepath F
.24723 .4306 -0.75 0 Mabsadd m
.24723 .4306 0 1 Mabsadd L
.24723 .4306 .75 0 Mabsadd L
.24723 .4306 0 -1 Mabsadd L
.24723 .4306 -0.75 0 Mabsadd L closepath F
.25092 .4306 -0.75 0 Mabsadd m
.25092 .4306 0 1 Mabsadd L
.25092 .4306 .75 0 Mabsadd L
.25092 .4306 0 -1 Mabsadd L
.25092 .4306 -0.75 0 Mabsadd L closepath F
.25461 .4306 -0.75 0 Mabsadd m
.25461 .4306 0 1 Mabsadd L
.25461 .4306 .75 0 Mabsadd L
.25461 .4306 0 -1 Mabsadd L
.25461 .4306 -0.75 0 Mabsadd L closepath F
.2583 .4306 -0.75 0 Mabsadd m
.2583 .4306 0 1 Mabsadd L
.2583 .4306 .75 0 Mabsadd L
.2583 .4306 0 -1 Mabsadd L
.2583 .4306 -0.75 0 Mabsadd L closepath F
.26199 .4306 -0.75 0 Mabsadd m
.26199 .4306 0 1 Mabsadd L
.26199 .4306 .75 0 Mabsadd L
.26199 .4306 0 -1 Mabsadd L
.26199 .4306 -0.75 0 Mabsadd L closepath F
.26568 .4306 -0.75 0 Mabsadd m
.26568 .4306 0 1 Mabsadd L
.26568 .4306 .75 0 Mabsadd L
.26568 .4306 0 -1 Mabsadd L
.26568 .4306 -0.75 0 Mabsadd L closepath F
.26937 .4306 -0.75 0 Mabsadd m
.26937 .4306 0 1 Mabsadd L
.26937 .4306 .75 0 Mabsadd L
.26937 .4306 0 -1 Mabsadd L
.26937 .4306 -0.75 0 Mabsadd L closepath F
.27306 .4306 -0.75 0 Mabsadd m
.27306 .4306 0 1 Mabsadd L
.27306 .4306 .75 0 Mabsadd L
.27306 .4306 0 -1 Mabsadd L
.27306 .4306 -0.75 0 Mabsadd L closepath F
.27675 .4306 -0.75 0 Mabsadd m
.27675 .4306 0 1 Mabsadd L
.27675 .4306 .75 0 Mabsadd L
.27675 .4306 0 -1 Mabsadd L
.27675 .4306 -0.75 0 Mabsadd L closepath F
.28044 .4306 -0.75 0 Mabsadd m
.28044 .4306 0 1 Mabsadd L
.28044 .4306 .75 0 Mabsadd L
.28044 .4306 0 -1 Mabsadd L
.28044 .4306 -0.75 0 Mabsadd L closepath F
.28413 .4306 -0.75 0 Mabsadd m
.28413 .4306 0 1 Mabsadd L
.28413 .4306 .75 0 Mabsadd L
.28413 .4306 0 -1 Mabsadd L
.28413 .4306 -0.75 0 Mabsadd L closepath F
.28782 .4306 -0.75 0 Mabsadd m
.28782 .4306 0 1 Mabsadd L
.28782 .4306 .75 0 Mabsadd L
.28782 .4306 0 -1 Mabsadd L
.28782 .4306 -0.75 0 Mabsadd L closepath F
.29151 .4306 -0.75 0 Mabsadd m
.29151 .4306 0 1 Mabsadd L
.29151 .4306 .75 0 Mabsadd L
.29151 .4306 0 -1 Mabsadd L
.29151 .4306 -0.75 0 Mabsadd L closepath F
.2952 .4306 -0.75 0 Mabsadd m
.2952 .4306 0 1 Mabsadd L
.2952 .4306 .75 0 Mabsadd L
.2952 .4306 0 -1 Mabsadd L
.2952 .4306 -0.75 0 Mabsadd L closepath F
.29889 .4306 -0.75 0 Mabsadd m
.29889 .4306 0 1 Mabsadd L
.29889 .4306 .75 0 Mabsadd L
.29889 .4306 0 -1 Mabsadd L
.29889 .4306 -0.75 0 Mabsadd L closepath F
.30258 .4306 -0.75 0 Mabsadd m
.30258 .4306 0 1 Mabsadd L
.30258 .4306 .75 0 Mabsadd L
.30258 .4306 0 -1 Mabsadd L
.30258 .4306 -0.75 0 Mabsadd L closepath F
.30627 .4306 -0.75 0 Mabsadd m
.30627 .4306 0 1 Mabsadd L
.30627 .4306 .75 0 Mabsadd L
.30627 .4306 0 -1 Mabsadd L
.30627 .4306 -0.75 0 Mabsadd L closepath F
.30996 .4306 -0.75 0 Mabsadd m
.30996 .4306 0 1 Mabsadd L
.30996 .4306 .75 0 Mabsadd L
.30996 .4306 0 -1 Mabsadd L
.30996 .4306 -0.75 0 Mabsadd L closepath F
.31365 .4306 -0.75 0 Mabsadd m
.31365 .4306 0 1 Mabsadd L
.31365 .4306 .75 0 Mabsadd L
.31365 .4306 0 -1 Mabsadd L
.31365 .4306 -0.75 0 Mabsadd L closepath F
.31734 .4306 -0.75 0 Mabsadd m
.31734 .4306 0 1 Mabsadd L
.31734 .4306 .75 0 Mabsadd L
.31734 .4306 0 -1 Mabsadd L
.31734 .4306 -0.75 0 Mabsadd L closepath F
.32103 .4306 -0.75 0 Mabsadd m
.32103 .4306 0 1 Mabsadd L
.32103 .4306 .75 0 Mabsadd L
.32103 .4306 0 -1 Mabsadd L
.32103 .4306 -0.75 0 Mabsadd L closepath F
.32472 .4306 -0.75 0 Mabsadd m
.32472 .4306 0 1 Mabsadd L
.32472 .4306 .75 0 Mabsadd L
.32472 .4306 0 -1 Mabsadd L
.32472 .4306 -0.75 0 Mabsadd L closepath F
.32841 .4306 -0.75 0 Mabsadd m
.32841 .4306 0 1 Mabsadd L
.32841 .4306 .75 0 Mabsadd L
.32841 .4306 0 -1 Mabsadd L
.32841 .4306 -0.75 0 Mabsadd L closepath F
.3321 .4306 -0.75 0 Mabsadd m
.3321 .4306 0 1 Mabsadd L
.3321 .4306 .75 0 Mabsadd L
.3321 .4306 0 -1 Mabsadd L
.3321 .4306 -0.75 0 Mabsadd L closepath F
.33579 .4306 -0.75 0 Mabsadd m
.33579 .4306 0 1 Mabsadd L
.33579 .4306 .75 0 Mabsadd L
.33579 .4306 0 -1 Mabsadd L
.33579 .4306 -0.75 0 Mabsadd L closepath F
.33948 .4306 -0.75 0 Mabsadd m
.33948 .4306 0 1 Mabsadd L
.33948 .4306 .75 0 Mabsadd L
.33948 .4306 0 -1 Mabsadd L
.33948 .4306 -0.75 0 Mabsadd L closepath F
.34317 .4306 -0.75 0 Mabsadd m
.34317 .4306 0 1 Mabsadd L
.34317 .4306 .75 0 Mabsadd L
.34317 .4306 0 -1 Mabsadd L
.34317 .4306 -0.75 0 Mabsadd L closepath F
.34686 .4306 -0.75 0 Mabsadd m
.34686 .4306 0 1 Mabsadd L
.34686 .4306 .75 0 Mabsadd L
.34686 .4306 0 -1 Mabsadd L
.34686 .4306 -0.75 0 Mabsadd L closepath F
.35055 .4306 -0.75 0 Mabsadd m
.35055 .4306 0 1 Mabsadd L
.35055 .4306 .75 0 Mabsadd L
.35055 .4306 0 -1 Mabsadd L
.35055 .4306 -0.75 0 Mabsadd L closepath F
.35424 .4306 -0.75 0 Mabsadd m
.35424 .4306 0 1 Mabsadd L
.35424 .4306 .75 0 Mabsadd L
.35424 .4306 0 -1 Mabsadd L
.35424 .4306 -0.75 0 Mabsadd L closepath F
.35793 .4306 -0.75 0 Mabsadd m
.35793 .4306 0 1 Mabsadd L
.35793 .4306 .75 0 Mabsadd L
.35793 .4306 0 -1 Mabsadd L
.35793 .4306 -0.75 0 Mabsadd L closepath F
.36162 .4306 -0.75 0 Mabsadd m
.36162 .4306 0 1 Mabsadd L
.36162 .4306 .75 0 Mabsadd L
.36162 .4306 0 -1 Mabsadd L
.36162 .4306 -0.75 0 Mabsadd L closepath F
.36531 .4306 -0.75 0 Mabsadd m
.36531 .4306 0 1 Mabsadd L
.36531 .4306 .75 0 Mabsadd L
.36531 .4306 0 -1 Mabsadd L
.36531 .4306 -0.75 0 Mabsadd L closepath F
.369 .4306 -0.75 0 Mabsadd m
.369 .4306 0 1 Mabsadd L
.369 .4306 .75 0 Mabsadd L
.369 .4306 0 -1 Mabsadd L
.369 .4306 -0.75 0 Mabsadd L closepath F
.37269 .4306 -0.75 0 Mabsadd m
.37269 .4306 0 1 Mabsadd L
.37269 .4306 .75 0 Mabsadd L
.37269 .4306 0 -1 Mabsadd L
.37269 .4306 -0.75 0 Mabsadd L closepath F
.37638 .4306 -0.75 0 Mabsadd m
.37638 .4306 0 1 Mabsadd L
.37638 .4306 .75 0 Mabsadd L
.37638 .4306 0 -1 Mabsadd L
.37638 .4306 -0.75 0 Mabsadd L closepath F
.38007 .4306 -0.75 0 Mabsadd m
.38007 .4306 0 1 Mabsadd L
.38007 .4306 .75 0 Mabsadd L
.38007 .4306 0 -1 Mabsadd L
.38007 .4306 -0.75 0 Mabsadd L closepath F
.38376 .4306 -0.75 0 Mabsadd m
.38376 .4306 0 1 Mabsadd L
.38376 .4306 .75 0 Mabsadd L
.38376 .4306 0 -1 Mabsadd L
.38376 .4306 -0.75 0 Mabsadd L closepath F
.38745 .4306 -0.75 0 Mabsadd m
.38745 .4306 0 1 Mabsadd L
.38745 .4306 .75 0 Mabsadd L
.38745 .4306 0 -1 Mabsadd L
.38745 .4306 -0.75 0 Mabsadd L closepath F
.39114 .4306 -0.75 0 Mabsadd m
.39114 .4306 0 1 Mabsadd L
.39114 .4306 .75 0 Mabsadd L
.39114 .4306 0 -1 Mabsadd L
.39114 .4306 -0.75 0 Mabsadd L closepath F
.39483 .4306 -0.75 0 Mabsadd m
.39483 .4306 0 1 Mabsadd L
.39483 .4306 .75 0 Mabsadd L
.39483 .4306 0 -1 Mabsadd L
.39483 .4306 -0.75 0 Mabsadd L closepath F
.39852 .4306 -0.75 0 Mabsadd m
.39852 .4306 0 1 Mabsadd L
.39852 .4306 .75 0 Mabsadd L
.39852 .4306 0 -1 Mabsadd L
.39852 .4306 -0.75 0 Mabsadd L closepath F
.40221 .4306 -0.75 0 Mabsadd m
.40221 .4306 0 1 Mabsadd L
.40221 .4306 .75 0 Mabsadd L
.40221 .4306 0 -1 Mabsadd L
.40221 .4306 -0.75 0 Mabsadd L closepath F
.4059 .4306 -0.75 0 Mabsadd m
.4059 .4306 0 1 Mabsadd L
.4059 .4306 .75 0 Mabsadd L
.4059 .4306 0 -1 Mabsadd L
.4059 .4306 -0.75 0 Mabsadd L closepath F
.40959 .4306 -0.75 0 Mabsadd m
.40959 .4306 0 1 Mabsadd L
.40959 .4306 .75 0 Mabsadd L
.40959 .4306 0 -1 Mabsadd L
.40959 .4306 -0.75 0 Mabsadd L closepath F
.41328 .4306 -0.75 0 Mabsadd m
.41328 .4306 0 1 Mabsadd L
.41328 .4306 .75 0 Mabsadd L
.41328 .4306 0 -1 Mabsadd L
.41328 .4306 -0.75 0 Mabsadd L closepath F
.41697 .4306 -0.75 0 Mabsadd m
.41697 .4306 0 1 Mabsadd L
.41697 .4306 .75 0 Mabsadd L
.41697 .4306 0 -1 Mabsadd L
.41697 .4306 -0.75 0 Mabsadd L closepath F
.42066 .4306 -0.75 0 Mabsadd m
.42066 .4306 0 1 Mabsadd L
.42066 .4306 .75 0 Mabsadd L
.42066 .4306 0 -1 Mabsadd L
.42066 .4306 -0.75 0 Mabsadd L closepath F
.42435 .4306 -0.75 0 Mabsadd m
.42435 .4306 0 1 Mabsadd L
.42435 .4306 .75 0 Mabsadd L
.42435 .4306 0 -1 Mabsadd L
.42435 .4306 -0.75 0 Mabsadd L closepath F
.42804 .4306 -0.75 0 Mabsadd m
.42804 .4306 0 1 Mabsadd L
.42804 .4306 .75 0 Mabsadd L
.42804 .4306 0 -1 Mabsadd L
.42804 .4306 -0.75 0 Mabsadd L closepath F
.43173 .4306 -0.75 0 Mabsadd m
.43173 .4306 0 1 Mabsadd L
.43173 .4306 .75 0 Mabsadd L
.43173 .4306 0 -1 Mabsadd L
.43173 .4306 -0.75 0 Mabsadd L closepath F
.43542 .4306 -0.75 0 Mabsadd m
.43542 .4306 0 1 Mabsadd L
.43542 .4306 .75 0 Mabsadd L
.43542 .4306 0 -1 Mabsadd L
.43542 .4306 -0.75 0 Mabsadd L closepath F
.43911 .4306 -0.75 0 Mabsadd m
.43911 .4306 0 1 Mabsadd L
.43911 .4306 .75 0 Mabsadd L
.43911 .4306 0 -1 Mabsadd L
.43911 .4306 -0.75 0 Mabsadd L closepath F
.4428 .4306 -0.75 0 Mabsadd m
.4428 .4306 0 1 Mabsadd L
.4428 .4306 .75 0 Mabsadd L
.4428 .4306 0 -1 Mabsadd L
.4428 .4306 -0.75 0 Mabsadd L closepath F
.44649 .4306 -0.75 0 Mabsadd m
.44649 .4306 0 1 Mabsadd L
.44649 .4306 .75 0 Mabsadd L
.44649 .4306 0 -1 Mabsadd L
.44649 .4306 -0.75 0 Mabsadd L closepath F
.45018 .4306 -0.75 0 Mabsadd m
.45018 .4306 0 1 Mabsadd L
.45018 .4306 .75 0 Mabsadd L
.45018 .4306 0 -1 Mabsadd L
.45018 .4306 -0.75 0 Mabsadd L closepath F
.45387 .4306 -0.75 0 Mabsadd m
.45387 .4306 0 1 Mabsadd L
.45387 .4306 .75 0 Mabsadd L
.45387 .4306 0 -1 Mabsadd L
.45387 .4306 -0.75 0 Mabsadd L closepath F
.45756 .4306 -0.75 0 Mabsadd m
.45756 .4306 0 1 Mabsadd L
.45756 .4306 .75 0 Mabsadd L
.45756 .4306 0 -1 Mabsadd L
.45756 .4306 -0.75 0 Mabsadd L closepath F
.46125 .4306 -0.75 0 Mabsadd m
.46125 .4306 0 1 Mabsadd L
.46125 .4306 .75 0 Mabsadd L
.46125 .4306 0 -1 Mabsadd L
.46125 .4306 -0.75 0 Mabsadd L closepath F
.46494 .4306 -0.75 0 Mabsadd m
.46494 .4306 0 1 Mabsadd L
.46494 .4306 .75 0 Mabsadd L
.46494 .4306 0 -1 Mabsadd L
.46494 .4306 -0.75 0 Mabsadd L closepath F
.46863 .4306 -0.75 0 Mabsadd m
.46863 .4306 0 1 Mabsadd L
.46863 .4306 .75 0 Mabsadd L
.46863 .4306 0 -1 Mabsadd L
.46863 .4306 -0.75 0 Mabsadd L closepath F
.47232 .4306 -0.75 0 Mabsadd m
.47232 .4306 0 1 Mabsadd L
.47232 .4306 .75 0 Mabsadd L
.47232 .4306 0 -1 Mabsadd L
.47232 .4306 -0.75 0 Mabsadd L closepath F
.47601 .4306 -0.75 0 Mabsadd m
.47601 .4306 0 1 Mabsadd L
.47601 .4306 .75 0 Mabsadd L
.47601 .4306 0 -1 Mabsadd L
.47601 .4306 -0.75 0 Mabsadd L closepath F
.4797 .4306 -0.75 0 Mabsadd m
.4797 .4306 0 1 Mabsadd L
.4797 .4306 .75 0 Mabsadd L
.4797 .4306 0 -1 Mabsadd L
.4797 .4306 -0.75 0 Mabsadd L closepath F
.48339 .4306 -0.75 0 Mabsadd m
.48339 .4306 0 1 Mabsadd L
.48339 .4306 .75 0 Mabsadd L
.48339 .4306 0 -1 Mabsadd L
.48339 .4306 -0.75 0 Mabsadd L closepath F
.48708 .4306 -0.75 0 Mabsadd m
.48708 .4306 0 1 Mabsadd L
.48708 .4306 .75 0 Mabsadd L
.48708 .4306 0 -1 Mabsadd L
.48708 .4306 -0.75 0 Mabsadd L closepath F
.49077 .4306 -0.75 0 Mabsadd m
.49077 .4306 0 1 Mabsadd L
.49077 .4306 .75 0 Mabsadd L
.49077 .4306 0 -1 Mabsadd L
.49077 .4306 -0.75 0 Mabsadd L closepath F
.49446 .4306 -0.75 0 Mabsadd m
.49446 .4306 0 1 Mabsadd L
.49446 .4306 .75 0 Mabsadd L
.49446 .4306 0 -1 Mabsadd L
.49446 .4306 -0.75 0 Mabsadd L closepath F
.49815 .4306 -0.75 0 Mabsadd m
.49815 .4306 0 1 Mabsadd L
.49815 .4306 .75 0 Mabsadd L
.49815 .4306 0 -1 Mabsadd L
.49815 .4306 -0.75 0 Mabsadd L closepath F
.50185 .4306 -0.75 0 Mabsadd m
.50185 .4306 0 1 Mabsadd L
.50185 .4306 .75 0 Mabsadd L
.50185 .4306 0 -1 Mabsadd L
.50185 .4306 -0.75 0 Mabsadd L closepath F
.50554 .4306 -0.75 0 Mabsadd m
.50554 .4306 0 1 Mabsadd L
.50554 .4306 .75 0 Mabsadd L
.50554 .4306 0 -1 Mabsadd L
.50554 .4306 -0.75 0 Mabsadd L closepath F
.50923 .4306 -0.75 0 Mabsadd m
.50923 .4306 0 1 Mabsadd L
.50923 .4306 .75 0 Mabsadd L
.50923 .4306 0 -1 Mabsadd L
.50923 .4306 -0.75 0 Mabsadd L closepath F
.51292 .4306 -0.75 0 Mabsadd m
.51292 .4306 0 1 Mabsadd L
.51292 .4306 .75 0 Mabsadd L
.51292 .4306 0 -1 Mabsadd L
.51292 .4306 -0.75 0 Mabsadd L closepath F
.51661 .4306 -0.75 0 Mabsadd m
.51661 .4306 0 1 Mabsadd L
.51661 .4306 .75 0 Mabsadd L
.51661 .4306 0 -1 Mabsadd L
.51661 .4306 -0.75 0 Mabsadd L closepath F
.5203 .4306 -0.75 0 Mabsadd m
.5203 .4306 0 1 Mabsadd L
.5203 .4306 .75 0 Mabsadd L
.5203 .4306 0 -1 Mabsadd L
.5203 .4306 -0.75 0 Mabsadd L closepath F
.52399 .4306 -0.75 0 Mabsadd m
.52399 .4306 0 1 Mabsadd L
.52399 .4306 .75 0 Mabsadd L
.52399 .4306 0 -1 Mabsadd L
.52399 .4306 -0.75 0 Mabsadd L closepath F
.52768 .4306 -0.75 0 Mabsadd m
.52768 .4306 0 1 Mabsadd L
.52768 .4306 .75 0 Mabsadd L
.52768 .4306 0 -1 Mabsadd L
.52768 .4306 -0.75 0 Mabsadd L closepath F
.53137 .4306 -0.75 0 Mabsadd m
.53137 .4306 0 1 Mabsadd L
.53137 .4306 .75 0 Mabsadd L
.53137 .4306 0 -1 Mabsadd L
.53137 .4306 -0.75 0 Mabsadd L closepath F
.53506 .4306 -0.75 0 Mabsadd m
.53506 .4306 0 1 Mabsadd L
.53506 .4306 .75 0 Mabsadd L
.53506 .4306 0 -1 Mabsadd L
.53506 .4306 -0.75 0 Mabsadd L closepath F
.53875 .4306 -0.75 0 Mabsadd m
.53875 .4306 0 1 Mabsadd L
.53875 .4306 .75 0 Mabsadd L
.53875 .4306 0 -1 Mabsadd L
.53875 .4306 -0.75 0 Mabsadd L closepath F
.54244 .4306 -0.75 0 Mabsadd m
.54244 .4306 0 1 Mabsadd L
.54244 .4306 .75 0 Mabsadd L
.54244 .4306 0 -1 Mabsadd L
.54244 .4306 -0.75 0 Mabsadd L closepath F
.54613 .4306 -0.75 0 Mabsadd m
.54613 .4306 0 1 Mabsadd L
.54613 .4306 .75 0 Mabsadd L
.54613 .4306 0 -1 Mabsadd L
.54613 .4306 -0.75 0 Mabsadd L closepath F
.54982 .4306 -0.75 0 Mabsadd m
.54982 .4306 0 1 Mabsadd L
.54982 .4306 .75 0 Mabsadd L
.54982 .4306 0 -1 Mabsadd L
.54982 .4306 -0.75 0 Mabsadd L closepath F
.55351 .4306 -0.75 0 Mabsadd m
.55351 .4306 0 1 Mabsadd L
.55351 .4306 .75 0 Mabsadd L
.55351 .4306 0 -1 Mabsadd L
.55351 .4306 -0.75 0 Mabsadd L closepath F
.5572 .4306 -0.75 0 Mabsadd m
.5572 .4306 0 1 Mabsadd L
.5572 .4306 .75 0 Mabsadd L
.5572 .4306 0 -1 Mabsadd L
.5572 .4306 -0.75 0 Mabsadd L closepath F
.56089 .4306 -0.75 0 Mabsadd m
.56089 .4306 0 1 Mabsadd L
.56089 .4306 .75 0 Mabsadd L
.56089 .4306 0 -1 Mabsadd L
.56089 .4306 -0.75 0 Mabsadd L closepath F
.56458 .4306 -0.75 0 Mabsadd m
.56458 .4306 0 1 Mabsadd L
.56458 .4306 .75 0 Mabsadd L
.56458 .4306 0 -1 Mabsadd L
.56458 .4306 -0.75 0 Mabsadd L closepath F
.56827 .4306 -0.75 0 Mabsadd m
.56827 .4306 0 1 Mabsadd L
.56827 .4306 .75 0 Mabsadd L
.56827 .4306 0 -1 Mabsadd L
.56827 .4306 -0.75 0 Mabsadd L closepath F
.57196 .4306 -0.75 0 Mabsadd m
.57196 .4306 0 1 Mabsadd L
.57196 .4306 .75 0 Mabsadd L
.57196 .4306 0 -1 Mabsadd L
.57196 .4306 -0.75 0 Mabsadd L closepath F
.57565 .4306 -0.75 0 Mabsadd m
.57565 .4306 0 1 Mabsadd L
.57565 .4306 .75 0 Mabsadd L
.57565 .4306 0 -1 Mabsadd L
.57565 .4306 -0.75 0 Mabsadd L closepath F
.57934 .4306 -0.75 0 Mabsadd m
.57934 .4306 0 1 Mabsadd L
.57934 .4306 .75 0 Mabsadd L
.57934 .4306 0 -1 Mabsadd L
.57934 .4306 -0.75 0 Mabsadd L closepath F
.58303 .4306 -0.75 0 Mabsadd m
.58303 .4306 0 1 Mabsadd L
.58303 .4306 .75 0 Mabsadd L
.58303 .4306 0 -1 Mabsadd L
.58303 .4306 -0.75 0 Mabsadd L closepath F
.58672 .4306 -0.75 0 Mabsadd m
.58672 .4306 0 1 Mabsadd L
.58672 .4306 .75 0 Mabsadd L
.58672 .4306 0 -1 Mabsadd L
.58672 .4306 -0.75 0 Mabsadd L closepath F
.59041 .4306 -0.75 0 Mabsadd m
.59041 .4306 0 1 Mabsadd L
.59041 .4306 .75 0 Mabsadd L
.59041 .4306 0 -1 Mabsadd L
.59041 .4306 -0.75 0 Mabsadd L closepath F
.5941 .4306 -0.75 0 Mabsadd m
.5941 .4306 0 1 Mabsadd L
.5941 .4306 .75 0 Mabsadd L
.5941 .4306 0 -1 Mabsadd L
.5941 .4306 -0.75 0 Mabsadd L closepath F
.59779 .4306 -0.75 0 Mabsadd m
.59779 .4306 0 1 Mabsadd L
.59779 .4306 .75 0 Mabsadd L
.59779 .4306 0 -1 Mabsadd L
.59779 .4306 -0.75 0 Mabsadd L closepath F
.60148 .4306 -0.75 0 Mabsadd m
.60148 .4306 0 1 Mabsadd L
.60148 .4306 .75 0 Mabsadd L
.60148 .4306 0 -1 Mabsadd L
.60148 .4306 -0.75 0 Mabsadd L closepath F
.60517 .4306 -0.75 0 Mabsadd m
.60517 .4306 0 1 Mabsadd L
.60517 .4306 .75 0 Mabsadd L
.60517 .4306 0 -1 Mabsadd L
.60517 .4306 -0.75 0 Mabsadd L closepath F
.60886 .4306 -0.75 0 Mabsadd m
.60886 .4306 0 1 Mabsadd L
.60886 .4306 .75 0 Mabsadd L
.60886 .4306 0 -1 Mabsadd L
.60886 .4306 -0.75 0 Mabsadd L closepath F
.61255 .4306 -0.75 0 Mabsadd m
.61255 .4306 0 1 Mabsadd L
.61255 .4306 .75 0 Mabsadd L
.61255 .4306 0 -1 Mabsadd L
.61255 .4306 -0.75 0 Mabsadd L closepath F
.61624 .4306 -0.75 0 Mabsadd m
.61624 .4306 0 1 Mabsadd L
.61624 .4306 .75 0 Mabsadd L
.61624 .4306 0 -1 Mabsadd L
.61624 .4306 -0.75 0 Mabsadd L closepath F
.61993 .4306 -0.75 0 Mabsadd m
.61993 .4306 0 1 Mabsadd L
.61993 .4306 .75 0 Mabsadd L
.61993 .4306 0 -1 Mabsadd L
.61993 .4306 -0.75 0 Mabsadd L closepath F
.62362 .4306 -0.75 0 Mabsadd m
.62362 .4306 0 1 Mabsadd L
.62362 .4306 .75 0 Mabsadd L
.62362 .4306 0 -1 Mabsadd L
.62362 .4306 -0.75 0 Mabsadd L closepath F
.62731 .4306 -0.75 0 Mabsadd m
.62731 .4306 0 1 Mabsadd L
.62731 .4306 .75 0 Mabsadd L
.62731 .4306 0 -1 Mabsadd L
.62731 .4306 -0.75 0 Mabsadd L closepath F
.631 .4306 -0.75 0 Mabsadd m
.631 .4306 0 1 Mabsadd L
.631 .4306 .75 0 Mabsadd L
.631 .4306 0 -1 Mabsadd L
.631 .4306 -0.75 0 Mabsadd L closepath F
.63469 .4306 -0.75 0 Mabsadd m
.63469 .4306 0 1 Mabsadd L
.63469 .4306 .75 0 Mabsadd L
.63469 .4306 0 -1 Mabsadd L
.63469 .4306 -0.75 0 Mabsadd L closepath F
.63838 .4306 -0.75 0 Mabsadd m
.63838 .4306 0 1 Mabsadd L
.63838 .4306 .75 0 Mabsadd L
.63838 .4306 0 -1 Mabsadd L
.63838 .4306 -0.75 0 Mabsadd L closepath F
.64207 .4306 -0.75 0 Mabsadd m
.64207 .4306 0 1 Mabsadd L
.64207 .4306 .75 0 Mabsadd L
.64207 .4306 0 -1 Mabsadd L
.64207 .4306 -0.75 0 Mabsadd L closepath F
.64576 .4306 -0.75 0 Mabsadd m
.64576 .4306 0 1 Mabsadd L
.64576 .4306 .75 0 Mabsadd L
.64576 .4306 0 -1 Mabsadd L
.64576 .4306 -0.75 0 Mabsadd L closepath F
.64945 .4306 -0.75 0 Mabsadd m
.64945 .4306 0 1 Mabsadd L
.64945 .4306 .75 0 Mabsadd L
.64945 .4306 0 -1 Mabsadd L
.64945 .4306 -0.75 0 Mabsadd L closepath F
.65314 .4306 -0.75 0 Mabsadd m
.65314 .4306 0 1 Mabsadd L
.65314 .4306 .75 0 Mabsadd L
.65314 .4306 0 -1 Mabsadd L
.65314 .4306 -0.75 0 Mabsadd L closepath F
.65683 .4306 -0.75 0 Mabsadd m
.65683 .4306 0 1 Mabsadd L
.65683 .4306 .75 0 Mabsadd L
.65683 .4306 0 -1 Mabsadd L
.65683 .4306 -0.75 0 Mabsadd L closepath F
.66052 .4306 -0.75 0 Mabsadd m
.66052 .4306 0 1 Mabsadd L
.66052 .4306 .75 0 Mabsadd L
.66052 .4306 0 -1 Mabsadd L
.66052 .4306 -0.75 0 Mabsadd L closepath F
.66421 .4306 -0.75 0 Mabsadd m
.66421 .4306 0 1 Mabsadd L
.66421 .4306 .75 0 Mabsadd L
.66421 .4306 0 -1 Mabsadd L
.66421 .4306 -0.75 0 Mabsadd L closepath F
.6679 .4306 -0.75 0 Mabsadd m
.6679 .4306 0 1 Mabsadd L
.6679 .4306 .75 0 Mabsadd L
.6679 .4306 0 -1 Mabsadd L
.6679 .4306 -0.75 0 Mabsadd L closepath F
.67159 .4306 -0.75 0 Mabsadd m
.67159 .4306 0 1 Mabsadd L
.67159 .4306 .75 0 Mabsadd L
.67159 .4306 0 -1 Mabsadd L
.67159 .4306 -0.75 0 Mabsadd L closepath F
.67528 .4306 -0.75 0 Mabsadd m
.67528 .4306 0 1 Mabsadd L
.67528 .4306 .75 0 Mabsadd L
.67528 .4306 0 -1 Mabsadd L
.67528 .4306 -0.75 0 Mabsadd L closepath F
.67897 .4306 -0.75 0 Mabsadd m
.67897 .4306 0 1 Mabsadd L
.67897 .4306 .75 0 Mabsadd L
.67897 .4306 0 -1 Mabsadd L
.67897 .4306 -0.75 0 Mabsadd L closepath F
.68266 .4306 -0.75 0 Mabsadd m
.68266 .4306 0 1 Mabsadd L
.68266 .4306 .75 0 Mabsadd L
.68266 .4306 0 -1 Mabsadd L
.68266 .4306 -0.75 0 Mabsadd L closepath F
.68635 .4306 -0.75 0 Mabsadd m
.68635 .4306 0 1 Mabsadd L
.68635 .4306 .75 0 Mabsadd L
.68635 .4306 0 -1 Mabsadd L
.68635 .4306 -0.75 0 Mabsadd L closepath F
.69004 .4306 -0.75 0 Mabsadd m
.69004 .4306 0 1 Mabsadd L
.69004 .4306 .75 0 Mabsadd L
.69004 .4306 0 -1 Mabsadd L
.69004 .4306 -0.75 0 Mabsadd L closepath F
.69373 .4306 -0.75 0 Mabsadd m
.69373 .4306 0 1 Mabsadd L
.69373 .4306 .75 0 Mabsadd L
.69373 .4306 0 -1 Mabsadd L
.69373 .4306 -0.75 0 Mabsadd L closepath F
.69742 .4306 -0.75 0 Mabsadd m
.69742 .4306 0 1 Mabsadd L
.69742 .4306 .75 0 Mabsadd L
.69742 .4306 0 -1 Mabsadd L
.69742 .4306 -0.75 0 Mabsadd L closepath F
.70111 .4306 -0.75 0 Mabsadd m
.70111 .4306 0 1 Mabsadd L
.70111 .4306 .75 0 Mabsadd L
.70111 .4306 0 -1 Mabsadd L
.70111 .4306 -0.75 0 Mabsadd L closepath F
.7048 .4306 -0.75 0 Mabsadd m
.7048 .4306 0 1 Mabsadd L
.7048 .4306 .75 0 Mabsadd L
.7048 .4306 0 -1 Mabsadd L
.7048 .4306 -0.75 0 Mabsadd L closepath F
.70849 .4306 -0.75 0 Mabsadd m
.70849 .4306 0 1 Mabsadd L
.70849 .4306 .75 0 Mabsadd L
.70849 .4306 0 -1 Mabsadd L
.70849 .4306 -0.75 0 Mabsadd L closepath F
.71218 .4306 -0.75 0 Mabsadd m
.71218 .4306 0 1 Mabsadd L
.71218 .4306 .75 0 Mabsadd L
.71218 .4306 0 -1 Mabsadd L
.71218 .4306 -0.75 0 Mabsadd L closepath F
.71587 .4306 -0.75 0 Mabsadd m
.71587 .4306 0 1 Mabsadd L
.71587 .4306 .75 0 Mabsadd L
.71587 .4306 0 -1 Mabsadd L
.71587 .4306 -0.75 0 Mabsadd L closepath F
.71956 .4306 -0.75 0 Mabsadd m
.71956 .4306 0 1 Mabsadd L
.71956 .4306 .75 0 Mabsadd L
.71956 .4306 0 -1 Mabsadd L
.71956 .4306 -0.75 0 Mabsadd L closepath F
.72325 .4306 -0.75 0 Mabsadd m
.72325 .4306 0 1 Mabsadd L
.72325 .4306 .75 0 Mabsadd L
.72325 .4306 0 -1 Mabsadd L
.72325 .4306 -0.75 0 Mabsadd L closepath F
.72694 .4306 -0.75 0 Mabsadd m
.72694 .4306 0 1 Mabsadd L
.72694 .4306 .75 0 Mabsadd L
.72694 .4306 0 -1 Mabsadd L
.72694 .4306 -0.75 0 Mabsadd L closepath F
.73063 .4306 -0.75 0 Mabsadd m
.73063 .4306 0 1 Mabsadd L
.73063 .4306 .75 0 Mabsadd L
.73063 .4306 0 -1 Mabsadd L
.73063 .4306 -0.75 0 Mabsadd L closepath F
.73432 .4306 -0.75 0 Mabsadd m
.73432 .4306 0 1 Mabsadd L
.73432 .4306 .75 0 Mabsadd L
.73432 .4306 0 -1 Mabsadd L
.73432 .4306 -0.75 0 Mabsadd L closepath F
.73801 .4306 -0.75 0 Mabsadd m
.73801 .4306 0 1 Mabsadd L
.73801 .4306 .75 0 Mabsadd L
.73801 .4306 0 -1 Mabsadd L
.73801 .4306 -0.75 0 Mabsadd L closepath F
.7417 .4306 -0.75 0 Mabsadd m
.7417 .4306 0 1 Mabsadd L
.7417 .4306 .75 0 Mabsadd L
.7417 .4306 0 -1 Mabsadd L
.7417 .4306 -0.75 0 Mabsadd L closepath F
.74539 .4306 -0.75 0 Mabsadd m
.74539 .4306 0 1 Mabsadd L
.74539 .4306 .75 0 Mabsadd L
.74539 .4306 0 -1 Mabsadd L
.74539 .4306 -0.75 0 Mabsadd L closepath F
.74908 .4306 -0.75 0 Mabsadd m
.74908 .4306 0 1 Mabsadd L
.74908 .4306 .75 0 Mabsadd L
.74908 .4306 0 -1 Mabsadd L
.74908 .4306 -0.75 0 Mabsadd L closepath F
.75277 .4306 -0.75 0 Mabsadd m
.75277 .4306 0 1 Mabsadd L
.75277 .4306 .75 0 Mabsadd L
.75277 .4306 0 -1 Mabsadd L
.75277 .4306 -0.75 0 Mabsadd L closepath F
.75646 .4306 -0.75 0 Mabsadd m
.75646 .4306 0 1 Mabsadd L
.75646 .4306 .75 0 Mabsadd L
.75646 .4306 0 -1 Mabsadd L
.75646 .4306 -0.75 0 Mabsadd L closepath F
.76015 .4306 -0.75 0 Mabsadd m
.76015 .4306 0 1 Mabsadd L
.76015 .4306 .75 0 Mabsadd L
.76015 .4306 0 -1 Mabsadd L
.76015 .4306 -0.75 0 Mabsadd L closepath F
.76384 .4306 -0.75 0 Mabsadd m
.76384 .4306 0 1 Mabsadd L
.76384 .4306 .75 0 Mabsadd L
.76384 .4306 0 -1 Mabsadd L
.76384 .4306 -0.75 0 Mabsadd L closepath F
.76753 .4306 -0.75 0 Mabsadd m
.76753 .4306 0 1 Mabsadd L
.76753 .4306 .75 0 Mabsadd L
.76753 .4306 0 -1 Mabsadd L
.76753 .4306 -0.75 0 Mabsadd L closepath F
.77122 .4306 -0.75 0 Mabsadd m
.77122 .4306 0 1 Mabsadd L
.77122 .4306 .75 0 Mabsadd L
.77122 .4306 0 -1 Mabsadd L
.77122 .4306 -0.75 0 Mabsadd L closepath F
.77491 .4306 -0.75 0 Mabsadd m
.77491 .4306 0 1 Mabsadd L
.77491 .4306 .75 0 Mabsadd L
.77491 .4306 0 -1 Mabsadd L
.77491 .4306 -0.75 0 Mabsadd L closepath F
.7786 .4306 -0.75 0 Mabsadd m
.7786 .4306 0 1 Mabsadd L
.7786 .4306 .75 0 Mabsadd L
.7786 .4306 0 -1 Mabsadd L
.7786 .4306 -0.75 0 Mabsadd L closepath F
.78229 .4306 -0.75 0 Mabsadd m
.78229 .4306 0 1 Mabsadd L
.78229 .4306 .75 0 Mabsadd L
.78229 .4306 0 -1 Mabsadd L
.78229 .4306 -0.75 0 Mabsadd L closepath F
.78598 .4306 -0.75 0 Mabsadd m
.78598 .4306 0 1 Mabsadd L
.78598 .4306 .75 0 Mabsadd L
.78598 .4306 0 -1 Mabsadd L
.78598 .4306 -0.75 0 Mabsadd L closepath F
.78967 .4306 -0.75 0 Mabsadd m
.78967 .4306 0 1 Mabsadd L
.78967 .4306 .75 0 Mabsadd L
.78967 .4306 0 -1 Mabsadd L
.78967 .4306 -0.75 0 Mabsadd L closepath F
.79336 .4306 -0.75 0 Mabsadd m
.79336 .4306 0 1 Mabsadd L
.79336 .4306 .75 0 Mabsadd L
.79336 .4306 0 -1 Mabsadd L
.79336 .4306 -0.75 0 Mabsadd L closepath F
.79705 .4306 -0.75 0 Mabsadd m
.79705 .4306 0 1 Mabsadd L
.79705 .4306 .75 0 Mabsadd L
.79705 .4306 0 -1 Mabsadd L
.79705 .4306 -0.75 0 Mabsadd L closepath F
.80074 .4306 -0.75 0 Mabsadd m
.80074 .4306 0 1 Mabsadd L
.80074 .4306 .75 0 Mabsadd L
.80074 .4306 0 -1 Mabsadd L
.80074 .4306 -0.75 0 Mabsadd L closepath F
.80443 .4306 -0.75 0 Mabsadd m
.80443 .4306 0 1 Mabsadd L
.80443 .4306 .75 0 Mabsadd L
.80443 .4306 0 -1 Mabsadd L
.80443 .4306 -0.75 0 Mabsadd L closepath F
.80812 .4306 -0.75 0 Mabsadd m
.80812 .4306 0 1 Mabsadd L
.80812 .4306 .75 0 Mabsadd L
.80812 .4306 0 -1 Mabsadd L
.80812 .4306 -0.75 0 Mabsadd L closepath F
.81181 .4306 -0.75 0 Mabsadd m
.81181 .4306 0 1 Mabsadd L
.81181 .4306 .75 0 Mabsadd L
.81181 .4306 0 -1 Mabsadd L
.81181 .4306 -0.75 0 Mabsadd L closepath F
.8155 .4306 -0.75 0 Mabsadd m
.8155 .4306 0 1 Mabsadd L
.8155 .4306 .75 0 Mabsadd L
.8155 .4306 0 -1 Mabsadd L
.8155 .4306 -0.75 0 Mabsadd L closepath F
.81919 .4306 -0.75 0 Mabsadd m
.81919 .4306 0 1 Mabsadd L
.81919 .4306 .75 0 Mabsadd L
.81919 .4306 0 -1 Mabsadd L
.81919 .4306 -0.75 0 Mabsadd L closepath F
.82288 .4306 -0.75 0 Mabsadd m
.82288 .4306 0 1 Mabsadd L
.82288 .4306 .75 0 Mabsadd L
.82288 .4306 0 -1 Mabsadd L
.82288 .4306 -0.75 0 Mabsadd L closepath F
.82657 .4306 -0.75 0 Mabsadd m
.82657 .4306 0 1 Mabsadd L
.82657 .4306 .75 0 Mabsadd L
.82657 .4306 0 -1 Mabsadd L
.82657 .4306 -0.75 0 Mabsadd L closepath F
.83026 .4306 -0.75 0 Mabsadd m
.83026 .4306 0 1 Mabsadd L
.83026 .4306 .75 0 Mabsadd L
.83026 .4306 0 -1 Mabsadd L
.83026 .4306 -0.75 0 Mabsadd L closepath F
.83395 .4306 -0.75 0 Mabsadd m
.83395 .4306 0 1 Mabsadd L
.83395 .4306 .75 0 Mabsadd L
.83395 .4306 0 -1 Mabsadd L
.83395 .4306 -0.75 0 Mabsadd L closepath F
.83764 .4306 -0.75 0 Mabsadd m
.83764 .4306 0 1 Mabsadd L
.83764 .4306 .75 0 Mabsadd L
.83764 .4306 0 -1 Mabsadd L
.83764 .4306 -0.75 0 Mabsadd L closepath F
.84133 .4306 -0.75 0 Mabsadd m
.84133 .4306 0 1 Mabsadd L
.84133 .4306 .75 0 Mabsadd L
.84133 .4306 0 -1 Mabsadd L
.84133 .4306 -0.75 0 Mabsadd L closepath F
.84502 .4306 -0.75 0 Mabsadd m
.84502 .4306 0 1 Mabsadd L
.84502 .4306 .75 0 Mabsadd L
.84502 .4306 0 -1 Mabsadd L
.84502 .4306 -0.75 0 Mabsadd L closepath F
.84871 .4306 -0.75 0 Mabsadd m
.84871 .4306 0 1 Mabsadd L
.84871 .4306 .75 0 Mabsadd L
.84871 .4306 0 -1 Mabsadd L
.84871 .4306 -0.75 0 Mabsadd L closepath F
.8524 .4306 -0.75 0 Mabsadd m
.8524 .4306 0 1 Mabsadd L
.8524 .4306 .75 0 Mabsadd L
.8524 .4306 0 -1 Mabsadd L
.8524 .4306 -0.75 0 Mabsadd L closepath F
.85609 .4306 -0.75 0 Mabsadd m
.85609 .4306 0 1 Mabsadd L
.85609 .4306 .75 0 Mabsadd L
.85609 .4306 0 -1 Mabsadd L
.85609 .4306 -0.75 0 Mabsadd L closepath F
.85978 .4306 -0.75 0 Mabsadd m
.85978 .4306 0 1 Mabsadd L
.85978 .4306 .75 0 Mabsadd L
.85978 .4306 0 -1 Mabsadd L
.85978 .4306 -0.75 0 Mabsadd L closepath F
.86347 .4306 -0.75 0 Mabsadd m
.86347 .4306 0 1 Mabsadd L
.86347 .4306 .75 0 Mabsadd L
.86347 .4306 0 -1 Mabsadd L
.86347 .4306 -0.75 0 Mabsadd L closepath F
.86716 .4306 -0.75 0 Mabsadd m
.86716 .4306 0 1 Mabsadd L
.86716 .4306 .75 0 Mabsadd L
.86716 .4306 0 -1 Mabsadd L
.86716 .4306 -0.75 0 Mabsadd L closepath F
.87085 .4306 -0.75 0 Mabsadd m
.87085 .4306 0 1 Mabsadd L
.87085 .4306 .75 0 Mabsadd L
.87085 .4306 0 -1 Mabsadd L
.87085 .4306 -0.75 0 Mabsadd L closepath F
.87454 .4306 -0.75 0 Mabsadd m
.87454 .4306 0 1 Mabsadd L
.87454 .4306 .75 0 Mabsadd L
.87454 .4306 0 -1 Mabsadd L
.87454 .4306 -0.75 0 Mabsadd L closepath F
.87823 .4306 -0.75 0 Mabsadd m
.87823 .4306 0 1 Mabsadd L
.87823 .4306 .75 0 Mabsadd L
.87823 .4306 0 -1 Mabsadd L
.87823 .4306 -0.75 0 Mabsadd L closepath F
.88192 .4306 -0.75 0 Mabsadd m
.88192 .4306 0 1 Mabsadd L
.88192 .4306 .75 0 Mabsadd L
.88192 .4306 0 -1 Mabsadd L
.88192 .4306 -0.75 0 Mabsadd L closepath F
.88561 .4306 -0.75 0 Mabsadd m
.88561 .4306 0 1 Mabsadd L
.88561 .4306 .75 0 Mabsadd L
.88561 .4306 0 -1 Mabsadd L
.88561 .4306 -0.75 0 Mabsadd L closepath F
.8893 .4306 -0.75 0 Mabsadd m
.8893 .4306 0 1 Mabsadd L
.8893 .4306 .75 0 Mabsadd L
.8893 .4306 0 -1 Mabsadd L
.8893 .4306 -0.75 0 Mabsadd L closepath F
.89299 .4306 -0.75 0 Mabsadd m
.89299 .4306 0 1 Mabsadd L
.89299 .4306 .75 0 Mabsadd L
.89299 .4306 0 -1 Mabsadd L
.89299 .4306 -0.75 0 Mabsadd L closepath F
.89668 .4306 -0.75 0 Mabsadd m
.89668 .4306 0 1 Mabsadd L
.89668 .4306 .75 0 Mabsadd L
.89668 .4306 0 -1 Mabsadd L
.89668 .4306 -0.75 0 Mabsadd L closepath F
.90037 .4306 -0.75 0 Mabsadd m
.90037 .4306 0 1 Mabsadd L
.90037 .4306 .75 0 Mabsadd L
.90037 .4306 0 -1 Mabsadd L
.90037 .4306 -0.75 0 Mabsadd L closepath F
.90406 .4306 -0.75 0 Mabsadd m
.90406 .4306 0 1 Mabsadd L
.90406 .4306 .75 0 Mabsadd L
.90406 .4306 0 -1 Mabsadd L
.90406 .4306 -0.75 0 Mabsadd L closepath F
.90775 .4306 -0.75 0 Mabsadd m
.90775 .4306 0 1 Mabsadd L
.90775 .4306 .75 0 Mabsadd L
.90775 .4306 0 -1 Mabsadd L
.90775 .4306 -0.75 0 Mabsadd L closepath F
.91144 .4306 -0.75 0 Mabsadd m
.91144 .4306 0 1 Mabsadd L
.91144 .4306 .75 0 Mabsadd L
.91144 .4306 0 -1 Mabsadd L
.91144 .4306 -0.75 0 Mabsadd L closepath F
.91513 .4306 -0.75 0 Mabsadd m
.91513 .4306 0 1 Mabsadd L
.91513 .4306 .75 0 Mabsadd L
.91513 .4306 0 -1 Mabsadd L
.91513 .4306 -0.75 0 Mabsadd L closepath F
.91882 .4306 -0.75 0 Mabsadd m
.91882 .4306 0 1 Mabsadd L
.91882 .4306 .75 0 Mabsadd L
.91882 .4306 0 -1 Mabsadd L
.91882 .4306 -0.75 0 Mabsadd L closepath F
.92251 .4306 -0.75 0 Mabsadd m
.92251 .4306 0 1 Mabsadd L
.92251 .4306 .75 0 Mabsadd L
.92251 .4306 0 -1 Mabsadd L
.92251 .4306 -0.75 0 Mabsadd L closepath F
.9262 .4306 -0.75 0 Mabsadd m
.9262 .4306 0 1 Mabsadd L
.9262 .4306 .75 0 Mabsadd L
.9262 .4306 0 -1 Mabsadd L
.9262 .4306 -0.75 0 Mabsadd L closepath F
.92989 .4306 -0.75 0 Mabsadd m
.92989 .4306 0 1 Mabsadd L
.92989 .4306 .75 0 Mabsadd L
.92989 .4306 0 -1 Mabsadd L
.92989 .4306 -0.75 0 Mabsadd L closepath F
.93358 .4306 -0.75 0 Mabsadd m
.93358 .4306 0 1 Mabsadd L
.93358 .4306 .75 0 Mabsadd L
.93358 .4306 0 -1 Mabsadd L
.93358 .4306 -0.75 0 Mabsadd L closepath F
.93727 .4306 -0.75 0 Mabsadd m
.93727 .4306 0 1 Mabsadd L
.93727 .4306 .75 0 Mabsadd L
.93727 .4306 0 -1 Mabsadd L
.93727 .4306 -0.75 0 Mabsadd L closepath F
.94096 .4306 -0.75 0 Mabsadd m
.94096 .4306 0 1 Mabsadd L
.94096 .4306 .75 0 Mabsadd L
.94096 .4306 0 -1 Mabsadd L
.94096 .4306 -0.75 0 Mabsadd L closepath F
.94465 .4306 -0.75 0 Mabsadd m
.94465 .4306 0 1 Mabsadd L
.94465 .4306 .75 0 Mabsadd L
.94465 .4306 0 -1 Mabsadd L
.94465 .4306 -0.75 0 Mabsadd L closepath F
.94834 .4306 -0.75 0 Mabsadd m
.94834 .4306 0 1 Mabsadd L
.94834 .4306 .75 0 Mabsadd L
.94834 .4306 0 -1 Mabsadd L
.94834 .4306 -0.75 0 Mabsadd L closepath F
.95203 .4306 -0.75 0 Mabsadd m
.95203 .4306 0 1 Mabsadd L
.95203 .4306 .75 0 Mabsadd L
.95203 .4306 0 -1 Mabsadd L
.95203 .4306 -0.75 0 Mabsadd L closepath F
.95572 .4306 -0.75 0 Mabsadd m
.95572 .4306 0 1 Mabsadd L
.95572 .4306 .75 0 Mabsadd L
.95572 .4306 0 -1 Mabsadd L
.95572 .4306 -0.75 0 Mabsadd L closepath F
.95941 .4306 -0.75 0 Mabsadd m
.95941 .4306 0 1 Mabsadd L
.95941 .4306 .75 0 Mabsadd L
.95941 .4306 0 -1 Mabsadd L
.95941 .4306 -0.75 0 Mabsadd L closepath F
.9631 .4306 -0.75 0 Mabsadd m
.9631 .4306 0 1 Mabsadd L
.9631 .4306 .75 0 Mabsadd L
.9631 .4306 0 -1 Mabsadd L
.9631 .4306 -0.75 0 Mabsadd L closepath F
.96679 .4306 -0.75 0 Mabsadd m
.96679 .4306 0 1 Mabsadd L
.96679 .4306 .75 0 Mabsadd L
.96679 .4306 0 -1 Mabsadd L
.96679 .4306 -0.75 0 Mabsadd L closepath F
.97048 .4306 -0.75 0 Mabsadd m
.97048 .4306 0 1 Mabsadd L
.97048 .4306 .75 0 Mabsadd L
.97048 .4306 0 -1 Mabsadd L
.97048 .4306 -0.75 0 Mabsadd L closepath F
.97417 .4306 -0.75 0 Mabsadd m
.97417 .4306 0 1 Mabsadd L
.97417 .4306 .75 0 Mabsadd L
.97417 .4306 0 -1 Mabsadd L
.97417 .4306 -0.75 0 Mabsadd L closepath F
.97786 .4306 -0.75 0 Mabsadd m
.97786 .4306 0 1 Mabsadd L
.97786 .4306 .75 0 Mabsadd L
.97786 .4306 0 -1 Mabsadd L
.97786 .4306 -0.75 0 Mabsadd L closepath F
.98155 .4306 -0.75 0 Mabsadd m
.98155 .4306 0 1 Mabsadd L
.98155 .4306 .75 0 Mabsadd L
.98155 .4306 0 -1 Mabsadd L
.98155 .4306 -0.75 0 Mabsadd L closepath F
.98524 .4306 -0.75 0 Mabsadd m
.98524 .4306 0 1 Mabsadd L
.98524 .4306 .75 0 Mabsadd L
.98524 .4306 0 -1 Mabsadd L
.98524 .4306 -0.75 0 Mabsadd L closepath F
.98893 .4306 -0.75 0 Mabsadd m
.98893 .4306 0 1 Mabsadd L
.98893 .4306 .75 0 Mabsadd L
.98893 .4306 0 -1 Mabsadd L
.98893 .4306 -0.75 0 Mabsadd L closepath F
.99262 .4306 -0.75 0 Mabsadd m
.99262 .4306 0 1 Mabsadd L
.99262 .4306 .75 0 Mabsadd L
.99262 .4306 0 -1 Mabsadd L
.99262 .4306 -0.75 0 Mabsadd L closepath F
.99631 .4306 -0.75 0 Mabsadd m
.99631 .4306 0 1 Mabsadd L
.99631 .4306 .75 0 Mabsadd L
.99631 .4306 0 -1 Mabsadd L
.99631 .4306 -0.75 0 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztW0uIHUUU7Xn9ut88ZzJ5CfNL1PDGGCKjIohkISoBMS7UheDC7RiEJCBK
Ej+4ceFK125duRJcKAiCiIggoiIG/ID/+EVN4l+MwqTtquq+fbvfudXVn2nD
6JDurld177mfunWrbr+X29aOH7r7nrXjhw+ujW8+unbfocMHj40P3Hs07vKn
PG9q7Hnec2NPtaO4mdyi+F+0om6qp7z9mHqEitXzTU/y56tbT3UN9ed+bjRu
+4DpAfPpcf3wU0qPoLyA+tILjfGnL2LZ+9R1f4k6RRPUUw/0pIENUkSwvZ5f
wlwfaz/ItOhL6iOfoKlmfgqQMO8h2eYtwEWPsnjUI9sB0SPugc3bYwC17jjU
zw2lNu8mNTM/+NbWct7rrhx+OV3W2mnRuG1ZgewkEFnqWnEjbdKnrsXSBdWe
rOUW8SQZS924rQtTeudrzGwiHy+ou7FkkIv/ttbCfz5YujBeJ7FeNhrmRhl3
41ApOUK0KO7/oNkcO0UnsdmJEB4txaMsF7W7G8cubIylkrhNk8eKJz4O32GC
iXht4HCCzlo7KnN0WRvszM9h1dqgXtlVdUhXi3ratpqOiyxB0Qc4IegbONI1
4e1CxmbWrwnvnBxWaO1f0aDvckc6i0rli0BnBb0CkbUJkXBKCOpx+LSeZtSo
zgGKMpqOL5MSZq2tGdXqg5YDb6ha+9Wbz1Fl27SgOdUxUChHVGtVQe1Xrep4
c4k3Iu8u1RopqIcro9CbsSjru9O4JErfpZVM8yyAuF3dh6rnCTmIZgDjLeo+
UD1Pyox3mLmIR59iRFrBC5JW5N1kIiMefVpGulXdA0X0jEw0BHpeR4zPyowH
zBTFo8/LRDcS0Qsy0TSZtY/IX5TJbyCil4oOup6GXpb5ryWiV2SiAel0FZG/
KpPvM+Tx6Gsy0TVE9LohKr51Np8m++ZB39UE9gYDGyiS7JiYEb3JJQ5ySMkC
oucikBaSO/aSO97ikPhoUDwUq+tKAnjb0PVNh5ec3FBa1ya8Y8gDizyk+irJ
O8EANH86yYkRgZRHVtOZYX0nyrUx+WQiUxXPS5LUy8jyd7kssHYq5GjdtRfY
k8gIiWiAkVGSRDFLGrC8sgvIfa+2H1012QOkvl9bqu/u8EuB4A+Kbk6TXwIh
bkSXUDR8KEcDMh9987NCYB8xMJ0WUK4ZE/nHXLY9jcyTORn7J+VuR0t4FwF8
WnTfEiC/mMg/M+SWQ54dqZ/YQKV3zPE5toE/kQ0XEsBJJhl9NVp8kUjchVAS
FJlwppaBAE4ygEDSewdg/KLeNK7LgYs2imUg+Uvmu74kZwkwfmUYh4AcRfwi
gPjaZd70wLl6IbIAhH7DoSayDorZeYDybek6qDqX6euJ5KiuA/s7w4G+S9ea
F7Zbt4y+neC/L9dUyNniboh9oYdCCx7VZaxq20Z6/lBbT+Q55JMRyTrFZdnz
cR/LTFOctcrNtibktl4d5K1kw2nDMCCnhlZGy8RlAYYWRhaoZ4pWoYPnFiL/
kTsZ5Ci+5tESmyWkn0qQyuIRrcS0QuXrPadx5QTtmiRngOTEQvu26ppztGOR
lJ8b2WdXbgjk/SJPbr33rNNAyK+lSDoQAlJcuwch/WbIm5SX680hQqDZ7+1q
xjYTXK9ObjXJH8osAVD4D8M0KqAkSBWKgYnYE+orG6Tmc1g8zUuXJHfH4382
E+dLznb1B0r3YumjNT5rWLdRCGTB4DQxTTIW2hm1Un85AvC9xK6Sxj6lekYc
u15ByO0Ty8CcExyKv3Z8WGV+xtVcKGjEn2UauRZwzYy3l2gtYJcda4oreAM9
KpZ1DmbKFUbyZ8lEbqf+Ssm+5RzN0z86ozU54Tfal6oHQWsuFhdhIemX2d/g
aFd2/N+oL+mbqpz9/uDv80/Df8vf2U9BLEGHykVLWSqS8wXdFqY7ub4HzGzt
WN2b/NZVt8H/APCm/gFvUQdH\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8002.82, -0.263095, 213.459, \
0.007392}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Saving to file", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numberOfExtensions", "=", "  ", 
    RowBox[{"Length", "[", "extensions", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", " ", 
    RowBox[{"j", "\[LessEqual]", "numberOfExtensions"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig13-50000\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "finalFigure", ",", 
       RowBox[{"ImageResolution", "\[Rule]", " ", "figureResolution"}]}], 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input"]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1432, 790},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"DemoText.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 151, 4, 109, "Title"],
Cell[722, 27, 65, 0, 37, "Subtitle"],
Cell[790, 29, 297, 6, 73, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1112, 39, 57, 0, 52, "Section"],
Cell[1172, 41, 779, 17, 310, "Subsubtitle"]
}, Closed]],
Cell[CellGroupData[{
Cell[1988, 63, 42, 0, 32, "Section"],
Cell[2033, 65, 224, 6, 60, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2294, 76, 29, 0, 32, "Section"],
Cell[2326, 78, 2426, 64, 620, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4789, 147, 53, 0, 32, "Section"],
Cell[4845, 149, 6038, 149, 700, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[10920, 303, 47, 0, 32, "Section"],
Cell[10970, 305, 1780, 53, 260, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12787, 363, 42, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[12854, 367, 14078, 342, 1400, "Input"],
Cell[26935, 711, 11130, 607, 194, 9938, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[38068, 1320, 274, 6, 25, "Print"],
Cell[38345, 1328, 177, 4, 25, "Print"],
Cell[38525, 1334, 10562, 608, 194, 9313, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[49090, 1944, 274, 6, 25, "Print"],
Cell[49367, 1952, 179, 4, 25, "Print"],
Cell[49549, 1958, 11506, 613, 194, 9940, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[61058, 2573, 274, 6, 25, "Print"],
Cell[61335, 2581, 181, 4, 25, "Print"],
Cell[61519, 2587, 11172, 607, 194, 9968, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[72694, 3196, 274, 6, 25, "Print"],
Cell[72971, 3204, 170, 4, 25, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[73190, 3214, 36, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[73251, 3218, 2441, 62, 119, "Input"],
Cell[75695, 3282, 311131, 8833, 194, 308910, 8793, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[386875, 12121, 42, 0, 32, "Section"],
Cell[386920, 12123, 787, 20, 120, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
